/* Generated by Cython 3.0.8 */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#if defined(CYTHON_LIMITED_API) && CYTHON_LIMITED_API
#define __PYX_EXTRA_ABI_MODULE_NAME "limited"
#else
#define __PYX_EXTRA_ABI_MODULE_NAME ""
#endif
#define CYTHON_ABI "3_0_8" __PYX_EXTRA_ABI_MODULE_NAME
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x030008F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1 && PYPY_VERSION_NUM >= 0x07030C00)
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_CLINE_IN_TRACEBACK
  #define CYTHON_CLINE_IN_TRACEBACK 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 1
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(Py_GIL_DISABLED) || defined(Py_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000 && PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #if PY_VERSION_HEX < 0x030400a1
    #undef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #elif !defined(CYTHON_USE_TP_FINALIZE)
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #if PY_VERSION_HEX < 0x030600B1
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5)
  #endif
  #if PY_VERSION_HEX < 0x030700A3
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    static CYTHON_INLINE PyObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030B0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030B0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
    #ifndef CO_OPTIMIZED
    #define CO_OPTIMIZED 0x0001
    #endif
    #ifndef CO_NEWLOCALS
    #define CO_NEWLOCALS 0x0002
    #endif
    #ifndef CO_VARARGS
    #define CO_VARARGS 0x0004
    #endif
    #ifndef CO_VARKEYWORDS
    #define CO_VARKEYWORDS 0x0008
    #endif
    #ifndef CO_ASYNC_GENERATOR
    #define CO_ASYNC_GENERATOR 0x0200
    #endif
    #ifndef CO_GENERATOR
    #define CO_GENERATOR 0x0020
    #endif
    #ifndef CO_COROUTINE
    #define CO_COROUTINE 0x0080
    #endif
#elif PY_VERSION_HEX >= 0x030B0000
  static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    PyObject *empty_bytes = PyBytes_FromStringAndSize("", 0);
    if (!empty_bytes) return NULL;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, empty_bytes);
    Py_DECREF(empty_bytes);
    return result;
  }
#elif PY_VERSION_HEX >= 0x030800B2 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef CO_COROUTINE
  #define CO_COROUTINE 0x80
#endif
#ifndef CO_ASYNC_GENERATOR
  #define CO_ASYNC_GENERATOR 0x200
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(((size_t)(n)) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_MAJOR_VERSION >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void *cfunc) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if __PYX_LIMITED_VERSION_HEX < 0x030900B1
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE(obj), name, func_ctype)
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if PY_MAJOR_VERSION < 3
    #if CYTHON_COMPILING_IN_PYPY
        #if PYPY_VERSION_NUM < 0x07030600
            #if defined(__cplusplus) && __cplusplus >= 201402L
                [[deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")]]
            #elif defined(__GNUC__) || defined(__clang__)
                __attribute__ ((__deprecated__("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")))
            #elif defined(_MSC_VER)
                __declspec(deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6"))
            #endif
            static CYTHON_INLINE int PyGILState_Check(void) {
                return 0;
            }
        #else  // PYPY_VERSION_NUM < 0x07030600
        #endif  // PYPY_VERSION_NUM < 0x07030600
    #else
        static CYTHON_INLINE int PyGILState_Check(void) {
            PyThreadState * tstate = _PyThreadState_Current;
            return tstate && (tstate == PyGILState_GetThisThreadState());
        }
    #endif
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000 || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && PY_VERSION_HEX < 0x030d0000 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyObject_GenericSetAttr((PyObject*)tp, k, v)
#else
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyDict_SetItem(tp->tp_dict, k, v)
#endif
#if CYTHON_USE_TYPE_SPECS && PY_VERSION_HEX >= 0x03080000
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535U : 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((int)sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = (Py_UNICODE) ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains) || (PY_MAJOR_VERSION == 2 && PYPY_VERSION_NUM < 0x07030500)
    #undef PyUnicode_Contains
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
#endif
#if PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static CYTHON_INLINE PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define __Pyx_Py3Int_Check(op)       PyLong_Check(op)
  #define __Pyx_Py3Int_CheckExact(op)  PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#else
  #define __Pyx_Py3Int_Check(op)       (PyLong_Check(op) || PyInt_Check(op))
  #define __Pyx_Py3Int_CheckExact(op)  (PyLong_CheckExact(op) || PyInt_CheckExact(op))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__yaml___yaml
#define __PYX_HAVE_API__yaml___yaml
/* Early includes */
#include "_yaml.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const wchar_t *u)
{
    const wchar_t *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#endif
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
#include <string.h>
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = (char) c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#include <string.h>
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "yaml/_yaml.pyx",
  "<stringsource>",
};
/* #### Code section: utility_code_proto_before_types ### */
/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_4yaml_5_yaml_Mark;
struct __pyx_obj_4yaml_5_yaml_CParser;
struct __pyx_obj_4yaml_5_yaml_CEmitter;

/* "yaml/_yaml.pyx":61
 * MappingNode = yaml.nodes.MappingNode
 * 
 * cdef class Mark:             # <<<<<<<<<<<<<<
 *     cdef readonly object name
 *     cdef readonly size_t index
 */
struct __pyx_obj_4yaml_5_yaml_Mark {
  PyObject_HEAD
  PyObject *name;
  size_t index;
  size_t line;
  size_t column;
  PyObject *buffer;
  PyObject *pointer;
};


/* "yaml/_yaml.pyx":244
 * #        self.style = style
 * 
 * cdef class CParser:             # <<<<<<<<<<<<<<
 * 
 *     cdef yaml_parser_t parser
 */
struct __pyx_obj_4yaml_5_yaml_CParser {
  PyObject_HEAD
  struct __pyx_vtabstruct_4yaml_5_yaml_CParser *__pyx_vtab;
  yaml_parser_t parser;
  yaml_event_t parsed_event;
  PyObject *stream;
  PyObject *stream_name;
  PyObject *current_token;
  PyObject *current_event;
  PyObject *anchors;
  PyObject *stream_cache;
  int stream_cache_len;
  int stream_cache_pos;
  int unicode_source;
};


/* "yaml/_yaml.pyx":887
 *     return 1
 * 
 * cdef class CEmitter:             # <<<<<<<<<<<<<<
 * 
 *     cdef yaml_emitter_t emitter
 */
struct __pyx_obj_4yaml_5_yaml_CEmitter {
  PyObject_HEAD
  struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *__pyx_vtab;
  yaml_emitter_t emitter;
  PyObject *stream;
  int document_start_implicit;
  int document_end_implicit;
  PyObject *use_version;
  PyObject *use_tags;
  PyObject *serialized_nodes;
  PyObject *anchors;
  int last_alias_id;
  int closed;
  int dump_unicode;
  PyObject *use_encoding;
};



/* "yaml/_yaml.pyx":244
 * #        self.style = style
 * 
 * cdef class CParser:             # <<<<<<<<<<<<<<
 * 
 *     cdef yaml_parser_t parser
 */

struct __pyx_vtabstruct_4yaml_5_yaml_CParser {
  PyObject *(*_parser_error)(struct __pyx_obj_4yaml_5_yaml_CParser *);
  PyObject *(*_scan)(struct __pyx_obj_4yaml_5_yaml_CParser *);
  PyObject *(*_token_to_object)(struct __pyx_obj_4yaml_5_yaml_CParser *, yaml_token_t *);
  PyObject *(*_parse)(struct __pyx_obj_4yaml_5_yaml_CParser *);
  PyObject *(*_event_to_object)(struct __pyx_obj_4yaml_5_yaml_CParser *, yaml_event_t *);
  PyObject *(*_compose_document)(struct __pyx_obj_4yaml_5_yaml_CParser *);
  PyObject *(*_compose_node)(struct __pyx_obj_4yaml_5_yaml_CParser *, PyObject *, PyObject *);
  PyObject *(*_compose_scalar_node)(struct __pyx_obj_4yaml_5_yaml_CParser *, PyObject *);
  PyObject *(*_compose_sequence_node)(struct __pyx_obj_4yaml_5_yaml_CParser *, PyObject *);
  PyObject *(*_compose_mapping_node)(struct __pyx_obj_4yaml_5_yaml_CParser *, PyObject *);
  int (*_parse_next_event)(struct __pyx_obj_4yaml_5_yaml_CParser *);
};
static struct __pyx_vtabstruct_4yaml_5_yaml_CParser *__pyx_vtabptr_4yaml_5_yaml_CParser;


/* "yaml/_yaml.pyx":887
 *     return 1
 * 
 * cdef class CEmitter:             # <<<<<<<<<<<<<<
 * 
 *     cdef yaml_emitter_t emitter
 */

struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter {
  PyObject *(*_emitter_error)(struct __pyx_obj_4yaml_5_yaml_CEmitter *);
  int (*_object_to_event)(struct __pyx_obj_4yaml_5_yaml_CEmitter *, PyObject *, yaml_event_t *);
  int (*_anchor_node)(struct __pyx_obj_4yaml_5_yaml_CEmitter *, PyObject *);
  int (*_serialize_node)(struct __pyx_obj_4yaml_5_yaml_CEmitter *, PyObject *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *__pyx_vtabptr_4yaml_5_yaml_CEmitter;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__))
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_VARARGS(args, i) PySequence_GetItem(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#else
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GetItem(args, i)
#endif
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_NewRef_VARARGS(arg) __Pyx_NewRef(arg)
    #define __Pyx_Arg_XDECREF_VARARGS(arg) Py_XDECREF(arg)
#else
    #define __Pyx_Arg_NewRef_VARARGS(arg) arg
    #define __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
    #define __Pyx_Arg_NewRef_FASTCALL(arg) arg  /* no-op, __Pyx_Arg_FASTCALL is direct and this needs
                                                   to have the same reference counting */
    #define __Pyx_Arg_XDECREF_FASTCALL(arg)
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
    #define __Pyx_Arg_NewRef_FASTCALL(arg) __Pyx_Arg_NewRef_VARARGS(arg)
    #define __Pyx_Arg_XDECREF_FASTCALL(arg) __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kw, const char* function_name, int kw_allowed);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if !CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03080000
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()
  #define __Pyx_PyFrame_GetLocalsplus(frame)  ((frame)->f_localsplus)
#else
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif
#endif
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* RaiseUnboundLocalError.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* HasAttr.proto */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* FixUpExtensionType.proto */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);
#endif

/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* ValidateBasesTuple.proto */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetupReduce.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce(PyObject* type_obj);
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type);
#endif

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple);
#endif

/* FetchSharedCythonModule.proto */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto */
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#else
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *typesModule=NULL, *methodType=NULL, *result=NULL;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    typesModule = PyImport_ImportModule("types");
    if (!typesModule) return NULL;
    methodType = PyObject_GetAttrString(typesModule, "MethodType");
    Py_DECREF(typesModule);
    if (!methodType) return NULL;
    result = PyObject_CallFunctionObjArgs(methodType, func, self, NULL);
    Py_DECREF(methodType);
    return result;
}
#elif PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc);
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static unsigned long __Pyx_get_runtime_version(void);
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

/* #### Code section: module_declarations ### */
static PyObject *__pyx_f_4yaml_5_yaml_7CParser__parser_error(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4yaml_5_yaml_7CParser__scan(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4yaml_5_yaml_7CParser__token_to_object(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, yaml_token_t *__pyx_v_token); /* proto*/
static PyObject *__pyx_f_4yaml_5_yaml_7CParser__parse(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4yaml_5_yaml_7CParser__event_to_object(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, yaml_event_t *__pyx_v_event); /* proto*/
static PyObject *__pyx_f_4yaml_5_yaml_7CParser__compose_document(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4yaml_5_yaml_7CParser__compose_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_parent, PyObject *__pyx_v_index); /* proto*/
static PyObject *__pyx_f_4yaml_5_yaml_7CParser__compose_scalar_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_anchor); /* proto*/
static PyObject *__pyx_f_4yaml_5_yaml_7CParser__compose_sequence_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_anchor); /* proto*/
static PyObject *__pyx_f_4yaml_5_yaml_7CParser__compose_mapping_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_anchor); /* proto*/
static int __pyx_f_4yaml_5_yaml_7CParser__parse_next_event(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_4yaml_5_yaml_8CEmitter__emitter_error(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self); /* proto*/
static int __pyx_f_4yaml_5_yaml_8CEmitter__object_to_event(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, PyObject *__pyx_v_event_object, yaml_event_t *__pyx_v_event); /* proto*/
static int __pyx_f_4yaml_5_yaml_8CEmitter__anchor_node(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, PyObject *__pyx_v_node); /* proto*/
static int __pyx_f_4yaml_5_yaml_8CEmitter__serialize_node(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_parent, PyObject *__pyx_v_index); /* proto*/

/* Module declarations from "yaml._yaml" */
static int __pyx_f_4yaml_5_yaml_input_handler(void *, unsigned char *, size_t, size_t *); /*proto*/
static int __pyx_f_4yaml_5_yaml_output_handler(void *, unsigned char *, size_t); /*proto*/
static PyObject *__pyx_f_4yaml_5_yaml___pyx_unpickle_Mark__set_state(struct __pyx_obj_4yaml_5_yaml_Mark *, PyObject *); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "yaml._yaml"
extern int __pyx_module_is_main_yaml___yaml;
int __pyx_module_is_main_yaml___yaml = 0;

/* Implementation of "yaml._yaml" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_MemoryError;
static PyObject *__pyx_builtin_AttributeError;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_ValueError;
/* #### Code section: string_decls ### */
static const char __pyx_k__2[] = "?";
static const char __pyx_k__4[] = "";
static const char __pyx_k__5[] = "'";
static const char __pyx_k__6[] = "\"";
static const char __pyx_k__7[] = "|";
static const char __pyx_k__8[] = ">";
static const char __pyx_k_gc[] = "gc";
static const char __pyx_k_TAG[] = "TAG";
static const char __pyx_k__12[] = "\r";
static const char __pyx_k__13[] = "\n";
static const char __pyx_k__14[] = "\r\n";
static const char __pyx_k__25[] = ".";
static const char __pyx_k__26[] = "*";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_tag[] = "tag";
static const char __pyx_k_Mark[] = "Mark";
static const char __pyx_k_YAML[] = "YAML";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_done[] = "done";
static const char __pyx_k_emit[] = "emit";
static const char __pyx_k_file[] = "<file>";
static const char __pyx_k_line[] = "line";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_mark[] = "mark";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_node[] = "node";
static const char __pyx_k_open[] = "open";
static const char __pyx_k_read[] = "read";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_tags[] = "tags";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_yaml[] = "yaml";
static const char __pyx_k_cache[] = "cache";
static const char __pyx_k_class[] = "__class__";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_error[] = "error";
static const char __pyx_k_event[] = "event";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_major[] = "major";
static const char __pyx_k_minor[] = "minor";
static const char __pyx_k_nodes[] = "nodes";
static const char __pyx_k_patch[] = "patch";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_style[] = "style";
static const char __pyx_k_token[] = "token";
static const char __pyx_k_utf_8[] = "utf-8";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_width[] = "width";
static const char __pyx_k_write[] = "write";
static const char __pyx_k_anchor[] = "anchor";
static const char __pyx_k_buffer[] = "buffer";
static const char __pyx_k_choice[] = "choice";
static const char __pyx_k_column[] = "column";
static const char __pyx_k_dict_2[] = "_dict";
static const char __pyx_k_enable[] = "enable";
static const char __pyx_k_events[] = "events";
static const char __pyx_k_handle[] = "handle";
static const char __pyx_k_id_03d[] = "id%03d";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_indent[] = "indent";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_parser[] = "parser";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_prefix[] = "prefix";
static const char __pyx_k_reader[] = "reader";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_stream[] = "stream";
static const char __pyx_k_tokens[] = "tokens";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_CParser[] = "CParser";
static const char __pyx_k_choices[] = "choices";
static const char __pyx_k_disable[] = "disable";
static const char __pyx_k_dispose[] = "dispose";
static const char __pyx_k_emitter[] = "emitter";
static const char __pyx_k_pointer[] = "pointer";
static const char __pyx_k_resolve[] = "resolve";
static const char __pyx_k_scanner[] = "scanner";
static const char __pyx_k_version[] = "version";
static const char __pyx_k_CEmitter[] = "CEmitter";
static const char __pyx_k_KeyToken[] = "KeyToken";
static const char __pyx_k_TagToken[] = "TagToken";
static const char __pyx_k_composer[] = "composer";
static const char __pyx_k_document[] = "document";
static const char __pyx_k_encoding[] = "encoding";
static const char __pyx_k_end_mark[] = "end_mark";
static const char __pyx_k_explicit[] = "explicit";
static const char __pyx_k_get_node[] = "get_node";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_implicit[] = "implicit";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_raw_scan[] = "raw_scan";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_YAMLError[] = "YAMLError";
static const char __pyx_k_canonical[] = "canonical";
static const char __pyx_k_get_event[] = "get_event";
static const char __pyx_k_get_token[] = "get_token";
static const char __pyx_k_isenabled[] = "isenabled";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_raw_parse[] = "raw_parse";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_serialize[] = "serialize";
static const char __pyx_k_utf_16_be[] = "utf-16-be";
static const char __pyx_k_utf_16_le[] = "utf-16-le";
static const char __pyx_k_AliasEvent[] = "AliasEvent";
static const char __pyx_k_AliasToken[] = "AliasToken";
static const char __pyx_k_ScalarNode[] = "ScalarNode";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_ValueToken[] = "ValueToken";
static const char __pyx_k_check_node[] = "check_node";
static const char __pyx_k_flow_style[] = "flow_style";
static const char __pyx_k_line_break[] = "line_break";
static const char __pyx_k_peek_event[] = "peek_event";
static const char __pyx_k_peek_token[] = "peek_token";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_serializer[] = "serializer";
static const char __pyx_k_start_mark[] = "start_mark";
static const char __pyx_k_yaml__yaml[] = "yaml._yaml";
static const char __pyx_k_AnchorToken[] = "AnchorToken";
static const char __pyx_k_MappingNode[] = "MappingNode";
static const char __pyx_k_MemoryError[] = "MemoryError";
static const char __pyx_k_ParserError[] = "ParserError";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_ReaderError[] = "ReaderError";
static const char __pyx_k_ScalarEvent[] = "ScalarEvent";
static const char __pyx_k_ScalarToken[] = "ScalarToken";
static const char __pyx_k_byte_string[] = "<byte string>";
static const char __pyx_k_check_event[] = "check_event";
static const char __pyx_k_check_token[] = "check_token";
static const char __pyx_k_constructor[] = "constructor";
static const char __pyx_k_event_class[] = "event_class";
static const char __pyx_k_get_snippet[] = "get_snippet";
static const char __pyx_k_get_version[] = "get_version";
static const char __pyx_k_representer[] = "representer";
static const char __pyx_k_token_class[] = "token_class";
static const char __pyx_k_EmitterError[] = "EmitterError";
static const char __pyx_k_ScannerError[] = "ScannerError";
static const char __pyx_k_SequenceNode[] = "SequenceNode";
static const char __pyx_k_event_object[] = "event_object";
static const char __pyx_k_explicit_end[] = "explicit_end";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_is_coroutine[] = "_is_coroutine";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_stringsource[] = "<stringsource>";
static const char __pyx_k_use_setstate[] = "use_setstate";
static const char __pyx_k_BlockEndToken[] = "BlockEndToken";
static const char __pyx_k_CEmitter_emit[] = "CEmitter.emit";
static const char __pyx_k_CEmitter_open[] = "CEmitter.open";
static const char __pyx_k_ComposerError[] = "ComposerError";
static const char __pyx_k_allow_unicode[] = "allow_unicode";
static const char __pyx_k_class_getitem[] = "__class_getitem__";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_too_many_tags[] = "too many tags";
static const char __pyx_k_AttributeError[] = "AttributeError";
static const char __pyx_k_CEmitter_close[] = "CEmitter.close";
static const char __pyx_k_DirectiveToken[] = "DirectiveToken";
static const char __pyx_k_FlowEntryToken[] = "FlowEntryToken";
static const char __pyx_k_StreamEndEvent[] = "StreamEndEvent";
static const char __pyx_k_StreamEndToken[] = "StreamEndToken";
static const char __pyx_k_explicit_start[] = "explicit_start";
static const char __pyx_k_unicode_string[] = "<unicode string>";
static const char __pyx_k_yaml__yaml_pyx[] = "yaml/_yaml.pyx";
static const char __pyx_k_BlockEntryToken[] = "BlockEntryToken";
static const char __pyx_k_CParser_dispose[] = "CParser.dispose";
static const char __pyx_k_MappingEndEvent[] = "MappingEndEvent";
static const char __pyx_k_SerializerError[] = "SerializerError";
static const char __pyx_k_ascend_resolver[] = "ascend_resolver";
static const char __pyx_k_get_single_node[] = "get_single_node";
static const char __pyx_k_invalid_event_s[] = "invalid event %s";
static const char __pyx_k_no_parser_error[] = "no parser error";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_CEmitter_dispose[] = "CEmitter.dispose";
static const char __pyx_k_CParser_get_node[] = "CParser.get_node";
static const char __pyx_k_CParser_raw_scan[] = "CParser.raw_scan";
static const char __pyx_k_ConstructorError[] = "ConstructorError";
static const char __pyx_k_DocumentEndEvent[] = "DocumentEndEvent";
static const char __pyx_k_DocumentEndToken[] = "DocumentEndToken";
static const char __pyx_k_Mark_get_snippet[] = "Mark.get_snippet";
static const char __pyx_k_RepresenterError[] = "RepresenterError";
static const char __pyx_k_SequenceEndEvent[] = "SequenceEndEvent";
static const char __pyx_k_StreamStartEvent[] = "StreamStartEvent";
static const char __pyx_k_StreamStartToken[] = "StreamStartToken";
static const char __pyx_k_descend_resolver[] = "descend_resolver";
static const char __pyx_k_no_emitter_error[] = "no emitter error";
static const char __pyx_k_CParser_get_event[] = "CParser.get_event";
static const char __pyx_k_CParser_get_token[] = "CParser.get_token";
static const char __pyx_k_CParser_raw_parse[] = "CParser.raw_parse";
static const char __pyx_k_MappingStartEvent[] = "MappingStartEvent";
static const char __pyx_k_pyx_unpickle_Mark[] = "__pyx_unpickle_Mark";
static const char __pyx_k_second_occurrence[] = "second occurrence";
static const char __pyx_k_version_directive[] = "version_directive";
static const char __pyx_k_CEmitter_serialize[] = "CEmitter.serialize";
static const char __pyx_k_CParser_check_node[] = "CParser.check_node";
static const char __pyx_k_CParser_peek_event[] = "CParser.peek_event";
static const char __pyx_k_CParser_peek_token[] = "CParser.peek_token";
static const char __pyx_k_DocumentStartEvent[] = "DocumentStartEvent";
static const char __pyx_k_DocumentStartToken[] = "DocumentStartToken";
static const char __pyx_k_SequenceStartEvent[] = "SequenceStartEvent";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_get_version_string[] = "get_version_string";
static const char __pyx_k_tag_directives_end[] = "tag_directives_end";
static const char __pyx_k_unknown_event_type[] = "unknown event type";
static const char __pyx_k_unknown_token_type[] = "unknown token type";
static const char __pyx_k_CParser_check_event[] = "CParser.check_event";
static const char __pyx_k_CParser_check_token[] = "CParser.check_token";
static const char __pyx_k_FlowMappingEndToken[] = "FlowMappingEndToken";
static const char __pyx_k_FlowSequenceEndToken[] = "FlowSequenceEndToken";
static const char __pyx_k_Mark___reduce_cython[] = "Mark.__reduce_cython__";
static const char __pyx_k_in_s_line_d_column_d[] = "  in \"%s\", line %d, column %d";
static const char __pyx_k_serializer_is_closed[] = "serializer is closed";
static const char __pyx_k_tag_directives_start[] = "tag_directives_start";
static const char __pyx_k_tag_directives_value[] = "tag_directives_value";
static const char __pyx_k_tag_must_be_a_string[] = "tag must be a string";
static const char __pyx_k_FlowMappingStartToken[] = "FlowMappingStartToken";
static const char __pyx_k_found_undefined_alias[] = "found undefined alias";
static const char __pyx_k_BlockMappingStartToken[] = "BlockMappingStartToken";
static const char __pyx_k_FlowSequenceStartToken[] = "FlowSequenceStartToken";
static const char __pyx_k_Mark___setstate_cython[] = "Mark.__setstate_cython__";
static const char __pyx_k_value_must_be_a_string[] = "value must be a string";
static const char __pyx_k_BlockSequenceStartToken[] = "BlockSequenceStartToken";
static const char __pyx_k_CParser___reduce_cython[] = "CParser.__reduce_cython__";
static const char __pyx_k_CParser_get_single_node[] = "CParser.get_single_node";
static const char __pyx_k_anchor_must_be_a_string[] = "anchor must be a string";
static const char __pyx_k_version_directive_value[] = "version_directive_value";
static const char __pyx_k_CEmitter___reduce_cython[] = "CEmitter.__reduce_cython__";
static const char __pyx_k_serializer_is_not_opened[] = "serializer is not opened";
static const char __pyx_k_CParser___setstate_cython[] = "CParser.__setstate_cython__";
static const char __pyx_k_CEmitter___setstate_cython[] = "CEmitter.__setstate_cython__";
static const char __pyx_k_a_string_value_is_expected[] = "a string value is expected";
static const char __pyx_k_but_found_another_document[] = "but found another document";
static const char __pyx_k_tag_handle_must_be_a_string[] = "tag handle must be a string";
static const char __pyx_k_tag_prefix_must_be_a_string[] = "tag prefix must be a string";
static const char __pyx_k_serializer_is_already_opened[] = "serializer is already opened";
static const char __pyx_k_Pickling_of_struct_members_such[] = "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)";
static const char __pyx_k_Incompatible_checksums_0x_x_vs_0[] = "Incompatible checksums (0x%x vs (0x27a7a5c, 0x5c0fd87, 0x3fa45b6) = (buffer, column, index, line, name, pointer))";
static const char __pyx_k_a_string_or_stream_input_is_requ[] = "a string or stream input is required";
static const char __pyx_k_expected_a_single_document_in_th[] = "expected a single document in the stream";
static const char __pyx_k_found_duplicate_anchor_first_occ[] = "found duplicate anchor; first occurrence";
static const char __pyx_k_self_parsed_event_cannot_be_conv[] = "self.parsed_event cannot be converted to a Python object for pickling";
/* #### Code section: decls ### */
static PyObject *__pyx_pf_4yaml_5_yaml_get_version_string(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_2get_version(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static int __pyx_pf_4yaml_5_yaml_4Mark___init__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self, PyObject *__pyx_v_name, size_t __pyx_v_index, size_t __pyx_v_line, size_t __pyx_v_column, PyObject *__pyx_v_buffer, PyObject *__pyx_v_pointer); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_2get_snippet(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_4__str__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_4name___get__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_5index___get__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_4line___get__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_6column___get__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_6buffer___get__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_7pointer___get__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_6__reduce_cython__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_8__setstate_cython__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_4yaml_5_yaml_7CParser___init__(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_stream); /* proto */
static void __pyx_pf_4yaml_5_yaml_7CParser_2__dealloc__(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_4dispose(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_6raw_scan(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_8get_token(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_10peek_token(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_12check_token(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_choices); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_14raw_parse(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_16get_event(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_18peek_event(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_20check_event(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_choices); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_22check_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_24get_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_26get_single_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_28__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_30__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_4yaml_5_yaml_8CEmitter___init__(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, PyObject *__pyx_v_stream, PyObject *__pyx_v_canonical, PyObject *__pyx_v_indent, PyObject *__pyx_v_width, PyObject *__pyx_v_allow_unicode, PyObject *__pyx_v_line_break, PyObject *__pyx_v_encoding, PyObject *__pyx_v_explicit_start, PyObject *__pyx_v_explicit_end, PyObject *__pyx_v_version, PyObject *__pyx_v_tags); /* proto */
static void __pyx_pf_4yaml_5_yaml_8CEmitter_2__dealloc__(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_4dispose(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_6emit(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, PyObject *__pyx_v_event_object); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_8open(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_10close(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_12serialize(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, PyObject *__pyx_v_node); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_14__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_16__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_4yaml_5_yaml_4__pyx_unpickle_Mark(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_4yaml_5_yaml_Mark(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4yaml_5_yaml_CParser(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_4yaml_5_yaml_CEmitter(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  #ifdef __Pyx_Generator_USED
  PyTypeObject *__pyx_GeneratorType;
  #endif
  #ifdef __Pyx_IterableCoroutine_USED
  PyTypeObject *__pyx_IterableCoroutineType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineAwaitType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineType;
  #endif
  #if CYTHON_USE_MODULE_STATE
  PyObject *__pyx_type_4yaml_5_yaml_Mark;
  PyObject *__pyx_type_4yaml_5_yaml_CParser;
  PyObject *__pyx_type_4yaml_5_yaml_CEmitter;
  #endif
  PyTypeObject *__pyx_ptype_4yaml_5_yaml_Mark;
  PyTypeObject *__pyx_ptype_4yaml_5_yaml_CParser;
  PyTypeObject *__pyx_ptype_4yaml_5_yaml_CEmitter;
  PyObject *__pyx_n_s_AliasEvent;
  PyObject *__pyx_n_s_AliasToken;
  PyObject *__pyx_n_s_AnchorToken;
  PyObject *__pyx_n_s_AttributeError;
  PyObject *__pyx_n_s_BlockEndToken;
  PyObject *__pyx_n_s_BlockEntryToken;
  PyObject *__pyx_n_s_BlockMappingStartToken;
  PyObject *__pyx_n_s_BlockSequenceStartToken;
  PyObject *__pyx_n_s_CEmitter;
  PyObject *__pyx_n_s_CEmitter___reduce_cython;
  PyObject *__pyx_n_s_CEmitter___setstate_cython;
  PyObject *__pyx_n_s_CEmitter_close;
  PyObject *__pyx_n_s_CEmitter_dispose;
  PyObject *__pyx_n_s_CEmitter_emit;
  PyObject *__pyx_n_s_CEmitter_open;
  PyObject *__pyx_n_s_CEmitter_serialize;
  PyObject *__pyx_n_s_CParser;
  PyObject *__pyx_n_s_CParser___reduce_cython;
  PyObject *__pyx_n_s_CParser___setstate_cython;
  PyObject *__pyx_n_s_CParser_check_event;
  PyObject *__pyx_n_s_CParser_check_node;
  PyObject *__pyx_n_s_CParser_check_token;
  PyObject *__pyx_n_s_CParser_dispose;
  PyObject *__pyx_n_s_CParser_get_event;
  PyObject *__pyx_n_s_CParser_get_node;
  PyObject *__pyx_n_s_CParser_get_single_node;
  PyObject *__pyx_n_s_CParser_get_token;
  PyObject *__pyx_n_s_CParser_peek_event;
  PyObject *__pyx_n_s_CParser_peek_token;
  PyObject *__pyx_n_s_CParser_raw_parse;
  PyObject *__pyx_n_s_CParser_raw_scan;
  PyObject *__pyx_n_s_ComposerError;
  PyObject *__pyx_n_s_ConstructorError;
  PyObject *__pyx_n_s_DirectiveToken;
  PyObject *__pyx_n_s_DocumentEndEvent;
  PyObject *__pyx_n_s_DocumentEndToken;
  PyObject *__pyx_n_s_DocumentStartEvent;
  PyObject *__pyx_n_s_DocumentStartToken;
  PyObject *__pyx_n_s_EmitterError;
  PyObject *__pyx_n_s_FlowEntryToken;
  PyObject *__pyx_n_s_FlowMappingEndToken;
  PyObject *__pyx_n_s_FlowMappingStartToken;
  PyObject *__pyx_n_s_FlowSequenceEndToken;
  PyObject *__pyx_n_s_FlowSequenceStartToken;
  PyObject *__pyx_kp_s_Incompatible_checksums_0x_x_vs_0;
  PyObject *__pyx_n_s_KeyToken;
  PyObject *__pyx_n_s_MappingEndEvent;
  PyObject *__pyx_n_s_MappingNode;
  PyObject *__pyx_n_s_MappingStartEvent;
  PyObject *__pyx_n_s_Mark;
  PyObject *__pyx_n_s_Mark___reduce_cython;
  PyObject *__pyx_n_s_Mark___setstate_cython;
  PyObject *__pyx_n_s_Mark_get_snippet;
  PyObject *__pyx_n_s_MemoryError;
  PyObject *__pyx_n_s_ParserError;
  PyObject *__pyx_n_s_PickleError;
  PyObject *__pyx_kp_s_Pickling_of_struct_members_such;
  PyObject *__pyx_n_s_ReaderError;
  PyObject *__pyx_n_s_RepresenterError;
  PyObject *__pyx_n_s_ScalarEvent;
  PyObject *__pyx_n_s_ScalarNode;
  PyObject *__pyx_n_s_ScalarToken;
  PyObject *__pyx_n_s_ScannerError;
  PyObject *__pyx_n_s_SequenceEndEvent;
  PyObject *__pyx_n_s_SequenceNode;
  PyObject *__pyx_n_s_SequenceStartEvent;
  PyObject *__pyx_n_s_SerializerError;
  PyObject *__pyx_n_s_StreamEndEvent;
  PyObject *__pyx_n_s_StreamEndToken;
  PyObject *__pyx_n_s_StreamStartEvent;
  PyObject *__pyx_n_s_StreamStartToken;
  PyObject *__pyx_n_u_TAG;
  PyObject *__pyx_n_s_TagToken;
  PyObject *__pyx_n_s_TypeError;
  PyObject *__pyx_n_s_ValueError;
  PyObject *__pyx_n_s_ValueToken;
  PyObject *__pyx_n_u_YAML;
  PyObject *__pyx_n_s_YAMLError;
  PyObject *__pyx_kp_s__12;
  PyObject *__pyx_kp_s__13;
  PyObject *__pyx_kp_s__14;
  PyObject *__pyx_n_s__2;
  PyObject *__pyx_kp_u__2;
  PyObject *__pyx_kp_u__25;
  PyObject *__pyx_n_s__26;
  PyObject *__pyx_kp_u__4;
  PyObject *__pyx_kp_s__5;
  PyObject *__pyx_kp_u__5;
  PyObject *__pyx_kp_s__6;
  PyObject *__pyx_kp_u__6;
  PyObject *__pyx_kp_s__7;
  PyObject *__pyx_kp_u__7;
  PyObject *__pyx_kp_s__8;
  PyObject *__pyx_kp_u__8;
  PyObject *__pyx_kp_u_a_string_or_stream_input_is_requ;
  PyObject *__pyx_kp_u_a_string_value_is_expected;
  PyObject *__pyx_n_s_allow_unicode;
  PyObject *__pyx_n_s_anchor;
  PyObject *__pyx_kp_u_anchor_must_be_a_string;
  PyObject *__pyx_n_s_ascend_resolver;
  PyObject *__pyx_n_s_asyncio_coroutines;
  PyObject *__pyx_n_s_buffer;
  PyObject *__pyx_kp_u_but_found_another_document;
  PyObject *__pyx_kp_u_byte_string;
  PyObject *__pyx_n_s_cache;
  PyObject *__pyx_n_s_canonical;
  PyObject *__pyx_n_s_check_event;
  PyObject *__pyx_n_s_check_node;
  PyObject *__pyx_n_s_check_token;
  PyObject *__pyx_n_s_choice;
  PyObject *__pyx_n_s_choices;
  PyObject *__pyx_n_s_class;
  PyObject *__pyx_n_s_class_getitem;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_close;
  PyObject *__pyx_n_s_column;
  PyObject *__pyx_n_s_composer;
  PyObject *__pyx_n_s_constructor;
  PyObject *__pyx_n_s_count;
  PyObject *__pyx_n_s_descend_resolver;
  PyObject *__pyx_n_s_dict;
  PyObject *__pyx_n_s_dict_2;
  PyObject *__pyx_kp_u_disable;
  PyObject *__pyx_n_s_dispose;
  PyObject *__pyx_n_s_document;
  PyObject *__pyx_n_s_done;
  PyObject *__pyx_n_s_emit;
  PyObject *__pyx_n_s_emitter;
  PyObject *__pyx_kp_u_enable;
  PyObject *__pyx_n_s_encoding;
  PyObject *__pyx_n_u_encoding;
  PyObject *__pyx_n_s_end_mark;
  PyObject *__pyx_n_s_error;
  PyObject *__pyx_n_s_event;
  PyObject *__pyx_n_s_event_class;
  PyObject *__pyx_n_s_event_object;
  PyObject *__pyx_n_s_events;
  PyObject *__pyx_kp_u_expected_a_single_document_in_th;
  PyObject *__pyx_n_s_explicit;
  PyObject *__pyx_n_s_explicit_end;
  PyObject *__pyx_n_s_explicit_start;
  PyObject *__pyx_kp_u_file;
  PyObject *__pyx_n_s_flow_style;
  PyObject *__pyx_kp_u_found_duplicate_anchor_first_occ;
  PyObject *__pyx_kp_u_found_undefined_alias;
  PyObject *__pyx_kp_u_gc;
  PyObject *__pyx_n_s_get_event;
  PyObject *__pyx_n_s_get_node;
  PyObject *__pyx_n_s_get_single_node;
  PyObject *__pyx_n_s_get_snippet;
  PyObject *__pyx_n_s_get_token;
  PyObject *__pyx_n_s_get_version;
  PyObject *__pyx_n_s_get_version_string;
  PyObject *__pyx_n_s_getstate;
  PyObject *__pyx_n_s_handle;
  PyObject *__pyx_kp_u_id_03d;
  PyObject *__pyx_n_s_implicit;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_kp_s_in_s_line_d_column_d;
  PyObject *__pyx_n_s_indent;
  PyObject *__pyx_n_s_index;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_kp_u_invalid_event_s;
  PyObject *__pyx_n_s_is_coroutine;
  PyObject *__pyx_kp_u_isenabled;
  PyObject *__pyx_n_s_line;
  PyObject *__pyx_n_s_line_break;
  PyObject *__pyx_n_s_main;
  PyObject *__pyx_n_s_major;
  PyObject *__pyx_n_s_mark;
  PyObject *__pyx_n_s_minor;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_s_name_2;
  PyObject *__pyx_n_s_new;
  PyObject *__pyx_kp_u_no_emitter_error;
  PyObject *__pyx_kp_u_no_parser_error;
  PyObject *__pyx_n_s_node;
  PyObject *__pyx_n_s_nodes;
  PyObject *__pyx_n_s_open;
  PyObject *__pyx_n_s_parser;
  PyObject *__pyx_n_s_patch;
  PyObject *__pyx_n_s_peek_event;
  PyObject *__pyx_n_s_peek_token;
  PyObject *__pyx_n_s_pickle;
  PyObject *__pyx_n_s_pointer;
  PyObject *__pyx_n_s_prefix;
  PyObject *__pyx_n_s_pyx_PickleError;
  PyObject *__pyx_n_s_pyx_checksum;
  PyObject *__pyx_n_s_pyx_result;
  PyObject *__pyx_n_s_pyx_state;
  PyObject *__pyx_n_s_pyx_type;
  PyObject *__pyx_n_s_pyx_unpickle_Mark;
  PyObject *__pyx_n_s_pyx_vtable;
  PyObject *__pyx_n_s_raw_parse;
  PyObject *__pyx_n_s_raw_scan;
  PyObject *__pyx_n_s_read;
  PyObject *__pyx_n_s_reader;
  PyObject *__pyx_n_s_reduce;
  PyObject *__pyx_n_s_reduce_cython;
  PyObject *__pyx_n_s_reduce_ex;
  PyObject *__pyx_n_s_representer;
  PyObject *__pyx_n_s_resolve;
  PyObject *__pyx_n_s_scanner;
  PyObject *__pyx_kp_u_second_occurrence;
  PyObject *__pyx_n_s_self;
  PyObject *__pyx_kp_s_self_parsed_event_cannot_be_conv;
  PyObject *__pyx_n_s_serialize;
  PyObject *__pyx_n_s_serializer;
  PyObject *__pyx_kp_u_serializer_is_already_opened;
  PyObject *__pyx_kp_u_serializer_is_closed;
  PyObject *__pyx_kp_u_serializer_is_not_opened;
  PyObject *__pyx_n_s_setstate;
  PyObject *__pyx_n_s_setstate_cython;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_n_s_start_mark;
  PyObject *__pyx_n_s_state;
  PyObject *__pyx_n_s_stream;
  PyObject *__pyx_kp_s_stringsource;
  PyObject *__pyx_n_s_style;
  PyObject *__pyx_n_s_tag;
  PyObject *__pyx_n_s_tag_directives_end;
  PyObject *__pyx_n_s_tag_directives_start;
  PyObject *__pyx_n_s_tag_directives_value;
  PyObject *__pyx_kp_u_tag_handle_must_be_a_string;
  PyObject *__pyx_kp_u_tag_must_be_a_string;
  PyObject *__pyx_kp_u_tag_prefix_must_be_a_string;
  PyObject *__pyx_n_s_tags;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_n_s_token;
  PyObject *__pyx_n_s_token_class;
  PyObject *__pyx_n_s_tokens;
  PyObject *__pyx_kp_u_too_many_tags;
  PyObject *__pyx_kp_u_unicode_string;
  PyObject *__pyx_kp_u_unknown_event_type;
  PyObject *__pyx_kp_u_unknown_token_type;
  PyObject *__pyx_n_s_update;
  PyObject *__pyx_n_s_use_setstate;
  PyObject *__pyx_kp_s_utf_16_be;
  PyObject *__pyx_kp_u_utf_16_be;
  PyObject *__pyx_kp_s_utf_16_le;
  PyObject *__pyx_kp_u_utf_16_le;
  PyObject *__pyx_kp_u_utf_8;
  PyObject *__pyx_n_s_value;
  PyObject *__pyx_kp_u_value_must_be_a_string;
  PyObject *__pyx_n_s_version;
  PyObject *__pyx_n_s_version_directive;
  PyObject *__pyx_n_s_version_directive_value;
  PyObject *__pyx_n_s_width;
  PyObject *__pyx_n_s_write;
  PyObject *__pyx_n_s_yaml;
  PyObject *__pyx_n_s_yaml__yaml;
  PyObject *__pyx_kp_s_yaml__yaml_pyx;
  PyObject *__pyx_int_0;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_41581148;
  PyObject *__pyx_int_66733494;
  PyObject *__pyx_int_96533895;
  PyObject *__pyx_tuple_;
  PyObject *__pyx_tuple__3;
  PyObject *__pyx_tuple__9;
  PyObject *__pyx_tuple__10;
  PyObject *__pyx_tuple__11;
  PyObject *__pyx_tuple__15;
  PyObject *__pyx_tuple__16;
  PyObject *__pyx_tuple__17;
  PyObject *__pyx_tuple__18;
  PyObject *__pyx_tuple__19;
  PyObject *__pyx_tuple__20;
  PyObject *__pyx_tuple__21;
  PyObject *__pyx_tuple__22;
  PyObject *__pyx_tuple__23;
  PyObject *__pyx_tuple__24;
  PyObject *__pyx_tuple__27;
  PyObject *__pyx_tuple__29;
  PyObject *__pyx_tuple__31;
  PyObject *__pyx_tuple__33;
  PyObject *__pyx_tuple__35;
  PyObject *__pyx_tuple__38;
  PyObject *__pyx_tuple__40;
  PyObject *__pyx_tuple__43;
  PyObject *__pyx_tuple__45;
  PyObject *__pyx_tuple__49;
  PyObject *__pyx_tuple__53;
  PyObject *__pyx_tuple__58;
  PyObject *__pyx_tuple__60;
  PyObject *__pyx_tuple__62;
  PyObject *__pyx_tuple__64;
  PyObject *__pyx_tuple__68;
  PyObject *__pyx_codeobj__28;
  PyObject *__pyx_codeobj__30;
  PyObject *__pyx_codeobj__32;
  PyObject *__pyx_codeobj__34;
  PyObject *__pyx_codeobj__36;
  PyObject *__pyx_codeobj__37;
  PyObject *__pyx_codeobj__39;
  PyObject *__pyx_codeobj__41;
  PyObject *__pyx_codeobj__42;
  PyObject *__pyx_codeobj__44;
  PyObject *__pyx_codeobj__46;
  PyObject *__pyx_codeobj__47;
  PyObject *__pyx_codeobj__48;
  PyObject *__pyx_codeobj__50;
  PyObject *__pyx_codeobj__51;
  PyObject *__pyx_codeobj__52;
  PyObject *__pyx_codeobj__54;
  PyObject *__pyx_codeobj__55;
  PyObject *__pyx_codeobj__56;
  PyObject *__pyx_codeobj__57;
  PyObject *__pyx_codeobj__59;
  PyObject *__pyx_codeobj__61;
  PyObject *__pyx_codeobj__63;
  PyObject *__pyx_codeobj__65;
  PyObject *__pyx_codeobj__66;
  PyObject *__pyx_codeobj__67;
  PyObject *__pyx_codeobj__69;
} __pyx_mstate;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#else
static __pyx_mstate __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstate *__pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_4yaml_5_yaml_Mark);
  Py_CLEAR(clear_module_state->__pyx_type_4yaml_5_yaml_Mark);
  Py_CLEAR(clear_module_state->__pyx_ptype_4yaml_5_yaml_CParser);
  Py_CLEAR(clear_module_state->__pyx_type_4yaml_5_yaml_CParser);
  Py_CLEAR(clear_module_state->__pyx_ptype_4yaml_5_yaml_CEmitter);
  Py_CLEAR(clear_module_state->__pyx_type_4yaml_5_yaml_CEmitter);
  Py_CLEAR(clear_module_state->__pyx_n_s_AliasEvent);
  Py_CLEAR(clear_module_state->__pyx_n_s_AliasToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_AnchorToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_AttributeError);
  Py_CLEAR(clear_module_state->__pyx_n_s_BlockEndToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_BlockEntryToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_BlockMappingStartToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_BlockSequenceStartToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_CEmitter);
  Py_CLEAR(clear_module_state->__pyx_n_s_CEmitter___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_CEmitter___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_CEmitter_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_CEmitter_dispose);
  Py_CLEAR(clear_module_state->__pyx_n_s_CEmitter_emit);
  Py_CLEAR(clear_module_state->__pyx_n_s_CEmitter_open);
  Py_CLEAR(clear_module_state->__pyx_n_s_CEmitter_serialize);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser_check_event);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser_check_node);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser_check_token);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser_dispose);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser_get_event);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser_get_node);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser_get_single_node);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser_get_token);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser_peek_event);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser_peek_token);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser_raw_parse);
  Py_CLEAR(clear_module_state->__pyx_n_s_CParser_raw_scan);
  Py_CLEAR(clear_module_state->__pyx_n_s_ComposerError);
  Py_CLEAR(clear_module_state->__pyx_n_s_ConstructorError);
  Py_CLEAR(clear_module_state->__pyx_n_s_DirectiveToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_DocumentEndEvent);
  Py_CLEAR(clear_module_state->__pyx_n_s_DocumentEndToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_DocumentStartEvent);
  Py_CLEAR(clear_module_state->__pyx_n_s_DocumentStartToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_EmitterError);
  Py_CLEAR(clear_module_state->__pyx_n_s_FlowEntryToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_FlowMappingEndToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_FlowMappingStartToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_FlowSequenceEndToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_FlowSequenceStartToken);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_CLEAR(clear_module_state->__pyx_n_s_KeyToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_MappingEndEvent);
  Py_CLEAR(clear_module_state->__pyx_n_s_MappingNode);
  Py_CLEAR(clear_module_state->__pyx_n_s_MappingStartEvent);
  Py_CLEAR(clear_module_state->__pyx_n_s_Mark);
  Py_CLEAR(clear_module_state->__pyx_n_s_Mark___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Mark___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Mark_get_snippet);
  Py_CLEAR(clear_module_state->__pyx_n_s_MemoryError);
  Py_CLEAR(clear_module_state->__pyx_n_s_ParserError);
  Py_CLEAR(clear_module_state->__pyx_n_s_PickleError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Pickling_of_struct_members_such);
  Py_CLEAR(clear_module_state->__pyx_n_s_ReaderError);
  Py_CLEAR(clear_module_state->__pyx_n_s_RepresenterError);
  Py_CLEAR(clear_module_state->__pyx_n_s_ScalarEvent);
  Py_CLEAR(clear_module_state->__pyx_n_s_ScalarNode);
  Py_CLEAR(clear_module_state->__pyx_n_s_ScalarToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_ScannerError);
  Py_CLEAR(clear_module_state->__pyx_n_s_SequenceEndEvent);
  Py_CLEAR(clear_module_state->__pyx_n_s_SequenceNode);
  Py_CLEAR(clear_module_state->__pyx_n_s_SequenceStartEvent);
  Py_CLEAR(clear_module_state->__pyx_n_s_SerializerError);
  Py_CLEAR(clear_module_state->__pyx_n_s_StreamEndEvent);
  Py_CLEAR(clear_module_state->__pyx_n_s_StreamEndToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_StreamStartEvent);
  Py_CLEAR(clear_module_state->__pyx_n_s_StreamStartToken);
  Py_CLEAR(clear_module_state->__pyx_n_u_TAG);
  Py_CLEAR(clear_module_state->__pyx_n_s_TagToken);
  Py_CLEAR(clear_module_state->__pyx_n_s_TypeError);
  Py_CLEAR(clear_module_state->__pyx_n_s_ValueError);
  Py_CLEAR(clear_module_state->__pyx_n_s_ValueToken);
  Py_CLEAR(clear_module_state->__pyx_n_u_YAML);
  Py_CLEAR(clear_module_state->__pyx_n_s_YAMLError);
  Py_CLEAR(clear_module_state->__pyx_kp_s__12);
  Py_CLEAR(clear_module_state->__pyx_kp_s__13);
  Py_CLEAR(clear_module_state->__pyx_kp_s__14);
  Py_CLEAR(clear_module_state->__pyx_n_s__2);
  Py_CLEAR(clear_module_state->__pyx_kp_u__2);
  Py_CLEAR(clear_module_state->__pyx_kp_u__25);
  Py_CLEAR(clear_module_state->__pyx_n_s__26);
  Py_CLEAR(clear_module_state->__pyx_kp_u__4);
  Py_CLEAR(clear_module_state->__pyx_kp_s__5);
  Py_CLEAR(clear_module_state->__pyx_kp_u__5);
  Py_CLEAR(clear_module_state->__pyx_kp_s__6);
  Py_CLEAR(clear_module_state->__pyx_kp_u__6);
  Py_CLEAR(clear_module_state->__pyx_kp_s__7);
  Py_CLEAR(clear_module_state->__pyx_kp_u__7);
  Py_CLEAR(clear_module_state->__pyx_kp_s__8);
  Py_CLEAR(clear_module_state->__pyx_kp_u__8);
  Py_CLEAR(clear_module_state->__pyx_kp_u_a_string_or_stream_input_is_requ);
  Py_CLEAR(clear_module_state->__pyx_kp_u_a_string_value_is_expected);
  Py_CLEAR(clear_module_state->__pyx_n_s_allow_unicode);
  Py_CLEAR(clear_module_state->__pyx_n_s_anchor);
  Py_CLEAR(clear_module_state->__pyx_kp_u_anchor_must_be_a_string);
  Py_CLEAR(clear_module_state->__pyx_n_s_ascend_resolver);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_coroutines);
  Py_CLEAR(clear_module_state->__pyx_n_s_buffer);
  Py_CLEAR(clear_module_state->__pyx_kp_u_but_found_another_document);
  Py_CLEAR(clear_module_state->__pyx_kp_u_byte_string);
  Py_CLEAR(clear_module_state->__pyx_n_s_cache);
  Py_CLEAR(clear_module_state->__pyx_n_s_canonical);
  Py_CLEAR(clear_module_state->__pyx_n_s_check_event);
  Py_CLEAR(clear_module_state->__pyx_n_s_check_node);
  Py_CLEAR(clear_module_state->__pyx_n_s_check_token);
  Py_CLEAR(clear_module_state->__pyx_n_s_choice);
  Py_CLEAR(clear_module_state->__pyx_n_s_choices);
  Py_CLEAR(clear_module_state->__pyx_n_s_class);
  Py_CLEAR(clear_module_state->__pyx_n_s_class_getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_close);
  Py_CLEAR(clear_module_state->__pyx_n_s_column);
  Py_CLEAR(clear_module_state->__pyx_n_s_composer);
  Py_CLEAR(clear_module_state->__pyx_n_s_constructor);
  Py_CLEAR(clear_module_state->__pyx_n_s_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_descend_resolver);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_disable);
  Py_CLEAR(clear_module_state->__pyx_n_s_dispose);
  Py_CLEAR(clear_module_state->__pyx_n_s_document);
  Py_CLEAR(clear_module_state->__pyx_n_s_done);
  Py_CLEAR(clear_module_state->__pyx_n_s_emit);
  Py_CLEAR(clear_module_state->__pyx_n_s_emitter);
  Py_CLEAR(clear_module_state->__pyx_kp_u_enable);
  Py_CLEAR(clear_module_state->__pyx_n_s_encoding);
  Py_CLEAR(clear_module_state->__pyx_n_u_encoding);
  Py_CLEAR(clear_module_state->__pyx_n_s_end_mark);
  Py_CLEAR(clear_module_state->__pyx_n_s_error);
  Py_CLEAR(clear_module_state->__pyx_n_s_event);
  Py_CLEAR(clear_module_state->__pyx_n_s_event_class);
  Py_CLEAR(clear_module_state->__pyx_n_s_event_object);
  Py_CLEAR(clear_module_state->__pyx_n_s_events);
  Py_CLEAR(clear_module_state->__pyx_kp_u_expected_a_single_document_in_th);
  Py_CLEAR(clear_module_state->__pyx_n_s_explicit);
  Py_CLEAR(clear_module_state->__pyx_n_s_explicit_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_explicit_start);
  Py_CLEAR(clear_module_state->__pyx_kp_u_file);
  Py_CLEAR(clear_module_state->__pyx_n_s_flow_style);
  Py_CLEAR(clear_module_state->__pyx_kp_u_found_duplicate_anchor_first_occ);
  Py_CLEAR(clear_module_state->__pyx_kp_u_found_undefined_alias);
  Py_CLEAR(clear_module_state->__pyx_kp_u_gc);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_event);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_node);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_single_node);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_snippet);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_token);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_version);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_version_string);
  Py_CLEAR(clear_module_state->__pyx_n_s_getstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_handle);
  Py_CLEAR(clear_module_state->__pyx_kp_u_id_03d);
  Py_CLEAR(clear_module_state->__pyx_n_s_implicit);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_kp_s_in_s_line_d_column_d);
  Py_CLEAR(clear_module_state->__pyx_n_s_indent);
  Py_CLEAR(clear_module_state->__pyx_n_s_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_kp_u_invalid_event_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coroutine);
  Py_CLEAR(clear_module_state->__pyx_kp_u_isenabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_break);
  Py_CLEAR(clear_module_state->__pyx_n_s_main);
  Py_CLEAR(clear_module_state->__pyx_n_s_major);
  Py_CLEAR(clear_module_state->__pyx_n_s_mark);
  Py_CLEAR(clear_module_state->__pyx_n_s_minor);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_name_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_new);
  Py_CLEAR(clear_module_state->__pyx_kp_u_no_emitter_error);
  Py_CLEAR(clear_module_state->__pyx_kp_u_no_parser_error);
  Py_CLEAR(clear_module_state->__pyx_n_s_node);
  Py_CLEAR(clear_module_state->__pyx_n_s_nodes);
  Py_CLEAR(clear_module_state->__pyx_n_s_open);
  Py_CLEAR(clear_module_state->__pyx_n_s_parser);
  Py_CLEAR(clear_module_state->__pyx_n_s_patch);
  Py_CLEAR(clear_module_state->__pyx_n_s_peek_event);
  Py_CLEAR(clear_module_state->__pyx_n_s_peek_token);
  Py_CLEAR(clear_module_state->__pyx_n_s_pickle);
  Py_CLEAR(clear_module_state->__pyx_n_s_pointer);
  Py_CLEAR(clear_module_state->__pyx_n_s_prefix);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_checksum);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_unpickle_Mark);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_vtable);
  Py_CLEAR(clear_module_state->__pyx_n_s_raw_parse);
  Py_CLEAR(clear_module_state->__pyx_n_s_raw_scan);
  Py_CLEAR(clear_module_state->__pyx_n_s_read);
  Py_CLEAR(clear_module_state->__pyx_n_s_reader);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_ex);
  Py_CLEAR(clear_module_state->__pyx_n_s_representer);
  Py_CLEAR(clear_module_state->__pyx_n_s_resolve);
  Py_CLEAR(clear_module_state->__pyx_n_s_scanner);
  Py_CLEAR(clear_module_state->__pyx_kp_u_second_occurrence);
  Py_CLEAR(clear_module_state->__pyx_n_s_self);
  Py_CLEAR(clear_module_state->__pyx_kp_s_self_parsed_event_cannot_be_conv);
  Py_CLEAR(clear_module_state->__pyx_n_s_serialize);
  Py_CLEAR(clear_module_state->__pyx_n_s_serializer);
  Py_CLEAR(clear_module_state->__pyx_kp_u_serializer_is_already_opened);
  Py_CLEAR(clear_module_state->__pyx_kp_u_serializer_is_closed);
  Py_CLEAR(clear_module_state->__pyx_kp_u_serializer_is_not_opened);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_n_s_start_mark);
  Py_CLEAR(clear_module_state->__pyx_n_s_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_stream);
  Py_CLEAR(clear_module_state->__pyx_kp_s_stringsource);
  Py_CLEAR(clear_module_state->__pyx_n_s_style);
  Py_CLEAR(clear_module_state->__pyx_n_s_tag);
  Py_CLEAR(clear_module_state->__pyx_n_s_tag_directives_end);
  Py_CLEAR(clear_module_state->__pyx_n_s_tag_directives_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_tag_directives_value);
  Py_CLEAR(clear_module_state->__pyx_kp_u_tag_handle_must_be_a_string);
  Py_CLEAR(clear_module_state->__pyx_kp_u_tag_must_be_a_string);
  Py_CLEAR(clear_module_state->__pyx_kp_u_tag_prefix_must_be_a_string);
  Py_CLEAR(clear_module_state->__pyx_n_s_tags);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_n_s_token);
  Py_CLEAR(clear_module_state->__pyx_n_s_token_class);
  Py_CLEAR(clear_module_state->__pyx_n_s_tokens);
  Py_CLEAR(clear_module_state->__pyx_kp_u_too_many_tags);
  Py_CLEAR(clear_module_state->__pyx_kp_u_unicode_string);
  Py_CLEAR(clear_module_state->__pyx_kp_u_unknown_event_type);
  Py_CLEAR(clear_module_state->__pyx_kp_u_unknown_token_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_update);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_setstate);
  Py_CLEAR(clear_module_state->__pyx_kp_s_utf_16_be);
  Py_CLEAR(clear_module_state->__pyx_kp_u_utf_16_be);
  Py_CLEAR(clear_module_state->__pyx_kp_s_utf_16_le);
  Py_CLEAR(clear_module_state->__pyx_kp_u_utf_16_le);
  Py_CLEAR(clear_module_state->__pyx_kp_u_utf_8);
  Py_CLEAR(clear_module_state->__pyx_n_s_value);
  Py_CLEAR(clear_module_state->__pyx_kp_u_value_must_be_a_string);
  Py_CLEAR(clear_module_state->__pyx_n_s_version);
  Py_CLEAR(clear_module_state->__pyx_n_s_version_directive);
  Py_CLEAR(clear_module_state->__pyx_n_s_version_directive_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_width);
  Py_CLEAR(clear_module_state->__pyx_n_s_write);
  Py_CLEAR(clear_module_state->__pyx_n_s_yaml);
  Py_CLEAR(clear_module_state->__pyx_n_s_yaml__yaml);
  Py_CLEAR(clear_module_state->__pyx_kp_s_yaml__yaml_pyx);
  Py_CLEAR(clear_module_state->__pyx_int_0);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_41581148);
  Py_CLEAR(clear_module_state->__pyx_int_66733494);
  Py_CLEAR(clear_module_state->__pyx_int_96533895);
  Py_CLEAR(clear_module_state->__pyx_tuple_);
  Py_CLEAR(clear_module_state->__pyx_tuple__3);
  Py_CLEAR(clear_module_state->__pyx_tuple__9);
  Py_CLEAR(clear_module_state->__pyx_tuple__10);
  Py_CLEAR(clear_module_state->__pyx_tuple__11);
  Py_CLEAR(clear_module_state->__pyx_tuple__15);
  Py_CLEAR(clear_module_state->__pyx_tuple__16);
  Py_CLEAR(clear_module_state->__pyx_tuple__17);
  Py_CLEAR(clear_module_state->__pyx_tuple__18);
  Py_CLEAR(clear_module_state->__pyx_tuple__19);
  Py_CLEAR(clear_module_state->__pyx_tuple__20);
  Py_CLEAR(clear_module_state->__pyx_tuple__21);
  Py_CLEAR(clear_module_state->__pyx_tuple__22);
  Py_CLEAR(clear_module_state->__pyx_tuple__23);
  Py_CLEAR(clear_module_state->__pyx_tuple__24);
  Py_CLEAR(clear_module_state->__pyx_tuple__27);
  Py_CLEAR(clear_module_state->__pyx_tuple__29);
  Py_CLEAR(clear_module_state->__pyx_tuple__31);
  Py_CLEAR(clear_module_state->__pyx_tuple__33);
  Py_CLEAR(clear_module_state->__pyx_tuple__35);
  Py_CLEAR(clear_module_state->__pyx_tuple__38);
  Py_CLEAR(clear_module_state->__pyx_tuple__40);
  Py_CLEAR(clear_module_state->__pyx_tuple__43);
  Py_CLEAR(clear_module_state->__pyx_tuple__45);
  Py_CLEAR(clear_module_state->__pyx_tuple__49);
  Py_CLEAR(clear_module_state->__pyx_tuple__53);
  Py_CLEAR(clear_module_state->__pyx_tuple__58);
  Py_CLEAR(clear_module_state->__pyx_tuple__60);
  Py_CLEAR(clear_module_state->__pyx_tuple__62);
  Py_CLEAR(clear_module_state->__pyx_tuple__64);
  Py_CLEAR(clear_module_state->__pyx_tuple__68);
  Py_CLEAR(clear_module_state->__pyx_codeobj__28);
  Py_CLEAR(clear_module_state->__pyx_codeobj__30);
  Py_CLEAR(clear_module_state->__pyx_codeobj__32);
  Py_CLEAR(clear_module_state->__pyx_codeobj__34);
  Py_CLEAR(clear_module_state->__pyx_codeobj__36);
  Py_CLEAR(clear_module_state->__pyx_codeobj__37);
  Py_CLEAR(clear_module_state->__pyx_codeobj__39);
  Py_CLEAR(clear_module_state->__pyx_codeobj__41);
  Py_CLEAR(clear_module_state->__pyx_codeobj__42);
  Py_CLEAR(clear_module_state->__pyx_codeobj__44);
  Py_CLEAR(clear_module_state->__pyx_codeobj__46);
  Py_CLEAR(clear_module_state->__pyx_codeobj__47);
  Py_CLEAR(clear_module_state->__pyx_codeobj__48);
  Py_CLEAR(clear_module_state->__pyx_codeobj__50);
  Py_CLEAR(clear_module_state->__pyx_codeobj__51);
  Py_CLEAR(clear_module_state->__pyx_codeobj__52);
  Py_CLEAR(clear_module_state->__pyx_codeobj__54);
  Py_CLEAR(clear_module_state->__pyx_codeobj__55);
  Py_CLEAR(clear_module_state->__pyx_codeobj__56);
  Py_CLEAR(clear_module_state->__pyx_codeobj__57);
  Py_CLEAR(clear_module_state->__pyx_codeobj__59);
  Py_CLEAR(clear_module_state->__pyx_codeobj__61);
  Py_CLEAR(clear_module_state->__pyx_codeobj__63);
  Py_CLEAR(clear_module_state->__pyx_codeobj__65);
  Py_CLEAR(clear_module_state->__pyx_codeobj__66);
  Py_CLEAR(clear_module_state->__pyx_codeobj__67);
  Py_CLEAR(clear_module_state->__pyx_codeobj__69);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_ptype_4yaml_5_yaml_Mark);
  Py_VISIT(traverse_module_state->__pyx_type_4yaml_5_yaml_Mark);
  Py_VISIT(traverse_module_state->__pyx_ptype_4yaml_5_yaml_CParser);
  Py_VISIT(traverse_module_state->__pyx_type_4yaml_5_yaml_CParser);
  Py_VISIT(traverse_module_state->__pyx_ptype_4yaml_5_yaml_CEmitter);
  Py_VISIT(traverse_module_state->__pyx_type_4yaml_5_yaml_CEmitter);
  Py_VISIT(traverse_module_state->__pyx_n_s_AliasEvent);
  Py_VISIT(traverse_module_state->__pyx_n_s_AliasToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_AnchorToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_AttributeError);
  Py_VISIT(traverse_module_state->__pyx_n_s_BlockEndToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_BlockEntryToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_BlockMappingStartToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_BlockSequenceStartToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_CEmitter);
  Py_VISIT(traverse_module_state->__pyx_n_s_CEmitter___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_CEmitter___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_CEmitter_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_CEmitter_dispose);
  Py_VISIT(traverse_module_state->__pyx_n_s_CEmitter_emit);
  Py_VISIT(traverse_module_state->__pyx_n_s_CEmitter_open);
  Py_VISIT(traverse_module_state->__pyx_n_s_CEmitter_serialize);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser_check_event);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser_check_node);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser_check_token);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser_dispose);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser_get_event);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser_get_node);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser_get_single_node);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser_get_token);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser_peek_event);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser_peek_token);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser_raw_parse);
  Py_VISIT(traverse_module_state->__pyx_n_s_CParser_raw_scan);
  Py_VISIT(traverse_module_state->__pyx_n_s_ComposerError);
  Py_VISIT(traverse_module_state->__pyx_n_s_ConstructorError);
  Py_VISIT(traverse_module_state->__pyx_n_s_DirectiveToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_DocumentEndEvent);
  Py_VISIT(traverse_module_state->__pyx_n_s_DocumentEndToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_DocumentStartEvent);
  Py_VISIT(traverse_module_state->__pyx_n_s_DocumentStartToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_EmitterError);
  Py_VISIT(traverse_module_state->__pyx_n_s_FlowEntryToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_FlowMappingEndToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_FlowMappingStartToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_FlowSequenceEndToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_FlowSequenceStartToken);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_VISIT(traverse_module_state->__pyx_n_s_KeyToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_MappingEndEvent);
  Py_VISIT(traverse_module_state->__pyx_n_s_MappingNode);
  Py_VISIT(traverse_module_state->__pyx_n_s_MappingStartEvent);
  Py_VISIT(traverse_module_state->__pyx_n_s_Mark);
  Py_VISIT(traverse_module_state->__pyx_n_s_Mark___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Mark___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Mark_get_snippet);
  Py_VISIT(traverse_module_state->__pyx_n_s_MemoryError);
  Py_VISIT(traverse_module_state->__pyx_n_s_ParserError);
  Py_VISIT(traverse_module_state->__pyx_n_s_PickleError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Pickling_of_struct_members_such);
  Py_VISIT(traverse_module_state->__pyx_n_s_ReaderError);
  Py_VISIT(traverse_module_state->__pyx_n_s_RepresenterError);
  Py_VISIT(traverse_module_state->__pyx_n_s_ScalarEvent);
  Py_VISIT(traverse_module_state->__pyx_n_s_ScalarNode);
  Py_VISIT(traverse_module_state->__pyx_n_s_ScalarToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_ScannerError);
  Py_VISIT(traverse_module_state->__pyx_n_s_SequenceEndEvent);
  Py_VISIT(traverse_module_state->__pyx_n_s_SequenceNode);
  Py_VISIT(traverse_module_state->__pyx_n_s_SequenceStartEvent);
  Py_VISIT(traverse_module_state->__pyx_n_s_SerializerError);
  Py_VISIT(traverse_module_state->__pyx_n_s_StreamEndEvent);
  Py_VISIT(traverse_module_state->__pyx_n_s_StreamEndToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_StreamStartEvent);
  Py_VISIT(traverse_module_state->__pyx_n_s_StreamStartToken);
  Py_VISIT(traverse_module_state->__pyx_n_u_TAG);
  Py_VISIT(traverse_module_state->__pyx_n_s_TagToken);
  Py_VISIT(traverse_module_state->__pyx_n_s_TypeError);
  Py_VISIT(traverse_module_state->__pyx_n_s_ValueError);
  Py_VISIT(traverse_module_state->__pyx_n_s_ValueToken);
  Py_VISIT(traverse_module_state->__pyx_n_u_YAML);
  Py_VISIT(traverse_module_state->__pyx_n_s_YAMLError);
  Py_VISIT(traverse_module_state->__pyx_kp_s__12);
  Py_VISIT(traverse_module_state->__pyx_kp_s__13);
  Py_VISIT(traverse_module_state->__pyx_kp_s__14);
  Py_VISIT(traverse_module_state->__pyx_n_s__2);
  Py_VISIT(traverse_module_state->__pyx_kp_u__2);
  Py_VISIT(traverse_module_state->__pyx_kp_u__25);
  Py_VISIT(traverse_module_state->__pyx_n_s__26);
  Py_VISIT(traverse_module_state->__pyx_kp_u__4);
  Py_VISIT(traverse_module_state->__pyx_kp_s__5);
  Py_VISIT(traverse_module_state->__pyx_kp_u__5);
  Py_VISIT(traverse_module_state->__pyx_kp_s__6);
  Py_VISIT(traverse_module_state->__pyx_kp_u__6);
  Py_VISIT(traverse_module_state->__pyx_kp_s__7);
  Py_VISIT(traverse_module_state->__pyx_kp_u__7);
  Py_VISIT(traverse_module_state->__pyx_kp_s__8);
  Py_VISIT(traverse_module_state->__pyx_kp_u__8);
  Py_VISIT(traverse_module_state->__pyx_kp_u_a_string_or_stream_input_is_requ);
  Py_VISIT(traverse_module_state->__pyx_kp_u_a_string_value_is_expected);
  Py_VISIT(traverse_module_state->__pyx_n_s_allow_unicode);
  Py_VISIT(traverse_module_state->__pyx_n_s_anchor);
  Py_VISIT(traverse_module_state->__pyx_kp_u_anchor_must_be_a_string);
  Py_VISIT(traverse_module_state->__pyx_n_s_ascend_resolver);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_coroutines);
  Py_VISIT(traverse_module_state->__pyx_n_s_buffer);
  Py_VISIT(traverse_module_state->__pyx_kp_u_but_found_another_document);
  Py_VISIT(traverse_module_state->__pyx_kp_u_byte_string);
  Py_VISIT(traverse_module_state->__pyx_n_s_cache);
  Py_VISIT(traverse_module_state->__pyx_n_s_canonical);
  Py_VISIT(traverse_module_state->__pyx_n_s_check_event);
  Py_VISIT(traverse_module_state->__pyx_n_s_check_node);
  Py_VISIT(traverse_module_state->__pyx_n_s_check_token);
  Py_VISIT(traverse_module_state->__pyx_n_s_choice);
  Py_VISIT(traverse_module_state->__pyx_n_s_choices);
  Py_VISIT(traverse_module_state->__pyx_n_s_class);
  Py_VISIT(traverse_module_state->__pyx_n_s_class_getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_close);
  Py_VISIT(traverse_module_state->__pyx_n_s_column);
  Py_VISIT(traverse_module_state->__pyx_n_s_composer);
  Py_VISIT(traverse_module_state->__pyx_n_s_constructor);
  Py_VISIT(traverse_module_state->__pyx_n_s_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_descend_resolver);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_disable);
  Py_VISIT(traverse_module_state->__pyx_n_s_dispose);
  Py_VISIT(traverse_module_state->__pyx_n_s_document);
  Py_VISIT(traverse_module_state->__pyx_n_s_done);
  Py_VISIT(traverse_module_state->__pyx_n_s_emit);
  Py_VISIT(traverse_module_state->__pyx_n_s_emitter);
  Py_VISIT(traverse_module_state->__pyx_kp_u_enable);
  Py_VISIT(traverse_module_state->__pyx_n_s_encoding);
  Py_VISIT(traverse_module_state->__pyx_n_u_encoding);
  Py_VISIT(traverse_module_state->__pyx_n_s_end_mark);
  Py_VISIT(traverse_module_state->__pyx_n_s_error);
  Py_VISIT(traverse_module_state->__pyx_n_s_event);
  Py_VISIT(traverse_module_state->__pyx_n_s_event_class);
  Py_VISIT(traverse_module_state->__pyx_n_s_event_object);
  Py_VISIT(traverse_module_state->__pyx_n_s_events);
  Py_VISIT(traverse_module_state->__pyx_kp_u_expected_a_single_document_in_th);
  Py_VISIT(traverse_module_state->__pyx_n_s_explicit);
  Py_VISIT(traverse_module_state->__pyx_n_s_explicit_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_explicit_start);
  Py_VISIT(traverse_module_state->__pyx_kp_u_file);
  Py_VISIT(traverse_module_state->__pyx_n_s_flow_style);
  Py_VISIT(traverse_module_state->__pyx_kp_u_found_duplicate_anchor_first_occ);
  Py_VISIT(traverse_module_state->__pyx_kp_u_found_undefined_alias);
  Py_VISIT(traverse_module_state->__pyx_kp_u_gc);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_event);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_node);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_single_node);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_snippet);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_token);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_version);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_version_string);
  Py_VISIT(traverse_module_state->__pyx_n_s_getstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_handle);
  Py_VISIT(traverse_module_state->__pyx_kp_u_id_03d);
  Py_VISIT(traverse_module_state->__pyx_n_s_implicit);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_kp_s_in_s_line_d_column_d);
  Py_VISIT(traverse_module_state->__pyx_n_s_indent);
  Py_VISIT(traverse_module_state->__pyx_n_s_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_kp_u_invalid_event_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coroutine);
  Py_VISIT(traverse_module_state->__pyx_kp_u_isenabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_break);
  Py_VISIT(traverse_module_state->__pyx_n_s_main);
  Py_VISIT(traverse_module_state->__pyx_n_s_major);
  Py_VISIT(traverse_module_state->__pyx_n_s_mark);
  Py_VISIT(traverse_module_state->__pyx_n_s_minor);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_name_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_new);
  Py_VISIT(traverse_module_state->__pyx_kp_u_no_emitter_error);
  Py_VISIT(traverse_module_state->__pyx_kp_u_no_parser_error);
  Py_VISIT(traverse_module_state->__pyx_n_s_node);
  Py_VISIT(traverse_module_state->__pyx_n_s_nodes);
  Py_VISIT(traverse_module_state->__pyx_n_s_open);
  Py_VISIT(traverse_module_state->__pyx_n_s_parser);
  Py_VISIT(traverse_module_state->__pyx_n_s_patch);
  Py_VISIT(traverse_module_state->__pyx_n_s_peek_event);
  Py_VISIT(traverse_module_state->__pyx_n_s_peek_token);
  Py_VISIT(traverse_module_state->__pyx_n_s_pickle);
  Py_VISIT(traverse_module_state->__pyx_n_s_pointer);
  Py_VISIT(traverse_module_state->__pyx_n_s_prefix);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_checksum);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_unpickle_Mark);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_vtable);
  Py_VISIT(traverse_module_state->__pyx_n_s_raw_parse);
  Py_VISIT(traverse_module_state->__pyx_n_s_raw_scan);
  Py_VISIT(traverse_module_state->__pyx_n_s_read);
  Py_VISIT(traverse_module_state->__pyx_n_s_reader);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_ex);
  Py_VISIT(traverse_module_state->__pyx_n_s_representer);
  Py_VISIT(traverse_module_state->__pyx_n_s_resolve);
  Py_VISIT(traverse_module_state->__pyx_n_s_scanner);
  Py_VISIT(traverse_module_state->__pyx_kp_u_second_occurrence);
  Py_VISIT(traverse_module_state->__pyx_n_s_self);
  Py_VISIT(traverse_module_state->__pyx_kp_s_self_parsed_event_cannot_be_conv);
  Py_VISIT(traverse_module_state->__pyx_n_s_serialize);
  Py_VISIT(traverse_module_state->__pyx_n_s_serializer);
  Py_VISIT(traverse_module_state->__pyx_kp_u_serializer_is_already_opened);
  Py_VISIT(traverse_module_state->__pyx_kp_u_serializer_is_closed);
  Py_VISIT(traverse_module_state->__pyx_kp_u_serializer_is_not_opened);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_n_s_start_mark);
  Py_VISIT(traverse_module_state->__pyx_n_s_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_stream);
  Py_VISIT(traverse_module_state->__pyx_kp_s_stringsource);
  Py_VISIT(traverse_module_state->__pyx_n_s_style);
  Py_VISIT(traverse_module_state->__pyx_n_s_tag);
  Py_VISIT(traverse_module_state->__pyx_n_s_tag_directives_end);
  Py_VISIT(traverse_module_state->__pyx_n_s_tag_directives_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_tag_directives_value);
  Py_VISIT(traverse_module_state->__pyx_kp_u_tag_handle_must_be_a_string);
  Py_VISIT(traverse_module_state->__pyx_kp_u_tag_must_be_a_string);
  Py_VISIT(traverse_module_state->__pyx_kp_u_tag_prefix_must_be_a_string);
  Py_VISIT(traverse_module_state->__pyx_n_s_tags);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_n_s_token);
  Py_VISIT(traverse_module_state->__pyx_n_s_token_class);
  Py_VISIT(traverse_module_state->__pyx_n_s_tokens);
  Py_VISIT(traverse_module_state->__pyx_kp_u_too_many_tags);
  Py_VISIT(traverse_module_state->__pyx_kp_u_unicode_string);
  Py_VISIT(traverse_module_state->__pyx_kp_u_unknown_event_type);
  Py_VISIT(traverse_module_state->__pyx_kp_u_unknown_token_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_update);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_setstate);
  Py_VISIT(traverse_module_state->__pyx_kp_s_utf_16_be);
  Py_VISIT(traverse_module_state->__pyx_kp_u_utf_16_be);
  Py_VISIT(traverse_module_state->__pyx_kp_s_utf_16_le);
  Py_VISIT(traverse_module_state->__pyx_kp_u_utf_16_le);
  Py_VISIT(traverse_module_state->__pyx_kp_u_utf_8);
  Py_VISIT(traverse_module_state->__pyx_n_s_value);
  Py_VISIT(traverse_module_state->__pyx_kp_u_value_must_be_a_string);
  Py_VISIT(traverse_module_state->__pyx_n_s_version);
  Py_VISIT(traverse_module_state->__pyx_n_s_version_directive);
  Py_VISIT(traverse_module_state->__pyx_n_s_version_directive_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_width);
  Py_VISIT(traverse_module_state->__pyx_n_s_write);
  Py_VISIT(traverse_module_state->__pyx_n_s_yaml);
  Py_VISIT(traverse_module_state->__pyx_n_s_yaml__yaml);
  Py_VISIT(traverse_module_state->__pyx_kp_s_yaml__yaml_pyx);
  Py_VISIT(traverse_module_state->__pyx_int_0);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_41581148);
  Py_VISIT(traverse_module_state->__pyx_int_66733494);
  Py_VISIT(traverse_module_state->__pyx_int_96533895);
  Py_VISIT(traverse_module_state->__pyx_tuple_);
  Py_VISIT(traverse_module_state->__pyx_tuple__3);
  Py_VISIT(traverse_module_state->__pyx_tuple__9);
  Py_VISIT(traverse_module_state->__pyx_tuple__10);
  Py_VISIT(traverse_module_state->__pyx_tuple__11);
  Py_VISIT(traverse_module_state->__pyx_tuple__15);
  Py_VISIT(traverse_module_state->__pyx_tuple__16);
  Py_VISIT(traverse_module_state->__pyx_tuple__17);
  Py_VISIT(traverse_module_state->__pyx_tuple__18);
  Py_VISIT(traverse_module_state->__pyx_tuple__19);
  Py_VISIT(traverse_module_state->__pyx_tuple__20);
  Py_VISIT(traverse_module_state->__pyx_tuple__21);
  Py_VISIT(traverse_module_state->__pyx_tuple__22);
  Py_VISIT(traverse_module_state->__pyx_tuple__23);
  Py_VISIT(traverse_module_state->__pyx_tuple__24);
  Py_VISIT(traverse_module_state->__pyx_tuple__27);
  Py_VISIT(traverse_module_state->__pyx_tuple__29);
  Py_VISIT(traverse_module_state->__pyx_tuple__31);
  Py_VISIT(traverse_module_state->__pyx_tuple__33);
  Py_VISIT(traverse_module_state->__pyx_tuple__35);
  Py_VISIT(traverse_module_state->__pyx_tuple__38);
  Py_VISIT(traverse_module_state->__pyx_tuple__40);
  Py_VISIT(traverse_module_state->__pyx_tuple__43);
  Py_VISIT(traverse_module_state->__pyx_tuple__45);
  Py_VISIT(traverse_module_state->__pyx_tuple__49);
  Py_VISIT(traverse_module_state->__pyx_tuple__53);
  Py_VISIT(traverse_module_state->__pyx_tuple__58);
  Py_VISIT(traverse_module_state->__pyx_tuple__60);
  Py_VISIT(traverse_module_state->__pyx_tuple__62);
  Py_VISIT(traverse_module_state->__pyx_tuple__64);
  Py_VISIT(traverse_module_state->__pyx_tuple__68);
  Py_VISIT(traverse_module_state->__pyx_codeobj__28);
  Py_VISIT(traverse_module_state->__pyx_codeobj__30);
  Py_VISIT(traverse_module_state->__pyx_codeobj__32);
  Py_VISIT(traverse_module_state->__pyx_codeobj__34);
  Py_VISIT(traverse_module_state->__pyx_codeobj__36);
  Py_VISIT(traverse_module_state->__pyx_codeobj__37);
  Py_VISIT(traverse_module_state->__pyx_codeobj__39);
  Py_VISIT(traverse_module_state->__pyx_codeobj__41);
  Py_VISIT(traverse_module_state->__pyx_codeobj__42);
  Py_VISIT(traverse_module_state->__pyx_codeobj__44);
  Py_VISIT(traverse_module_state->__pyx_codeobj__46);
  Py_VISIT(traverse_module_state->__pyx_codeobj__47);
  Py_VISIT(traverse_module_state->__pyx_codeobj__48);
  Py_VISIT(traverse_module_state->__pyx_codeobj__50);
  Py_VISIT(traverse_module_state->__pyx_codeobj__51);
  Py_VISIT(traverse_module_state->__pyx_codeobj__52);
  Py_VISIT(traverse_module_state->__pyx_codeobj__54);
  Py_VISIT(traverse_module_state->__pyx_codeobj__55);
  Py_VISIT(traverse_module_state->__pyx_codeobj__56);
  Py_VISIT(traverse_module_state->__pyx_codeobj__57);
  Py_VISIT(traverse_module_state->__pyx_codeobj__59);
  Py_VISIT(traverse_module_state->__pyx_codeobj__61);
  Py_VISIT(traverse_module_state->__pyx_codeobj__63);
  Py_VISIT(traverse_module_state->__pyx_codeobj__65);
  Py_VISIT(traverse_module_state->__pyx_codeobj__66);
  Py_VISIT(traverse_module_state->__pyx_codeobj__67);
  Py_VISIT(traverse_module_state->__pyx_codeobj__69);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#ifdef __Pyx_Generator_USED
#define __pyx_GeneratorType __pyx_mstate_global->__pyx_GeneratorType
#endif
#ifdef __Pyx_IterableCoroutine_USED
#define __pyx_IterableCoroutineType __pyx_mstate_global->__pyx_IterableCoroutineType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineAwaitType __pyx_mstate_global->__pyx_CoroutineAwaitType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineType __pyx_mstate_global->__pyx_CoroutineType
#endif
#if CYTHON_USE_MODULE_STATE
#define __pyx_type_4yaml_5_yaml_Mark __pyx_mstate_global->__pyx_type_4yaml_5_yaml_Mark
#define __pyx_type_4yaml_5_yaml_CParser __pyx_mstate_global->__pyx_type_4yaml_5_yaml_CParser
#define __pyx_type_4yaml_5_yaml_CEmitter __pyx_mstate_global->__pyx_type_4yaml_5_yaml_CEmitter
#endif
#define __pyx_ptype_4yaml_5_yaml_Mark __pyx_mstate_global->__pyx_ptype_4yaml_5_yaml_Mark
#define __pyx_ptype_4yaml_5_yaml_CParser __pyx_mstate_global->__pyx_ptype_4yaml_5_yaml_CParser
#define __pyx_ptype_4yaml_5_yaml_CEmitter __pyx_mstate_global->__pyx_ptype_4yaml_5_yaml_CEmitter
#define __pyx_n_s_AliasEvent __pyx_mstate_global->__pyx_n_s_AliasEvent
#define __pyx_n_s_AliasToken __pyx_mstate_global->__pyx_n_s_AliasToken
#define __pyx_n_s_AnchorToken __pyx_mstate_global->__pyx_n_s_AnchorToken
#define __pyx_n_s_AttributeError __pyx_mstate_global->__pyx_n_s_AttributeError
#define __pyx_n_s_BlockEndToken __pyx_mstate_global->__pyx_n_s_BlockEndToken
#define __pyx_n_s_BlockEntryToken __pyx_mstate_global->__pyx_n_s_BlockEntryToken
#define __pyx_n_s_BlockMappingStartToken __pyx_mstate_global->__pyx_n_s_BlockMappingStartToken
#define __pyx_n_s_BlockSequenceStartToken __pyx_mstate_global->__pyx_n_s_BlockSequenceStartToken
#define __pyx_n_s_CEmitter __pyx_mstate_global->__pyx_n_s_CEmitter
#define __pyx_n_s_CEmitter___reduce_cython __pyx_mstate_global->__pyx_n_s_CEmitter___reduce_cython
#define __pyx_n_s_CEmitter___setstate_cython __pyx_mstate_global->__pyx_n_s_CEmitter___setstate_cython
#define __pyx_n_s_CEmitter_close __pyx_mstate_global->__pyx_n_s_CEmitter_close
#define __pyx_n_s_CEmitter_dispose __pyx_mstate_global->__pyx_n_s_CEmitter_dispose
#define __pyx_n_s_CEmitter_emit __pyx_mstate_global->__pyx_n_s_CEmitter_emit
#define __pyx_n_s_CEmitter_open __pyx_mstate_global->__pyx_n_s_CEmitter_open
#define __pyx_n_s_CEmitter_serialize __pyx_mstate_global->__pyx_n_s_CEmitter_serialize
#define __pyx_n_s_CParser __pyx_mstate_global->__pyx_n_s_CParser
#define __pyx_n_s_CParser___reduce_cython __pyx_mstate_global->__pyx_n_s_CParser___reduce_cython
#define __pyx_n_s_CParser___setstate_cython __pyx_mstate_global->__pyx_n_s_CParser___setstate_cython
#define __pyx_n_s_CParser_check_event __pyx_mstate_global->__pyx_n_s_CParser_check_event
#define __pyx_n_s_CParser_check_node __pyx_mstate_global->__pyx_n_s_CParser_check_node
#define __pyx_n_s_CParser_check_token __pyx_mstate_global->__pyx_n_s_CParser_check_token
#define __pyx_n_s_CParser_dispose __pyx_mstate_global->__pyx_n_s_CParser_dispose
#define __pyx_n_s_CParser_get_event __pyx_mstate_global->__pyx_n_s_CParser_get_event
#define __pyx_n_s_CParser_get_node __pyx_mstate_global->__pyx_n_s_CParser_get_node
#define __pyx_n_s_CParser_get_single_node __pyx_mstate_global->__pyx_n_s_CParser_get_single_node
#define __pyx_n_s_CParser_get_token __pyx_mstate_global->__pyx_n_s_CParser_get_token
#define __pyx_n_s_CParser_peek_event __pyx_mstate_global->__pyx_n_s_CParser_peek_event
#define __pyx_n_s_CParser_peek_token __pyx_mstate_global->__pyx_n_s_CParser_peek_token
#define __pyx_n_s_CParser_raw_parse __pyx_mstate_global->__pyx_n_s_CParser_raw_parse
#define __pyx_n_s_CParser_raw_scan __pyx_mstate_global->__pyx_n_s_CParser_raw_scan
#define __pyx_n_s_ComposerError __pyx_mstate_global->__pyx_n_s_ComposerError
#define __pyx_n_s_ConstructorError __pyx_mstate_global->__pyx_n_s_ConstructorError
#define __pyx_n_s_DirectiveToken __pyx_mstate_global->__pyx_n_s_DirectiveToken
#define __pyx_n_s_DocumentEndEvent __pyx_mstate_global->__pyx_n_s_DocumentEndEvent
#define __pyx_n_s_DocumentEndToken __pyx_mstate_global->__pyx_n_s_DocumentEndToken
#define __pyx_n_s_DocumentStartEvent __pyx_mstate_global->__pyx_n_s_DocumentStartEvent
#define __pyx_n_s_DocumentStartToken __pyx_mstate_global->__pyx_n_s_DocumentStartToken
#define __pyx_n_s_EmitterError __pyx_mstate_global->__pyx_n_s_EmitterError
#define __pyx_n_s_FlowEntryToken __pyx_mstate_global->__pyx_n_s_FlowEntryToken
#define __pyx_n_s_FlowMappingEndToken __pyx_mstate_global->__pyx_n_s_FlowMappingEndToken
#define __pyx_n_s_FlowMappingStartToken __pyx_mstate_global->__pyx_n_s_FlowMappingStartToken
#define __pyx_n_s_FlowSequenceEndToken __pyx_mstate_global->__pyx_n_s_FlowSequenceEndToken
#define __pyx_n_s_FlowSequenceStartToken __pyx_mstate_global->__pyx_n_s_FlowSequenceStartToken
#define __pyx_kp_s_Incompatible_checksums_0x_x_vs_0 __pyx_mstate_global->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0
#define __pyx_n_s_KeyToken __pyx_mstate_global->__pyx_n_s_KeyToken
#define __pyx_n_s_MappingEndEvent __pyx_mstate_global->__pyx_n_s_MappingEndEvent
#define __pyx_n_s_MappingNode __pyx_mstate_global->__pyx_n_s_MappingNode
#define __pyx_n_s_MappingStartEvent __pyx_mstate_global->__pyx_n_s_MappingStartEvent
#define __pyx_n_s_Mark __pyx_mstate_global->__pyx_n_s_Mark
#define __pyx_n_s_Mark___reduce_cython __pyx_mstate_global->__pyx_n_s_Mark___reduce_cython
#define __pyx_n_s_Mark___setstate_cython __pyx_mstate_global->__pyx_n_s_Mark___setstate_cython
#define __pyx_n_s_Mark_get_snippet __pyx_mstate_global->__pyx_n_s_Mark_get_snippet
#define __pyx_n_s_MemoryError __pyx_mstate_global->__pyx_n_s_MemoryError
#define __pyx_n_s_ParserError __pyx_mstate_global->__pyx_n_s_ParserError
#define __pyx_n_s_PickleError __pyx_mstate_global->__pyx_n_s_PickleError
#define __pyx_kp_s_Pickling_of_struct_members_such __pyx_mstate_global->__pyx_kp_s_Pickling_of_struct_members_such
#define __pyx_n_s_ReaderError __pyx_mstate_global->__pyx_n_s_ReaderError
#define __pyx_n_s_RepresenterError __pyx_mstate_global->__pyx_n_s_RepresenterError
#define __pyx_n_s_ScalarEvent __pyx_mstate_global->__pyx_n_s_ScalarEvent
#define __pyx_n_s_ScalarNode __pyx_mstate_global->__pyx_n_s_ScalarNode
#define __pyx_n_s_ScalarToken __pyx_mstate_global->__pyx_n_s_ScalarToken
#define __pyx_n_s_ScannerError __pyx_mstate_global->__pyx_n_s_ScannerError
#define __pyx_n_s_SequenceEndEvent __pyx_mstate_global->__pyx_n_s_SequenceEndEvent
#define __pyx_n_s_SequenceNode __pyx_mstate_global->__pyx_n_s_SequenceNode
#define __pyx_n_s_SequenceStartEvent __pyx_mstate_global->__pyx_n_s_SequenceStartEvent
#define __pyx_n_s_SerializerError __pyx_mstate_global->__pyx_n_s_SerializerError
#define __pyx_n_s_StreamEndEvent __pyx_mstate_global->__pyx_n_s_StreamEndEvent
#define __pyx_n_s_StreamEndToken __pyx_mstate_global->__pyx_n_s_StreamEndToken
#define __pyx_n_s_StreamStartEvent __pyx_mstate_global->__pyx_n_s_StreamStartEvent
#define __pyx_n_s_StreamStartToken __pyx_mstate_global->__pyx_n_s_StreamStartToken
#define __pyx_n_u_TAG __pyx_mstate_global->__pyx_n_u_TAG
#define __pyx_n_s_TagToken __pyx_mstate_global->__pyx_n_s_TagToken
#define __pyx_n_s_TypeError __pyx_mstate_global->__pyx_n_s_TypeError
#define __pyx_n_s_ValueError __pyx_mstate_global->__pyx_n_s_ValueError
#define __pyx_n_s_ValueToken __pyx_mstate_global->__pyx_n_s_ValueToken
#define __pyx_n_u_YAML __pyx_mstate_global->__pyx_n_u_YAML
#define __pyx_n_s_YAMLError __pyx_mstate_global->__pyx_n_s_YAMLError
#define __pyx_kp_s__12 __pyx_mstate_global->__pyx_kp_s__12
#define __pyx_kp_s__13 __pyx_mstate_global->__pyx_kp_s__13
#define __pyx_kp_s__14 __pyx_mstate_global->__pyx_kp_s__14
#define __pyx_n_s__2 __pyx_mstate_global->__pyx_n_s__2
#define __pyx_kp_u__2 __pyx_mstate_global->__pyx_kp_u__2
#define __pyx_kp_u__25 __pyx_mstate_global->__pyx_kp_u__25
#define __pyx_n_s__26 __pyx_mstate_global->__pyx_n_s__26
#define __pyx_kp_u__4 __pyx_mstate_global->__pyx_kp_u__4
#define __pyx_kp_s__5 __pyx_mstate_global->__pyx_kp_s__5
#define __pyx_kp_u__5 __pyx_mstate_global->__pyx_kp_u__5
#define __pyx_kp_s__6 __pyx_mstate_global->__pyx_kp_s__6
#define __pyx_kp_u__6 __pyx_mstate_global->__pyx_kp_u__6
#define __pyx_kp_s__7 __pyx_mstate_global->__pyx_kp_s__7
#define __pyx_kp_u__7 __pyx_mstate_global->__pyx_kp_u__7
#define __pyx_kp_s__8 __pyx_mstate_global->__pyx_kp_s__8
#define __pyx_kp_u__8 __pyx_mstate_global->__pyx_kp_u__8
#define __pyx_kp_u_a_string_or_stream_input_is_requ __pyx_mstate_global->__pyx_kp_u_a_string_or_stream_input_is_requ
#define __pyx_kp_u_a_string_value_is_expected __pyx_mstate_global->__pyx_kp_u_a_string_value_is_expected
#define __pyx_n_s_allow_unicode __pyx_mstate_global->__pyx_n_s_allow_unicode
#define __pyx_n_s_anchor __pyx_mstate_global->__pyx_n_s_anchor
#define __pyx_kp_u_anchor_must_be_a_string __pyx_mstate_global->__pyx_kp_u_anchor_must_be_a_string
#define __pyx_n_s_ascend_resolver __pyx_mstate_global->__pyx_n_s_ascend_resolver
#define __pyx_n_s_asyncio_coroutines __pyx_mstate_global->__pyx_n_s_asyncio_coroutines
#define __pyx_n_s_buffer __pyx_mstate_global->__pyx_n_s_buffer
#define __pyx_kp_u_but_found_another_document __pyx_mstate_global->__pyx_kp_u_but_found_another_document
#define __pyx_kp_u_byte_string __pyx_mstate_global->__pyx_kp_u_byte_string
#define __pyx_n_s_cache __pyx_mstate_global->__pyx_n_s_cache
#define __pyx_n_s_canonical __pyx_mstate_global->__pyx_n_s_canonical
#define __pyx_n_s_check_event __pyx_mstate_global->__pyx_n_s_check_event
#define __pyx_n_s_check_node __pyx_mstate_global->__pyx_n_s_check_node
#define __pyx_n_s_check_token __pyx_mstate_global->__pyx_n_s_check_token
#define __pyx_n_s_choice __pyx_mstate_global->__pyx_n_s_choice
#define __pyx_n_s_choices __pyx_mstate_global->__pyx_n_s_choices
#define __pyx_n_s_class __pyx_mstate_global->__pyx_n_s_class
#define __pyx_n_s_class_getitem __pyx_mstate_global->__pyx_n_s_class_getitem
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_close __pyx_mstate_global->__pyx_n_s_close
#define __pyx_n_s_column __pyx_mstate_global->__pyx_n_s_column
#define __pyx_n_s_composer __pyx_mstate_global->__pyx_n_s_composer
#define __pyx_n_s_constructor __pyx_mstate_global->__pyx_n_s_constructor
#define __pyx_n_s_count __pyx_mstate_global->__pyx_n_s_count
#define __pyx_n_s_descend_resolver __pyx_mstate_global->__pyx_n_s_descend_resolver
#define __pyx_n_s_dict __pyx_mstate_global->__pyx_n_s_dict
#define __pyx_n_s_dict_2 __pyx_mstate_global->__pyx_n_s_dict_2
#define __pyx_kp_u_disable __pyx_mstate_global->__pyx_kp_u_disable
#define __pyx_n_s_dispose __pyx_mstate_global->__pyx_n_s_dispose
#define __pyx_n_s_document __pyx_mstate_global->__pyx_n_s_document
#define __pyx_n_s_done __pyx_mstate_global->__pyx_n_s_done
#define __pyx_n_s_emit __pyx_mstate_global->__pyx_n_s_emit
#define __pyx_n_s_emitter __pyx_mstate_global->__pyx_n_s_emitter
#define __pyx_kp_u_enable __pyx_mstate_global->__pyx_kp_u_enable
#define __pyx_n_s_encoding __pyx_mstate_global->__pyx_n_s_encoding
#define __pyx_n_u_encoding __pyx_mstate_global->__pyx_n_u_encoding
#define __pyx_n_s_end_mark __pyx_mstate_global->__pyx_n_s_end_mark
#define __pyx_n_s_error __pyx_mstate_global->__pyx_n_s_error
#define __pyx_n_s_event __pyx_mstate_global->__pyx_n_s_event
#define __pyx_n_s_event_class __pyx_mstate_global->__pyx_n_s_event_class
#define __pyx_n_s_event_object __pyx_mstate_global->__pyx_n_s_event_object
#define __pyx_n_s_events __pyx_mstate_global->__pyx_n_s_events
#define __pyx_kp_u_expected_a_single_document_in_th __pyx_mstate_global->__pyx_kp_u_expected_a_single_document_in_th
#define __pyx_n_s_explicit __pyx_mstate_global->__pyx_n_s_explicit
#define __pyx_n_s_explicit_end __pyx_mstate_global->__pyx_n_s_explicit_end
#define __pyx_n_s_explicit_start __pyx_mstate_global->__pyx_n_s_explicit_start
#define __pyx_kp_u_file __pyx_mstate_global->__pyx_kp_u_file
#define __pyx_n_s_flow_style __pyx_mstate_global->__pyx_n_s_flow_style
#define __pyx_kp_u_found_duplicate_anchor_first_occ __pyx_mstate_global->__pyx_kp_u_found_duplicate_anchor_first_occ
#define __pyx_kp_u_found_undefined_alias __pyx_mstate_global->__pyx_kp_u_found_undefined_alias
#define __pyx_kp_u_gc __pyx_mstate_global->__pyx_kp_u_gc
#define __pyx_n_s_get_event __pyx_mstate_global->__pyx_n_s_get_event
#define __pyx_n_s_get_node __pyx_mstate_global->__pyx_n_s_get_node
#define __pyx_n_s_get_single_node __pyx_mstate_global->__pyx_n_s_get_single_node
#define __pyx_n_s_get_snippet __pyx_mstate_global->__pyx_n_s_get_snippet
#define __pyx_n_s_get_token __pyx_mstate_global->__pyx_n_s_get_token
#define __pyx_n_s_get_version __pyx_mstate_global->__pyx_n_s_get_version
#define __pyx_n_s_get_version_string __pyx_mstate_global->__pyx_n_s_get_version_string
#define __pyx_n_s_getstate __pyx_mstate_global->__pyx_n_s_getstate
#define __pyx_n_s_handle __pyx_mstate_global->__pyx_n_s_handle
#define __pyx_kp_u_id_03d __pyx_mstate_global->__pyx_kp_u_id_03d
#define __pyx_n_s_implicit __pyx_mstate_global->__pyx_n_s_implicit
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_kp_s_in_s_line_d_column_d __pyx_mstate_global->__pyx_kp_s_in_s_line_d_column_d
#define __pyx_n_s_indent __pyx_mstate_global->__pyx_n_s_indent
#define __pyx_n_s_index __pyx_mstate_global->__pyx_n_s_index
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_kp_u_invalid_event_s __pyx_mstate_global->__pyx_kp_u_invalid_event_s
#define __pyx_n_s_is_coroutine __pyx_mstate_global->__pyx_n_s_is_coroutine
#define __pyx_kp_u_isenabled __pyx_mstate_global->__pyx_kp_u_isenabled
#define __pyx_n_s_line __pyx_mstate_global->__pyx_n_s_line
#define __pyx_n_s_line_break __pyx_mstate_global->__pyx_n_s_line_break
#define __pyx_n_s_main __pyx_mstate_global->__pyx_n_s_main
#define __pyx_n_s_major __pyx_mstate_global->__pyx_n_s_major
#define __pyx_n_s_mark __pyx_mstate_global->__pyx_n_s_mark
#define __pyx_n_s_minor __pyx_mstate_global->__pyx_n_s_minor
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_s_name_2 __pyx_mstate_global->__pyx_n_s_name_2
#define __pyx_n_s_new __pyx_mstate_global->__pyx_n_s_new
#define __pyx_kp_u_no_emitter_error __pyx_mstate_global->__pyx_kp_u_no_emitter_error
#define __pyx_kp_u_no_parser_error __pyx_mstate_global->__pyx_kp_u_no_parser_error
#define __pyx_n_s_node __pyx_mstate_global->__pyx_n_s_node
#define __pyx_n_s_nodes __pyx_mstate_global->__pyx_n_s_nodes
#define __pyx_n_s_open __pyx_mstate_global->__pyx_n_s_open
#define __pyx_n_s_parser __pyx_mstate_global->__pyx_n_s_parser
#define __pyx_n_s_patch __pyx_mstate_global->__pyx_n_s_patch
#define __pyx_n_s_peek_event __pyx_mstate_global->__pyx_n_s_peek_event
#define __pyx_n_s_peek_token __pyx_mstate_global->__pyx_n_s_peek_token
#define __pyx_n_s_pickle __pyx_mstate_global->__pyx_n_s_pickle
#define __pyx_n_s_pointer __pyx_mstate_global->__pyx_n_s_pointer
#define __pyx_n_s_prefix __pyx_mstate_global->__pyx_n_s_prefix
#define __pyx_n_s_pyx_PickleError __pyx_mstate_global->__pyx_n_s_pyx_PickleError
#define __pyx_n_s_pyx_checksum __pyx_mstate_global->__pyx_n_s_pyx_checksum
#define __pyx_n_s_pyx_result __pyx_mstate_global->__pyx_n_s_pyx_result
#define __pyx_n_s_pyx_state __pyx_mstate_global->__pyx_n_s_pyx_state
#define __pyx_n_s_pyx_type __pyx_mstate_global->__pyx_n_s_pyx_type
#define __pyx_n_s_pyx_unpickle_Mark __pyx_mstate_global->__pyx_n_s_pyx_unpickle_Mark
#define __pyx_n_s_pyx_vtable __pyx_mstate_global->__pyx_n_s_pyx_vtable
#define __pyx_n_s_raw_parse __pyx_mstate_global->__pyx_n_s_raw_parse
#define __pyx_n_s_raw_scan __pyx_mstate_global->__pyx_n_s_raw_scan
#define __pyx_n_s_read __pyx_mstate_global->__pyx_n_s_read
#define __pyx_n_s_reader __pyx_mstate_global->__pyx_n_s_reader
#define __pyx_n_s_reduce __pyx_mstate_global->__pyx_n_s_reduce
#define __pyx_n_s_reduce_cython __pyx_mstate_global->__pyx_n_s_reduce_cython
#define __pyx_n_s_reduce_ex __pyx_mstate_global->__pyx_n_s_reduce_ex
#define __pyx_n_s_representer __pyx_mstate_global->__pyx_n_s_representer
#define __pyx_n_s_resolve __pyx_mstate_global->__pyx_n_s_resolve
#define __pyx_n_s_scanner __pyx_mstate_global->__pyx_n_s_scanner
#define __pyx_kp_u_second_occurrence __pyx_mstate_global->__pyx_kp_u_second_occurrence
#define __pyx_n_s_self __pyx_mstate_global->__pyx_n_s_self
#define __pyx_kp_s_self_parsed_event_cannot_be_conv __pyx_mstate_global->__pyx_kp_s_self_parsed_event_cannot_be_conv
#define __pyx_n_s_serialize __pyx_mstate_global->__pyx_n_s_serialize
#define __pyx_n_s_serializer __pyx_mstate_global->__pyx_n_s_serializer
#define __pyx_kp_u_serializer_is_already_opened __pyx_mstate_global->__pyx_kp_u_serializer_is_already_opened
#define __pyx_kp_u_serializer_is_closed __pyx_mstate_global->__pyx_kp_u_serializer_is_closed
#define __pyx_kp_u_serializer_is_not_opened __pyx_mstate_global->__pyx_kp_u_serializer_is_not_opened
#define __pyx_n_s_setstate __pyx_mstate_global->__pyx_n_s_setstate
#define __pyx_n_s_setstate_cython __pyx_mstate_global->__pyx_n_s_setstate_cython
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_n_s_start_mark __pyx_mstate_global->__pyx_n_s_start_mark
#define __pyx_n_s_state __pyx_mstate_global->__pyx_n_s_state
#define __pyx_n_s_stream __pyx_mstate_global->__pyx_n_s_stream
#define __pyx_kp_s_stringsource __pyx_mstate_global->__pyx_kp_s_stringsource
#define __pyx_n_s_style __pyx_mstate_global->__pyx_n_s_style
#define __pyx_n_s_tag __pyx_mstate_global->__pyx_n_s_tag
#define __pyx_n_s_tag_directives_end __pyx_mstate_global->__pyx_n_s_tag_directives_end
#define __pyx_n_s_tag_directives_start __pyx_mstate_global->__pyx_n_s_tag_directives_start
#define __pyx_n_s_tag_directives_value __pyx_mstate_global->__pyx_n_s_tag_directives_value
#define __pyx_kp_u_tag_handle_must_be_a_string __pyx_mstate_global->__pyx_kp_u_tag_handle_must_be_a_string
#define __pyx_kp_u_tag_must_be_a_string __pyx_mstate_global->__pyx_kp_u_tag_must_be_a_string
#define __pyx_kp_u_tag_prefix_must_be_a_string __pyx_mstate_global->__pyx_kp_u_tag_prefix_must_be_a_string
#define __pyx_n_s_tags __pyx_mstate_global->__pyx_n_s_tags
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_n_s_token __pyx_mstate_global->__pyx_n_s_token
#define __pyx_n_s_token_class __pyx_mstate_global->__pyx_n_s_token_class
#define __pyx_n_s_tokens __pyx_mstate_global->__pyx_n_s_tokens
#define __pyx_kp_u_too_many_tags __pyx_mstate_global->__pyx_kp_u_too_many_tags
#define __pyx_kp_u_unicode_string __pyx_mstate_global->__pyx_kp_u_unicode_string
#define __pyx_kp_u_unknown_event_type __pyx_mstate_global->__pyx_kp_u_unknown_event_type
#define __pyx_kp_u_unknown_token_type __pyx_mstate_global->__pyx_kp_u_unknown_token_type
#define __pyx_n_s_update __pyx_mstate_global->__pyx_n_s_update
#define __pyx_n_s_use_setstate __pyx_mstate_global->__pyx_n_s_use_setstate
#define __pyx_kp_s_utf_16_be __pyx_mstate_global->__pyx_kp_s_utf_16_be
#define __pyx_kp_u_utf_16_be __pyx_mstate_global->__pyx_kp_u_utf_16_be
#define __pyx_kp_s_utf_16_le __pyx_mstate_global->__pyx_kp_s_utf_16_le
#define __pyx_kp_u_utf_16_le __pyx_mstate_global->__pyx_kp_u_utf_16_le
#define __pyx_kp_u_utf_8 __pyx_mstate_global->__pyx_kp_u_utf_8
#define __pyx_n_s_value __pyx_mstate_global->__pyx_n_s_value
#define __pyx_kp_u_value_must_be_a_string __pyx_mstate_global->__pyx_kp_u_value_must_be_a_string
#define __pyx_n_s_version __pyx_mstate_global->__pyx_n_s_version
#define __pyx_n_s_version_directive __pyx_mstate_global->__pyx_n_s_version_directive
#define __pyx_n_s_version_directive_value __pyx_mstate_global->__pyx_n_s_version_directive_value
#define __pyx_n_s_width __pyx_mstate_global->__pyx_n_s_width
#define __pyx_n_s_write __pyx_mstate_global->__pyx_n_s_write
#define __pyx_n_s_yaml __pyx_mstate_global->__pyx_n_s_yaml
#define __pyx_n_s_yaml__yaml __pyx_mstate_global->__pyx_n_s_yaml__yaml
#define __pyx_kp_s_yaml__yaml_pyx __pyx_mstate_global->__pyx_kp_s_yaml__yaml_pyx
#define __pyx_int_0 __pyx_mstate_global->__pyx_int_0
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_41581148 __pyx_mstate_global->__pyx_int_41581148
#define __pyx_int_66733494 __pyx_mstate_global->__pyx_int_66733494
#define __pyx_int_96533895 __pyx_mstate_global->__pyx_int_96533895
#define __pyx_tuple_ __pyx_mstate_global->__pyx_tuple_
#define __pyx_tuple__3 __pyx_mstate_global->__pyx_tuple__3
#define __pyx_tuple__9 __pyx_mstate_global->__pyx_tuple__9
#define __pyx_tuple__10 __pyx_mstate_global->__pyx_tuple__10
#define __pyx_tuple__11 __pyx_mstate_global->__pyx_tuple__11
#define __pyx_tuple__15 __pyx_mstate_global->__pyx_tuple__15
#define __pyx_tuple__16 __pyx_mstate_global->__pyx_tuple__16
#define __pyx_tuple__17 __pyx_mstate_global->__pyx_tuple__17
#define __pyx_tuple__18 __pyx_mstate_global->__pyx_tuple__18
#define __pyx_tuple__19 __pyx_mstate_global->__pyx_tuple__19
#define __pyx_tuple__20 __pyx_mstate_global->__pyx_tuple__20
#define __pyx_tuple__21 __pyx_mstate_global->__pyx_tuple__21
#define __pyx_tuple__22 __pyx_mstate_global->__pyx_tuple__22
#define __pyx_tuple__23 __pyx_mstate_global->__pyx_tuple__23
#define __pyx_tuple__24 __pyx_mstate_global->__pyx_tuple__24
#define __pyx_tuple__27 __pyx_mstate_global->__pyx_tuple__27
#define __pyx_tuple__29 __pyx_mstate_global->__pyx_tuple__29
#define __pyx_tuple__31 __pyx_mstate_global->__pyx_tuple__31
#define __pyx_tuple__33 __pyx_mstate_global->__pyx_tuple__33
#define __pyx_tuple__35 __pyx_mstate_global->__pyx_tuple__35
#define __pyx_tuple__38 __pyx_mstate_global->__pyx_tuple__38
#define __pyx_tuple__40 __pyx_mstate_global->__pyx_tuple__40
#define __pyx_tuple__43 __pyx_mstate_global->__pyx_tuple__43
#define __pyx_tuple__45 __pyx_mstate_global->__pyx_tuple__45
#define __pyx_tuple__49 __pyx_mstate_global->__pyx_tuple__49
#define __pyx_tuple__53 __pyx_mstate_global->__pyx_tuple__53
#define __pyx_tuple__58 __pyx_mstate_global->__pyx_tuple__58
#define __pyx_tuple__60 __pyx_mstate_global->__pyx_tuple__60
#define __pyx_tuple__62 __pyx_mstate_global->__pyx_tuple__62
#define __pyx_tuple__64 __pyx_mstate_global->__pyx_tuple__64
#define __pyx_tuple__68 __pyx_mstate_global->__pyx_tuple__68
#define __pyx_codeobj__28 __pyx_mstate_global->__pyx_codeobj__28
#define __pyx_codeobj__30 __pyx_mstate_global->__pyx_codeobj__30
#define __pyx_codeobj__32 __pyx_mstate_global->__pyx_codeobj__32
#define __pyx_codeobj__34 __pyx_mstate_global->__pyx_codeobj__34
#define __pyx_codeobj__36 __pyx_mstate_global->__pyx_codeobj__36
#define __pyx_codeobj__37 __pyx_mstate_global->__pyx_codeobj__37
#define __pyx_codeobj__39 __pyx_mstate_global->__pyx_codeobj__39
#define __pyx_codeobj__41 __pyx_mstate_global->__pyx_codeobj__41
#define __pyx_codeobj__42 __pyx_mstate_global->__pyx_codeobj__42
#define __pyx_codeobj__44 __pyx_mstate_global->__pyx_codeobj__44
#define __pyx_codeobj__46 __pyx_mstate_global->__pyx_codeobj__46
#define __pyx_codeobj__47 __pyx_mstate_global->__pyx_codeobj__47
#define __pyx_codeobj__48 __pyx_mstate_global->__pyx_codeobj__48
#define __pyx_codeobj__50 __pyx_mstate_global->__pyx_codeobj__50
#define __pyx_codeobj__51 __pyx_mstate_global->__pyx_codeobj__51
#define __pyx_codeobj__52 __pyx_mstate_global->__pyx_codeobj__52
#define __pyx_codeobj__54 __pyx_mstate_global->__pyx_codeobj__54
#define __pyx_codeobj__55 __pyx_mstate_global->__pyx_codeobj__55
#define __pyx_codeobj__56 __pyx_mstate_global->__pyx_codeobj__56
#define __pyx_codeobj__57 __pyx_mstate_global->__pyx_codeobj__57
#define __pyx_codeobj__59 __pyx_mstate_global->__pyx_codeobj__59
#define __pyx_codeobj__61 __pyx_mstate_global->__pyx_codeobj__61
#define __pyx_codeobj__63 __pyx_mstate_global->__pyx_codeobj__63
#define __pyx_codeobj__65 __pyx_mstate_global->__pyx_codeobj__65
#define __pyx_codeobj__66 __pyx_mstate_global->__pyx_codeobj__66
#define __pyx_codeobj__67 __pyx_mstate_global->__pyx_codeobj__67
#define __pyx_codeobj__69 __pyx_mstate_global->__pyx_codeobj__69
/* #### Code section: module_code ### */

/* "yaml/_yaml.pyx":4
 * import yaml
 * 
 * def get_version_string():             # <<<<<<<<<<<<<<
 *     cdef const char *value
 *     value = yaml_get_version_string()
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_1get_version_string(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_1get_version_string = {"get_version_string", (PyCFunction)__pyx_pw_4yaml_5_yaml_1get_version_string, METH_NOARGS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_1get_version_string(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_version_string (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_4yaml_5_yaml_get_version_string(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_get_version_string(CYTHON_UNUSED PyObject *__pyx_self) {
  char const *__pyx_v_value;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_version_string", 1);

  /* "yaml/_yaml.pyx":6
 * def get_version_string():
 *     cdef const char *value
 *     value = yaml_get_version_string()             # <<<<<<<<<<<<<<
 *     return PyUnicode_FromString(value)
 * 
 */
  __pyx_v_value = yaml_get_version_string();

  /* "yaml/_yaml.pyx":7
 *     cdef const char *value
 *     value = yaml_get_version_string()
 *     return PyUnicode_FromString(value)             # <<<<<<<<<<<<<<
 * 
 * def get_version():
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyUnicode_FromString(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":4
 * import yaml
 * 
 * def get_version_string():             # <<<<<<<<<<<<<<
 *     cdef const char *value
 *     value = yaml_get_version_string()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("yaml._yaml.get_version_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":9
 *     return PyUnicode_FromString(value)
 * 
 * def get_version():             # <<<<<<<<<<<<<<
 *     cdef int major, minor, patch
 *     yaml_get_version(&major, &minor, &patch)
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_3get_version(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_3get_version = {"get_version", (PyCFunction)__pyx_pw_4yaml_5_yaml_3get_version, METH_NOARGS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_3get_version(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_version (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_4yaml_5_yaml_2get_version(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_2get_version(CYTHON_UNUSED PyObject *__pyx_self) {
  int __pyx_v_major;
  int __pyx_v_minor;
  int __pyx_v_patch;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_version", 1);

  /* "yaml/_yaml.pyx":11
 * def get_version():
 *     cdef int major, minor, patch
 *     yaml_get_version(&major, &minor, &patch)             # <<<<<<<<<<<<<<
 *     return (major, minor, patch)
 * 
 */
  yaml_get_version((&__pyx_v_major), (&__pyx_v_minor), (&__pyx_v_patch));

  /* "yaml/_yaml.pyx":12
 *     cdef int major, minor, patch
 *     yaml_get_version(&major, &minor, &patch)
 *     return (major, minor, patch)             # <<<<<<<<<<<<<<
 * 
 * #Mark = yaml.error.Mark
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_major); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_minor); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_patch); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1)) __PYX_ERR(0, 12, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2)) __PYX_ERR(0, 12, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_3)) __PYX_ERR(0, 12, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":9
 *     return PyUnicode_FromString(value)
 * 
 * def get_version():             # <<<<<<<<<<<<<<
 *     cdef int major, minor, patch
 *     yaml_get_version(&major, &minor, &patch)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("yaml._yaml.get_version", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":69
 *     cdef readonly pointer
 * 
 *     def __init__(self, object name, size_t index, size_t line, size_t column,             # <<<<<<<<<<<<<<
 *             object buffer, object pointer):
 *         self.name = name
 */

/* Python wrapper */
static int __pyx_pw_4yaml_5_yaml_4Mark_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4yaml_5_yaml_4Mark_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  size_t __pyx_v_index;
  size_t __pyx_v_line;
  size_t __pyx_v_column;
  PyObject *__pyx_v_buffer = 0;
  PyObject *__pyx_v_pointer = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,&__pyx_n_s_index,&__pyx_n_s_line,&__pyx_n_s_column,&__pyx_n_s_buffer,&__pyx_n_s_pointer,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 69, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_index)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 69, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 6, 6, 1); __PYX_ERR(0, 69, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_line)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 69, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 6, 6, 2); __PYX_ERR(0, 69, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_column)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 69, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 6, 6, 3); __PYX_ERR(0, 69, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_buffer)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[4]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 69, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 6, 6, 4); __PYX_ERR(0, 69, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pointer)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[5]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 69, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 6, 6, 5); __PYX_ERR(0, 69, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 69, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 6)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
      values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
      values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
      values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
      values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
    }
    __pyx_v_name = values[0];
    __pyx_v_index = __Pyx_PyInt_As_size_t(values[1]); if (unlikely((__pyx_v_index == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 69, __pyx_L3_error)
    __pyx_v_line = __Pyx_PyInt_As_size_t(values[2]); if (unlikely((__pyx_v_line == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 69, __pyx_L3_error)
    __pyx_v_column = __Pyx_PyInt_As_size_t(values[3]); if (unlikely((__pyx_v_column == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 69, __pyx_L3_error)
    __pyx_v_buffer = values[4];
    __pyx_v_pointer = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 6, 6, __pyx_nargs); __PYX_ERR(0, 69, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("yaml._yaml.Mark.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4yaml_5_yaml_4Mark___init__(((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_v_self), __pyx_v_name, __pyx_v_index, __pyx_v_line, __pyx_v_column, __pyx_v_buffer, __pyx_v_pointer);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4yaml_5_yaml_4Mark___init__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self, PyObject *__pyx_v_name, size_t __pyx_v_index, size_t __pyx_v_line, size_t __pyx_v_column, PyObject *__pyx_v_buffer, PyObject *__pyx_v_pointer) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "yaml/_yaml.pyx":71
 *     def __init__(self, object name, size_t index, size_t line, size_t column,
 *             object buffer, object pointer):
 *         self.name = name             # <<<<<<<<<<<<<<
 *         self.index = index
 *         self.line = line
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_v_name;

  /* "yaml/_yaml.pyx":72
 *             object buffer, object pointer):
 *         self.name = name
 *         self.index = index             # <<<<<<<<<<<<<<
 *         self.line = line
 *         self.column = column
 */
  __pyx_v_self->index = __pyx_v_index;

  /* "yaml/_yaml.pyx":73
 *         self.name = name
 *         self.index = index
 *         self.line = line             # <<<<<<<<<<<<<<
 *         self.column = column
 *         self.buffer = buffer
 */
  __pyx_v_self->line = __pyx_v_line;

  /* "yaml/_yaml.pyx":74
 *         self.index = index
 *         self.line = line
 *         self.column = column             # <<<<<<<<<<<<<<
 *         self.buffer = buffer
 *         self.pointer = pointer
 */
  __pyx_v_self->column = __pyx_v_column;

  /* "yaml/_yaml.pyx":75
 *         self.line = line
 *         self.column = column
 *         self.buffer = buffer             # <<<<<<<<<<<<<<
 *         self.pointer = pointer
 * 
 */
  __Pyx_INCREF(__pyx_v_buffer);
  __Pyx_GIVEREF(__pyx_v_buffer);
  __Pyx_GOTREF(__pyx_v_self->buffer);
  __Pyx_DECREF(__pyx_v_self->buffer);
  __pyx_v_self->buffer = __pyx_v_buffer;

  /* "yaml/_yaml.pyx":76
 *         self.column = column
 *         self.buffer = buffer
 *         self.pointer = pointer             # <<<<<<<<<<<<<<
 * 
 *     def get_snippet(self):
 */
  __Pyx_INCREF(__pyx_v_pointer);
  __Pyx_GIVEREF(__pyx_v_pointer);
  __Pyx_GOTREF(__pyx_v_self->pointer);
  __Pyx_DECREF(__pyx_v_self->pointer);
  __pyx_v_self->pointer = __pyx_v_pointer;

  /* "yaml/_yaml.pyx":69
 *     cdef readonly pointer
 * 
 *     def __init__(self, object name, size_t index, size_t line, size_t column,             # <<<<<<<<<<<<<<
 *             object buffer, object pointer):
 *         self.name = name
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":78
 *         self.pointer = pointer
 * 
 *     def get_snippet(self):             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_3get_snippet(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_4Mark_3get_snippet = {"get_snippet", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_4Mark_3get_snippet, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_3get_snippet(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_snippet (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_snippet", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_snippet", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_4Mark_2get_snippet(((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_2get_snippet(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_snippet", 1);

  /* "yaml/_yaml.pyx":79
 * 
 *     def get_snippet(self):
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":78
 *         self.pointer = pointer
 * 
 *     def get_snippet(self):             # <<<<<<<<<<<<<<
 *         return None
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":81
 *         return None
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         where = "  in \"%s\", line %d, column %d"   \
 *                 % (self.name, self.line+1, self.column+1)
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_5__str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_5__str__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_4yaml_5_yaml_4Mark_4__str__(((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_4__str__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self) {
  PyObject *__pyx_v_where = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "yaml/_yaml.pyx":83
 *     def __str__(self):
 *         where = "  in \"%s\", line %d, column %d"   \
 *                 % (self.name, self.line+1, self.column+1)             # <<<<<<<<<<<<<<
 *         return where
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->line + 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_FromSize_t((__pyx_v_self->column + 1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_self->name);
  __Pyx_GIVEREF(__pyx_v_self->name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_self->name)) __PYX_ERR(0, 83, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(0, 83, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2)) __PYX_ERR(0, 83, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_in_s_line_d_column_d, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_where = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":84
 *         where = "  in \"%s\", line %d, column %d"   \
 *                 % (self.name, self.line+1, self.column+1)
 *         return where             # <<<<<<<<<<<<<<
 * 
 * #class YAMLError(Exception):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_where);
  __pyx_r = __pyx_v_where;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":81
 *         return None
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         where = "  in \"%s\", line %d, column %d"   \
 *                 % (self.name, self.line+1, self.column+1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("yaml._yaml.Mark.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_where);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":62
 * 
 * cdef class Mark:
 *     cdef readonly object name             # <<<<<<<<<<<<<<
 *     cdef readonly size_t index
 *     cdef readonly size_t line
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_4name_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_4name_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_4yaml_5_yaml_4Mark_4name___get__(((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_4name___get__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":63
 * cdef class Mark:
 *     cdef readonly object name
 *     cdef readonly size_t index             # <<<<<<<<<<<<<<
 *     cdef readonly size_t line
 *     cdef readonly size_t column
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_5index_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_5index_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_4yaml_5_yaml_4Mark_5index___get__(((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_5index___get__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("yaml._yaml.Mark.index.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":64
 *     cdef readonly object name
 *     cdef readonly size_t index
 *     cdef readonly size_t line             # <<<<<<<<<<<<<<
 *     cdef readonly size_t column
 *     cdef readonly buffer
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_4line_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_4line_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_4yaml_5_yaml_4Mark_4line___get__(((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_4line___get__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->line); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("yaml._yaml.Mark.line.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":65
 *     cdef readonly size_t index
 *     cdef readonly size_t line
 *     cdef readonly size_t column             # <<<<<<<<<<<<<<
 *     cdef readonly buffer
 *     cdef readonly pointer
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_6column_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_6column_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_4yaml_5_yaml_4Mark_6column___get__(((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_6column___get__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("yaml._yaml.Mark.column.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":66
 *     cdef readonly size_t line
 *     cdef readonly size_t column
 *     cdef readonly buffer             # <<<<<<<<<<<<<<
 *     cdef readonly pointer
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_6buffer_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_6buffer_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_4yaml_5_yaml_4Mark_6buffer___get__(((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_6buffer___get__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->buffer);
  __pyx_r = __pyx_v_self->buffer;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":67
 *     cdef readonly size_t column
 *     cdef readonly buffer
 *     cdef readonly pointer             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, object name, size_t index, size_t line, size_t column,
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_7pointer_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_7pointer_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_4yaml_5_yaml_4Mark_7pointer___get__(((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_7pointer___get__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->pointer);
  __pyx_r = __pyx_v_self->pointer;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_4Mark_7__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_4Mark_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_4Mark_6__reduce_cython__(((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_6__reduce_cython__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.buffer, self.column, self.index, self.line, self.name, self.pointer)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->column); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_self->index); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_self->line); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(6); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self->buffer);
  __Pyx_GIVEREF(__pyx_v_self->buffer);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self->buffer)) __PYX_ERR(1, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->name);
  __Pyx_GIVEREF(__pyx_v_self->name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_v_self->name)) __PYX_ERR(1, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->pointer);
  __Pyx_GIVEREF(__pyx_v_self->pointer);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 5, __pyx_v_self->pointer)) __PYX_ERR(1, 5, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.buffer, self.column, self.index, self.line, self.name, self.pointer)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_4 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v__dict = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "(tree fragment)":7
 *     state = (self.buffer, self.column, self.index, self.line, self.name, self.pointer)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_5 = (__pyx_v__dict != Py_None);
  if (__pyx_t_5) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v__dict)) __PYX_ERR(1, 8, __pyx_L1_error);
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.buffer is not None or self.name is not None or self.pointer is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.buffer, self.column, self.index, self.line, self.name, self.pointer)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.buffer is not None or self.name is not None or self.pointer is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_Mark, (type(self), 0x27a7a5c, None), state
 */
  /*else*/ {
    __pyx_t_6 = (__pyx_v_self->buffer != Py_None);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_self->name != Py_None);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_self->pointer != Py_None);
    __pyx_t_5 = __pyx_t_6;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_5;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.buffer is not None or self.name is not None or self.pointer is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Mark, (type(self), 0x27a7a5c, None), state
 *     else:
 */
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.buffer is not None or self.name is not None or self.pointer is not None
 *     if use_setstate:
 *         return __pyx_unpickle_Mark, (type(self), 0x27a7a5c, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_Mark, (type(self), 0x27a7a5c, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyx_unpickle_Mark); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_41581148);
    __Pyx_GIVEREF(__pyx_int_41581148);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_int_41581148)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, Py_None)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_state)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.buffer is not None or self.name is not None or self.pointer is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Mark, (type(self), 0x27a7a5c, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_Mark, (type(self), 0x27a7a5c, None), state
 *     else:
 *         return __pyx_unpickle_Mark, (type(self), 0x27a7a5c, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Mark__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pyx_unpickle_Mark); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_41581148);
    __Pyx_GIVEREF(__pyx_int_41581148);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_int_41581148)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_state)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("yaml._yaml.Mark.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Mark, (type(self), 0x27a7a5c, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Mark__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_4Mark_9__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_4Mark_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_4Mark_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 16, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 16, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 16, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("yaml._yaml.Mark.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4yaml_5_yaml_4Mark_8__setstate_cython__(((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_4Mark_8__setstate_cython__(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_Mark, (type(self), 0x27a7a5c, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Mark__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_4yaml_5_yaml___pyx_unpickle_Mark__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Mark, (type(self), 0x27a7a5c, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Mark__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("yaml._yaml.Mark.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":259
 *     cdef int unicode_source
 * 
 *     def __init__(self, stream):             # <<<<<<<<<<<<<<
 *         cdef is_readable
 *         if yaml_parser_initialize(&self.parser) == 0:
 */

/* Python wrapper */
static int __pyx_pw_4yaml_5_yaml_7CParser_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4yaml_5_yaml_7CParser_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_stream = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_stream,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_stream)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 259, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 259, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_stream = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 259, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("yaml._yaml.CParser.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser___init__(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self), __pyx_v_stream);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4yaml_5_yaml_7CParser___init__(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_stream) {
  PyObject *__pyx_v_is_readable = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_stream);

  /* "yaml/_yaml.pyx":261
 *     def __init__(self, stream):
 *         cdef is_readable
 *         if yaml_parser_initialize(&self.parser) == 0:             # <<<<<<<<<<<<<<
 *             raise MemoryError
 *         self.parsed_event.type = YAML_NO_EVENT
 */
  __pyx_t_1 = (yaml_parser_initialize((&__pyx_v_self->parser)) == 0);
  if (unlikely(__pyx_t_1)) {

    /* "yaml/_yaml.pyx":262
 *         cdef is_readable
 *         if yaml_parser_initialize(&self.parser) == 0:
 *             raise MemoryError             # <<<<<<<<<<<<<<
 *         self.parsed_event.type = YAML_NO_EVENT
 *         is_readable = 1
 */
    PyErr_NoMemory(); __PYX_ERR(0, 262, __pyx_L1_error)

    /* "yaml/_yaml.pyx":261
 *     def __init__(self, stream):
 *         cdef is_readable
 *         if yaml_parser_initialize(&self.parser) == 0:             # <<<<<<<<<<<<<<
 *             raise MemoryError
 *         self.parsed_event.type = YAML_NO_EVENT
 */
  }

  /* "yaml/_yaml.pyx":263
 *         if yaml_parser_initialize(&self.parser) == 0:
 *             raise MemoryError
 *         self.parsed_event.type = YAML_NO_EVENT             # <<<<<<<<<<<<<<
 *         is_readable = 1
 *         try:
 */
  __pyx_v_self->parsed_event.type = YAML_NO_EVENT;

  /* "yaml/_yaml.pyx":264
 *             raise MemoryError
 *         self.parsed_event.type = YAML_NO_EVENT
 *         is_readable = 1             # <<<<<<<<<<<<<<
 *         try:
 *             stream.read
 */
  __Pyx_INCREF(__pyx_int_1);
  __pyx_v_is_readable = __pyx_int_1;

  /* "yaml/_yaml.pyx":265
 *         self.parsed_event.type = YAML_NO_EVENT
 *         is_readable = 1
 *         try:             # <<<<<<<<<<<<<<
 *             stream.read
 *         except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "yaml/_yaml.pyx":266
 *         is_readable = 1
 *         try:
 *             stream.read             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             is_readable = 0
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_stream, __pyx_n_s_read); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 266, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "yaml/_yaml.pyx":265
 *         self.parsed_event.type = YAML_NO_EVENT
 *         is_readable = 1
 *         try:             # <<<<<<<<<<<<<<
 *             stream.read
 *         except AttributeError:
 */
    }
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "yaml/_yaml.pyx":267
 *         try:
 *             stream.read
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             is_readable = 0
 *         self.unicode_source = 0
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("yaml._yaml.CParser.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(0, 267, __pyx_L6_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);

      /* "yaml/_yaml.pyx":268
 *             stream.read
 *         except AttributeError:
 *             is_readable = 0             # <<<<<<<<<<<<<<
 *         self.unicode_source = 0
 *         if is_readable:
 */
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_DECREF_SET(__pyx_v_is_readable, __pyx_int_0);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L5_exception_handled;
    }
    goto __pyx_L6_except_error;

    /* "yaml/_yaml.pyx":265
 *         self.parsed_event.type = YAML_NO_EVENT
 *         is_readable = 1
 *         try:             # <<<<<<<<<<<<<<
 *             stream.read
 *         except AttributeError:
 */
    __pyx_L6_except_error:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    __pyx_L9_try_end:;
  }

  /* "yaml/_yaml.pyx":269
 *         except AttributeError:
 *             is_readable = 0
 *         self.unicode_source = 0             # <<<<<<<<<<<<<<
 *         if is_readable:
 *             self.stream = stream
 */
  __pyx_v_self->unicode_source = 0;

  /* "yaml/_yaml.pyx":270
 *             is_readable = 0
 *         self.unicode_source = 0
 *         if is_readable:             # <<<<<<<<<<<<<<
 *             self.stream = stream
 *             try:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_is_readable); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 270, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":271
 *         self.unicode_source = 0
 *         if is_readable:
 *             self.stream = stream             # <<<<<<<<<<<<<<
 *             try:
 *                 self.stream_name = stream.name
 */
    __Pyx_INCREF(__pyx_v_stream);
    __Pyx_GIVEREF(__pyx_v_stream);
    __Pyx_GOTREF(__pyx_v_self->stream);
    __Pyx_DECREF(__pyx_v_self->stream);
    __pyx_v_self->stream = __pyx_v_stream;

    /* "yaml/_yaml.pyx":272
 *         if is_readable:
 *             self.stream = stream
 *             try:             # <<<<<<<<<<<<<<
 *                 self.stream_name = stream.name
 *             except AttributeError:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_3, &__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_2);
      /*try:*/ {

        /* "yaml/_yaml.pyx":273
 *             self.stream = stream
 *             try:
 *                 self.stream_name = stream.name             # <<<<<<<<<<<<<<
 *             except AttributeError:
 *                 self.stream_name = u'<file>'
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_stream, __pyx_n_s_name); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 273, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_v_self->stream_name);
        __Pyx_DECREF(__pyx_v_self->stream_name);
        __pyx_v_self->stream_name = __pyx_t_8;
        __pyx_t_8 = 0;

        /* "yaml/_yaml.pyx":272
 *         if is_readable:
 *             self.stream = stream
 *             try:             # <<<<<<<<<<<<<<
 *                 self.stream_name = stream.name
 *             except AttributeError:
 */
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L18_try_end;
      __pyx_L13_error:;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "yaml/_yaml.pyx":274
 *             try:
 *                 self.stream_name = stream.name
 *             except AttributeError:             # <<<<<<<<<<<<<<
 *                 self.stream_name = u'<file>'
 *             self.stream_cache = None
 */
      __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
      if (__pyx_t_6) {
        __Pyx_AddTraceback("yaml._yaml.CParser.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 274, __pyx_L15_except_error)
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_5);

        /* "yaml/_yaml.pyx":275
 *                 self.stream_name = stream.name
 *             except AttributeError:
 *                 self.stream_name = u'<file>'             # <<<<<<<<<<<<<<
 *             self.stream_cache = None
 *             self.stream_cache_len = 0
 */
        __Pyx_INCREF(__pyx_kp_u_file);
        __Pyx_GIVEREF(__pyx_kp_u_file);
        __Pyx_GOTREF(__pyx_v_self->stream_name);
        __Pyx_DECREF(__pyx_v_self->stream_name);
        __pyx_v_self->stream_name = __pyx_kp_u_file;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L14_exception_handled;
      }
      goto __pyx_L15_except_error;

      /* "yaml/_yaml.pyx":272
 *         if is_readable:
 *             self.stream = stream
 *             try:             # <<<<<<<<<<<<<<
 *                 self.stream_name = stream.name
 *             except AttributeError:
 */
      __pyx_L15_except_error:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_3, __pyx_t_2);
      goto __pyx_L1_error;
      __pyx_L14_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_3, __pyx_t_2);
      __pyx_L18_try_end:;
    }

    /* "yaml/_yaml.pyx":276
 *             except AttributeError:
 *                 self.stream_name = u'<file>'
 *             self.stream_cache = None             # <<<<<<<<<<<<<<
 *             self.stream_cache_len = 0
 *             self.stream_cache_pos = 0
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->stream_cache);
    __Pyx_DECREF(__pyx_v_self->stream_cache);
    __pyx_v_self->stream_cache = Py_None;

    /* "yaml/_yaml.pyx":277
 *                 self.stream_name = u'<file>'
 *             self.stream_cache = None
 *             self.stream_cache_len = 0             # <<<<<<<<<<<<<<
 *             self.stream_cache_pos = 0
 *             yaml_parser_set_input(&self.parser, input_handler, <void *>self)
 */
    __pyx_v_self->stream_cache_len = 0;

    /* "yaml/_yaml.pyx":278
 *             self.stream_cache = None
 *             self.stream_cache_len = 0
 *             self.stream_cache_pos = 0             # <<<<<<<<<<<<<<
 *             yaml_parser_set_input(&self.parser, input_handler, <void *>self)
 *         else:
 */
    __pyx_v_self->stream_cache_pos = 0;

    /* "yaml/_yaml.pyx":279
 *             self.stream_cache_len = 0
 *             self.stream_cache_pos = 0
 *             yaml_parser_set_input(&self.parser, input_handler, <void *>self)             # <<<<<<<<<<<<<<
 *         else:
 *             if PyUnicode_CheckExact(stream) != 0:
 */
    yaml_parser_set_input((&__pyx_v_self->parser), __pyx_f_4yaml_5_yaml_input_handler, ((void *)__pyx_v_self));

    /* "yaml/_yaml.pyx":270
 *             is_readable = 0
 *         self.unicode_source = 0
 *         if is_readable:             # <<<<<<<<<<<<<<
 *             self.stream = stream
 *             try:
 */
    goto __pyx_L12;
  }

  /* "yaml/_yaml.pyx":281
 *             yaml_parser_set_input(&self.parser, input_handler, <void *>self)
 *         else:
 *             if PyUnicode_CheckExact(stream) != 0:             # <<<<<<<<<<<<<<
 *                 stream = PyUnicode_AsUTF8String(stream)
 *                 self.stream_name = u'<unicode string>'
 */
  /*else*/ {
    __pyx_t_1 = (PyUnicode_CheckExact(__pyx_v_stream) != 0);
    if (__pyx_t_1) {

      /* "yaml/_yaml.pyx":282
 *         else:
 *             if PyUnicode_CheckExact(stream) != 0:
 *                 stream = PyUnicode_AsUTF8String(stream)             # <<<<<<<<<<<<<<
 *                 self.stream_name = u'<unicode string>'
 *                 self.unicode_source = 1
 */
      __pyx_t_5 = PyUnicode_AsUTF8String(__pyx_v_stream); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 282, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_stream, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "yaml/_yaml.pyx":283
 *             if PyUnicode_CheckExact(stream) != 0:
 *                 stream = PyUnicode_AsUTF8String(stream)
 *                 self.stream_name = u'<unicode string>'             # <<<<<<<<<<<<<<
 *                 self.unicode_source = 1
 *             else:
 */
      __Pyx_INCREF(__pyx_kp_u_unicode_string);
      __Pyx_GIVEREF(__pyx_kp_u_unicode_string);
      __Pyx_GOTREF(__pyx_v_self->stream_name);
      __Pyx_DECREF(__pyx_v_self->stream_name);
      __pyx_v_self->stream_name = __pyx_kp_u_unicode_string;

      /* "yaml/_yaml.pyx":284
 *                 stream = PyUnicode_AsUTF8String(stream)
 *                 self.stream_name = u'<unicode string>'
 *                 self.unicode_source = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 self.stream_name = u'<byte string>'
 */
      __pyx_v_self->unicode_source = 1;

      /* "yaml/_yaml.pyx":281
 *             yaml_parser_set_input(&self.parser, input_handler, <void *>self)
 *         else:
 *             if PyUnicode_CheckExact(stream) != 0:             # <<<<<<<<<<<<<<
 *                 stream = PyUnicode_AsUTF8String(stream)
 *                 self.stream_name = u'<unicode string>'
 */
      goto __pyx_L21;
    }

    /* "yaml/_yaml.pyx":286
 *                 self.unicode_source = 1
 *             else:
 *                 self.stream_name = u'<byte string>'             # <<<<<<<<<<<<<<
 *             if PyBytes_CheckExact(stream) == 0:
 *                 raise TypeError(u"a string or stream input is required")
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_kp_u_byte_string);
      __Pyx_GIVEREF(__pyx_kp_u_byte_string);
      __Pyx_GOTREF(__pyx_v_self->stream_name);
      __Pyx_DECREF(__pyx_v_self->stream_name);
      __pyx_v_self->stream_name = __pyx_kp_u_byte_string;
    }
    __pyx_L21:;

    /* "yaml/_yaml.pyx":287
 *             else:
 *                 self.stream_name = u'<byte string>'
 *             if PyBytes_CheckExact(stream) == 0:             # <<<<<<<<<<<<<<
 *                 raise TypeError(u"a string or stream input is required")
 *             self.stream = stream
 */
    __pyx_t_1 = (PyBytes_CheckExact(__pyx_v_stream) == 0);
    if (unlikely(__pyx_t_1)) {

      /* "yaml/_yaml.pyx":288
 *                 self.stream_name = u'<byte string>'
 *             if PyBytes_CheckExact(stream) == 0:
 *                 raise TypeError(u"a string or stream input is required")             # <<<<<<<<<<<<<<
 *             self.stream = stream
 *             yaml_parser_set_input_string(&self.parser, PyBytes_AS_Yaml_STRING(stream), PyBytes_GET_SIZE(stream))
 */
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 288, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(0, 288, __pyx_L1_error)

      /* "yaml/_yaml.pyx":287
 *             else:
 *                 self.stream_name = u'<byte string>'
 *             if PyBytes_CheckExact(stream) == 0:             # <<<<<<<<<<<<<<
 *                 raise TypeError(u"a string or stream input is required")
 *             self.stream = stream
 */
    }

    /* "yaml/_yaml.pyx":289
 *             if PyBytes_CheckExact(stream) == 0:
 *                 raise TypeError(u"a string or stream input is required")
 *             self.stream = stream             # <<<<<<<<<<<<<<
 *             yaml_parser_set_input_string(&self.parser, PyBytes_AS_Yaml_STRING(stream), PyBytes_GET_SIZE(stream))
 *         self.current_token = None
 */
    __Pyx_INCREF(__pyx_v_stream);
    __Pyx_GIVEREF(__pyx_v_stream);
    __Pyx_GOTREF(__pyx_v_self->stream);
    __Pyx_DECREF(__pyx_v_self->stream);
    __pyx_v_self->stream = __pyx_v_stream;

    /* "yaml/_yaml.pyx":290
 *                 raise TypeError(u"a string or stream input is required")
 *             self.stream = stream
 *             yaml_parser_set_input_string(&self.parser, PyBytes_AS_Yaml_STRING(stream), PyBytes_GET_SIZE(stream))             # <<<<<<<<<<<<<<
 *         self.current_token = None
 *         self.current_event = None
 */
    yaml_parser_set_input_string((&__pyx_v_self->parser), PyBytes_AS_Yaml_STRING(__pyx_v_stream), PyBytes_GET_SIZE(__pyx_v_stream));
  }
  __pyx_L12:;

  /* "yaml/_yaml.pyx":291
 *             self.stream = stream
 *             yaml_parser_set_input_string(&self.parser, PyBytes_AS_Yaml_STRING(stream), PyBytes_GET_SIZE(stream))
 *         self.current_token = None             # <<<<<<<<<<<<<<
 *         self.current_event = None
 *         self.anchors = {}
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->current_token);
  __Pyx_DECREF(__pyx_v_self->current_token);
  __pyx_v_self->current_token = Py_None;

  /* "yaml/_yaml.pyx":292
 *             yaml_parser_set_input_string(&self.parser, PyBytes_AS_Yaml_STRING(stream), PyBytes_GET_SIZE(stream))
 *         self.current_token = None
 *         self.current_event = None             # <<<<<<<<<<<<<<
 *         self.anchors = {}
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->current_event);
  __Pyx_DECREF(__pyx_v_self->current_event);
  __pyx_v_self->current_event = Py_None;

  /* "yaml/_yaml.pyx":293
 *         self.current_token = None
 *         self.current_event = None
 *         self.anchors = {}             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->anchors);
  __Pyx_DECREF(__pyx_v_self->anchors);
  __pyx_v_self->anchors = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "yaml/_yaml.pyx":259
 *     cdef int unicode_source
 * 
 *     def __init__(self, stream):             # <<<<<<<<<<<<<<
 *         cdef is_readable
 *         if yaml_parser_initialize(&self.parser) == 0:
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("yaml._yaml.CParser.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_is_readable);
  __Pyx_XDECREF(__pyx_v_stream);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":295
 *         self.anchors = {}
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         yaml_parser_delete(&self.parser)
 *         yaml_event_delete(&self.parsed_event)
 */

/* Python wrapper */
static void __pyx_pw_4yaml_5_yaml_7CParser_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_4yaml_5_yaml_7CParser_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_4yaml_5_yaml_7CParser_2__dealloc__(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_4yaml_5_yaml_7CParser_2__dealloc__(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {

  /* "yaml/_yaml.pyx":296
 * 
 *     def __dealloc__(self):
 *         yaml_parser_delete(&self.parser)             # <<<<<<<<<<<<<<
 *         yaml_event_delete(&self.parsed_event)
 * 
 */
  yaml_parser_delete((&__pyx_v_self->parser));

  /* "yaml/_yaml.pyx":297
 *     def __dealloc__(self):
 *         yaml_parser_delete(&self.parser)
 *         yaml_event_delete(&self.parsed_event)             # <<<<<<<<<<<<<<
 * 
 *     def dispose(self):
 */
  yaml_event_delete((&__pyx_v_self->parsed_event));

  /* "yaml/_yaml.pyx":295
 *         self.anchors = {}
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         yaml_parser_delete(&self.parser)
 *         yaml_event_delete(&self.parsed_event)
 */

  /* function exit code */
}

/* "yaml/_yaml.pyx":299
 *         yaml_event_delete(&self.parsed_event)
 * 
 *     def dispose(self):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_5dispose(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_5dispose = {"dispose", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_5dispose, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_5dispose(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dispose (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("dispose", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dispose", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_4dispose(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_4dispose(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dispose", 1);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":302
 *         pass
 * 
 *     cdef object _parser_error(self):             # <<<<<<<<<<<<<<
 *         if self.parser.error == YAML_MEMORY_ERROR:
 *             return MemoryError
 */

static PyObject *__pyx_f_4yaml_5_yaml_7CParser__parser_error(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_context_mark = NULL;
  struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_problem_mark = NULL;
  PyObject *__pyx_v_context = NULL;
  PyObject *__pyx_v_problem = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_parser_error", 1);

  /* "yaml/_yaml.pyx":303
 * 
 *     cdef object _parser_error(self):
 *         if self.parser.error == YAML_MEMORY_ERROR:             # <<<<<<<<<<<<<<
 *             return MemoryError
 *         elif self.parser.error == YAML_READER_ERROR:
 */
  switch (__pyx_v_self->parser.error) {
    case YAML_MEMORY_ERROR:

    /* "yaml/_yaml.pyx":304
 *     cdef object _parser_error(self):
 *         if self.parser.error == YAML_MEMORY_ERROR:
 *             return MemoryError             # <<<<<<<<<<<<<<
 *         elif self.parser.error == YAML_READER_ERROR:
 *             return ReaderError(self.stream_name, self.parser.problem_offset,
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_builtin_MemoryError);
    __pyx_r = __pyx_builtin_MemoryError;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":303
 * 
 *     cdef object _parser_error(self):
 *         if self.parser.error == YAML_MEMORY_ERROR:             # <<<<<<<<<<<<<<
 *             return MemoryError
 *         elif self.parser.error == YAML_READER_ERROR:
 */
    break;
    case YAML_READER_ERROR:

    /* "yaml/_yaml.pyx":306
 *             return MemoryError
 *         elif self.parser.error == YAML_READER_ERROR:
 *             return ReaderError(self.stream_name, self.parser.problem_offset,             # <<<<<<<<<<<<<<
 *                     self.parser.problem_value, u'?', PyUnicode_FromString(self.parser.problem))
 *         elif self.parser.error == YAML_SCANNER_ERROR    \
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_ReaderError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parser.problem_offset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "yaml/_yaml.pyx":307
 *         elif self.parser.error == YAML_READER_ERROR:
 *             return ReaderError(self.stream_name, self.parser.problem_offset,
 *                     self.parser.problem_value, u'?', PyUnicode_FromString(self.parser.problem))             # <<<<<<<<<<<<<<
 *         elif self.parser.error == YAML_SCANNER_ERROR    \
 *                 or self.parser.error == YAML_PARSER_ERROR:
 */
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->parser.problem_value); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyUnicode_FromString(__pyx_v_self->parser.problem); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[6] = {__pyx_t_6, __pyx_v_self->stream_name, __pyx_t_3, __pyx_t_4, __pyx_kp_u__2, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_7, 5+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 306, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":305
 *         if self.parser.error == YAML_MEMORY_ERROR:
 *             return MemoryError
 *         elif self.parser.error == YAML_READER_ERROR:             # <<<<<<<<<<<<<<
 *             return ReaderError(self.stream_name, self.parser.problem_offset,
 *                     self.parser.problem_value, u'?', PyUnicode_FromString(self.parser.problem))
 */
    break;
    case YAML_SCANNER_ERROR:

    /* "yaml/_yaml.pyx":308
 *             return ReaderError(self.stream_name, self.parser.problem_offset,
 *                     self.parser.problem_value, u'?', PyUnicode_FromString(self.parser.problem))
 *         elif self.parser.error == YAML_SCANNER_ERROR    \             # <<<<<<<<<<<<<<
 *                 or self.parser.error == YAML_PARSER_ERROR:
 *             context_mark = None
 */
    case YAML_PARSER_ERROR:

    /* "yaml/_yaml.pyx":310
 *         elif self.parser.error == YAML_SCANNER_ERROR    \
 *                 or self.parser.error == YAML_PARSER_ERROR:
 *             context_mark = None             # <<<<<<<<<<<<<<
 *             problem_mark = None
 *             if self.parser.context != NULL:
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_context_mark = ((struct __pyx_obj_4yaml_5_yaml_Mark *)Py_None);

    /* "yaml/_yaml.pyx":311
 *                 or self.parser.error == YAML_PARSER_ERROR:
 *             context_mark = None
 *             problem_mark = None             # <<<<<<<<<<<<<<
 *             if self.parser.context != NULL:
 *                 context_mark = Mark(self.stream_name,
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_problem_mark = ((struct __pyx_obj_4yaml_5_yaml_Mark *)Py_None);

    /* "yaml/_yaml.pyx":312
 *             context_mark = None
 *             problem_mark = None
 *             if self.parser.context != NULL:             # <<<<<<<<<<<<<<
 *                 context_mark = Mark(self.stream_name,
 *                         self.parser.context_mark.index,
 */
    __pyx_t_8 = (__pyx_v_self->parser.context != NULL);
    if (__pyx_t_8) {

      /* "yaml/_yaml.pyx":314
 *             if self.parser.context != NULL:
 *                 context_mark = Mark(self.stream_name,
 *                         self.parser.context_mark.index,             # <<<<<<<<<<<<<<
 *                         self.parser.context_mark.line,
 *                         self.parser.context_mark.column, None, None)
 */
      __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parser.context_mark.index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 314, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);

      /* "yaml/_yaml.pyx":315
 *                 context_mark = Mark(self.stream_name,
 *                         self.parser.context_mark.index,
 *                         self.parser.context_mark.line,             # <<<<<<<<<<<<<<
 *                         self.parser.context_mark.column, None, None)
 *             if self.parser.problem != NULL:
 */
      __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parser.context_mark.line); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 315, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "yaml/_yaml.pyx":316
 *                         self.parser.context_mark.index,
 *                         self.parser.context_mark.line,
 *                         self.parser.context_mark.column, None, None)             # <<<<<<<<<<<<<<
 *             if self.parser.problem != NULL:
 *                 problem_mark = Mark(self.stream_name,
 */
      __pyx_t_5 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parser.context_mark.column); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 316, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);

      /* "yaml/_yaml.pyx":313
 *             problem_mark = None
 *             if self.parser.context != NULL:
 *                 context_mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                         self.parser.context_mark.index,
 *                         self.parser.context_mark.line,
 */
      __pyx_t_4 = PyTuple_New(6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 313, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_self->stream_name);
      __Pyx_GIVEREF(__pyx_v_self->stream_name);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 313, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(0, 313, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_2);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_2)) __PYX_ERR(0, 313, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_5)) __PYX_ERR(0, 313, __pyx_L1_error);
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 4, Py_None)) __PYX_ERR(0, 313, __pyx_L1_error);
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 5, Py_None)) __PYX_ERR(0, 313, __pyx_L1_error);
      __pyx_t_1 = 0;
      __pyx_t_2 = 0;
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 313, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_context_mark, ((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_t_5));
      __pyx_t_5 = 0;

      /* "yaml/_yaml.pyx":312
 *             context_mark = None
 *             problem_mark = None
 *             if self.parser.context != NULL:             # <<<<<<<<<<<<<<
 *                 context_mark = Mark(self.stream_name,
 *                         self.parser.context_mark.index,
 */
    }

    /* "yaml/_yaml.pyx":317
 *                         self.parser.context_mark.line,
 *                         self.parser.context_mark.column, None, None)
 *             if self.parser.problem != NULL:             # <<<<<<<<<<<<<<
 *                 problem_mark = Mark(self.stream_name,
 *                         self.parser.problem_mark.index,
 */
    __pyx_t_8 = (__pyx_v_self->parser.problem != NULL);
    if (__pyx_t_8) {

      /* "yaml/_yaml.pyx":319
 *             if self.parser.problem != NULL:
 *                 problem_mark = Mark(self.stream_name,
 *                         self.parser.problem_mark.index,             # <<<<<<<<<<<<<<
 *                         self.parser.problem_mark.line,
 *                         self.parser.problem_mark.column, None, None)
 */
      __pyx_t_5 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parser.problem_mark.index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 319, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);

      /* "yaml/_yaml.pyx":320
 *                 problem_mark = Mark(self.stream_name,
 *                         self.parser.problem_mark.index,
 *                         self.parser.problem_mark.line,             # <<<<<<<<<<<<<<
 *                         self.parser.problem_mark.column, None, None)
 *             context = None
 */
      __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parser.problem_mark.line); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 320, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "yaml/_yaml.pyx":321
 *                         self.parser.problem_mark.index,
 *                         self.parser.problem_mark.line,
 *                         self.parser.problem_mark.column, None, None)             # <<<<<<<<<<<<<<
 *             context = None
 *             if self.parser.context != NULL:
 */
      __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parser.problem_mark.column); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "yaml/_yaml.pyx":318
 *                         self.parser.context_mark.column, None, None)
 *             if self.parser.problem != NULL:
 *                 problem_mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                         self.parser.problem_mark.index,
 *                         self.parser.problem_mark.line,
 */
      __pyx_t_1 = PyTuple_New(6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_self->stream_name);
      __Pyx_GIVEREF(__pyx_v_self->stream_name);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 318, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5)) __PYX_ERR(0, 318, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_4)) __PYX_ERR(0, 318, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_2);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_2)) __PYX_ERR(0, 318, __pyx_L1_error);
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 4, Py_None)) __PYX_ERR(0, 318, __pyx_L1_error);
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 5, Py_None)) __PYX_ERR(0, 318, __pyx_L1_error);
      __pyx_t_5 = 0;
      __pyx_t_4 = 0;
      __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_problem_mark, ((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "yaml/_yaml.pyx":317
 *                         self.parser.context_mark.line,
 *                         self.parser.context_mark.column, None, None)
 *             if self.parser.problem != NULL:             # <<<<<<<<<<<<<<
 *                 problem_mark = Mark(self.stream_name,
 *                         self.parser.problem_mark.index,
 */
    }

    /* "yaml/_yaml.pyx":322
 *                         self.parser.problem_mark.line,
 *                         self.parser.problem_mark.column, None, None)
 *             context = None             # <<<<<<<<<<<<<<
 *             if self.parser.context != NULL:
 *                 context = PyUnicode_FromString(self.parser.context)
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_context = Py_None;

    /* "yaml/_yaml.pyx":323
 *                         self.parser.problem_mark.column, None, None)
 *             context = None
 *             if self.parser.context != NULL:             # <<<<<<<<<<<<<<
 *                 context = PyUnicode_FromString(self.parser.context)
 *             problem = PyUnicode_FromString(self.parser.problem)
 */
    __pyx_t_8 = (__pyx_v_self->parser.context != NULL);
    if (__pyx_t_8) {

      /* "yaml/_yaml.pyx":324
 *             context = None
 *             if self.parser.context != NULL:
 *                 context = PyUnicode_FromString(self.parser.context)             # <<<<<<<<<<<<<<
 *             problem = PyUnicode_FromString(self.parser.problem)
 *             if self.parser.error == YAML_SCANNER_ERROR:
 */
      __pyx_t_2 = PyUnicode_FromString(__pyx_v_self->parser.context); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 324, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_context, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "yaml/_yaml.pyx":323
 *                         self.parser.problem_mark.column, None, None)
 *             context = None
 *             if self.parser.context != NULL:             # <<<<<<<<<<<<<<
 *                 context = PyUnicode_FromString(self.parser.context)
 *             problem = PyUnicode_FromString(self.parser.problem)
 */
    }

    /* "yaml/_yaml.pyx":325
 *             if self.parser.context != NULL:
 *                 context = PyUnicode_FromString(self.parser.context)
 *             problem = PyUnicode_FromString(self.parser.problem)             # <<<<<<<<<<<<<<
 *             if self.parser.error == YAML_SCANNER_ERROR:
 *                 return ScannerError(context, context_mark, problem, problem_mark)
 */
    __pyx_t_2 = PyUnicode_FromString(__pyx_v_self->parser.problem); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_problem = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":326
 *                 context = PyUnicode_FromString(self.parser.context)
 *             problem = PyUnicode_FromString(self.parser.problem)
 *             if self.parser.error == YAML_SCANNER_ERROR:             # <<<<<<<<<<<<<<
 *                 return ScannerError(context, context_mark, problem, problem_mark)
 *             else:
 */
    __pyx_t_8 = (__pyx_v_self->parser.error == YAML_SCANNER_ERROR);
    if (__pyx_t_8) {

      /* "yaml/_yaml.pyx":327
 *             problem = PyUnicode_FromString(self.parser.problem)
 *             if self.parser.error == YAML_SCANNER_ERROR:
 *                 return ScannerError(context, context_mark, problem, problem_mark)             # <<<<<<<<<<<<<<
 *             else:
 *                 return ParserError(context, context_mark, problem, problem_mark)
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ScannerError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 327, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_context, ((PyObject *)__pyx_v_context_mark), __pyx_v_problem, ((PyObject *)__pyx_v_problem_mark)};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 4+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 327, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "yaml/_yaml.pyx":326
 *                 context = PyUnicode_FromString(self.parser.context)
 *             problem = PyUnicode_FromString(self.parser.problem)
 *             if self.parser.error == YAML_SCANNER_ERROR:             # <<<<<<<<<<<<<<
 *                 return ScannerError(context, context_mark, problem, problem_mark)
 *             else:
 */
    }

    /* "yaml/_yaml.pyx":329
 *                 return ScannerError(context, context_mark, problem, problem_mark)
 *             else:
 *                 return ParserError(context, context_mark, problem, problem_mark)             # <<<<<<<<<<<<<<
 *         raise ValueError(u"no parser error")
 * 
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ParserError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 329, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = NULL;
      __pyx_t_7 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_7 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_context, ((PyObject *)__pyx_v_context_mark), __pyx_v_problem, ((PyObject *)__pyx_v_problem_mark)};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 4+__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 329, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;
    }

    /* "yaml/_yaml.pyx":308
 *             return ReaderError(self.stream_name, self.parser.problem_offset,
 *                     self.parser.problem_value, u'?', PyUnicode_FromString(self.parser.problem))
 *         elif self.parser.error == YAML_SCANNER_ERROR    \             # <<<<<<<<<<<<<<
 *                 or self.parser.error == YAML_PARSER_ERROR:
 *             context_mark = None
 */
    break;
    default: break;
  }

  /* "yaml/_yaml.pyx":330
 *             else:
 *                 return ParserError(context, context_mark, problem, problem_mark)
 *         raise ValueError(u"no parser error")             # <<<<<<<<<<<<<<
 * 
 *     def raw_scan(self):
 */
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(0, 330, __pyx_L1_error)

  /* "yaml/_yaml.pyx":302
 *         pass
 * 
 *     cdef object _parser_error(self):             # <<<<<<<<<<<<<<
 *         if self.parser.error == YAML_MEMORY_ERROR:
 *             return MemoryError
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("yaml._yaml.CParser._parser_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_context_mark);
  __Pyx_XDECREF((PyObject *)__pyx_v_problem_mark);
  __Pyx_XDECREF(__pyx_v_context);
  __Pyx_XDECREF(__pyx_v_problem);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":332
 *         raise ValueError(u"no parser error")
 * 
 *     def raw_scan(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_token_t token
 *         cdef int done
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_7raw_scan(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_7raw_scan = {"raw_scan", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_7raw_scan, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_7raw_scan(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("raw_scan (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("raw_scan", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "raw_scan", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_6raw_scan(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_6raw_scan(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  yaml_token_t __pyx_v_token;
  int __pyx_v_done;
  int __pyx_v_count;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("raw_scan", 1);

  /* "yaml/_yaml.pyx":336
 *         cdef int done
 *         cdef int count
 *         count = 0             # <<<<<<<<<<<<<<
 *         done = 0
 *         while done == 0:
 */
  __pyx_v_count = 0;

  /* "yaml/_yaml.pyx":337
 *         cdef int count
 *         count = 0
 *         done = 0             # <<<<<<<<<<<<<<
 *         while done == 0:
 *             if yaml_parser_scan(&self.parser, &token) == 0:
 */
  __pyx_v_done = 0;

  /* "yaml/_yaml.pyx":338
 *         count = 0
 *         done = 0
 *         while done == 0:             # <<<<<<<<<<<<<<
 *             if yaml_parser_scan(&self.parser, &token) == 0:
 *                 error = self._parser_error()
 */
  while (1) {
    __pyx_t_1 = (__pyx_v_done == 0);
    if (!__pyx_t_1) break;

    /* "yaml/_yaml.pyx":339
 *         done = 0
 *         while done == 0:
 *             if yaml_parser_scan(&self.parser, &token) == 0:             # <<<<<<<<<<<<<<
 *                 error = self._parser_error()
 *                 raise error
 */
    __pyx_t_2 = yaml_parser_scan((&__pyx_v_self->parser), (&__pyx_v_token)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 339, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 == 0);
    if (unlikely(__pyx_t_1)) {

      /* "yaml/_yaml.pyx":340
 *         while done == 0:
 *             if yaml_parser_scan(&self.parser, &token) == 0:
 *                 error = self._parser_error()             # <<<<<<<<<<<<<<
 *                 raise error
 *             if token.type == YAML_NO_TOKEN:
 */
      __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parser_error(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 340, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_error = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "yaml/_yaml.pyx":341
 *             if yaml_parser_scan(&self.parser, &token) == 0:
 *                 error = self._parser_error()
 *                 raise error             # <<<<<<<<<<<<<<
 *             if token.type == YAML_NO_TOKEN:
 *                 done = 1
 */
      __Pyx_Raise(__pyx_v_error, 0, 0, 0);
      __PYX_ERR(0, 341, __pyx_L1_error)

      /* "yaml/_yaml.pyx":339
 *         done = 0
 *         while done == 0:
 *             if yaml_parser_scan(&self.parser, &token) == 0:             # <<<<<<<<<<<<<<
 *                 error = self._parser_error()
 *                 raise error
 */
    }

    /* "yaml/_yaml.pyx":342
 *                 error = self._parser_error()
 *                 raise error
 *             if token.type == YAML_NO_TOKEN:             # <<<<<<<<<<<<<<
 *                 done = 1
 *             else:
 */
    __pyx_t_1 = (__pyx_v_token.type == YAML_NO_TOKEN);
    if (__pyx_t_1) {

      /* "yaml/_yaml.pyx":343
 *                 raise error
 *             if token.type == YAML_NO_TOKEN:
 *                 done = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 count = count+1
 */
      __pyx_v_done = 1;

      /* "yaml/_yaml.pyx":342
 *                 error = self._parser_error()
 *                 raise error
 *             if token.type == YAML_NO_TOKEN:             # <<<<<<<<<<<<<<
 *                 done = 1
 *             else:
 */
      goto __pyx_L6;
    }

    /* "yaml/_yaml.pyx":345
 *                 done = 1
 *             else:
 *                 count = count+1             # <<<<<<<<<<<<<<
 *             yaml_token_delete(&token)
 *         return count
 */
    /*else*/ {
      __pyx_v_count = (__pyx_v_count + 1);
    }
    __pyx_L6:;

    /* "yaml/_yaml.pyx":346
 *             else:
 *                 count = count+1
 *             yaml_token_delete(&token)             # <<<<<<<<<<<<<<
 *         return count
 * 
 */
    yaml_token_delete((&__pyx_v_token));
  }

  /* "yaml/_yaml.pyx":347
 *                 count = count+1
 *             yaml_token_delete(&token)
 *         return count             # <<<<<<<<<<<<<<
 * 
 *     cdef object _scan(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_count); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":332
 *         raise ValueError(u"no parser error")
 * 
 *     def raw_scan(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_token_t token
 *         cdef int done
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("yaml._yaml.CParser.raw_scan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":349
 *         return count
 * 
 *     cdef object _scan(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_token_t token
 *         if yaml_parser_scan(&self.parser, &token) == 0:
 */

static PyObject *__pyx_f_4yaml_5_yaml_7CParser__scan(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  yaml_token_t __pyx_v_token;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_v_token_object = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_scan", 1);

  /* "yaml/_yaml.pyx":351
 *     cdef object _scan(self):
 *         cdef yaml_token_t token
 *         if yaml_parser_scan(&self.parser, &token) == 0:             # <<<<<<<<<<<<<<
 *             error = self._parser_error()
 *             raise error
 */
  __pyx_t_1 = yaml_parser_scan((&__pyx_v_self->parser), (&__pyx_v_token)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 351, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (unlikely(__pyx_t_2)) {

    /* "yaml/_yaml.pyx":352
 *         cdef yaml_token_t token
 *         if yaml_parser_scan(&self.parser, &token) == 0:
 *             error = self._parser_error()             # <<<<<<<<<<<<<<
 *             raise error
 *         token_object = self._token_to_object(&token)
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parser_error(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 352, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_error = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "yaml/_yaml.pyx":353
 *         if yaml_parser_scan(&self.parser, &token) == 0:
 *             error = self._parser_error()
 *             raise error             # <<<<<<<<<<<<<<
 *         token_object = self._token_to_object(&token)
 *         yaml_token_delete(&token)
 */
    __Pyx_Raise(__pyx_v_error, 0, 0, 0);
    __PYX_ERR(0, 353, __pyx_L1_error)

    /* "yaml/_yaml.pyx":351
 *     cdef object _scan(self):
 *         cdef yaml_token_t token
 *         if yaml_parser_scan(&self.parser, &token) == 0:             # <<<<<<<<<<<<<<
 *             error = self._parser_error()
 *             raise error
 */
  }

  /* "yaml/_yaml.pyx":354
 *             error = self._parser_error()
 *             raise error
 *         token_object = self._token_to_object(&token)             # <<<<<<<<<<<<<<
 *         yaml_token_delete(&token)
 *         return token_object
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_token_to_object(__pyx_v_self, (&__pyx_v_token)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_token_object = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "yaml/_yaml.pyx":355
 *             raise error
 *         token_object = self._token_to_object(&token)
 *         yaml_token_delete(&token)             # <<<<<<<<<<<<<<
 *         return token_object
 * 
 */
  yaml_token_delete((&__pyx_v_token));

  /* "yaml/_yaml.pyx":356
 *         token_object = self._token_to_object(&token)
 *         yaml_token_delete(&token)
 *         return token_object             # <<<<<<<<<<<<<<
 * 
 *     cdef object _token_to_object(self, yaml_token_t *token):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_token_object);
  __pyx_r = __pyx_v_token_object;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":349
 *         return count
 * 
 *     cdef object _scan(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_token_t token
 *         if yaml_parser_scan(&self.parser, &token) == 0:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("yaml._yaml.CParser._scan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XDECREF(__pyx_v_token_object);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":358
 *         return token_object
 * 
 *     cdef object _token_to_object(self, yaml_token_t *token):             # <<<<<<<<<<<<<<
 *         start_mark = Mark(self.stream_name,
 *                 token.start_mark.index,
 */

static PyObject *__pyx_f_4yaml_5_yaml_7CParser__token_to_object(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, yaml_token_t *__pyx_v_token) {
  struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_start_mark = NULL;
  struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_end_mark = NULL;
  PyObject *__pyx_v_encoding = NULL;
  PyObject *__pyx_v_handle = NULL;
  PyObject *__pyx_v_prefix = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_suffix = NULL;
  int __pyx_v_plain;
  PyObject *__pyx_v_style = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_token_to_object", 1);

  /* "yaml/_yaml.pyx":360
 *     cdef object _token_to_object(self, yaml_token_t *token):
 *         start_mark = Mark(self.stream_name,
 *                 token.start_mark.index,             # <<<<<<<<<<<<<<
 *                 token.start_mark.line,
 *                 token.start_mark.column,
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_token->start_mark.index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "yaml/_yaml.pyx":361
 *         start_mark = Mark(self.stream_name,
 *                 token.start_mark.index,
 *                 token.start_mark.line,             # <<<<<<<<<<<<<<
 *                 token.start_mark.column,
 *                 None, None)
 */
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_token->start_mark.line); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "yaml/_yaml.pyx":362
 *                 token.start_mark.index,
 *                 token.start_mark.line,
 *                 token.start_mark.column,             # <<<<<<<<<<<<<<
 *                 None, None)
 *         end_mark = Mark(self.stream_name,
 */
  __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_token->start_mark.column); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "yaml/_yaml.pyx":359
 * 
 *     cdef object _token_to_object(self, yaml_token_t *token):
 *         start_mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                 token.start_mark.index,
 *                 token.start_mark.line,
 */
  __pyx_t_4 = PyTuple_New(6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self->stream_name);
  __Pyx_GIVEREF(__pyx_v_self->stream_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 359, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(0, 359, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_2)) __PYX_ERR(0, 359, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_3)) __PYX_ERR(0, 359, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 4, Py_None)) __PYX_ERR(0, 359, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 5, Py_None)) __PYX_ERR(0, 359, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_start_mark = ((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "yaml/_yaml.pyx":365
 *                 None, None)
 *         end_mark = Mark(self.stream_name,
 *                 token.end_mark.index,             # <<<<<<<<<<<<<<
 *                 token.end_mark.line,
 *                 token.end_mark.column,
 */
  __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_token->end_mark.index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 365, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "yaml/_yaml.pyx":366
 *         end_mark = Mark(self.stream_name,
 *                 token.end_mark.index,
 *                 token.end_mark.line,             # <<<<<<<<<<<<<<
 *                 token.end_mark.column,
 *                 None, None)
 */
  __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_v_token->end_mark.line); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "yaml/_yaml.pyx":367
 *                 token.end_mark.index,
 *                 token.end_mark.line,
 *                 token.end_mark.column,             # <<<<<<<<<<<<<<
 *                 None, None)
 *         if token.type == YAML_NO_TOKEN:
 */
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_token->end_mark.column); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "yaml/_yaml.pyx":364
 *                 token.start_mark.column,
 *                 None, None)
 *         end_mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                 token.end_mark.index,
 *                 token.end_mark.line,
 */
  __pyx_t_1 = PyTuple_New(6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->stream_name);
  __Pyx_GIVEREF(__pyx_v_self->stream_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 364, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3)) __PYX_ERR(0, 364, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_4)) __PYX_ERR(0, 364, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_2)) __PYX_ERR(0, 364, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 4, Py_None)) __PYX_ERR(0, 364, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 5, Py_None)) __PYX_ERR(0, 364, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_end_mark = ((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":369
 *                 token.end_mark.column,
 *                 None, None)
 *         if token.type == YAML_NO_TOKEN:             # <<<<<<<<<<<<<<
 *             return None
 *         elif token.type == YAML_STREAM_START_TOKEN:
 */
  switch (__pyx_v_token->type) {
    case YAML_NO_TOKEN:

    /* "yaml/_yaml.pyx":370
 *                 None, None)
 *         if token.type == YAML_NO_TOKEN:
 *             return None             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_STREAM_START_TOKEN:
 *             encoding = None
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":369
 *                 token.end_mark.column,
 *                 None, None)
 *         if token.type == YAML_NO_TOKEN:             # <<<<<<<<<<<<<<
 *             return None
 *         elif token.type == YAML_STREAM_START_TOKEN:
 */
    break;
    case YAML_STREAM_START_TOKEN:

    /* "yaml/_yaml.pyx":372
 *             return None
 *         elif token.type == YAML_STREAM_START_TOKEN:
 *             encoding = None             # <<<<<<<<<<<<<<
 *             if token.data.stream_start.encoding == YAML_UTF8_ENCODING:
 *                 if self.unicode_source == 0:
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_encoding = ((PyObject*)Py_None);

    /* "yaml/_yaml.pyx":373
 *         elif token.type == YAML_STREAM_START_TOKEN:
 *             encoding = None
 *             if token.data.stream_start.encoding == YAML_UTF8_ENCODING:             # <<<<<<<<<<<<<<
 *                 if self.unicode_source == 0:
 *                     encoding = u"utf-8"
 */
    switch (__pyx_v_token->data.stream_start.encoding) {
      case YAML_UTF8_ENCODING:

      /* "yaml/_yaml.pyx":374
 *             encoding = None
 *             if token.data.stream_start.encoding == YAML_UTF8_ENCODING:
 *                 if self.unicode_source == 0:             # <<<<<<<<<<<<<<
 *                     encoding = u"utf-8"
 *             elif token.data.stream_start.encoding == YAML_UTF16LE_ENCODING:
 */
      __pyx_t_5 = (__pyx_v_self->unicode_source == 0);
      if (__pyx_t_5) {

        /* "yaml/_yaml.pyx":375
 *             if token.data.stream_start.encoding == YAML_UTF8_ENCODING:
 *                 if self.unicode_source == 0:
 *                     encoding = u"utf-8"             # <<<<<<<<<<<<<<
 *             elif token.data.stream_start.encoding == YAML_UTF16LE_ENCODING:
 *                 encoding = u"utf-16-le"
 */
        __Pyx_INCREF(__pyx_kp_u_utf_8);
        __Pyx_DECREF_SET(__pyx_v_encoding, __pyx_kp_u_utf_8);

        /* "yaml/_yaml.pyx":374
 *             encoding = None
 *             if token.data.stream_start.encoding == YAML_UTF8_ENCODING:
 *                 if self.unicode_source == 0:             # <<<<<<<<<<<<<<
 *                     encoding = u"utf-8"
 *             elif token.data.stream_start.encoding == YAML_UTF16LE_ENCODING:
 */
      }

      /* "yaml/_yaml.pyx":373
 *         elif token.type == YAML_STREAM_START_TOKEN:
 *             encoding = None
 *             if token.data.stream_start.encoding == YAML_UTF8_ENCODING:             # <<<<<<<<<<<<<<
 *                 if self.unicode_source == 0:
 *                     encoding = u"utf-8"
 */
      break;
      case YAML_UTF16LE_ENCODING:

      /* "yaml/_yaml.pyx":377
 *                     encoding = u"utf-8"
 *             elif token.data.stream_start.encoding == YAML_UTF16LE_ENCODING:
 *                 encoding = u"utf-16-le"             # <<<<<<<<<<<<<<
 *             elif token.data.stream_start.encoding == YAML_UTF16BE_ENCODING:
 *                 encoding = u"utf-16-be"
 */
      __Pyx_INCREF(__pyx_kp_u_utf_16_le);
      __Pyx_DECREF_SET(__pyx_v_encoding, __pyx_kp_u_utf_16_le);

      /* "yaml/_yaml.pyx":376
 *                 if self.unicode_source == 0:
 *                     encoding = u"utf-8"
 *             elif token.data.stream_start.encoding == YAML_UTF16LE_ENCODING:             # <<<<<<<<<<<<<<
 *                 encoding = u"utf-16-le"
 *             elif token.data.stream_start.encoding == YAML_UTF16BE_ENCODING:
 */
      break;
      case YAML_UTF16BE_ENCODING:

      /* "yaml/_yaml.pyx":379
 *                 encoding = u"utf-16-le"
 *             elif token.data.stream_start.encoding == YAML_UTF16BE_ENCODING:
 *                 encoding = u"utf-16-be"             # <<<<<<<<<<<<<<
 *             return StreamStartToken(start_mark, end_mark, encoding)
 *         elif token.type == YAML_STREAM_END_TOKEN:
 */
      __Pyx_INCREF(__pyx_kp_u_utf_16_be);
      __Pyx_DECREF_SET(__pyx_v_encoding, __pyx_kp_u_utf_16_be);

      /* "yaml/_yaml.pyx":378
 *             elif token.data.stream_start.encoding == YAML_UTF16LE_ENCODING:
 *                 encoding = u"utf-16-le"
 *             elif token.data.stream_start.encoding == YAML_UTF16BE_ENCODING:             # <<<<<<<<<<<<<<
 *                 encoding = u"utf-16-be"
 *             return StreamStartToken(start_mark, end_mark, encoding)
 */
      break;
      default: break;
    }

    /* "yaml/_yaml.pyx":380
 *             elif token.data.stream_start.encoding == YAML_UTF16BE_ENCODING:
 *                 encoding = u"utf-16-be"
 *             return StreamStartToken(start_mark, end_mark, encoding)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_STREAM_END_TOKEN:
 *             return StreamEndToken(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_StreamStartToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 380, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_4, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark), __pyx_v_encoding};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 380, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":371
 *         if token.type == YAML_NO_TOKEN:
 *             return None
 *         elif token.type == YAML_STREAM_START_TOKEN:             # <<<<<<<<<<<<<<
 *             encoding = None
 *             if token.data.stream_start.encoding == YAML_UTF8_ENCODING:
 */
    break;
    case YAML_STREAM_END_TOKEN:

    /* "yaml/_yaml.pyx":382
 *             return StreamStartToken(start_mark, end_mark, encoding)
 *         elif token.type == YAML_STREAM_END_TOKEN:
 *             return StreamEndToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_VERSION_DIRECTIVE_TOKEN:
 *             return DirectiveToken(u"YAML",
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_StreamEndToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 382, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":381
 *                 encoding = u"utf-16-be"
 *             return StreamStartToken(start_mark, end_mark, encoding)
 *         elif token.type == YAML_STREAM_END_TOKEN:             # <<<<<<<<<<<<<<
 *             return StreamEndToken(start_mark, end_mark)
 *         elif token.type == YAML_VERSION_DIRECTIVE_TOKEN:
 */
    break;
    case YAML_VERSION_DIRECTIVE_TOKEN:

    /* "yaml/_yaml.pyx":384
 *             return StreamEndToken(start_mark, end_mark)
 *         elif token.type == YAML_VERSION_DIRECTIVE_TOKEN:
 *             return DirectiveToken(u"YAML",             # <<<<<<<<<<<<<<
 *                     (token.data.version_directive.major,
 *                         token.data.version_directive.minor),
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_DirectiveToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "yaml/_yaml.pyx":385
 *         elif token.type == YAML_VERSION_DIRECTIVE_TOKEN:
 *             return DirectiveToken(u"YAML",
 *                     (token.data.version_directive.major,             # <<<<<<<<<<<<<<
 *                         token.data.version_directive.minor),
 *                     start_mark, end_mark)
 */
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_token->data.version_directive.major); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 385, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);

    /* "yaml/_yaml.pyx":386
 *             return DirectiveToken(u"YAML",
 *                     (token.data.version_directive.major,
 *                         token.data.version_directive.minor),             # <<<<<<<<<<<<<<
 *                     start_mark, end_mark)
 *         elif token.type == YAML_TAG_DIRECTIVE_TOKEN:
 */
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_token->data.version_directive.minor); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "yaml/_yaml.pyx":385
 *         elif token.type == YAML_VERSION_DIRECTIVE_TOKEN:
 *             return DirectiveToken(u"YAML",
 *                     (token.data.version_directive.major,             # <<<<<<<<<<<<<<
 *                         token.data.version_directive.minor),
 *                     start_mark, end_mark)
 */
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 385, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_4)) __PYX_ERR(0, 385, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_3)) __PYX_ERR(0, 385, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_3 = 0;

    /* "yaml/_yaml.pyx":387
 *                     (token.data.version_directive.major,
 *                         token.data.version_directive.minor),
 *                     start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_TAG_DIRECTIVE_TOKEN:
 *             handle = PyUnicode_FromYamlString(token.data.tag_directive.handle)
 */
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_3, __pyx_n_u_YAML, __pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 384, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":383
 *         elif token.type == YAML_STREAM_END_TOKEN:
 *             return StreamEndToken(start_mark, end_mark)
 *         elif token.type == YAML_VERSION_DIRECTIVE_TOKEN:             # <<<<<<<<<<<<<<
 *             return DirectiveToken(u"YAML",
 *                     (token.data.version_directive.major,
 */
    break;
    case YAML_TAG_DIRECTIVE_TOKEN:

    /* "yaml/_yaml.pyx":389
 *                     start_mark, end_mark)
 *         elif token.type == YAML_TAG_DIRECTIVE_TOKEN:
 *             handle = PyUnicode_FromYamlString(token.data.tag_directive.handle)             # <<<<<<<<<<<<<<
 *             prefix = PyUnicode_FromYamlString(token.data.tag_directive.prefix)
 *             return DirectiveToken(u"TAG", (handle, prefix),
 */
    __pyx_t_2 = PyUnicode_FromYamlString(__pyx_v_token->data.tag_directive.handle); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_handle = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":390
 *         elif token.type == YAML_TAG_DIRECTIVE_TOKEN:
 *             handle = PyUnicode_FromYamlString(token.data.tag_directive.handle)
 *             prefix = PyUnicode_FromYamlString(token.data.tag_directive.prefix)             # <<<<<<<<<<<<<<
 *             return DirectiveToken(u"TAG", (handle, prefix),
 *                     start_mark, end_mark)
 */
    __pyx_t_2 = PyUnicode_FromYamlString(__pyx_v_token->data.tag_directive.prefix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_prefix = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":391
 *             handle = PyUnicode_FromYamlString(token.data.tag_directive.handle)
 *             prefix = PyUnicode_FromYamlString(token.data.tag_directive.prefix)
 *             return DirectiveToken(u"TAG", (handle, prefix),             # <<<<<<<<<<<<<<
 *                     start_mark, end_mark)
 *         elif token.type == YAML_DOCUMENT_START_TOKEN:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_DirectiveToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_v_handle);
    __Pyx_GIVEREF(__pyx_v_handle);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_handle)) __PYX_ERR(0, 391, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_prefix);
    __Pyx_GIVEREF(__pyx_v_prefix);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_prefix)) __PYX_ERR(0, 391, __pyx_L1_error);

    /* "yaml/_yaml.pyx":392
 *             prefix = PyUnicode_FromYamlString(token.data.tag_directive.prefix)
 *             return DirectiveToken(u"TAG", (handle, prefix),
 *                     start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_DOCUMENT_START_TOKEN:
 *             return DocumentStartToken(start_mark, end_mark)
 */
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_3, __pyx_n_u_TAG, __pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 4+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 391, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":388
 *                         token.data.version_directive.minor),
 *                     start_mark, end_mark)
 *         elif token.type == YAML_TAG_DIRECTIVE_TOKEN:             # <<<<<<<<<<<<<<
 *             handle = PyUnicode_FromYamlString(token.data.tag_directive.handle)
 *             prefix = PyUnicode_FromYamlString(token.data.tag_directive.prefix)
 */
    break;
    case YAML_DOCUMENT_START_TOKEN:

    /* "yaml/_yaml.pyx":394
 *                     start_mark, end_mark)
 *         elif token.type == YAML_DOCUMENT_START_TOKEN:
 *             return DocumentStartToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_DOCUMENT_END_TOKEN:
 *             return DocumentEndToken(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_DocumentStartToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 394, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 394, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":393
 *             return DirectiveToken(u"TAG", (handle, prefix),
 *                     start_mark, end_mark)
 *         elif token.type == YAML_DOCUMENT_START_TOKEN:             # <<<<<<<<<<<<<<
 *             return DocumentStartToken(start_mark, end_mark)
 *         elif token.type == YAML_DOCUMENT_END_TOKEN:
 */
    break;
    case YAML_DOCUMENT_END_TOKEN:

    /* "yaml/_yaml.pyx":396
 *             return DocumentStartToken(start_mark, end_mark)
 *         elif token.type == YAML_DOCUMENT_END_TOKEN:
 *             return DocumentEndToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_BLOCK_SEQUENCE_START_TOKEN:
 *             return BlockSequenceStartToken(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_DocumentEndToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":395
 *         elif token.type == YAML_DOCUMENT_START_TOKEN:
 *             return DocumentStartToken(start_mark, end_mark)
 *         elif token.type == YAML_DOCUMENT_END_TOKEN:             # <<<<<<<<<<<<<<
 *             return DocumentEndToken(start_mark, end_mark)
 *         elif token.type == YAML_BLOCK_SEQUENCE_START_TOKEN:
 */
    break;
    case YAML_BLOCK_SEQUENCE_START_TOKEN:

    /* "yaml/_yaml.pyx":398
 *             return DocumentEndToken(start_mark, end_mark)
 *         elif token.type == YAML_BLOCK_SEQUENCE_START_TOKEN:
 *             return BlockSequenceStartToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_BLOCK_MAPPING_START_TOKEN:
 *             return BlockMappingStartToken(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_BlockSequenceStartToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 398, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 398, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":397
 *         elif token.type == YAML_DOCUMENT_END_TOKEN:
 *             return DocumentEndToken(start_mark, end_mark)
 *         elif token.type == YAML_BLOCK_SEQUENCE_START_TOKEN:             # <<<<<<<<<<<<<<
 *             return BlockSequenceStartToken(start_mark, end_mark)
 *         elif token.type == YAML_BLOCK_MAPPING_START_TOKEN:
 */
    break;
    case YAML_BLOCK_MAPPING_START_TOKEN:

    /* "yaml/_yaml.pyx":400
 *             return BlockSequenceStartToken(start_mark, end_mark)
 *         elif token.type == YAML_BLOCK_MAPPING_START_TOKEN:
 *             return BlockMappingStartToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_BLOCK_END_TOKEN:
 *             return BlockEndToken(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_BlockMappingStartToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 400, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 400, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":399
 *         elif token.type == YAML_BLOCK_SEQUENCE_START_TOKEN:
 *             return BlockSequenceStartToken(start_mark, end_mark)
 *         elif token.type == YAML_BLOCK_MAPPING_START_TOKEN:             # <<<<<<<<<<<<<<
 *             return BlockMappingStartToken(start_mark, end_mark)
 *         elif token.type == YAML_BLOCK_END_TOKEN:
 */
    break;
    case YAML_BLOCK_END_TOKEN:

    /* "yaml/_yaml.pyx":402
 *             return BlockMappingStartToken(start_mark, end_mark)
 *         elif token.type == YAML_BLOCK_END_TOKEN:
 *             return BlockEndToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_FLOW_SEQUENCE_START_TOKEN:
 *             return FlowSequenceStartToken(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_BlockEndToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 402, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":401
 *         elif token.type == YAML_BLOCK_MAPPING_START_TOKEN:
 *             return BlockMappingStartToken(start_mark, end_mark)
 *         elif token.type == YAML_BLOCK_END_TOKEN:             # <<<<<<<<<<<<<<
 *             return BlockEndToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_SEQUENCE_START_TOKEN:
 */
    break;
    case YAML_FLOW_SEQUENCE_START_TOKEN:

    /* "yaml/_yaml.pyx":404
 *             return BlockEndToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_SEQUENCE_START_TOKEN:
 *             return FlowSequenceStartToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_FLOW_SEQUENCE_END_TOKEN:
 *             return FlowSequenceEndToken(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_FlowSequenceStartToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 404, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":403
 *         elif token.type == YAML_BLOCK_END_TOKEN:
 *             return BlockEndToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_SEQUENCE_START_TOKEN:             # <<<<<<<<<<<<<<
 *             return FlowSequenceStartToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_SEQUENCE_END_TOKEN:
 */
    break;
    case YAML_FLOW_SEQUENCE_END_TOKEN:

    /* "yaml/_yaml.pyx":406
 *             return FlowSequenceStartToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_SEQUENCE_END_TOKEN:
 *             return FlowSequenceEndToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_FLOW_MAPPING_START_TOKEN:
 *             return FlowMappingStartToken(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_FlowSequenceEndToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 406, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":405
 *         elif token.type == YAML_FLOW_SEQUENCE_START_TOKEN:
 *             return FlowSequenceStartToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_SEQUENCE_END_TOKEN:             # <<<<<<<<<<<<<<
 *             return FlowSequenceEndToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_MAPPING_START_TOKEN:
 */
    break;
    case YAML_FLOW_MAPPING_START_TOKEN:

    /* "yaml/_yaml.pyx":408
 *             return FlowSequenceEndToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_MAPPING_START_TOKEN:
 *             return FlowMappingStartToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_FLOW_MAPPING_END_TOKEN:
 *             return FlowMappingEndToken(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_FlowMappingStartToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 408, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":407
 *         elif token.type == YAML_FLOW_SEQUENCE_END_TOKEN:
 *             return FlowSequenceEndToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_MAPPING_START_TOKEN:             # <<<<<<<<<<<<<<
 *             return FlowMappingStartToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_MAPPING_END_TOKEN:
 */
    break;
    case YAML_FLOW_MAPPING_END_TOKEN:

    /* "yaml/_yaml.pyx":410
 *             return FlowMappingStartToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_MAPPING_END_TOKEN:
 *             return FlowMappingEndToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_BLOCK_ENTRY_TOKEN:
 *             return BlockEntryToken(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_FlowMappingEndToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 410, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 410, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":409
 *         elif token.type == YAML_FLOW_MAPPING_START_TOKEN:
 *             return FlowMappingStartToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_MAPPING_END_TOKEN:             # <<<<<<<<<<<<<<
 *             return FlowMappingEndToken(start_mark, end_mark)
 *         elif token.type == YAML_BLOCK_ENTRY_TOKEN:
 */
    break;
    case YAML_BLOCK_ENTRY_TOKEN:

    /* "yaml/_yaml.pyx":412
 *             return FlowMappingEndToken(start_mark, end_mark)
 *         elif token.type == YAML_BLOCK_ENTRY_TOKEN:
 *             return BlockEntryToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_FLOW_ENTRY_TOKEN:
 *             return FlowEntryToken(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_BlockEntryToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 412, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":411
 *         elif token.type == YAML_FLOW_MAPPING_END_TOKEN:
 *             return FlowMappingEndToken(start_mark, end_mark)
 *         elif token.type == YAML_BLOCK_ENTRY_TOKEN:             # <<<<<<<<<<<<<<
 *             return BlockEntryToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_ENTRY_TOKEN:
 */
    break;
    case YAML_FLOW_ENTRY_TOKEN:

    /* "yaml/_yaml.pyx":414
 *             return BlockEntryToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_ENTRY_TOKEN:
 *             return FlowEntryToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_KEY_TOKEN:
 *             return KeyToken(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_FlowEntryToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 414, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":413
 *         elif token.type == YAML_BLOCK_ENTRY_TOKEN:
 *             return BlockEntryToken(start_mark, end_mark)
 *         elif token.type == YAML_FLOW_ENTRY_TOKEN:             # <<<<<<<<<<<<<<
 *             return FlowEntryToken(start_mark, end_mark)
 *         elif token.type == YAML_KEY_TOKEN:
 */
    break;
    case YAML_KEY_TOKEN:

    /* "yaml/_yaml.pyx":416
 *             return FlowEntryToken(start_mark, end_mark)
 *         elif token.type == YAML_KEY_TOKEN:
 *             return KeyToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_VALUE_TOKEN:
 *             return ValueToken(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_KeyToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 416, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":415
 *         elif token.type == YAML_FLOW_ENTRY_TOKEN:
 *             return FlowEntryToken(start_mark, end_mark)
 *         elif token.type == YAML_KEY_TOKEN:             # <<<<<<<<<<<<<<
 *             return KeyToken(start_mark, end_mark)
 *         elif token.type == YAML_VALUE_TOKEN:
 */
    break;
    case YAML_VALUE_TOKEN:

    /* "yaml/_yaml.pyx":418
 *             return KeyToken(start_mark, end_mark)
 *         elif token.type == YAML_VALUE_TOKEN:
 *             return ValueToken(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_ALIAS_TOKEN:
 *             value = PyUnicode_FromYamlString(token.data.alias.value)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ValueToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 418, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 418, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":417
 *         elif token.type == YAML_KEY_TOKEN:
 *             return KeyToken(start_mark, end_mark)
 *         elif token.type == YAML_VALUE_TOKEN:             # <<<<<<<<<<<<<<
 *             return ValueToken(start_mark, end_mark)
 *         elif token.type == YAML_ALIAS_TOKEN:
 */
    break;
    case YAML_ALIAS_TOKEN:

    /* "yaml/_yaml.pyx":420
 *             return ValueToken(start_mark, end_mark)
 *         elif token.type == YAML_ALIAS_TOKEN:
 *             value = PyUnicode_FromYamlString(token.data.alias.value)             # <<<<<<<<<<<<<<
 *             return AliasToken(value, start_mark, end_mark)
 *         elif token.type == YAML_ANCHOR_TOKEN:
 */
    __pyx_t_2 = PyUnicode_FromYamlString(__pyx_v_token->data.alias.value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 420, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_value = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":421
 *         elif token.type == YAML_ALIAS_TOKEN:
 *             value = PyUnicode_FromYamlString(token.data.alias.value)
 *             return AliasToken(value, start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_ANCHOR_TOKEN:
 *             value = PyUnicode_FromYamlString(token.data.anchor.value)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_AliasToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 421, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_v_value, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 421, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":419
 *         elif token.type == YAML_VALUE_TOKEN:
 *             return ValueToken(start_mark, end_mark)
 *         elif token.type == YAML_ALIAS_TOKEN:             # <<<<<<<<<<<<<<
 *             value = PyUnicode_FromYamlString(token.data.alias.value)
 *             return AliasToken(value, start_mark, end_mark)
 */
    break;
    case YAML_ANCHOR_TOKEN:

    /* "yaml/_yaml.pyx":423
 *             return AliasToken(value, start_mark, end_mark)
 *         elif token.type == YAML_ANCHOR_TOKEN:
 *             value = PyUnicode_FromYamlString(token.data.anchor.value)             # <<<<<<<<<<<<<<
 *             return AnchorToken(value, start_mark, end_mark)
 *         elif token.type == YAML_TAG_TOKEN:
 */
    __pyx_t_2 = PyUnicode_FromYamlString(__pyx_v_token->data.anchor.value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 423, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_value = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":424
 *         elif token.type == YAML_ANCHOR_TOKEN:
 *             value = PyUnicode_FromYamlString(token.data.anchor.value)
 *             return AnchorToken(value, start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_TAG_TOKEN:
 *             handle = PyUnicode_FromYamlString(token.data.tag.handle)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_AnchorToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_v_value, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 424, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":422
 *             value = PyUnicode_FromYamlString(token.data.alias.value)
 *             return AliasToken(value, start_mark, end_mark)
 *         elif token.type == YAML_ANCHOR_TOKEN:             # <<<<<<<<<<<<<<
 *             value = PyUnicode_FromYamlString(token.data.anchor.value)
 *             return AnchorToken(value, start_mark, end_mark)
 */
    break;
    case YAML_TAG_TOKEN:

    /* "yaml/_yaml.pyx":426
 *             return AnchorToken(value, start_mark, end_mark)
 *         elif token.type == YAML_TAG_TOKEN:
 *             handle = PyUnicode_FromYamlString(token.data.tag.handle)             # <<<<<<<<<<<<<<
 *             suffix = PyUnicode_FromYamlString(token.data.tag.suffix)
 *             if not handle:
 */
    __pyx_t_2 = PyUnicode_FromYamlString(__pyx_v_token->data.tag.handle); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 426, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_handle = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":427
 *         elif token.type == YAML_TAG_TOKEN:
 *             handle = PyUnicode_FromYamlString(token.data.tag.handle)
 *             suffix = PyUnicode_FromYamlString(token.data.tag.suffix)             # <<<<<<<<<<<<<<
 *             if not handle:
 *                 handle = None
 */
    __pyx_t_2 = PyUnicode_FromYamlString(__pyx_v_token->data.tag.suffix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_suffix = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":428
 *             handle = PyUnicode_FromYamlString(token.data.tag.handle)
 *             suffix = PyUnicode_FromYamlString(token.data.tag.suffix)
 *             if not handle:             # <<<<<<<<<<<<<<
 *                 handle = None
 *             return TagToken((handle, suffix), start_mark, end_mark)
 */
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_handle); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 428, __pyx_L1_error)
    __pyx_t_8 = (!__pyx_t_5);
    if (__pyx_t_8) {

      /* "yaml/_yaml.pyx":429
 *             suffix = PyUnicode_FromYamlString(token.data.tag.suffix)
 *             if not handle:
 *                 handle = None             # <<<<<<<<<<<<<<
 *             return TagToken((handle, suffix), start_mark, end_mark)
 *         elif token.type == YAML_SCALAR_TOKEN:
 */
      __Pyx_INCREF(Py_None);
      __Pyx_DECREF_SET(__pyx_v_handle, Py_None);

      /* "yaml/_yaml.pyx":428
 *             handle = PyUnicode_FromYamlString(token.data.tag.handle)
 *             suffix = PyUnicode_FromYamlString(token.data.tag.suffix)
 *             if not handle:             # <<<<<<<<<<<<<<
 *                 handle = None
 *             return TagToken((handle, suffix), start_mark, end_mark)
 */
    }

    /* "yaml/_yaml.pyx":430
 *             if not handle:
 *                 handle = None
 *             return TagToken((handle, suffix), start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif token.type == YAML_SCALAR_TOKEN:
 *             value = PyUnicode_DecodeUTF8(<char *>token.data.scalar.value,
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_TagToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 430, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 430, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_v_handle);
    __Pyx_GIVEREF(__pyx_v_handle);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_handle)) __PYX_ERR(0, 430, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_suffix);
    __Pyx_GIVEREF(__pyx_v_suffix);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_suffix)) __PYX_ERR(0, 430, __pyx_L1_error);
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 430, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":425
 *             value = PyUnicode_FromYamlString(token.data.anchor.value)
 *             return AnchorToken(value, start_mark, end_mark)
 *         elif token.type == YAML_TAG_TOKEN:             # <<<<<<<<<<<<<<
 *             handle = PyUnicode_FromYamlString(token.data.tag.handle)
 *             suffix = PyUnicode_FromYamlString(token.data.tag.suffix)
 */
    break;
    case YAML_SCALAR_TOKEN:

    /* "yaml/_yaml.pyx":432
 *             return TagToken((handle, suffix), start_mark, end_mark)
 *         elif token.type == YAML_SCALAR_TOKEN:
 *             value = PyUnicode_DecodeUTF8(<char *>token.data.scalar.value,             # <<<<<<<<<<<<<<
 *                     token.data.scalar.length, 'strict')
 *             plain = False
 */
    __pyx_t_2 = PyUnicode_DecodeUTF8(((char *)__pyx_v_token->data.scalar.value), __pyx_v_token->data.scalar.length, ((char *)"strict")); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_value = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":434
 *             value = PyUnicode_DecodeUTF8(<char *>token.data.scalar.value,
 *                     token.data.scalar.length, 'strict')
 *             plain = False             # <<<<<<<<<<<<<<
 *             style = None
 *             if token.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:
 */
    __pyx_v_plain = 0;

    /* "yaml/_yaml.pyx":435
 *                     token.data.scalar.length, 'strict')
 *             plain = False
 *             style = None             # <<<<<<<<<<<<<<
 *             if token.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:
 *                 plain = True
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_style = ((PyObject*)Py_None);

    /* "yaml/_yaml.pyx":436
 *             plain = False
 *             style = None
 *             if token.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *                 plain = True
 *                 style = u''
 */
    switch (__pyx_v_token->data.scalar.style) {
      case YAML_PLAIN_SCALAR_STYLE:

      /* "yaml/_yaml.pyx":437
 *             style = None
 *             if token.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:
 *                 plain = True             # <<<<<<<<<<<<<<
 *                 style = u''
 *             elif token.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 */
      __pyx_v_plain = 1;

      /* "yaml/_yaml.pyx":438
 *             if token.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:
 *                 plain = True
 *                 style = u''             # <<<<<<<<<<<<<<
 *             elif token.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 *                 style = u'\''
 */
      __Pyx_INCREF(__pyx_kp_u__4);
      __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__4);

      /* "yaml/_yaml.pyx":436
 *             plain = False
 *             style = None
 *             if token.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *                 plain = True
 *                 style = u''
 */
      break;
      case YAML_SINGLE_QUOTED_SCALAR_STYLE:

      /* "yaml/_yaml.pyx":440
 *                 style = u''
 *             elif token.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 *                 style = u'\''             # <<<<<<<<<<<<<<
 *             elif token.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:
 *                 style = u'"'
 */
      __Pyx_INCREF(__pyx_kp_u__5);
      __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__5);

      /* "yaml/_yaml.pyx":439
 *                 plain = True
 *                 style = u''
 *             elif token.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *                 style = u'\''
 *             elif token.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:
 */
      break;
      case YAML_DOUBLE_QUOTED_SCALAR_STYLE:

      /* "yaml/_yaml.pyx":442
 *                 style = u'\''
 *             elif token.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:
 *                 style = u'"'             # <<<<<<<<<<<<<<
 *             elif token.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:
 *                 style = u'|'
 */
      __Pyx_INCREF(__pyx_kp_u__6);
      __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__6);

      /* "yaml/_yaml.pyx":441
 *             elif token.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 *                 style = u'\''
 *             elif token.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *                 style = u'"'
 *             elif token.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:
 */
      break;
      case YAML_LITERAL_SCALAR_STYLE:

      /* "yaml/_yaml.pyx":444
 *                 style = u'"'
 *             elif token.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:
 *                 style = u'|'             # <<<<<<<<<<<<<<
 *             elif token.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:
 *                 style = u'>'
 */
      __Pyx_INCREF(__pyx_kp_u__7);
      __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__7);

      /* "yaml/_yaml.pyx":443
 *             elif token.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:
 *                 style = u'"'
 *             elif token.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *                 style = u'|'
 *             elif token.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:
 */
      break;
      case YAML_FOLDED_SCALAR_STYLE:

      /* "yaml/_yaml.pyx":446
 *                 style = u'|'
 *             elif token.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:
 *                 style = u'>'             # <<<<<<<<<<<<<<
 *             return ScalarToken(value, plain,
 *                     start_mark, end_mark, style)
 */
      __Pyx_INCREF(__pyx_kp_u__8);
      __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__8);

      /* "yaml/_yaml.pyx":445
 *             elif token.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:
 *                 style = u'|'
 *             elif token.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *                 style = u'>'
 *             return ScalarToken(value, plain,
 */
      break;
      default: break;
    }

    /* "yaml/_yaml.pyx":447
 *             elif token.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:
 *                 style = u'>'
 *             return ScalarToken(value, plain,             # <<<<<<<<<<<<<<
 *                     start_mark, end_mark, style)
 *         else:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ScalarToken); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 447, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_plain); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 447, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);

    /* "yaml/_yaml.pyx":448
 *                 style = u'>'
 *             return ScalarToken(value, plain,
 *                     start_mark, end_mark, style)             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError(u"unknown token type")
 */
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[6] = {__pyx_t_3, __pyx_v_value, __pyx_t_7, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark), __pyx_v_style};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 5+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 447, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":431
 *                 handle = None
 *             return TagToken((handle, suffix), start_mark, end_mark)
 *         elif token.type == YAML_SCALAR_TOKEN:             # <<<<<<<<<<<<<<
 *             value = PyUnicode_DecodeUTF8(<char *>token.data.scalar.value,
 *                     token.data.scalar.length, 'strict')
 */
    break;
    default:

    /* "yaml/_yaml.pyx":450
 *                     start_mark, end_mark, style)
 *         else:
 *             raise ValueError(u"unknown token type")             # <<<<<<<<<<<<<<
 * 
 *     def get_token(self):
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 450, __pyx_L1_error)
    break;
  }

  /* "yaml/_yaml.pyx":358
 *         return token_object
 * 
 *     cdef object _token_to_object(self, yaml_token_t *token):             # <<<<<<<<<<<<<<
 *         start_mark = Mark(self.stream_name,
 *                 token.start_mark.index,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("yaml._yaml.CParser._token_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_start_mark);
  __Pyx_XDECREF((PyObject *)__pyx_v_end_mark);
  __Pyx_XDECREF(__pyx_v_encoding);
  __Pyx_XDECREF(__pyx_v_handle);
  __Pyx_XDECREF(__pyx_v_prefix);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_suffix);
  __Pyx_XDECREF(__pyx_v_style);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":452
 *             raise ValueError(u"unknown token type")
 * 
 *     def get_token(self):             # <<<<<<<<<<<<<<
 *         if self.current_token is not None:
 *             value = self.current_token
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_9get_token(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_9get_token = {"get_token", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_9get_token, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_9get_token(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_token (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_token", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_token", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_8get_token(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_8get_token(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_token", 1);

  /* "yaml/_yaml.pyx":453
 * 
 *     def get_token(self):
 *         if self.current_token is not None:             # <<<<<<<<<<<<<<
 *             value = self.current_token
 *             self.current_token = None
 */
  __pyx_t_1 = (__pyx_v_self->current_token != Py_None);
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":454
 *     def get_token(self):
 *         if self.current_token is not None:
 *             value = self.current_token             # <<<<<<<<<<<<<<
 *             self.current_token = None
 *         else:
 */
    __pyx_t_2 = __pyx_v_self->current_token;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_value = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":455
 *         if self.current_token is not None:
 *             value = self.current_token
 *             self.current_token = None             # <<<<<<<<<<<<<<
 *         else:
 *             value = self._scan()
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->current_token);
    __Pyx_DECREF(__pyx_v_self->current_token);
    __pyx_v_self->current_token = Py_None;

    /* "yaml/_yaml.pyx":453
 * 
 *     def get_token(self):
 *         if self.current_token is not None:             # <<<<<<<<<<<<<<
 *             value = self.current_token
 *             self.current_token = None
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":457
 *             self.current_token = None
 *         else:
 *             value = self._scan()             # <<<<<<<<<<<<<<
 *         return value
 * 
 */
  /*else*/ {
    __pyx_t_2 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_scan(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_value = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "yaml/_yaml.pyx":458
 *         else:
 *             value = self._scan()
 *         return value             # <<<<<<<<<<<<<<
 * 
 *     def peek_token(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_value);
  __pyx_r = __pyx_v_value;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":452
 *             raise ValueError(u"unknown token type")
 * 
 *     def get_token(self):             # <<<<<<<<<<<<<<
 *         if self.current_token is not None:
 *             value = self.current_token
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("yaml._yaml.CParser.get_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":460
 *         return value
 * 
 *     def peek_token(self):             # <<<<<<<<<<<<<<
 *         if self.current_token is None:
 *             self.current_token = self._scan()
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_11peek_token(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_11peek_token = {"peek_token", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_11peek_token, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_11peek_token(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("peek_token (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("peek_token", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "peek_token", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_10peek_token(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_10peek_token(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("peek_token", 1);

  /* "yaml/_yaml.pyx":461
 * 
 *     def peek_token(self):
 *         if self.current_token is None:             # <<<<<<<<<<<<<<
 *             self.current_token = self._scan()
 *         return self.current_token
 */
  __pyx_t_1 = (__pyx_v_self->current_token == Py_None);
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":462
 *     def peek_token(self):
 *         if self.current_token is None:
 *             self.current_token = self._scan()             # <<<<<<<<<<<<<<
 *         return self.current_token
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_scan(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 462, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->current_token);
    __Pyx_DECREF(__pyx_v_self->current_token);
    __pyx_v_self->current_token = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":461
 * 
 *     def peek_token(self):
 *         if self.current_token is None:             # <<<<<<<<<<<<<<
 *             self.current_token = self._scan()
 *         return self.current_token
 */
  }

  /* "yaml/_yaml.pyx":463
 *         if self.current_token is None:
 *             self.current_token = self._scan()
 *         return self.current_token             # <<<<<<<<<<<<<<
 * 
 *     def check_token(self, *choices):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->current_token);
  __pyx_r = __pyx_v_self->current_token;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":460
 *         return value
 * 
 *     def peek_token(self):             # <<<<<<<<<<<<<<
 *         if self.current_token is None:
 *             self.current_token = self._scan()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("yaml._yaml.CParser.peek_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":465
 *         return self.current_token
 * 
 *     def check_token(self, *choices):             # <<<<<<<<<<<<<<
 *         if self.current_token is None:
 *             self.current_token = self._scan()
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_13check_token(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_13check_token = {"check_token", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_13check_token, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_13check_token(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_choices = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("check_token (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "check_token", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_choices = __pyx_args;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_12check_token(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self), __pyx_v_choices);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_choices);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_12check_token(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_choices) {
  PyObject *__pyx_v_token_class = NULL;
  PyObject *__pyx_v_choice = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_token", 1);

  /* "yaml/_yaml.pyx":466
 * 
 *     def check_token(self, *choices):
 *         if self.current_token is None:             # <<<<<<<<<<<<<<
 *             self.current_token = self._scan()
 *         if self.current_token is None:
 */
  __pyx_t_1 = (__pyx_v_self->current_token == Py_None);
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":467
 *     def check_token(self, *choices):
 *         if self.current_token is None:
 *             self.current_token = self._scan()             # <<<<<<<<<<<<<<
 *         if self.current_token is None:
 *             return False
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_scan(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 467, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->current_token);
    __Pyx_DECREF(__pyx_v_self->current_token);
    __pyx_v_self->current_token = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":466
 * 
 *     def check_token(self, *choices):
 *         if self.current_token is None:             # <<<<<<<<<<<<<<
 *             self.current_token = self._scan()
 *         if self.current_token is None:
 */
  }

  /* "yaml/_yaml.pyx":468
 *         if self.current_token is None:
 *             self.current_token = self._scan()
 *         if self.current_token is None:             # <<<<<<<<<<<<<<
 *             return False
 *         if not choices:
 */
  __pyx_t_1 = (__pyx_v_self->current_token == Py_None);
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":469
 *             self.current_token = self._scan()
 *         if self.current_token is None:
 *             return False             # <<<<<<<<<<<<<<
 *         if not choices:
 *             return True
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":468
 *         if self.current_token is None:
 *             self.current_token = self._scan()
 *         if self.current_token is None:             # <<<<<<<<<<<<<<
 *             return False
 *         if not choices:
 */
  }

  /* "yaml/_yaml.pyx":470
 *         if self.current_token is None:
 *             return False
 *         if not choices:             # <<<<<<<<<<<<<<
 *             return True
 *         token_class = self.current_token.__class__
 */
  __pyx_t_1 = (PyTuple_GET_SIZE(__pyx_v_choices) != 0);
  __pyx_t_3 = (!__pyx_t_1);
  if (__pyx_t_3) {

    /* "yaml/_yaml.pyx":471
 *             return False
 *         if not choices:
 *             return True             # <<<<<<<<<<<<<<
 *         token_class = self.current_token.__class__
 *         for choice in choices:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":470
 *         if self.current_token is None:
 *             return False
 *         if not choices:             # <<<<<<<<<<<<<<
 *             return True
 *         token_class = self.current_token.__class__
 */
  }

  /* "yaml/_yaml.pyx":472
 *         if not choices:
 *             return True
 *         token_class = self.current_token.__class__             # <<<<<<<<<<<<<<
 *         for choice in choices:
 *             if token_class is choice:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->current_token, __pyx_n_s_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_token_class = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":473
 *             return True
 *         token_class = self.current_token.__class__
 *         for choice in choices:             # <<<<<<<<<<<<<<
 *             if token_class is choice:
 *                 return True
 */
  __pyx_t_2 = __pyx_v_choices; __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 473, __pyx_L1_error)
      #endif
      if (__pyx_t_4 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_5); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 473, __pyx_L1_error)
    #else
    __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_choice, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "yaml/_yaml.pyx":474
 *         token_class = self.current_token.__class__
 *         for choice in choices:
 *             if token_class is choice:             # <<<<<<<<<<<<<<
 *                 return True
 *         return False
 */
    __pyx_t_3 = (__pyx_v_token_class == __pyx_v_choice);
    if (__pyx_t_3) {

      /* "yaml/_yaml.pyx":475
 *         for choice in choices:
 *             if token_class is choice:
 *                 return True             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "yaml/_yaml.pyx":474
 *         token_class = self.current_token.__class__
 *         for choice in choices:
 *             if token_class is choice:             # <<<<<<<<<<<<<<
 *                 return True
 *         return False
 */
    }

    /* "yaml/_yaml.pyx":473
 *             return True
 *         token_class = self.current_token.__class__
 *         for choice in choices:             # <<<<<<<<<<<<<<
 *             if token_class is choice:
 *                 return True
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":476
 *             if token_class is choice:
 *                 return True
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     def raw_parse(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":465
 *         return self.current_token
 * 
 *     def check_token(self, *choices):             # <<<<<<<<<<<<<<
 *         if self.current_token is None:
 *             self.current_token = self._scan()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("yaml._yaml.CParser.check_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_token_class);
  __Pyx_XDECREF(__pyx_v_choice);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":478
 *         return False
 * 
 *     def raw_parse(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef int done
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_15raw_parse(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_15raw_parse = {"raw_parse", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_15raw_parse, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_15raw_parse(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("raw_parse (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("raw_parse", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "raw_parse", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_14raw_parse(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_14raw_parse(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  yaml_event_t __pyx_v_event;
  int __pyx_v_done;
  int __pyx_v_count;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("raw_parse", 1);

  /* "yaml/_yaml.pyx":482
 *         cdef int done
 *         cdef int count
 *         count = 0             # <<<<<<<<<<<<<<
 *         done = 0
 *         while done == 0:
 */
  __pyx_v_count = 0;

  /* "yaml/_yaml.pyx":483
 *         cdef int count
 *         count = 0
 *         done = 0             # <<<<<<<<<<<<<<
 *         while done == 0:
 *             if yaml_parser_parse(&self.parser, &event) == 0:
 */
  __pyx_v_done = 0;

  /* "yaml/_yaml.pyx":484
 *         count = 0
 *         done = 0
 *         while done == 0:             # <<<<<<<<<<<<<<
 *             if yaml_parser_parse(&self.parser, &event) == 0:
 *                 error = self._parser_error()
 */
  while (1) {
    __pyx_t_1 = (__pyx_v_done == 0);
    if (!__pyx_t_1) break;

    /* "yaml/_yaml.pyx":485
 *         done = 0
 *         while done == 0:
 *             if yaml_parser_parse(&self.parser, &event) == 0:             # <<<<<<<<<<<<<<
 *                 error = self._parser_error()
 *                 raise error
 */
    __pyx_t_2 = yaml_parser_parse((&__pyx_v_self->parser), (&__pyx_v_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 485, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 == 0);
    if (unlikely(__pyx_t_1)) {

      /* "yaml/_yaml.pyx":486
 *         while done == 0:
 *             if yaml_parser_parse(&self.parser, &event) == 0:
 *                 error = self._parser_error()             # <<<<<<<<<<<<<<
 *                 raise error
 *             if event.type == YAML_NO_EVENT:
 */
      __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parser_error(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_error = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "yaml/_yaml.pyx":487
 *             if yaml_parser_parse(&self.parser, &event) == 0:
 *                 error = self._parser_error()
 *                 raise error             # <<<<<<<<<<<<<<
 *             if event.type == YAML_NO_EVENT:
 *                 done = 1
 */
      __Pyx_Raise(__pyx_v_error, 0, 0, 0);
      __PYX_ERR(0, 487, __pyx_L1_error)

      /* "yaml/_yaml.pyx":485
 *         done = 0
 *         while done == 0:
 *             if yaml_parser_parse(&self.parser, &event) == 0:             # <<<<<<<<<<<<<<
 *                 error = self._parser_error()
 *                 raise error
 */
    }

    /* "yaml/_yaml.pyx":488
 *                 error = self._parser_error()
 *                 raise error
 *             if event.type == YAML_NO_EVENT:             # <<<<<<<<<<<<<<
 *                 done = 1
 *             else:
 */
    __pyx_t_1 = (__pyx_v_event.type == YAML_NO_EVENT);
    if (__pyx_t_1) {

      /* "yaml/_yaml.pyx":489
 *                 raise error
 *             if event.type == YAML_NO_EVENT:
 *                 done = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 count = count+1
 */
      __pyx_v_done = 1;

      /* "yaml/_yaml.pyx":488
 *                 error = self._parser_error()
 *                 raise error
 *             if event.type == YAML_NO_EVENT:             # <<<<<<<<<<<<<<
 *                 done = 1
 *             else:
 */
      goto __pyx_L6;
    }

    /* "yaml/_yaml.pyx":491
 *                 done = 1
 *             else:
 *                 count = count+1             # <<<<<<<<<<<<<<
 *             yaml_event_delete(&event)
 *         return count
 */
    /*else*/ {
      __pyx_v_count = (__pyx_v_count + 1);
    }
    __pyx_L6:;

    /* "yaml/_yaml.pyx":492
 *             else:
 *                 count = count+1
 *             yaml_event_delete(&event)             # <<<<<<<<<<<<<<
 *         return count
 * 
 */
    yaml_event_delete((&__pyx_v_event));
  }

  /* "yaml/_yaml.pyx":493
 *                 count = count+1
 *             yaml_event_delete(&event)
 *         return count             # <<<<<<<<<<<<<<
 * 
 *     cdef object _parse(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_count); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":478
 *         return False
 * 
 *     def raw_parse(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef int done
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("yaml._yaml.CParser.raw_parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":495
 *         return count
 * 
 *     cdef object _parse(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         if yaml_parser_parse(&self.parser, &event) == 0:
 */

static PyObject *__pyx_f_4yaml_5_yaml_7CParser__parse(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  yaml_event_t __pyx_v_event;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_v_event_object = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_parse", 1);

  /* "yaml/_yaml.pyx":497
 *     cdef object _parse(self):
 *         cdef yaml_event_t event
 *         if yaml_parser_parse(&self.parser, &event) == 0:             # <<<<<<<<<<<<<<
 *             error = self._parser_error()
 *             raise error
 */
  __pyx_t_1 = yaml_parser_parse((&__pyx_v_self->parser), (&__pyx_v_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 497, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (unlikely(__pyx_t_2)) {

    /* "yaml/_yaml.pyx":498
 *         cdef yaml_event_t event
 *         if yaml_parser_parse(&self.parser, &event) == 0:
 *             error = self._parser_error()             # <<<<<<<<<<<<<<
 *             raise error
 *         event_object = self._event_to_object(&event)
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parser_error(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_error = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "yaml/_yaml.pyx":499
 *         if yaml_parser_parse(&self.parser, &event) == 0:
 *             error = self._parser_error()
 *             raise error             # <<<<<<<<<<<<<<
 *         event_object = self._event_to_object(&event)
 *         yaml_event_delete(&event)
 */
    __Pyx_Raise(__pyx_v_error, 0, 0, 0);
    __PYX_ERR(0, 499, __pyx_L1_error)

    /* "yaml/_yaml.pyx":497
 *     cdef object _parse(self):
 *         cdef yaml_event_t event
 *         if yaml_parser_parse(&self.parser, &event) == 0:             # <<<<<<<<<<<<<<
 *             error = self._parser_error()
 *             raise error
 */
  }

  /* "yaml/_yaml.pyx":500
 *             error = self._parser_error()
 *             raise error
 *         event_object = self._event_to_object(&event)             # <<<<<<<<<<<<<<
 *         yaml_event_delete(&event)
 *         return event_object
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_event_to_object(__pyx_v_self, (&__pyx_v_event)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_event_object = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "yaml/_yaml.pyx":501
 *             raise error
 *         event_object = self._event_to_object(&event)
 *         yaml_event_delete(&event)             # <<<<<<<<<<<<<<
 *         return event_object
 * 
 */
  yaml_event_delete((&__pyx_v_event));

  /* "yaml/_yaml.pyx":502
 *         event_object = self._event_to_object(&event)
 *         yaml_event_delete(&event)
 *         return event_object             # <<<<<<<<<<<<<<
 * 
 *     cdef object _event_to_object(self, yaml_event_t *event):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_event_object);
  __pyx_r = __pyx_v_event_object;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":495
 *         return count
 * 
 *     cdef object _parse(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         if yaml_parser_parse(&self.parser, &event) == 0:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("yaml._yaml.CParser._parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XDECREF(__pyx_v_event_object);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":504
 *         return event_object
 * 
 *     cdef object _event_to_object(self, yaml_event_t *event):             # <<<<<<<<<<<<<<
 *         cdef yaml_tag_directive_t *tag_directive
 *         start_mark = Mark(self.stream_name,
 */

static PyObject *__pyx_f_4yaml_5_yaml_7CParser__event_to_object(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, yaml_event_t *__pyx_v_event) {
  yaml_tag_directive_t *__pyx_v_tag_directive;
  struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_start_mark = NULL;
  struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_end_mark = NULL;
  PyObject *__pyx_v_encoding = NULL;
  int __pyx_v_explicit;
  PyObject *__pyx_v_version = NULL;
  PyObject *__pyx_v_tags = NULL;
  PyObject *__pyx_v_handle = NULL;
  PyObject *__pyx_v_prefix = NULL;
  PyObject *__pyx_v_anchor = NULL;
  PyObject *__pyx_v_tag = NULL;
  PyObject *__pyx_v_value = NULL;
  int __pyx_v_plain_implicit;
  int __pyx_v_quoted_implicit;
  PyObject *__pyx_v_style = NULL;
  int __pyx_v_implicit;
  PyObject *__pyx_v_flow_style = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  yaml_tag_directive_t *__pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_event_to_object", 1);

  /* "yaml/_yaml.pyx":507
 *         cdef yaml_tag_directive_t *tag_directive
 *         start_mark = Mark(self.stream_name,
 *                 event.start_mark.index,             # <<<<<<<<<<<<<<
 *                 event.start_mark.line,
 *                 event.start_mark.column,
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_event->start_mark.index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "yaml/_yaml.pyx":508
 *         start_mark = Mark(self.stream_name,
 *                 event.start_mark.index,
 *                 event.start_mark.line,             # <<<<<<<<<<<<<<
 *                 event.start_mark.column,
 *                 None, None)
 */
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_event->start_mark.line); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "yaml/_yaml.pyx":509
 *                 event.start_mark.index,
 *                 event.start_mark.line,
 *                 event.start_mark.column,             # <<<<<<<<<<<<<<
 *                 None, None)
 *         end_mark = Mark(self.stream_name,
 */
  __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_event->start_mark.column); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "yaml/_yaml.pyx":506
 *     cdef object _event_to_object(self, yaml_event_t *event):
 *         cdef yaml_tag_directive_t *tag_directive
 *         start_mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                 event.start_mark.index,
 *                 event.start_mark.line,
 */
  __pyx_t_4 = PyTuple_New(6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self->stream_name);
  __Pyx_GIVEREF(__pyx_v_self->stream_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 506, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(0, 506, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_2)) __PYX_ERR(0, 506, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_3)) __PYX_ERR(0, 506, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 4, Py_None)) __PYX_ERR(0, 506, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 5, Py_None)) __PYX_ERR(0, 506, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_start_mark = ((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "yaml/_yaml.pyx":512
 *                 None, None)
 *         end_mark = Mark(self.stream_name,
 *                 event.end_mark.index,             # <<<<<<<<<<<<<<
 *                 event.end_mark.line,
 *                 event.end_mark.column,
 */
  __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_event->end_mark.index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "yaml/_yaml.pyx":513
 *         end_mark = Mark(self.stream_name,
 *                 event.end_mark.index,
 *                 event.end_mark.line,             # <<<<<<<<<<<<<<
 *                 event.end_mark.column,
 *                 None, None)
 */
  __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_v_event->end_mark.line); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "yaml/_yaml.pyx":514
 *                 event.end_mark.index,
 *                 event.end_mark.line,
 *                 event.end_mark.column,             # <<<<<<<<<<<<<<
 *                 None, None)
 *         if event.type == YAML_NO_EVENT:
 */
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_event->end_mark.column); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "yaml/_yaml.pyx":511
 *                 event.start_mark.column,
 *                 None, None)
 *         end_mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                 event.end_mark.index,
 *                 event.end_mark.line,
 */
  __pyx_t_1 = PyTuple_New(6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->stream_name);
  __Pyx_GIVEREF(__pyx_v_self->stream_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 511, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3)) __PYX_ERR(0, 511, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_4)) __PYX_ERR(0, 511, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_2)) __PYX_ERR(0, 511, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 4, Py_None)) __PYX_ERR(0, 511, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 5, Py_None)) __PYX_ERR(0, 511, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_end_mark = ((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":516
 *                 event.end_mark.column,
 *                 None, None)
 *         if event.type == YAML_NO_EVENT:             # <<<<<<<<<<<<<<
 *             return None
 *         elif event.type == YAML_STREAM_START_EVENT:
 */
  switch (__pyx_v_event->type) {
    case YAML_NO_EVENT:

    /* "yaml/_yaml.pyx":517
 *                 None, None)
 *         if event.type == YAML_NO_EVENT:
 *             return None             # <<<<<<<<<<<<<<
 *         elif event.type == YAML_STREAM_START_EVENT:
 *             encoding = None
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":516
 *                 event.end_mark.column,
 *                 None, None)
 *         if event.type == YAML_NO_EVENT:             # <<<<<<<<<<<<<<
 *             return None
 *         elif event.type == YAML_STREAM_START_EVENT:
 */
    break;
    case YAML_STREAM_START_EVENT:

    /* "yaml/_yaml.pyx":519
 *             return None
 *         elif event.type == YAML_STREAM_START_EVENT:
 *             encoding = None             # <<<<<<<<<<<<<<
 *             if event.data.stream_start.encoding == YAML_UTF8_ENCODING:
 *                 if self.unicode_source == 0:
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_encoding = ((PyObject*)Py_None);

    /* "yaml/_yaml.pyx":520
 *         elif event.type == YAML_STREAM_START_EVENT:
 *             encoding = None
 *             if event.data.stream_start.encoding == YAML_UTF8_ENCODING:             # <<<<<<<<<<<<<<
 *                 if self.unicode_source == 0:
 *                     encoding = u"utf-8"
 */
    switch (__pyx_v_event->data.stream_start.encoding) {
      case YAML_UTF8_ENCODING:

      /* "yaml/_yaml.pyx":521
 *             encoding = None
 *             if event.data.stream_start.encoding == YAML_UTF8_ENCODING:
 *                 if self.unicode_source == 0:             # <<<<<<<<<<<<<<
 *                     encoding = u"utf-8"
 *             elif event.data.stream_start.encoding == YAML_UTF16LE_ENCODING:
 */
      __pyx_t_5 = (__pyx_v_self->unicode_source == 0);
      if (__pyx_t_5) {

        /* "yaml/_yaml.pyx":522
 *             if event.data.stream_start.encoding == YAML_UTF8_ENCODING:
 *                 if self.unicode_source == 0:
 *                     encoding = u"utf-8"             # <<<<<<<<<<<<<<
 *             elif event.data.stream_start.encoding == YAML_UTF16LE_ENCODING:
 *                 encoding = u"utf-16-le"
 */
        __Pyx_INCREF(__pyx_kp_u_utf_8);
        __Pyx_DECREF_SET(__pyx_v_encoding, __pyx_kp_u_utf_8);

        /* "yaml/_yaml.pyx":521
 *             encoding = None
 *             if event.data.stream_start.encoding == YAML_UTF8_ENCODING:
 *                 if self.unicode_source == 0:             # <<<<<<<<<<<<<<
 *                     encoding = u"utf-8"
 *             elif event.data.stream_start.encoding == YAML_UTF16LE_ENCODING:
 */
      }

      /* "yaml/_yaml.pyx":520
 *         elif event.type == YAML_STREAM_START_EVENT:
 *             encoding = None
 *             if event.data.stream_start.encoding == YAML_UTF8_ENCODING:             # <<<<<<<<<<<<<<
 *                 if self.unicode_source == 0:
 *                     encoding = u"utf-8"
 */
      break;
      case YAML_UTF16LE_ENCODING:

      /* "yaml/_yaml.pyx":524
 *                     encoding = u"utf-8"
 *             elif event.data.stream_start.encoding == YAML_UTF16LE_ENCODING:
 *                 encoding = u"utf-16-le"             # <<<<<<<<<<<<<<
 *             elif event.data.stream_start.encoding == YAML_UTF16BE_ENCODING:
 *                 encoding = u"utf-16-be"
 */
      __Pyx_INCREF(__pyx_kp_u_utf_16_le);
      __Pyx_DECREF_SET(__pyx_v_encoding, __pyx_kp_u_utf_16_le);

      /* "yaml/_yaml.pyx":523
 *                 if self.unicode_source == 0:
 *                     encoding = u"utf-8"
 *             elif event.data.stream_start.encoding == YAML_UTF16LE_ENCODING:             # <<<<<<<<<<<<<<
 *                 encoding = u"utf-16-le"
 *             elif event.data.stream_start.encoding == YAML_UTF16BE_ENCODING:
 */
      break;
      case YAML_UTF16BE_ENCODING:

      /* "yaml/_yaml.pyx":526
 *                 encoding = u"utf-16-le"
 *             elif event.data.stream_start.encoding == YAML_UTF16BE_ENCODING:
 *                 encoding = u"utf-16-be"             # <<<<<<<<<<<<<<
 *             return StreamStartEvent(start_mark, end_mark, encoding)
 *         elif event.type == YAML_STREAM_END_EVENT:
 */
      __Pyx_INCREF(__pyx_kp_u_utf_16_be);
      __Pyx_DECREF_SET(__pyx_v_encoding, __pyx_kp_u_utf_16_be);

      /* "yaml/_yaml.pyx":525
 *             elif event.data.stream_start.encoding == YAML_UTF16LE_ENCODING:
 *                 encoding = u"utf-16-le"
 *             elif event.data.stream_start.encoding == YAML_UTF16BE_ENCODING:             # <<<<<<<<<<<<<<
 *                 encoding = u"utf-16-be"
 *             return StreamStartEvent(start_mark, end_mark, encoding)
 */
      break;
      default: break;
    }

    /* "yaml/_yaml.pyx":527
 *             elif event.data.stream_start.encoding == YAML_UTF16BE_ENCODING:
 *                 encoding = u"utf-16-be"
 *             return StreamStartEvent(start_mark, end_mark, encoding)             # <<<<<<<<<<<<<<
 *         elif event.type == YAML_STREAM_END_EVENT:
 *             return StreamEndEvent(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_StreamStartEvent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 527, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_4, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark), __pyx_v_encoding};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 527, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":518
 *         if event.type == YAML_NO_EVENT:
 *             return None
 *         elif event.type == YAML_STREAM_START_EVENT:             # <<<<<<<<<<<<<<
 *             encoding = None
 *             if event.data.stream_start.encoding == YAML_UTF8_ENCODING:
 */
    break;
    case YAML_STREAM_END_EVENT:

    /* "yaml/_yaml.pyx":529
 *             return StreamStartEvent(start_mark, end_mark, encoding)
 *         elif event.type == YAML_STREAM_END_EVENT:
 *             return StreamEndEvent(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif event.type == YAML_DOCUMENT_START_EVENT:
 *             explicit = False
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_StreamEndEvent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 529, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":528
 *                 encoding = u"utf-16-be"
 *             return StreamStartEvent(start_mark, end_mark, encoding)
 *         elif event.type == YAML_STREAM_END_EVENT:             # <<<<<<<<<<<<<<
 *             return StreamEndEvent(start_mark, end_mark)
 *         elif event.type == YAML_DOCUMENT_START_EVENT:
 */
    break;
    case YAML_DOCUMENT_START_EVENT:

    /* "yaml/_yaml.pyx":531
 *             return StreamEndEvent(start_mark, end_mark)
 *         elif event.type == YAML_DOCUMENT_START_EVENT:
 *             explicit = False             # <<<<<<<<<<<<<<
 *             if event.data.document_start.implicit == 0:
 *                 explicit = True
 */
    __pyx_v_explicit = 0;

    /* "yaml/_yaml.pyx":532
 *         elif event.type == YAML_DOCUMENT_START_EVENT:
 *             explicit = False
 *             if event.data.document_start.implicit == 0:             # <<<<<<<<<<<<<<
 *                 explicit = True
 *             version = None
 */
    __pyx_t_5 = (__pyx_v_event->data.document_start.implicit == 0);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":533
 *             explicit = False
 *             if event.data.document_start.implicit == 0:
 *                 explicit = True             # <<<<<<<<<<<<<<
 *             version = None
 *             if event.data.document_start.version_directive != NULL:
 */
      __pyx_v_explicit = 1;

      /* "yaml/_yaml.pyx":532
 *         elif event.type == YAML_DOCUMENT_START_EVENT:
 *             explicit = False
 *             if event.data.document_start.implicit == 0:             # <<<<<<<<<<<<<<
 *                 explicit = True
 *             version = None
 */
    }

    /* "yaml/_yaml.pyx":534
 *             if event.data.document_start.implicit == 0:
 *                 explicit = True
 *             version = None             # <<<<<<<<<<<<<<
 *             if event.data.document_start.version_directive != NULL:
 *                 version = (event.data.document_start.version_directive.major,
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_version = Py_None;

    /* "yaml/_yaml.pyx":535
 *                 explicit = True
 *             version = None
 *             if event.data.document_start.version_directive != NULL:             # <<<<<<<<<<<<<<
 *                 version = (event.data.document_start.version_directive.major,
 *                         event.data.document_start.version_directive.minor)
 */
    __pyx_t_5 = (__pyx_v_event->data.document_start.version_directive != NULL);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":536
 *             version = None
 *             if event.data.document_start.version_directive != NULL:
 *                 version = (event.data.document_start.version_directive.major,             # <<<<<<<<<<<<<<
 *                         event.data.document_start.version_directive.minor)
 *             tags = None
 */
      __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_event->data.document_start.version_directive->major); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "yaml/_yaml.pyx":537
 *             if event.data.document_start.version_directive != NULL:
 *                 version = (event.data.document_start.version_directive.major,
 *                         event.data.document_start.version_directive.minor)             # <<<<<<<<<<<<<<
 *             tags = None
 *             if event.data.document_start.tag_directives.start != NULL:
 */
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_event->data.document_start.version_directive->minor); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 537, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);

      /* "yaml/_yaml.pyx":536
 *             version = None
 *             if event.data.document_start.version_directive != NULL:
 *                 version = (event.data.document_start.version_directive.major,             # <<<<<<<<<<<<<<
 *                         event.data.document_start.version_directive.minor)
 *             tags = None
 */
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(0, 536, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_1);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(0, 536, __pyx_L1_error);
      __pyx_t_2 = 0;
      __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_version, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "yaml/_yaml.pyx":535
 *                 explicit = True
 *             version = None
 *             if event.data.document_start.version_directive != NULL:             # <<<<<<<<<<<<<<
 *                 version = (event.data.document_start.version_directive.major,
 *                         event.data.document_start.version_directive.minor)
 */
    }

    /* "yaml/_yaml.pyx":538
 *                 version = (event.data.document_start.version_directive.major,
 *                         event.data.document_start.version_directive.minor)
 *             tags = None             # <<<<<<<<<<<<<<
 *             if event.data.document_start.tag_directives.start != NULL:
 *                 tags = {}
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_tags = ((PyObject*)Py_None);

    /* "yaml/_yaml.pyx":539
 *                         event.data.document_start.version_directive.minor)
 *             tags = None
 *             if event.data.document_start.tag_directives.start != NULL:             # <<<<<<<<<<<<<<
 *                 tags = {}
 *                 tag_directive = event.data.document_start.tag_directives.start
 */
    __pyx_t_5 = (__pyx_v_event->data.document_start.tag_directives.start != NULL);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":540
 *             tags = None
 *             if event.data.document_start.tag_directives.start != NULL:
 *                 tags = {}             # <<<<<<<<<<<<<<
 *                 tag_directive = event.data.document_start.tag_directives.start
 *                 while tag_directive != event.data.document_start.tag_directives.end:
 */
      __pyx_t_4 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_tags, ((PyObject*)__pyx_t_4));
      __pyx_t_4 = 0;

      /* "yaml/_yaml.pyx":541
 *             if event.data.document_start.tag_directives.start != NULL:
 *                 tags = {}
 *                 tag_directive = event.data.document_start.tag_directives.start             # <<<<<<<<<<<<<<
 *                 while tag_directive != event.data.document_start.tag_directives.end:
 *                     handle = PyUnicode_FromYamlString(tag_directive.handle)
 */
      __pyx_t_7 = __pyx_v_event->data.document_start.tag_directives.start;
      __pyx_v_tag_directive = __pyx_t_7;

      /* "yaml/_yaml.pyx":542
 *                 tags = {}
 *                 tag_directive = event.data.document_start.tag_directives.start
 *                 while tag_directive != event.data.document_start.tag_directives.end:             # <<<<<<<<<<<<<<
 *                     handle = PyUnicode_FromYamlString(tag_directive.handle)
 *                     prefix = PyUnicode_FromYamlString(tag_directive.prefix)
 */
      while (1) {
        __pyx_t_5 = (__pyx_v_tag_directive != __pyx_v_event->data.document_start.tag_directives.end);
        if (!__pyx_t_5) break;

        /* "yaml/_yaml.pyx":543
 *                 tag_directive = event.data.document_start.tag_directives.start
 *                 while tag_directive != event.data.document_start.tag_directives.end:
 *                     handle = PyUnicode_FromYamlString(tag_directive.handle)             # <<<<<<<<<<<<<<
 *                     prefix = PyUnicode_FromYamlString(tag_directive.prefix)
 *                     tags[handle] = prefix
 */
        __pyx_t_4 = PyUnicode_FromYamlString(__pyx_v_tag_directive->handle); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 543, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_v_handle, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "yaml/_yaml.pyx":544
 *                 while tag_directive != event.data.document_start.tag_directives.end:
 *                     handle = PyUnicode_FromYamlString(tag_directive.handle)
 *                     prefix = PyUnicode_FromYamlString(tag_directive.prefix)             # <<<<<<<<<<<<<<
 *                     tags[handle] = prefix
 *                     tag_directive = tag_directive+1
 */
        __pyx_t_4 = PyUnicode_FromYamlString(__pyx_v_tag_directive->prefix); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 544, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_XDECREF_SET(__pyx_v_prefix, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "yaml/_yaml.pyx":545
 *                     handle = PyUnicode_FromYamlString(tag_directive.handle)
 *                     prefix = PyUnicode_FromYamlString(tag_directive.prefix)
 *                     tags[handle] = prefix             # <<<<<<<<<<<<<<
 *                     tag_directive = tag_directive+1
 *             return DocumentStartEvent(start_mark, end_mark,
 */
        if (unlikely((PyDict_SetItem(__pyx_v_tags, __pyx_v_handle, __pyx_v_prefix) < 0))) __PYX_ERR(0, 545, __pyx_L1_error)

        /* "yaml/_yaml.pyx":546
 *                     prefix = PyUnicode_FromYamlString(tag_directive.prefix)
 *                     tags[handle] = prefix
 *                     tag_directive = tag_directive+1             # <<<<<<<<<<<<<<
 *             return DocumentStartEvent(start_mark, end_mark,
 *                     explicit, version, tags)
 */
        __pyx_v_tag_directive = (__pyx_v_tag_directive + 1);
      }

      /* "yaml/_yaml.pyx":539
 *                         event.data.document_start.version_directive.minor)
 *             tags = None
 *             if event.data.document_start.tag_directives.start != NULL:             # <<<<<<<<<<<<<<
 *                 tags = {}
 *                 tag_directive = event.data.document_start.tag_directives.start
 */
    }

    /* "yaml/_yaml.pyx":547
 *                     tags[handle] = prefix
 *                     tag_directive = tag_directive+1
 *             return DocumentStartEvent(start_mark, end_mark,             # <<<<<<<<<<<<<<
 *                     explicit, version, tags)
 *         elif event.type == YAML_DOCUMENT_END_EVENT:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_DocumentStartEvent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 547, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "yaml/_yaml.pyx":548
 *                     tag_directive = tag_directive+1
 *             return DocumentStartEvent(start_mark, end_mark,
 *                     explicit, version, tags)             # <<<<<<<<<<<<<<
 *         elif event.type == YAML_DOCUMENT_END_EVENT:
 *             explicit = False
 */
    __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_explicit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 548, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[6] = {__pyx_t_3, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark), __pyx_t_2, __pyx_v_version, __pyx_v_tags};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 5+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 547, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":530
 *         elif event.type == YAML_STREAM_END_EVENT:
 *             return StreamEndEvent(start_mark, end_mark)
 *         elif event.type == YAML_DOCUMENT_START_EVENT:             # <<<<<<<<<<<<<<
 *             explicit = False
 *             if event.data.document_start.implicit == 0:
 */
    break;
    case YAML_DOCUMENT_END_EVENT:

    /* "yaml/_yaml.pyx":550
 *                     explicit, version, tags)
 *         elif event.type == YAML_DOCUMENT_END_EVENT:
 *             explicit = False             # <<<<<<<<<<<<<<
 *             if event.data.document_end.implicit == 0:
 *                 explicit = True
 */
    __pyx_v_explicit = 0;

    /* "yaml/_yaml.pyx":551
 *         elif event.type == YAML_DOCUMENT_END_EVENT:
 *             explicit = False
 *             if event.data.document_end.implicit == 0:             # <<<<<<<<<<<<<<
 *                 explicit = True
 *             return DocumentEndEvent(start_mark, end_mark, explicit)
 */
    __pyx_t_5 = (__pyx_v_event->data.document_end.implicit == 0);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":552
 *             explicit = False
 *             if event.data.document_end.implicit == 0:
 *                 explicit = True             # <<<<<<<<<<<<<<
 *             return DocumentEndEvent(start_mark, end_mark, explicit)
 *         elif event.type == YAML_ALIAS_EVENT:
 */
      __pyx_v_explicit = 1;

      /* "yaml/_yaml.pyx":551
 *         elif event.type == YAML_DOCUMENT_END_EVENT:
 *             explicit = False
 *             if event.data.document_end.implicit == 0:             # <<<<<<<<<<<<<<
 *                 explicit = True
 *             return DocumentEndEvent(start_mark, end_mark, explicit)
 */
    }

    /* "yaml/_yaml.pyx":553
 *             if event.data.document_end.implicit == 0:
 *                 explicit = True
 *             return DocumentEndEvent(start_mark, end_mark, explicit)             # <<<<<<<<<<<<<<
 *         elif event.type == YAML_ALIAS_EVENT:
 *             anchor = PyUnicode_FromYamlString(event.data.alias.anchor)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_DocumentEndEvent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_explicit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_3, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark), __pyx_t_2};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 553, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":549
 *             return DocumentStartEvent(start_mark, end_mark,
 *                     explicit, version, tags)
 *         elif event.type == YAML_DOCUMENT_END_EVENT:             # <<<<<<<<<<<<<<
 *             explicit = False
 *             if event.data.document_end.implicit == 0:
 */
    break;
    case YAML_ALIAS_EVENT:

    /* "yaml/_yaml.pyx":555
 *             return DocumentEndEvent(start_mark, end_mark, explicit)
 *         elif event.type == YAML_ALIAS_EVENT:
 *             anchor = PyUnicode_FromYamlString(event.data.alias.anchor)             # <<<<<<<<<<<<<<
 *             return AliasEvent(anchor, start_mark, end_mark)
 *         elif event.type == YAML_SCALAR_EVENT:
 */
    __pyx_t_4 = PyUnicode_FromYamlString(__pyx_v_event->data.alias.anchor); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_anchor = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":556
 *         elif event.type == YAML_ALIAS_EVENT:
 *             anchor = PyUnicode_FromYamlString(event.data.alias.anchor)
 *             return AliasEvent(anchor, start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif event.type == YAML_SCALAR_EVENT:
 *             anchor = None
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_AliasEvent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_2, __pyx_v_anchor, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 3+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 556, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":554
 *                 explicit = True
 *             return DocumentEndEvent(start_mark, end_mark, explicit)
 *         elif event.type == YAML_ALIAS_EVENT:             # <<<<<<<<<<<<<<
 *             anchor = PyUnicode_FromYamlString(event.data.alias.anchor)
 *             return AliasEvent(anchor, start_mark, end_mark)
 */
    break;
    case YAML_SCALAR_EVENT:

    /* "yaml/_yaml.pyx":558
 *             return AliasEvent(anchor, start_mark, end_mark)
 *         elif event.type == YAML_SCALAR_EVENT:
 *             anchor = None             # <<<<<<<<<<<<<<
 *             if event.data.scalar.anchor != NULL:
 *                 anchor = PyUnicode_FromYamlString(event.data.scalar.anchor)
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_anchor = Py_None;

    /* "yaml/_yaml.pyx":559
 *         elif event.type == YAML_SCALAR_EVENT:
 *             anchor = None
 *             if event.data.scalar.anchor != NULL:             # <<<<<<<<<<<<<<
 *                 anchor = PyUnicode_FromYamlString(event.data.scalar.anchor)
 *             tag = None
 */
    __pyx_t_5 = (__pyx_v_event->data.scalar.anchor != NULL);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":560
 *             anchor = None
 *             if event.data.scalar.anchor != NULL:
 *                 anchor = PyUnicode_FromYamlString(event.data.scalar.anchor)             # <<<<<<<<<<<<<<
 *             tag = None
 *             if event.data.scalar.tag != NULL:
 */
      __pyx_t_4 = PyUnicode_FromYamlString(__pyx_v_event->data.scalar.anchor); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 560, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_anchor, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "yaml/_yaml.pyx":559
 *         elif event.type == YAML_SCALAR_EVENT:
 *             anchor = None
 *             if event.data.scalar.anchor != NULL:             # <<<<<<<<<<<<<<
 *                 anchor = PyUnicode_FromYamlString(event.data.scalar.anchor)
 *             tag = None
 */
    }

    /* "yaml/_yaml.pyx":561
 *             if event.data.scalar.anchor != NULL:
 *                 anchor = PyUnicode_FromYamlString(event.data.scalar.anchor)
 *             tag = None             # <<<<<<<<<<<<<<
 *             if event.data.scalar.tag != NULL:
 *                 tag = PyUnicode_FromYamlString(event.data.scalar.tag)
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_tag = Py_None;

    /* "yaml/_yaml.pyx":562
 *                 anchor = PyUnicode_FromYamlString(event.data.scalar.anchor)
 *             tag = None
 *             if event.data.scalar.tag != NULL:             # <<<<<<<<<<<<<<
 *                 tag = PyUnicode_FromYamlString(event.data.scalar.tag)
 *             value = PyUnicode_DecodeUTF8(<char *>event.data.scalar.value,
 */
    __pyx_t_5 = (__pyx_v_event->data.scalar.tag != NULL);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":563
 *             tag = None
 *             if event.data.scalar.tag != NULL:
 *                 tag = PyUnicode_FromYamlString(event.data.scalar.tag)             # <<<<<<<<<<<<<<
 *             value = PyUnicode_DecodeUTF8(<char *>event.data.scalar.value,
 *                     event.data.scalar.length, 'strict')
 */
      __pyx_t_4 = PyUnicode_FromYamlString(__pyx_v_event->data.scalar.tag); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 563, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_tag, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "yaml/_yaml.pyx":562
 *                 anchor = PyUnicode_FromYamlString(event.data.scalar.anchor)
 *             tag = None
 *             if event.data.scalar.tag != NULL:             # <<<<<<<<<<<<<<
 *                 tag = PyUnicode_FromYamlString(event.data.scalar.tag)
 *             value = PyUnicode_DecodeUTF8(<char *>event.data.scalar.value,
 */
    }

    /* "yaml/_yaml.pyx":564
 *             if event.data.scalar.tag != NULL:
 *                 tag = PyUnicode_FromYamlString(event.data.scalar.tag)
 *             value = PyUnicode_DecodeUTF8(<char *>event.data.scalar.value,             # <<<<<<<<<<<<<<
 *                     event.data.scalar.length, 'strict')
 *             plain_implicit = False
 */
    __pyx_t_4 = PyUnicode_DecodeUTF8(((char *)__pyx_v_event->data.scalar.value), __pyx_v_event->data.scalar.length, ((char *)"strict")); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 564, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_value = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":566
 *             value = PyUnicode_DecodeUTF8(<char *>event.data.scalar.value,
 *                     event.data.scalar.length, 'strict')
 *             plain_implicit = False             # <<<<<<<<<<<<<<
 *             if event.data.scalar.plain_implicit == 1:
 *                 plain_implicit = True
 */
    __pyx_v_plain_implicit = 0;

    /* "yaml/_yaml.pyx":567
 *                     event.data.scalar.length, 'strict')
 *             plain_implicit = False
 *             if event.data.scalar.plain_implicit == 1:             # <<<<<<<<<<<<<<
 *                 plain_implicit = True
 *             quoted_implicit = False
 */
    __pyx_t_5 = (__pyx_v_event->data.scalar.plain_implicit == 1);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":568
 *             plain_implicit = False
 *             if event.data.scalar.plain_implicit == 1:
 *                 plain_implicit = True             # <<<<<<<<<<<<<<
 *             quoted_implicit = False
 *             if event.data.scalar.quoted_implicit == 1:
 */
      __pyx_v_plain_implicit = 1;

      /* "yaml/_yaml.pyx":567
 *                     event.data.scalar.length, 'strict')
 *             plain_implicit = False
 *             if event.data.scalar.plain_implicit == 1:             # <<<<<<<<<<<<<<
 *                 plain_implicit = True
 *             quoted_implicit = False
 */
    }

    /* "yaml/_yaml.pyx":569
 *             if event.data.scalar.plain_implicit == 1:
 *                 plain_implicit = True
 *             quoted_implicit = False             # <<<<<<<<<<<<<<
 *             if event.data.scalar.quoted_implicit == 1:
 *                 quoted_implicit = True
 */
    __pyx_v_quoted_implicit = 0;

    /* "yaml/_yaml.pyx":570
 *                 plain_implicit = True
 *             quoted_implicit = False
 *             if event.data.scalar.quoted_implicit == 1:             # <<<<<<<<<<<<<<
 *                 quoted_implicit = True
 *             style = None
 */
    __pyx_t_5 = (__pyx_v_event->data.scalar.quoted_implicit == 1);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":571
 *             quoted_implicit = False
 *             if event.data.scalar.quoted_implicit == 1:
 *                 quoted_implicit = True             # <<<<<<<<<<<<<<
 *             style = None
 *             if event.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:
 */
      __pyx_v_quoted_implicit = 1;

      /* "yaml/_yaml.pyx":570
 *                 plain_implicit = True
 *             quoted_implicit = False
 *             if event.data.scalar.quoted_implicit == 1:             # <<<<<<<<<<<<<<
 *                 quoted_implicit = True
 *             style = None
 */
    }

    /* "yaml/_yaml.pyx":572
 *             if event.data.scalar.quoted_implicit == 1:
 *                 quoted_implicit = True
 *             style = None             # <<<<<<<<<<<<<<
 *             if event.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:
 *                 style = u''
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_style = ((PyObject*)Py_None);

    /* "yaml/_yaml.pyx":573
 *                 quoted_implicit = True
 *             style = None
 *             if event.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *                 style = u''
 *             elif event.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 */
    switch (__pyx_v_event->data.scalar.style) {
      case YAML_PLAIN_SCALAR_STYLE:

      /* "yaml/_yaml.pyx":574
 *             style = None
 *             if event.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:
 *                 style = u''             # <<<<<<<<<<<<<<
 *             elif event.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 *                 style = u'\''
 */
      __Pyx_INCREF(__pyx_kp_u__4);
      __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__4);

      /* "yaml/_yaml.pyx":573
 *                 quoted_implicit = True
 *             style = None
 *             if event.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *                 style = u''
 *             elif event.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 */
      break;
      case YAML_SINGLE_QUOTED_SCALAR_STYLE:

      /* "yaml/_yaml.pyx":576
 *                 style = u''
 *             elif event.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 *                 style = u'\''             # <<<<<<<<<<<<<<
 *             elif event.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:
 *                 style = u'"'
 */
      __Pyx_INCREF(__pyx_kp_u__5);
      __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__5);

      /* "yaml/_yaml.pyx":575
 *             if event.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:
 *                 style = u''
 *             elif event.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *                 style = u'\''
 *             elif event.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:
 */
      break;
      case YAML_DOUBLE_QUOTED_SCALAR_STYLE:

      /* "yaml/_yaml.pyx":578
 *                 style = u'\''
 *             elif event.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:
 *                 style = u'"'             # <<<<<<<<<<<<<<
 *             elif event.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:
 *                 style = u'|'
 */
      __Pyx_INCREF(__pyx_kp_u__6);
      __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__6);

      /* "yaml/_yaml.pyx":577
 *             elif event.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 *                 style = u'\''
 *             elif event.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *                 style = u'"'
 *             elif event.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:
 */
      break;
      case YAML_LITERAL_SCALAR_STYLE:

      /* "yaml/_yaml.pyx":580
 *                 style = u'"'
 *             elif event.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:
 *                 style = u'|'             # <<<<<<<<<<<<<<
 *             elif event.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:
 *                 style = u'>'
 */
      __Pyx_INCREF(__pyx_kp_u__7);
      __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__7);

      /* "yaml/_yaml.pyx":579
 *             elif event.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:
 *                 style = u'"'
 *             elif event.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *                 style = u'|'
 *             elif event.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:
 */
      break;
      case YAML_FOLDED_SCALAR_STYLE:

      /* "yaml/_yaml.pyx":582
 *                 style = u'|'
 *             elif event.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:
 *                 style = u'>'             # <<<<<<<<<<<<<<
 *             return ScalarEvent(anchor, tag,
 *                     (plain_implicit, quoted_implicit),
 */
      __Pyx_INCREF(__pyx_kp_u__8);
      __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__8);

      /* "yaml/_yaml.pyx":581
 *             elif event.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:
 *                 style = u'|'
 *             elif event.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *                 style = u'>'
 *             return ScalarEvent(anchor, tag,
 */
      break;
      default: break;
    }

    /* "yaml/_yaml.pyx":583
 *             elif event.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:
 *                 style = u'>'
 *             return ScalarEvent(anchor, tag,             # <<<<<<<<<<<<<<
 *                     (plain_implicit, quoted_implicit),
 *                     value, start_mark, end_mark, style)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ScalarEvent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "yaml/_yaml.pyx":584
 *                 style = u'>'
 *             return ScalarEvent(anchor, tag,
 *                     (plain_implicit, quoted_implicit),             # <<<<<<<<<<<<<<
 *                     value, start_mark, end_mark, style)
 *         elif event.type == YAML_SEQUENCE_START_EVENT:
 */
    __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_plain_implicit); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_quoted_implicit); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2)) __PYX_ERR(0, 584, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_3)) __PYX_ERR(0, 584, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;

    /* "yaml/_yaml.pyx":585
 *             return ScalarEvent(anchor, tag,
 *                     (plain_implicit, quoted_implicit),
 *                     value, start_mark, end_mark, style)             # <<<<<<<<<<<<<<
 *         elif event.type == YAML_SEQUENCE_START_EVENT:
 *             anchor = None
 */
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[8] = {__pyx_t_3, __pyx_v_anchor, __pyx_v_tag, __pyx_t_8, __pyx_v_value, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark), __pyx_v_style};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 7+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 583, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":557
 *             anchor = PyUnicode_FromYamlString(event.data.alias.anchor)
 *             return AliasEvent(anchor, start_mark, end_mark)
 *         elif event.type == YAML_SCALAR_EVENT:             # <<<<<<<<<<<<<<
 *             anchor = None
 *             if event.data.scalar.anchor != NULL:
 */
    break;
    case YAML_SEQUENCE_START_EVENT:

    /* "yaml/_yaml.pyx":587
 *                     value, start_mark, end_mark, style)
 *         elif event.type == YAML_SEQUENCE_START_EVENT:
 *             anchor = None             # <<<<<<<<<<<<<<
 *             if event.data.sequence_start.anchor != NULL:
 *                 anchor = PyUnicode_FromYamlString(event.data.sequence_start.anchor)
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_anchor = Py_None;

    /* "yaml/_yaml.pyx":588
 *         elif event.type == YAML_SEQUENCE_START_EVENT:
 *             anchor = None
 *             if event.data.sequence_start.anchor != NULL:             # <<<<<<<<<<<<<<
 *                 anchor = PyUnicode_FromYamlString(event.data.sequence_start.anchor)
 *             tag = None
 */
    __pyx_t_5 = (__pyx_v_event->data.sequence_start.anchor != NULL);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":589
 *             anchor = None
 *             if event.data.sequence_start.anchor != NULL:
 *                 anchor = PyUnicode_FromYamlString(event.data.sequence_start.anchor)             # <<<<<<<<<<<<<<
 *             tag = None
 *             if event.data.sequence_start.tag != NULL:
 */
      __pyx_t_4 = PyUnicode_FromYamlString(__pyx_v_event->data.sequence_start.anchor); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 589, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_anchor, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "yaml/_yaml.pyx":588
 *         elif event.type == YAML_SEQUENCE_START_EVENT:
 *             anchor = None
 *             if event.data.sequence_start.anchor != NULL:             # <<<<<<<<<<<<<<
 *                 anchor = PyUnicode_FromYamlString(event.data.sequence_start.anchor)
 *             tag = None
 */
    }

    /* "yaml/_yaml.pyx":590
 *             if event.data.sequence_start.anchor != NULL:
 *                 anchor = PyUnicode_FromYamlString(event.data.sequence_start.anchor)
 *             tag = None             # <<<<<<<<<<<<<<
 *             if event.data.sequence_start.tag != NULL:
 *                 tag = PyUnicode_FromYamlString(event.data.sequence_start.tag)
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_tag = Py_None;

    /* "yaml/_yaml.pyx":591
 *                 anchor = PyUnicode_FromYamlString(event.data.sequence_start.anchor)
 *             tag = None
 *             if event.data.sequence_start.tag != NULL:             # <<<<<<<<<<<<<<
 *                 tag = PyUnicode_FromYamlString(event.data.sequence_start.tag)
 *             implicit = False
 */
    __pyx_t_5 = (__pyx_v_event->data.sequence_start.tag != NULL);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":592
 *             tag = None
 *             if event.data.sequence_start.tag != NULL:
 *                 tag = PyUnicode_FromYamlString(event.data.sequence_start.tag)             # <<<<<<<<<<<<<<
 *             implicit = False
 *             if event.data.sequence_start.implicit == 1:
 */
      __pyx_t_4 = PyUnicode_FromYamlString(__pyx_v_event->data.sequence_start.tag); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 592, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_tag, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "yaml/_yaml.pyx":591
 *                 anchor = PyUnicode_FromYamlString(event.data.sequence_start.anchor)
 *             tag = None
 *             if event.data.sequence_start.tag != NULL:             # <<<<<<<<<<<<<<
 *                 tag = PyUnicode_FromYamlString(event.data.sequence_start.tag)
 *             implicit = False
 */
    }

    /* "yaml/_yaml.pyx":593
 *             if event.data.sequence_start.tag != NULL:
 *                 tag = PyUnicode_FromYamlString(event.data.sequence_start.tag)
 *             implicit = False             # <<<<<<<<<<<<<<
 *             if event.data.sequence_start.implicit == 1:
 *                 implicit = True
 */
    __pyx_v_implicit = 0;

    /* "yaml/_yaml.pyx":594
 *                 tag = PyUnicode_FromYamlString(event.data.sequence_start.tag)
 *             implicit = False
 *             if event.data.sequence_start.implicit == 1:             # <<<<<<<<<<<<<<
 *                 implicit = True
 *             flow_style = None
 */
    __pyx_t_5 = (__pyx_v_event->data.sequence_start.implicit == 1);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":595
 *             implicit = False
 *             if event.data.sequence_start.implicit == 1:
 *                 implicit = True             # <<<<<<<<<<<<<<
 *             flow_style = None
 *             if event.data.sequence_start.style == YAML_FLOW_SEQUENCE_STYLE:
 */
      __pyx_v_implicit = 1;

      /* "yaml/_yaml.pyx":594
 *                 tag = PyUnicode_FromYamlString(event.data.sequence_start.tag)
 *             implicit = False
 *             if event.data.sequence_start.implicit == 1:             # <<<<<<<<<<<<<<
 *                 implicit = True
 *             flow_style = None
 */
    }

    /* "yaml/_yaml.pyx":596
 *             if event.data.sequence_start.implicit == 1:
 *                 implicit = True
 *             flow_style = None             # <<<<<<<<<<<<<<
 *             if event.data.sequence_start.style == YAML_FLOW_SEQUENCE_STYLE:
 *                 flow_style = True
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_flow_style = Py_None;

    /* "yaml/_yaml.pyx":597
 *                 implicit = True
 *             flow_style = None
 *             if event.data.sequence_start.style == YAML_FLOW_SEQUENCE_STYLE:             # <<<<<<<<<<<<<<
 *                 flow_style = True
 *             elif event.data.sequence_start.style == YAML_BLOCK_SEQUENCE_STYLE:
 */
    switch (__pyx_v_event->data.sequence_start.style) {
      case YAML_FLOW_SEQUENCE_STYLE:

      /* "yaml/_yaml.pyx":598
 *             flow_style = None
 *             if event.data.sequence_start.style == YAML_FLOW_SEQUENCE_STYLE:
 *                 flow_style = True             # <<<<<<<<<<<<<<
 *             elif event.data.sequence_start.style == YAML_BLOCK_SEQUENCE_STYLE:
 *                 flow_style = False
 */
      __Pyx_INCREF(Py_True);
      __Pyx_DECREF_SET(__pyx_v_flow_style, Py_True);

      /* "yaml/_yaml.pyx":597
 *                 implicit = True
 *             flow_style = None
 *             if event.data.sequence_start.style == YAML_FLOW_SEQUENCE_STYLE:             # <<<<<<<<<<<<<<
 *                 flow_style = True
 *             elif event.data.sequence_start.style == YAML_BLOCK_SEQUENCE_STYLE:
 */
      break;
      case YAML_BLOCK_SEQUENCE_STYLE:

      /* "yaml/_yaml.pyx":600
 *                 flow_style = True
 *             elif event.data.sequence_start.style == YAML_BLOCK_SEQUENCE_STYLE:
 *                 flow_style = False             # <<<<<<<<<<<<<<
 *             return SequenceStartEvent(anchor, tag, implicit,
 *                     start_mark, end_mark, flow_style)
 */
      __Pyx_INCREF(Py_False);
      __Pyx_DECREF_SET(__pyx_v_flow_style, Py_False);

      /* "yaml/_yaml.pyx":599
 *             if event.data.sequence_start.style == YAML_FLOW_SEQUENCE_STYLE:
 *                 flow_style = True
 *             elif event.data.sequence_start.style == YAML_BLOCK_SEQUENCE_STYLE:             # <<<<<<<<<<<<<<
 *                 flow_style = False
 *             return SequenceStartEvent(anchor, tag, implicit,
 */
      break;
      default: break;
    }

    /* "yaml/_yaml.pyx":601
 *             elif event.data.sequence_start.style == YAML_BLOCK_SEQUENCE_STYLE:
 *                 flow_style = False
 *             return SequenceStartEvent(anchor, tag, implicit,             # <<<<<<<<<<<<<<
 *                     start_mark, end_mark, flow_style)
 *         elif event.type == YAML_MAPPING_START_EVENT:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SequenceStartEvent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyBool_FromLong(__pyx_v_implicit); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);

    /* "yaml/_yaml.pyx":602
 *                 flow_style = False
 *             return SequenceStartEvent(anchor, tag, implicit,
 *                     start_mark, end_mark, flow_style)             # <<<<<<<<<<<<<<
 *         elif event.type == YAML_MAPPING_START_EVENT:
 *             anchor = None
 */
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[7] = {__pyx_t_3, __pyx_v_anchor, __pyx_v_tag, __pyx_t_8, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark), __pyx_v_flow_style};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 6+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 601, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":586
 *                     (plain_implicit, quoted_implicit),
 *                     value, start_mark, end_mark, style)
 *         elif event.type == YAML_SEQUENCE_START_EVENT:             # <<<<<<<<<<<<<<
 *             anchor = None
 *             if event.data.sequence_start.anchor != NULL:
 */
    break;
    case YAML_MAPPING_START_EVENT:

    /* "yaml/_yaml.pyx":604
 *                     start_mark, end_mark, flow_style)
 *         elif event.type == YAML_MAPPING_START_EVENT:
 *             anchor = None             # <<<<<<<<<<<<<<
 *             if event.data.mapping_start.anchor != NULL:
 *                 anchor = PyUnicode_FromYamlString(event.data.mapping_start.anchor)
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_anchor = Py_None;

    /* "yaml/_yaml.pyx":605
 *         elif event.type == YAML_MAPPING_START_EVENT:
 *             anchor = None
 *             if event.data.mapping_start.anchor != NULL:             # <<<<<<<<<<<<<<
 *                 anchor = PyUnicode_FromYamlString(event.data.mapping_start.anchor)
 *             tag = None
 */
    __pyx_t_5 = (__pyx_v_event->data.mapping_start.anchor != NULL);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":606
 *             anchor = None
 *             if event.data.mapping_start.anchor != NULL:
 *                 anchor = PyUnicode_FromYamlString(event.data.mapping_start.anchor)             # <<<<<<<<<<<<<<
 *             tag = None
 *             if event.data.mapping_start.tag != NULL:
 */
      __pyx_t_4 = PyUnicode_FromYamlString(__pyx_v_event->data.mapping_start.anchor); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_anchor, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "yaml/_yaml.pyx":605
 *         elif event.type == YAML_MAPPING_START_EVENT:
 *             anchor = None
 *             if event.data.mapping_start.anchor != NULL:             # <<<<<<<<<<<<<<
 *                 anchor = PyUnicode_FromYamlString(event.data.mapping_start.anchor)
 *             tag = None
 */
    }

    /* "yaml/_yaml.pyx":607
 *             if event.data.mapping_start.anchor != NULL:
 *                 anchor = PyUnicode_FromYamlString(event.data.mapping_start.anchor)
 *             tag = None             # <<<<<<<<<<<<<<
 *             if event.data.mapping_start.tag != NULL:
 *                 tag = PyUnicode_FromYamlString(event.data.mapping_start.tag)
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_tag = Py_None;

    /* "yaml/_yaml.pyx":608
 *                 anchor = PyUnicode_FromYamlString(event.data.mapping_start.anchor)
 *             tag = None
 *             if event.data.mapping_start.tag != NULL:             # <<<<<<<<<<<<<<
 *                 tag = PyUnicode_FromYamlString(event.data.mapping_start.tag)
 *             implicit = False
 */
    __pyx_t_5 = (__pyx_v_event->data.mapping_start.tag != NULL);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":609
 *             tag = None
 *             if event.data.mapping_start.tag != NULL:
 *                 tag = PyUnicode_FromYamlString(event.data.mapping_start.tag)             # <<<<<<<<<<<<<<
 *             implicit = False
 *             if event.data.mapping_start.implicit == 1:
 */
      __pyx_t_4 = PyUnicode_FromYamlString(__pyx_v_event->data.mapping_start.tag); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 609, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_tag, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "yaml/_yaml.pyx":608
 *                 anchor = PyUnicode_FromYamlString(event.data.mapping_start.anchor)
 *             tag = None
 *             if event.data.mapping_start.tag != NULL:             # <<<<<<<<<<<<<<
 *                 tag = PyUnicode_FromYamlString(event.data.mapping_start.tag)
 *             implicit = False
 */
    }

    /* "yaml/_yaml.pyx":610
 *             if event.data.mapping_start.tag != NULL:
 *                 tag = PyUnicode_FromYamlString(event.data.mapping_start.tag)
 *             implicit = False             # <<<<<<<<<<<<<<
 *             if event.data.mapping_start.implicit == 1:
 *                 implicit = True
 */
    __pyx_v_implicit = 0;

    /* "yaml/_yaml.pyx":611
 *                 tag = PyUnicode_FromYamlString(event.data.mapping_start.tag)
 *             implicit = False
 *             if event.data.mapping_start.implicit == 1:             # <<<<<<<<<<<<<<
 *                 implicit = True
 *             flow_style = None
 */
    __pyx_t_5 = (__pyx_v_event->data.mapping_start.implicit == 1);
    if (__pyx_t_5) {

      /* "yaml/_yaml.pyx":612
 *             implicit = False
 *             if event.data.mapping_start.implicit == 1:
 *                 implicit = True             # <<<<<<<<<<<<<<
 *             flow_style = None
 *             if event.data.mapping_start.style == YAML_FLOW_MAPPING_STYLE:
 */
      __pyx_v_implicit = 1;

      /* "yaml/_yaml.pyx":611
 *                 tag = PyUnicode_FromYamlString(event.data.mapping_start.tag)
 *             implicit = False
 *             if event.data.mapping_start.implicit == 1:             # <<<<<<<<<<<<<<
 *                 implicit = True
 *             flow_style = None
 */
    }

    /* "yaml/_yaml.pyx":613
 *             if event.data.mapping_start.implicit == 1:
 *                 implicit = True
 *             flow_style = None             # <<<<<<<<<<<<<<
 *             if event.data.mapping_start.style == YAML_FLOW_MAPPING_STYLE:
 *                 flow_style = True
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_flow_style = Py_None;

    /* "yaml/_yaml.pyx":614
 *                 implicit = True
 *             flow_style = None
 *             if event.data.mapping_start.style == YAML_FLOW_MAPPING_STYLE:             # <<<<<<<<<<<<<<
 *                 flow_style = True
 *             elif event.data.mapping_start.style == YAML_BLOCK_MAPPING_STYLE:
 */
    switch (__pyx_v_event->data.mapping_start.style) {
      case YAML_FLOW_MAPPING_STYLE:

      /* "yaml/_yaml.pyx":615
 *             flow_style = None
 *             if event.data.mapping_start.style == YAML_FLOW_MAPPING_STYLE:
 *                 flow_style = True             # <<<<<<<<<<<<<<
 *             elif event.data.mapping_start.style == YAML_BLOCK_MAPPING_STYLE:
 *                 flow_style = False
 */
      __Pyx_INCREF(Py_True);
      __Pyx_DECREF_SET(__pyx_v_flow_style, Py_True);

      /* "yaml/_yaml.pyx":614
 *                 implicit = True
 *             flow_style = None
 *             if event.data.mapping_start.style == YAML_FLOW_MAPPING_STYLE:             # <<<<<<<<<<<<<<
 *                 flow_style = True
 *             elif event.data.mapping_start.style == YAML_BLOCK_MAPPING_STYLE:
 */
      break;
      case YAML_BLOCK_MAPPING_STYLE:

      /* "yaml/_yaml.pyx":617
 *                 flow_style = True
 *             elif event.data.mapping_start.style == YAML_BLOCK_MAPPING_STYLE:
 *                 flow_style = False             # <<<<<<<<<<<<<<
 *             return MappingStartEvent(anchor, tag, implicit,
 *                     start_mark, end_mark, flow_style)
 */
      __Pyx_INCREF(Py_False);
      __Pyx_DECREF_SET(__pyx_v_flow_style, Py_False);

      /* "yaml/_yaml.pyx":616
 *             if event.data.mapping_start.style == YAML_FLOW_MAPPING_STYLE:
 *                 flow_style = True
 *             elif event.data.mapping_start.style == YAML_BLOCK_MAPPING_STYLE:             # <<<<<<<<<<<<<<
 *                 flow_style = False
 *             return MappingStartEvent(anchor, tag, implicit,
 */
      break;
      default: break;
    }

    /* "yaml/_yaml.pyx":618
 *             elif event.data.mapping_start.style == YAML_BLOCK_MAPPING_STYLE:
 *                 flow_style = False
 *             return MappingStartEvent(anchor, tag, implicit,             # <<<<<<<<<<<<<<
 *                     start_mark, end_mark, flow_style)
 *         elif event.type == YAML_SEQUENCE_END_EVENT:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MappingStartEvent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_PyBool_FromLong(__pyx_v_implicit); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);

    /* "yaml/_yaml.pyx":619
 *                 flow_style = False
 *             return MappingStartEvent(anchor, tag, implicit,
 *                     start_mark, end_mark, flow_style)             # <<<<<<<<<<<<<<
 *         elif event.type == YAML_SEQUENCE_END_EVENT:
 *             return SequenceEndEvent(start_mark, end_mark)
 */
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[7] = {__pyx_t_3, __pyx_v_anchor, __pyx_v_tag, __pyx_t_8, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark), __pyx_v_flow_style};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 6+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 618, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":603
 *             return SequenceStartEvent(anchor, tag, implicit,
 *                     start_mark, end_mark, flow_style)
 *         elif event.type == YAML_MAPPING_START_EVENT:             # <<<<<<<<<<<<<<
 *             anchor = None
 *             if event.data.mapping_start.anchor != NULL:
 */
    break;
    case YAML_SEQUENCE_END_EVENT:

    /* "yaml/_yaml.pyx":621
 *                     start_mark, end_mark, flow_style)
 *         elif event.type == YAML_SEQUENCE_END_EVENT:
 *             return SequenceEndEvent(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         elif event.type == YAML_MAPPING_END_EVENT:
 *             return MappingEndEvent(start_mark, end_mark)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SequenceEndEvent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_8, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 621, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":620
 *             return MappingStartEvent(anchor, tag, implicit,
 *                     start_mark, end_mark, flow_style)
 *         elif event.type == YAML_SEQUENCE_END_EVENT:             # <<<<<<<<<<<<<<
 *             return SequenceEndEvent(start_mark, end_mark)
 *         elif event.type == YAML_MAPPING_END_EVENT:
 */
    break;
    case YAML_MAPPING_END_EVENT:

    /* "yaml/_yaml.pyx":623
 *             return SequenceEndEvent(start_mark, end_mark)
 *         elif event.type == YAML_MAPPING_END_EVENT:
 *             return MappingEndEvent(start_mark, end_mark)             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError(u"unknown event type")
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MappingEndEvent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 623, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_8, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark)};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":622
 *         elif event.type == YAML_SEQUENCE_END_EVENT:
 *             return SequenceEndEvent(start_mark, end_mark)
 *         elif event.type == YAML_MAPPING_END_EVENT:             # <<<<<<<<<<<<<<
 *             return MappingEndEvent(start_mark, end_mark)
 *         else:
 */
    break;
    default:

    /* "yaml/_yaml.pyx":625
 *             return MappingEndEvent(start_mark, end_mark)
 *         else:
 *             raise ValueError(u"unknown event type")             # <<<<<<<<<<<<<<
 * 
 *     def get_event(self):
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 625, __pyx_L1_error)
    break;
  }

  /* "yaml/_yaml.pyx":504
 *         return event_object
 * 
 *     cdef object _event_to_object(self, yaml_event_t *event):             # <<<<<<<<<<<<<<
 *         cdef yaml_tag_directive_t *tag_directive
 *         start_mark = Mark(self.stream_name,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("yaml._yaml.CParser._event_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_start_mark);
  __Pyx_XDECREF((PyObject *)__pyx_v_end_mark);
  __Pyx_XDECREF(__pyx_v_encoding);
  __Pyx_XDECREF(__pyx_v_version);
  __Pyx_XDECREF(__pyx_v_tags);
  __Pyx_XDECREF(__pyx_v_handle);
  __Pyx_XDECREF(__pyx_v_prefix);
  __Pyx_XDECREF(__pyx_v_anchor);
  __Pyx_XDECREF(__pyx_v_tag);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_style);
  __Pyx_XDECREF(__pyx_v_flow_style);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":627
 *             raise ValueError(u"unknown event type")
 * 
 *     def get_event(self):             # <<<<<<<<<<<<<<
 *         if self.current_event is not None:
 *             value = self.current_event
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_17get_event(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_17get_event = {"get_event", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_17get_event, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_17get_event(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_event (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_event", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_event", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_16get_event(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_16get_event(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_event", 1);

  /* "yaml/_yaml.pyx":628
 * 
 *     def get_event(self):
 *         if self.current_event is not None:             # <<<<<<<<<<<<<<
 *             value = self.current_event
 *             self.current_event = None
 */
  __pyx_t_1 = (__pyx_v_self->current_event != Py_None);
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":629
 *     def get_event(self):
 *         if self.current_event is not None:
 *             value = self.current_event             # <<<<<<<<<<<<<<
 *             self.current_event = None
 *         else:
 */
    __pyx_t_2 = __pyx_v_self->current_event;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_value = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":630
 *         if self.current_event is not None:
 *             value = self.current_event
 *             self.current_event = None             # <<<<<<<<<<<<<<
 *         else:
 *             value = self._parse()
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->current_event);
    __Pyx_DECREF(__pyx_v_self->current_event);
    __pyx_v_self->current_event = Py_None;

    /* "yaml/_yaml.pyx":628
 * 
 *     def get_event(self):
 *         if self.current_event is not None:             # <<<<<<<<<<<<<<
 *             value = self.current_event
 *             self.current_event = None
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":632
 *             self.current_event = None
 *         else:
 *             value = self._parse()             # <<<<<<<<<<<<<<
 *         return value
 * 
 */
  /*else*/ {
    __pyx_t_2 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_value = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "yaml/_yaml.pyx":633
 *         else:
 *             value = self._parse()
 *         return value             # <<<<<<<<<<<<<<
 * 
 *     def peek_event(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_value);
  __pyx_r = __pyx_v_value;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":627
 *             raise ValueError(u"unknown event type")
 * 
 *     def get_event(self):             # <<<<<<<<<<<<<<
 *         if self.current_event is not None:
 *             value = self.current_event
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("yaml._yaml.CParser.get_event", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":635
 *         return value
 * 
 *     def peek_event(self):             # <<<<<<<<<<<<<<
 *         if self.current_event is None:
 *             self.current_event = self._parse()
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_19peek_event(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_19peek_event = {"peek_event", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_19peek_event, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_19peek_event(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("peek_event (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("peek_event", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "peek_event", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_18peek_event(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_18peek_event(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("peek_event", 1);

  /* "yaml/_yaml.pyx":636
 * 
 *     def peek_event(self):
 *         if self.current_event is None:             # <<<<<<<<<<<<<<
 *             self.current_event = self._parse()
 *         return self.current_event
 */
  __pyx_t_1 = (__pyx_v_self->current_event == Py_None);
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":637
 *     def peek_event(self):
 *         if self.current_event is None:
 *             self.current_event = self._parse()             # <<<<<<<<<<<<<<
 *         return self.current_event
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->current_event);
    __Pyx_DECREF(__pyx_v_self->current_event);
    __pyx_v_self->current_event = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":636
 * 
 *     def peek_event(self):
 *         if self.current_event is None:             # <<<<<<<<<<<<<<
 *             self.current_event = self._parse()
 *         return self.current_event
 */
  }

  /* "yaml/_yaml.pyx":638
 *         if self.current_event is None:
 *             self.current_event = self._parse()
 *         return self.current_event             # <<<<<<<<<<<<<<
 * 
 *     def check_event(self, *choices):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->current_event);
  __pyx_r = __pyx_v_self->current_event;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":635
 *         return value
 * 
 *     def peek_event(self):             # <<<<<<<<<<<<<<
 *         if self.current_event is None:
 *             self.current_event = self._parse()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("yaml._yaml.CParser.peek_event", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":640
 *         return self.current_event
 * 
 *     def check_event(self, *choices):             # <<<<<<<<<<<<<<
 *         if self.current_event is None:
 *             self.current_event = self._parse()
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_21check_event(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_21check_event = {"check_event", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_21check_event, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_21check_event(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_choices = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("check_event (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "check_event", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_choices = __pyx_args;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_20check_event(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self), __pyx_v_choices);

  /* function exit code */
  __Pyx_DECREF(__pyx_v_choices);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_20check_event(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_choices) {
  PyObject *__pyx_v_event_class = NULL;
  PyObject *__pyx_v_choice = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_event", 1);

  /* "yaml/_yaml.pyx":641
 * 
 *     def check_event(self, *choices):
 *         if self.current_event is None:             # <<<<<<<<<<<<<<
 *             self.current_event = self._parse()
 *         if self.current_event is None:
 */
  __pyx_t_1 = (__pyx_v_self->current_event == Py_None);
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":642
 *     def check_event(self, *choices):
 *         if self.current_event is None:
 *             self.current_event = self._parse()             # <<<<<<<<<<<<<<
 *         if self.current_event is None:
 *             return False
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 642, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->current_event);
    __Pyx_DECREF(__pyx_v_self->current_event);
    __pyx_v_self->current_event = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":641
 * 
 *     def check_event(self, *choices):
 *         if self.current_event is None:             # <<<<<<<<<<<<<<
 *             self.current_event = self._parse()
 *         if self.current_event is None:
 */
  }

  /* "yaml/_yaml.pyx":643
 *         if self.current_event is None:
 *             self.current_event = self._parse()
 *         if self.current_event is None:             # <<<<<<<<<<<<<<
 *             return False
 *         if not choices:
 */
  __pyx_t_1 = (__pyx_v_self->current_event == Py_None);
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":644
 *             self.current_event = self._parse()
 *         if self.current_event is None:
 *             return False             # <<<<<<<<<<<<<<
 *         if not choices:
 *             return True
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":643
 *         if self.current_event is None:
 *             self.current_event = self._parse()
 *         if self.current_event is None:             # <<<<<<<<<<<<<<
 *             return False
 *         if not choices:
 */
  }

  /* "yaml/_yaml.pyx":645
 *         if self.current_event is None:
 *             return False
 *         if not choices:             # <<<<<<<<<<<<<<
 *             return True
 *         event_class = self.current_event.__class__
 */
  __pyx_t_1 = (PyTuple_GET_SIZE(__pyx_v_choices) != 0);
  __pyx_t_3 = (!__pyx_t_1);
  if (__pyx_t_3) {

    /* "yaml/_yaml.pyx":646
 *             return False
 *         if not choices:
 *             return True             # <<<<<<<<<<<<<<
 *         event_class = self.current_event.__class__
 *         for choice in choices:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":645
 *         if self.current_event is None:
 *             return False
 *         if not choices:             # <<<<<<<<<<<<<<
 *             return True
 *         event_class = self.current_event.__class__
 */
  }

  /* "yaml/_yaml.pyx":647
 *         if not choices:
 *             return True
 *         event_class = self.current_event.__class__             # <<<<<<<<<<<<<<
 *         for choice in choices:
 *             if event_class is choice:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->current_event, __pyx_n_s_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_event_class = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":648
 *             return True
 *         event_class = self.current_event.__class__
 *         for choice in choices:             # <<<<<<<<<<<<<<
 *             if event_class is choice:
 *                 return True
 */
  __pyx_t_2 = __pyx_v_choices; __Pyx_INCREF(__pyx_t_2);
  __pyx_t_4 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 648, __pyx_L1_error)
      #endif
      if (__pyx_t_4 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_5); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 648, __pyx_L1_error)
    #else
    __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_choice, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "yaml/_yaml.pyx":649
 *         event_class = self.current_event.__class__
 *         for choice in choices:
 *             if event_class is choice:             # <<<<<<<<<<<<<<
 *                 return True
 *         return False
 */
    __pyx_t_3 = (__pyx_v_event_class == __pyx_v_choice);
    if (__pyx_t_3) {

      /* "yaml/_yaml.pyx":650
 *         for choice in choices:
 *             if event_class is choice:
 *                 return True             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "yaml/_yaml.pyx":649
 *         event_class = self.current_event.__class__
 *         for choice in choices:
 *             if event_class is choice:             # <<<<<<<<<<<<<<
 *                 return True
 *         return False
 */
    }

    /* "yaml/_yaml.pyx":648
 *             return True
 *         event_class = self.current_event.__class__
 *         for choice in choices:             # <<<<<<<<<<<<<<
 *             if event_class is choice:
 *                 return True
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":651
 *             if event_class is choice:
 *                 return True
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     def check_node(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":640
 *         return self.current_event
 * 
 *     def check_event(self, *choices):             # <<<<<<<<<<<<<<
 *         if self.current_event is None:
 *             self.current_event = self._parse()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("yaml._yaml.CParser.check_event", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_event_class);
  __Pyx_XDECREF(__pyx_v_choice);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":653
 *         return False
 * 
 *     def check_node(self):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         if self.parsed_event.type == YAML_STREAM_START_EVENT:
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_23check_node(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_23check_node = {"check_node", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_23check_node, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_23check_node(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("check_node (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("check_node", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "check_node", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_22check_node(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_22check_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("check_node", 1);

  /* "yaml/_yaml.pyx":654
 * 
 *     def check_node(self):
 *         self._parse_next_event()             # <<<<<<<<<<<<<<
 *         if self.parsed_event.type == YAML_STREAM_START_EVENT:
 *             yaml_event_delete(&self.parsed_event)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse_next_event(__pyx_v_self); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 654, __pyx_L1_error)

  /* "yaml/_yaml.pyx":655
 *     def check_node(self):
 *         self._parse_next_event()
 *         if self.parsed_event.type == YAML_STREAM_START_EVENT:             # <<<<<<<<<<<<<<
 *             yaml_event_delete(&self.parsed_event)
 *             self._parse_next_event()
 */
  __pyx_t_2 = (__pyx_v_self->parsed_event.type == YAML_STREAM_START_EVENT);
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":656
 *         self._parse_next_event()
 *         if self.parsed_event.type == YAML_STREAM_START_EVENT:
 *             yaml_event_delete(&self.parsed_event)             # <<<<<<<<<<<<<<
 *             self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 */
    yaml_event_delete((&__pyx_v_self->parsed_event));

    /* "yaml/_yaml.pyx":657
 *         if self.parsed_event.type == YAML_STREAM_START_EVENT:
 *             yaml_event_delete(&self.parsed_event)
 *             self._parse_next_event()             # <<<<<<<<<<<<<<
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 *             return True
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse_next_event(__pyx_v_self); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 657, __pyx_L1_error)

    /* "yaml/_yaml.pyx":655
 *     def check_node(self):
 *         self._parse_next_event()
 *         if self.parsed_event.type == YAML_STREAM_START_EVENT:             # <<<<<<<<<<<<<<
 *             yaml_event_delete(&self.parsed_event)
 *             self._parse_next_event()
 */
  }

  /* "yaml/_yaml.pyx":658
 *             yaml_event_delete(&self.parsed_event)
 *             self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:             # <<<<<<<<<<<<<<
 *             return True
 *         return False
 */
  __pyx_t_2 = (__pyx_v_self->parsed_event.type != YAML_STREAM_END_EVENT);
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":659
 *             self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 *             return True             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":658
 *             yaml_event_delete(&self.parsed_event)
 *             self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:             # <<<<<<<<<<<<<<
 *             return True
 *         return False
 */
  }

  /* "yaml/_yaml.pyx":660
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 *             return True
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     def get_node(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":653
 *         return False
 * 
 *     def check_node(self):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         if self.parsed_event.type == YAML_STREAM_START_EVENT:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("yaml._yaml.CParser.check_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":662
 *         return False
 * 
 *     def get_node(self):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_25get_node(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_25get_node = {"get_node", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_25get_node, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_25get_node(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_node (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_node", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_node", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_24get_node(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_24get_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_node", 1);

  /* "yaml/_yaml.pyx":663
 * 
 *     def get_node(self):
 *         self._parse_next_event()             # <<<<<<<<<<<<<<
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 *             return self._compose_document()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse_next_event(__pyx_v_self); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 663, __pyx_L1_error)

  /* "yaml/_yaml.pyx":664
 *     def get_node(self):
 *         self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:             # <<<<<<<<<<<<<<
 *             return self._compose_document()
 * 
 */
  __pyx_t_2 = (__pyx_v_self->parsed_event.type != YAML_STREAM_END_EVENT);
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":665
 *         self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 *             return self._compose_document()             # <<<<<<<<<<<<<<
 * 
 *     def get_single_node(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_compose_document(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 665, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":664
 *     def get_node(self):
 *         self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:             # <<<<<<<<<<<<<<
 *             return self._compose_document()
 * 
 */
  }

  /* "yaml/_yaml.pyx":662
 *         return False
 * 
 *     def get_node(self):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("yaml._yaml.CParser.get_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":667
 *             return self._compose_document()
 * 
 *     def get_single_node(self):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         yaml_event_delete(&self.parsed_event)
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_27get_single_node(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_27get_single_node = {"get_single_node", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_27get_single_node, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_27get_single_node(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_single_node (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_single_node", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_single_node", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_26get_single_node(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_26get_single_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  PyObject *__pyx_v_document = NULL;
  struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_mark = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_single_node", 1);

  /* "yaml/_yaml.pyx":668
 * 
 *     def get_single_node(self):
 *         self._parse_next_event()             # <<<<<<<<<<<<<<
 *         yaml_event_delete(&self.parsed_event)
 *         self._parse_next_event()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse_next_event(__pyx_v_self); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 668, __pyx_L1_error)

  /* "yaml/_yaml.pyx":669
 *     def get_single_node(self):
 *         self._parse_next_event()
 *         yaml_event_delete(&self.parsed_event)             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         document = None
 */
  yaml_event_delete((&__pyx_v_self->parsed_event));

  /* "yaml/_yaml.pyx":670
 *         self._parse_next_event()
 *         yaml_event_delete(&self.parsed_event)
 *         self._parse_next_event()             # <<<<<<<<<<<<<<
 *         document = None
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse_next_event(__pyx_v_self); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 670, __pyx_L1_error)

  /* "yaml/_yaml.pyx":671
 *         yaml_event_delete(&self.parsed_event)
 *         self._parse_next_event()
 *         document = None             # <<<<<<<<<<<<<<
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 *             document = self._compose_document()
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_document = Py_None;

  /* "yaml/_yaml.pyx":672
 *         self._parse_next_event()
 *         document = None
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:             # <<<<<<<<<<<<<<
 *             document = self._compose_document()
 *         self._parse_next_event()
 */
  __pyx_t_2 = (__pyx_v_self->parsed_event.type != YAML_STREAM_END_EVENT);
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":673
 *         document = None
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 *             document = self._compose_document()             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_compose_document(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 673, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_document, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "yaml/_yaml.pyx":672
 *         self._parse_next_event()
 *         document = None
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:             # <<<<<<<<<<<<<<
 *             document = self._compose_document()
 *         self._parse_next_event()
 */
  }

  /* "yaml/_yaml.pyx":674
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 *             document = self._compose_document()
 *         self._parse_next_event()             # <<<<<<<<<<<<<<
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 *             mark = Mark(self.stream_name,
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse_next_event(__pyx_v_self); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 674, __pyx_L1_error)

  /* "yaml/_yaml.pyx":675
 *             document = self._compose_document()
 *         self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:             # <<<<<<<<<<<<<<
 *             mark = Mark(self.stream_name,
 *                     self.parsed_event.start_mark.index,
 */
  __pyx_t_2 = (__pyx_v_self->parsed_event.type != YAML_STREAM_END_EVENT);
  if (unlikely(__pyx_t_2)) {

    /* "yaml/_yaml.pyx":677
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 *             mark = Mark(self.stream_name,
 *                     self.parsed_event.start_mark.index,             # <<<<<<<<<<<<<<
 *                     self.parsed_event.start_mark.line,
 *                     self.parsed_event.start_mark.column,
 */
    __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "yaml/_yaml.pyx":678
 *             mark = Mark(self.stream_name,
 *                     self.parsed_event.start_mark.index,
 *                     self.parsed_event.start_mark.line,             # <<<<<<<<<<<<<<
 *                     self.parsed_event.start_mark.column,
 *                     None, None)
 */
    __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.line); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 678, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);

    /* "yaml/_yaml.pyx":679
 *                     self.parsed_event.start_mark.index,
 *                     self.parsed_event.start_mark.line,
 *                     self.parsed_event.start_mark.column,             # <<<<<<<<<<<<<<
 *                     None, None)
 *             raise ComposerError(u"expected a single document in the stream",
 */
    __pyx_t_5 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.column); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);

    /* "yaml/_yaml.pyx":676
 *         self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 *             mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                     self.parsed_event.start_mark.index,
 *                     self.parsed_event.start_mark.line,
 */
    __pyx_t_6 = PyTuple_New(6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 676, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_self->stream_name);
    __Pyx_GIVEREF(__pyx_v_self->stream_name);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 676, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_3)) __PYX_ERR(0, 676, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_4)) __PYX_ERR(0, 676, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_5)) __PYX_ERR(0, 676, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 4, Py_None)) __PYX_ERR(0, 676, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 5, Py_None)) __PYX_ERR(0, 676, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 676, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_mark = ((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "yaml/_yaml.pyx":681
 *                     self.parsed_event.start_mark.column,
 *                     None, None)
 *             raise ComposerError(u"expected a single document in the stream",             # <<<<<<<<<<<<<<
 *                     document.start_mark, u"but found another document", mark)
 *         return document
 */
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_ComposerError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);

    /* "yaml/_yaml.pyx":682
 *                     None, None)
 *             raise ComposerError(u"expected a single document in the stream",
 *                     document.start_mark, u"but found another document", mark)             # <<<<<<<<<<<<<<
 *         return document
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_document, __pyx_n_s_start_mark); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 682, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = NULL;
    __pyx_t_1 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_1 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_3, __pyx_kp_u_expected_a_single_document_in_th, __pyx_t_4, __pyx_kp_u_but_found_another_document, ((PyObject *)__pyx_v_mark)};
      __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_1, 4+__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 681, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 681, __pyx_L1_error)

    /* "yaml/_yaml.pyx":675
 *             document = self._compose_document()
 *         self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:             # <<<<<<<<<<<<<<
 *             mark = Mark(self.stream_name,
 *                     self.parsed_event.start_mark.index,
 */
  }

  /* "yaml/_yaml.pyx":683
 *             raise ComposerError(u"expected a single document in the stream",
 *                     document.start_mark, u"but found another document", mark)
 *         return document             # <<<<<<<<<<<<<<
 * 
 *     cdef object _compose_document(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_document);
  __pyx_r = __pyx_v_document;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":667
 *             return self._compose_document()
 * 
 *     def get_single_node(self):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         yaml_event_delete(&self.parsed_event)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("yaml._yaml.CParser.get_single_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_document);
  __Pyx_XDECREF((PyObject *)__pyx_v_mark);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":685
 *         return document
 * 
 *     cdef object _compose_document(self):             # <<<<<<<<<<<<<<
 *         yaml_event_delete(&self.parsed_event)
 *         node = self._compose_node(None, None)
 */

static PyObject *__pyx_f_4yaml_5_yaml_7CParser__compose_document(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_compose_document", 1);

  /* "yaml/_yaml.pyx":686
 * 
 *     cdef object _compose_document(self):
 *         yaml_event_delete(&self.parsed_event)             # <<<<<<<<<<<<<<
 *         node = self._compose_node(None, None)
 *         self._parse_next_event()
 */
  yaml_event_delete((&__pyx_v_self->parsed_event));

  /* "yaml/_yaml.pyx":687
 *     cdef object _compose_document(self):
 *         yaml_event_delete(&self.parsed_event)
 *         node = self._compose_node(None, None)             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         yaml_event_delete(&self.parsed_event)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_compose_node(__pyx_v_self, Py_None, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_node = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "yaml/_yaml.pyx":688
 *         yaml_event_delete(&self.parsed_event)
 *         node = self._compose_node(None, None)
 *         self._parse_next_event()             # <<<<<<<<<<<<<<
 *         yaml_event_delete(&self.parsed_event)
 *         self.anchors = {}
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse_next_event(__pyx_v_self); if (unlikely(__pyx_t_2 == ((int)0))) __PYX_ERR(0, 688, __pyx_L1_error)

  /* "yaml/_yaml.pyx":689
 *         node = self._compose_node(None, None)
 *         self._parse_next_event()
 *         yaml_event_delete(&self.parsed_event)             # <<<<<<<<<<<<<<
 *         self.anchors = {}
 *         return node
 */
  yaml_event_delete((&__pyx_v_self->parsed_event));

  /* "yaml/_yaml.pyx":690
 *         self._parse_next_event()
 *         yaml_event_delete(&self.parsed_event)
 *         self.anchors = {}             # <<<<<<<<<<<<<<
 *         return node
 * 
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->anchors);
  __Pyx_DECREF(__pyx_v_self->anchors);
  __pyx_v_self->anchors = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "yaml/_yaml.pyx":691
 *         yaml_event_delete(&self.parsed_event)
 *         self.anchors = {}
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     cdef object _compose_node(self, object parent, object index):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":685
 *         return document
 * 
 *     cdef object _compose_document(self):             # <<<<<<<<<<<<<<
 *         yaml_event_delete(&self.parsed_event)
 *         node = self._compose_node(None, None)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("yaml._yaml.CParser._compose_document", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":693
 *         return node
 * 
 *     cdef object _compose_node(self, object parent, object index):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         if self.parsed_event.type == YAML_ALIAS_EVENT:
 */

static PyObject *__pyx_f_4yaml_5_yaml_7CParser__compose_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_parent, PyObject *__pyx_v_index) {
  PyObject *__pyx_v_anchor = NULL;
  struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_mark = NULL;
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_compose_node", 1);

  /* "yaml/_yaml.pyx":694
 * 
 *     cdef object _compose_node(self, object parent, object index):
 *         self._parse_next_event()             # <<<<<<<<<<<<<<
 *         if self.parsed_event.type == YAML_ALIAS_EVENT:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.alias.anchor)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse_next_event(__pyx_v_self); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 694, __pyx_L1_error)

  /* "yaml/_yaml.pyx":695
 *     cdef object _compose_node(self, object parent, object index):
 *         self._parse_next_event()
 *         if self.parsed_event.type == YAML_ALIAS_EVENT:             # <<<<<<<<<<<<<<
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.alias.anchor)
 *             if anchor not in self.anchors:
 */
  __pyx_t_2 = (__pyx_v_self->parsed_event.type == YAML_ALIAS_EVENT);
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":696
 *         self._parse_next_event()
 *         if self.parsed_event.type == YAML_ALIAS_EVENT:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.alias.anchor)             # <<<<<<<<<<<<<<
 *             if anchor not in self.anchors:
 *                 mark = Mark(self.stream_name,
 */
    __pyx_t_3 = PyUnicode_FromYamlString(__pyx_v_self->parsed_event.data.alias.anchor); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_anchor = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "yaml/_yaml.pyx":697
 *         if self.parsed_event.type == YAML_ALIAS_EVENT:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.alias.anchor)
 *             if anchor not in self.anchors:             # <<<<<<<<<<<<<<
 *                 mark = Mark(self.stream_name,
 *                         self.parsed_event.start_mark.index,
 */
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_anchor, __pyx_v_self->anchors, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 697, __pyx_L1_error)
    if (unlikely(__pyx_t_2)) {

      /* "yaml/_yaml.pyx":699
 *             if anchor not in self.anchors:
 *                 mark = Mark(self.stream_name,
 *                         self.parsed_event.start_mark.index,             # <<<<<<<<<<<<<<
 *                         self.parsed_event.start_mark.line,
 *                         self.parsed_event.start_mark.column,
 */
      __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 699, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "yaml/_yaml.pyx":700
 *                 mark = Mark(self.stream_name,
 *                         self.parsed_event.start_mark.index,
 *                         self.parsed_event.start_mark.line,             # <<<<<<<<<<<<<<
 *                         self.parsed_event.start_mark.column,
 *                         None, None)
 */
      __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.line); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 700, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "yaml/_yaml.pyx":701
 *                         self.parsed_event.start_mark.index,
 *                         self.parsed_event.start_mark.line,
 *                         self.parsed_event.start_mark.column,             # <<<<<<<<<<<<<<
 *                         None, None)
 *                 raise ComposerError(None, None, u"found undefined alias", mark)
 */
      __pyx_t_5 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.column); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 701, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);

      /* "yaml/_yaml.pyx":698
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.alias.anchor)
 *             if anchor not in self.anchors:
 *                 mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                         self.parsed_event.start_mark.index,
 *                         self.parsed_event.start_mark.line,
 */
      __pyx_t_6 = PyTuple_New(6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 698, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_v_self->stream_name);
      __Pyx_GIVEREF(__pyx_v_self->stream_name);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 698, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_3);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_3)) __PYX_ERR(0, 698, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_4)) __PYX_ERR(0, 698, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_5)) __PYX_ERR(0, 698, __pyx_L1_error);
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 4, Py_None)) __PYX_ERR(0, 698, __pyx_L1_error);
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 5, Py_None)) __PYX_ERR(0, 698, __pyx_L1_error);
      __pyx_t_3 = 0;
      __pyx_t_4 = 0;
      __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 698, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_mark = ((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_t_5);
      __pyx_t_5 = 0;

      /* "yaml/_yaml.pyx":703
 *                         self.parsed_event.start_mark.column,
 *                         None, None)
 *                 raise ComposerError(None, None, u"found undefined alias", mark)             # <<<<<<<<<<<<<<
 *             yaml_event_delete(&self.parsed_event)
 *             return self.anchors[anchor]
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_ComposerError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 703, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = NULL;
      __pyx_t_1 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_1 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_4, Py_None, Py_None, __pyx_kp_u_found_undefined_alias, ((PyObject *)__pyx_v_mark)};
        __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_1, 4+__pyx_t_1);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 703, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(0, 703, __pyx_L1_error)

      /* "yaml/_yaml.pyx":697
 *         if self.parsed_event.type == YAML_ALIAS_EVENT:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.alias.anchor)
 *             if anchor not in self.anchors:             # <<<<<<<<<<<<<<
 *                 mark = Mark(self.stream_name,
 *                         self.parsed_event.start_mark.index,
 */
    }

    /* "yaml/_yaml.pyx":704
 *                         None, None)
 *                 raise ComposerError(None, None, u"found undefined alias", mark)
 *             yaml_event_delete(&self.parsed_event)             # <<<<<<<<<<<<<<
 *             return self.anchors[anchor]
 *         anchor = None
 */
    yaml_event_delete((&__pyx_v_self->parsed_event));

    /* "yaml/_yaml.pyx":705
 *                 raise ComposerError(None, None, u"found undefined alias", mark)
 *             yaml_event_delete(&self.parsed_event)
 *             return self.anchors[anchor]             # <<<<<<<<<<<<<<
 *         anchor = None
 *         if self.parsed_event.type == YAML_SCALAR_EVENT  \
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_v_self->anchors, __pyx_v_anchor); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":695
 *     cdef object _compose_node(self, object parent, object index):
 *         self._parse_next_event()
 *         if self.parsed_event.type == YAML_ALIAS_EVENT:             # <<<<<<<<<<<<<<
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.alias.anchor)
 *             if anchor not in self.anchors:
 */
  }

  /* "yaml/_yaml.pyx":706
 *             yaml_event_delete(&self.parsed_event)
 *             return self.anchors[anchor]
 *         anchor = None             # <<<<<<<<<<<<<<
 *         if self.parsed_event.type == YAML_SCALAR_EVENT  \
 *                 and self.parsed_event.data.scalar.anchor != NULL:
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_anchor = Py_None;

  /* "yaml/_yaml.pyx":707
 *             return self.anchors[anchor]
 *         anchor = None
 *         if self.parsed_event.type == YAML_SCALAR_EVENT  \             # <<<<<<<<<<<<<<
 *                 and self.parsed_event.data.scalar.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.scalar.anchor)
 */
  __pyx_t_7 = (__pyx_v_self->parsed_event.type == YAML_SCALAR_EVENT);
  if (__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L6_bool_binop_done;
  }

  /* "yaml/_yaml.pyx":708
 *         anchor = None
 *         if self.parsed_event.type == YAML_SCALAR_EVENT  \
 *                 and self.parsed_event.data.scalar.anchor != NULL:             # <<<<<<<<<<<<<<
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.scalar.anchor)
 *         elif self.parsed_event.type == YAML_SEQUENCE_START_EVENT    \
 */
  __pyx_t_7 = (__pyx_v_self->parsed_event.data.scalar.anchor != NULL);
  __pyx_t_2 = __pyx_t_7;
  __pyx_L6_bool_binop_done:;

  /* "yaml/_yaml.pyx":707
 *             return self.anchors[anchor]
 *         anchor = None
 *         if self.parsed_event.type == YAML_SCALAR_EVENT  \             # <<<<<<<<<<<<<<
 *                 and self.parsed_event.data.scalar.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.scalar.anchor)
 */
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":709
 *         if self.parsed_event.type == YAML_SCALAR_EVENT  \
 *                 and self.parsed_event.data.scalar.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.scalar.anchor)             # <<<<<<<<<<<<<<
 *         elif self.parsed_event.type == YAML_SEQUENCE_START_EVENT    \
 *                 and self.parsed_event.data.sequence_start.anchor != NULL:
 */
    __pyx_t_5 = PyUnicode_FromYamlString(__pyx_v_self->parsed_event.data.scalar.anchor); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 709, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_anchor, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "yaml/_yaml.pyx":707
 *             return self.anchors[anchor]
 *         anchor = None
 *         if self.parsed_event.type == YAML_SCALAR_EVENT  \             # <<<<<<<<<<<<<<
 *                 and self.parsed_event.data.scalar.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.scalar.anchor)
 */
    goto __pyx_L5;
  }

  /* "yaml/_yaml.pyx":710
 *                 and self.parsed_event.data.scalar.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.scalar.anchor)
 *         elif self.parsed_event.type == YAML_SEQUENCE_START_EVENT    \             # <<<<<<<<<<<<<<
 *                 and self.parsed_event.data.sequence_start.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.anchor)
 */
  __pyx_t_7 = (__pyx_v_self->parsed_event.type == YAML_SEQUENCE_START_EVENT);
  if (__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L8_bool_binop_done;
  }

  /* "yaml/_yaml.pyx":711
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.scalar.anchor)
 *         elif self.parsed_event.type == YAML_SEQUENCE_START_EVENT    \
 *                 and self.parsed_event.data.sequence_start.anchor != NULL:             # <<<<<<<<<<<<<<
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.anchor)
 *         elif self.parsed_event.type == YAML_MAPPING_START_EVENT    \
 */
  __pyx_t_7 = (__pyx_v_self->parsed_event.data.sequence_start.anchor != NULL);
  __pyx_t_2 = __pyx_t_7;
  __pyx_L8_bool_binop_done:;

  /* "yaml/_yaml.pyx":710
 *                 and self.parsed_event.data.scalar.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.scalar.anchor)
 *         elif self.parsed_event.type == YAML_SEQUENCE_START_EVENT    \             # <<<<<<<<<<<<<<
 *                 and self.parsed_event.data.sequence_start.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.anchor)
 */
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":712
 *         elif self.parsed_event.type == YAML_SEQUENCE_START_EVENT    \
 *                 and self.parsed_event.data.sequence_start.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.anchor)             # <<<<<<<<<<<<<<
 *         elif self.parsed_event.type == YAML_MAPPING_START_EVENT    \
 *                 and self.parsed_event.data.mapping_start.anchor != NULL:
 */
    __pyx_t_5 = PyUnicode_FromYamlString(__pyx_v_self->parsed_event.data.sequence_start.anchor); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 712, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_anchor, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "yaml/_yaml.pyx":710
 *                 and self.parsed_event.data.scalar.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.scalar.anchor)
 *         elif self.parsed_event.type == YAML_SEQUENCE_START_EVENT    \             # <<<<<<<<<<<<<<
 *                 and self.parsed_event.data.sequence_start.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.anchor)
 */
    goto __pyx_L5;
  }

  /* "yaml/_yaml.pyx":713
 *                 and self.parsed_event.data.sequence_start.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.anchor)
 *         elif self.parsed_event.type == YAML_MAPPING_START_EVENT    \             # <<<<<<<<<<<<<<
 *                 and self.parsed_event.data.mapping_start.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.anchor)
 */
  __pyx_t_7 = (__pyx_v_self->parsed_event.type == YAML_MAPPING_START_EVENT);
  if (__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L10_bool_binop_done;
  }

  /* "yaml/_yaml.pyx":714
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.anchor)
 *         elif self.parsed_event.type == YAML_MAPPING_START_EVENT    \
 *                 and self.parsed_event.data.mapping_start.anchor != NULL:             # <<<<<<<<<<<<<<
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.anchor)
 *         if anchor is not None:
 */
  __pyx_t_7 = (__pyx_v_self->parsed_event.data.mapping_start.anchor != NULL);
  __pyx_t_2 = __pyx_t_7;
  __pyx_L10_bool_binop_done:;

  /* "yaml/_yaml.pyx":713
 *                 and self.parsed_event.data.sequence_start.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.anchor)
 *         elif self.parsed_event.type == YAML_MAPPING_START_EVENT    \             # <<<<<<<<<<<<<<
 *                 and self.parsed_event.data.mapping_start.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.anchor)
 */
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":715
 *         elif self.parsed_event.type == YAML_MAPPING_START_EVENT    \
 *                 and self.parsed_event.data.mapping_start.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.anchor)             # <<<<<<<<<<<<<<
 *         if anchor is not None:
 *             if anchor in self.anchors:
 */
    __pyx_t_5 = PyUnicode_FromYamlString(__pyx_v_self->parsed_event.data.mapping_start.anchor); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 715, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF_SET(__pyx_v_anchor, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "yaml/_yaml.pyx":713
 *                 and self.parsed_event.data.sequence_start.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.anchor)
 *         elif self.parsed_event.type == YAML_MAPPING_START_EVENT    \             # <<<<<<<<<<<<<<
 *                 and self.parsed_event.data.mapping_start.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.anchor)
 */
  }
  __pyx_L5:;

  /* "yaml/_yaml.pyx":716
 *                 and self.parsed_event.data.mapping_start.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.anchor)
 *         if anchor is not None:             # <<<<<<<<<<<<<<
 *             if anchor in self.anchors:
 *                 mark = Mark(self.stream_name,
 */
  __pyx_t_2 = (__pyx_v_anchor != Py_None);
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":717
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.anchor)
 *         if anchor is not None:
 *             if anchor in self.anchors:             # <<<<<<<<<<<<<<
 *                 mark = Mark(self.stream_name,
 *                         self.parsed_event.start_mark.index,
 */
    __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_anchor, __pyx_v_self->anchors, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 717, __pyx_L1_error)
    if (unlikely(__pyx_t_2)) {

      /* "yaml/_yaml.pyx":719
 *             if anchor in self.anchors:
 *                 mark = Mark(self.stream_name,
 *                         self.parsed_event.start_mark.index,             # <<<<<<<<<<<<<<
 *                         self.parsed_event.start_mark.line,
 *                         self.parsed_event.start_mark.column,
 */
      __pyx_t_5 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.index); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 719, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);

      /* "yaml/_yaml.pyx":720
 *                 mark = Mark(self.stream_name,
 *                         self.parsed_event.start_mark.index,
 *                         self.parsed_event.start_mark.line,             # <<<<<<<<<<<<<<
 *                         self.parsed_event.start_mark.column,
 *                         None, None)
 */
      __pyx_t_6 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.line); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 720, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);

      /* "yaml/_yaml.pyx":721
 *                         self.parsed_event.start_mark.index,
 *                         self.parsed_event.start_mark.line,
 *                         self.parsed_event.start_mark.column,             # <<<<<<<<<<<<<<
 *                         None, None)
 *                 raise ComposerError(u"found duplicate anchor; first occurrence",
 */
      __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.column); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 721, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "yaml/_yaml.pyx":718
 *         if anchor is not None:
 *             if anchor in self.anchors:
 *                 mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                         self.parsed_event.start_mark.index,
 *                         self.parsed_event.start_mark.line,
 */
      __pyx_t_3 = PyTuple_New(6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 718, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_self->stream_name);
      __Pyx_GIVEREF(__pyx_v_self->stream_name);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 718, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_5)) __PYX_ERR(0, 718, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_6);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_6)) __PYX_ERR(0, 718, __pyx_L1_error);
      __Pyx_GIVEREF(__pyx_t_4);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_4)) __PYX_ERR(0, 718, __pyx_L1_error);
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 4, Py_None)) __PYX_ERR(0, 718, __pyx_L1_error);
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 5, Py_None)) __PYX_ERR(0, 718, __pyx_L1_error);
      __pyx_t_5 = 0;
      __pyx_t_6 = 0;
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 718, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_mark = ((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_t_4);
      __pyx_t_4 = 0;

      /* "yaml/_yaml.pyx":723
 *                         self.parsed_event.start_mark.column,
 *                         None, None)
 *                 raise ComposerError(u"found duplicate anchor; first occurrence",             # <<<<<<<<<<<<<<
 *                         self.anchors[anchor].start_mark, u"second occurrence", mark)
 *         self.descend_resolver(parent, index)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_ComposerError); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 723, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "yaml/_yaml.pyx":724
 *                         None, None)
 *                 raise ComposerError(u"found duplicate anchor; first occurrence",
 *                         self.anchors[anchor].start_mark, u"second occurrence", mark)             # <<<<<<<<<<<<<<
 *         self.descend_resolver(parent, index)
 *         if self.parsed_event.type == YAML_SCALAR_EVENT:
 */
      __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_self->anchors, __pyx_v_anchor); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 724, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_start_mark); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 724, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_1 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_1 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_6, __pyx_kp_u_found_duplicate_anchor_first_occ, __pyx_t_5, __pyx_kp_u_second_occurrence, ((PyObject *)__pyx_v_mark)};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_1, 4+__pyx_t_1);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 723, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 723, __pyx_L1_error)

      /* "yaml/_yaml.pyx":717
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.anchor)
 *         if anchor is not None:
 *             if anchor in self.anchors:             # <<<<<<<<<<<<<<
 *                 mark = Mark(self.stream_name,
 *                         self.parsed_event.start_mark.index,
 */
    }

    /* "yaml/_yaml.pyx":716
 *                 and self.parsed_event.data.mapping_start.anchor != NULL:
 *             anchor = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.anchor)
 *         if anchor is not None:             # <<<<<<<<<<<<<<
 *             if anchor in self.anchors:
 *                 mark = Mark(self.stream_name,
 */
  }

  /* "yaml/_yaml.pyx":725
 *                 raise ComposerError(u"found duplicate anchor; first occurrence",
 *                         self.anchors[anchor].start_mark, u"second occurrence", mark)
 *         self.descend_resolver(parent, index)             # <<<<<<<<<<<<<<
 *         if self.parsed_event.type == YAML_SCALAR_EVENT:
 *             node = self._compose_scalar_node(anchor)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_descend_resolver); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 725, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_1 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_1 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_parent, __pyx_v_index};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_1, 2+__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 725, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "yaml/_yaml.pyx":726
 *                         self.anchors[anchor].start_mark, u"second occurrence", mark)
 *         self.descend_resolver(parent, index)
 *         if self.parsed_event.type == YAML_SCALAR_EVENT:             # <<<<<<<<<<<<<<
 *             node = self._compose_scalar_node(anchor)
 *         elif self.parsed_event.type == YAML_SEQUENCE_START_EVENT:
 */
  switch (__pyx_v_self->parsed_event.type) {
    case YAML_SCALAR_EVENT:

    /* "yaml/_yaml.pyx":727
 *         self.descend_resolver(parent, index)
 *         if self.parsed_event.type == YAML_SCALAR_EVENT:
 *             node = self._compose_scalar_node(anchor)             # <<<<<<<<<<<<<<
 *         elif self.parsed_event.type == YAML_SEQUENCE_START_EVENT:
 *             node = self._compose_sequence_node(anchor)
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_compose_scalar_node(__pyx_v_self, __pyx_v_anchor); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 727, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_node = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":726
 *                         self.anchors[anchor].start_mark, u"second occurrence", mark)
 *         self.descend_resolver(parent, index)
 *         if self.parsed_event.type == YAML_SCALAR_EVENT:             # <<<<<<<<<<<<<<
 *             node = self._compose_scalar_node(anchor)
 *         elif self.parsed_event.type == YAML_SEQUENCE_START_EVENT:
 */
    break;
    case YAML_SEQUENCE_START_EVENT:

    /* "yaml/_yaml.pyx":729
 *             node = self._compose_scalar_node(anchor)
 *         elif self.parsed_event.type == YAML_SEQUENCE_START_EVENT:
 *             node = self._compose_sequence_node(anchor)             # <<<<<<<<<<<<<<
 *         elif self.parsed_event.type == YAML_MAPPING_START_EVENT:
 *             node = self._compose_mapping_node(anchor)
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_compose_sequence_node(__pyx_v_self, __pyx_v_anchor); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_node = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":728
 *         if self.parsed_event.type == YAML_SCALAR_EVENT:
 *             node = self._compose_scalar_node(anchor)
 *         elif self.parsed_event.type == YAML_SEQUENCE_START_EVENT:             # <<<<<<<<<<<<<<
 *             node = self._compose_sequence_node(anchor)
 *         elif self.parsed_event.type == YAML_MAPPING_START_EVENT:
 */
    break;
    case YAML_MAPPING_START_EVENT:

    /* "yaml/_yaml.pyx":731
 *             node = self._compose_sequence_node(anchor)
 *         elif self.parsed_event.type == YAML_MAPPING_START_EVENT:
 *             node = self._compose_mapping_node(anchor)             # <<<<<<<<<<<<<<
 *         self.ascend_resolver()
 *         return node
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_compose_mapping_node(__pyx_v_self, __pyx_v_anchor); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 731, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_node = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":730
 *         elif self.parsed_event.type == YAML_SEQUENCE_START_EVENT:
 *             node = self._compose_sequence_node(anchor)
 *         elif self.parsed_event.type == YAML_MAPPING_START_EVENT:             # <<<<<<<<<<<<<<
 *             node = self._compose_mapping_node(anchor)
 *         self.ascend_resolver()
 */
    break;
    default: break;
  }

  /* "yaml/_yaml.pyx":732
 *         elif self.parsed_event.type == YAML_MAPPING_START_EVENT:
 *             node = self._compose_mapping_node(anchor)
 *         self.ascend_resolver()             # <<<<<<<<<<<<<<
 *         return node
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_ascend_resolver); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_1 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_1 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_1, 0+__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 732, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "yaml/_yaml.pyx":733
 *             node = self._compose_mapping_node(anchor)
 *         self.ascend_resolver()
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     cdef _compose_scalar_node(self, object anchor):
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_node)) { __Pyx_RaiseUnboundLocalError("node"); __PYX_ERR(0, 733, __pyx_L1_error) }
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":693
 *         return node
 * 
 *     cdef object _compose_node(self, object parent, object index):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         if self.parsed_event.type == YAML_ALIAS_EVENT:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("yaml._yaml.CParser._compose_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_anchor);
  __Pyx_XDECREF((PyObject *)__pyx_v_mark);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":735
 *         return node
 * 
 *     cdef _compose_scalar_node(self, object anchor):             # <<<<<<<<<<<<<<
 *         start_mark = Mark(self.stream_name,
 *                 self.parsed_event.start_mark.index,
 */

static PyObject *__pyx_f_4yaml_5_yaml_7CParser__compose_scalar_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_anchor) {
  struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_start_mark = NULL;
  struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_end_mark = NULL;
  PyObject *__pyx_v_value = NULL;
  int __pyx_v_plain_implicit;
  int __pyx_v_quoted_implicit;
  PyObject *__pyx_v_tag = NULL;
  PyObject *__pyx_v_style = NULL;
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_compose_scalar_node", 1);

  /* "yaml/_yaml.pyx":737
 *     cdef _compose_scalar_node(self, object anchor):
 *         start_mark = Mark(self.stream_name,
 *                 self.parsed_event.start_mark.index,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.start_mark.line,
 *                 self.parsed_event.start_mark.column,
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "yaml/_yaml.pyx":738
 *         start_mark = Mark(self.stream_name,
 *                 self.parsed_event.start_mark.index,
 *                 self.parsed_event.start_mark.line,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.start_mark.column,
 *                 None, None)
 */
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.line); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "yaml/_yaml.pyx":739
 *                 self.parsed_event.start_mark.index,
 *                 self.parsed_event.start_mark.line,
 *                 self.parsed_event.start_mark.column,             # <<<<<<<<<<<<<<
 *                 None, None)
 *         end_mark = Mark(self.stream_name,
 */
  __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.column); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "yaml/_yaml.pyx":736
 * 
 *     cdef _compose_scalar_node(self, object anchor):
 *         start_mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.start_mark.index,
 *                 self.parsed_event.start_mark.line,
 */
  __pyx_t_4 = PyTuple_New(6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self->stream_name);
  __Pyx_GIVEREF(__pyx_v_self->stream_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 736, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(0, 736, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_2)) __PYX_ERR(0, 736, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_3)) __PYX_ERR(0, 736, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 4, Py_None)) __PYX_ERR(0, 736, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 5, Py_None)) __PYX_ERR(0, 736, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 736, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_start_mark = ((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "yaml/_yaml.pyx":742
 *                 None, None)
 *         end_mark = Mark(self.stream_name,
 *                 self.parsed_event.end_mark.index,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.end_mark.line,
 *                 self.parsed_event.end_mark.column,
 */
  __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.end_mark.index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 742, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "yaml/_yaml.pyx":743
 *         end_mark = Mark(self.stream_name,
 *                 self.parsed_event.end_mark.index,
 *                 self.parsed_event.end_mark.line,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.end_mark.column,
 *                 None, None)
 */
  __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.end_mark.line); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "yaml/_yaml.pyx":744
 *                 self.parsed_event.end_mark.index,
 *                 self.parsed_event.end_mark.line,
 *                 self.parsed_event.end_mark.column,             # <<<<<<<<<<<<<<
 *                 None, None)
 *         value = PyUnicode_DecodeUTF8(<char *>self.parsed_event.data.scalar.value,
 */
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.end_mark.column); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "yaml/_yaml.pyx":741
 *                 self.parsed_event.start_mark.column,
 *                 None, None)
 *         end_mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.end_mark.index,
 *                 self.parsed_event.end_mark.line,
 */
  __pyx_t_1 = PyTuple_New(6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->stream_name);
  __Pyx_GIVEREF(__pyx_v_self->stream_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 741, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3)) __PYX_ERR(0, 741, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_4)) __PYX_ERR(0, 741, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_2)) __PYX_ERR(0, 741, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 4, Py_None)) __PYX_ERR(0, 741, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 5, Py_None)) __PYX_ERR(0, 741, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_end_mark = ((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":746
 *                 self.parsed_event.end_mark.column,
 *                 None, None)
 *         value = PyUnicode_DecodeUTF8(<char *>self.parsed_event.data.scalar.value,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.data.scalar.length, 'strict')
 *         plain_implicit = False
 */
  __pyx_t_2 = PyUnicode_DecodeUTF8(((char *)__pyx_v_self->parsed_event.data.scalar.value), __pyx_v_self->parsed_event.data.scalar.length, ((char *)"strict")); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_value = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":748
 *         value = PyUnicode_DecodeUTF8(<char *>self.parsed_event.data.scalar.value,
 *                 self.parsed_event.data.scalar.length, 'strict')
 *         plain_implicit = False             # <<<<<<<<<<<<<<
 *         if self.parsed_event.data.scalar.plain_implicit == 1:
 *             plain_implicit = True
 */
  __pyx_v_plain_implicit = 0;

  /* "yaml/_yaml.pyx":749
 *                 self.parsed_event.data.scalar.length, 'strict')
 *         plain_implicit = False
 *         if self.parsed_event.data.scalar.plain_implicit == 1:             # <<<<<<<<<<<<<<
 *             plain_implicit = True
 *         quoted_implicit = False
 */
  __pyx_t_5 = (__pyx_v_self->parsed_event.data.scalar.plain_implicit == 1);
  if (__pyx_t_5) {

    /* "yaml/_yaml.pyx":750
 *         plain_implicit = False
 *         if self.parsed_event.data.scalar.plain_implicit == 1:
 *             plain_implicit = True             # <<<<<<<<<<<<<<
 *         quoted_implicit = False
 *         if self.parsed_event.data.scalar.quoted_implicit == 1:
 */
    __pyx_v_plain_implicit = 1;

    /* "yaml/_yaml.pyx":749
 *                 self.parsed_event.data.scalar.length, 'strict')
 *         plain_implicit = False
 *         if self.parsed_event.data.scalar.plain_implicit == 1:             # <<<<<<<<<<<<<<
 *             plain_implicit = True
 *         quoted_implicit = False
 */
  }

  /* "yaml/_yaml.pyx":751
 *         if self.parsed_event.data.scalar.plain_implicit == 1:
 *             plain_implicit = True
 *         quoted_implicit = False             # <<<<<<<<<<<<<<
 *         if self.parsed_event.data.scalar.quoted_implicit == 1:
 *             quoted_implicit = True
 */
  __pyx_v_quoted_implicit = 0;

  /* "yaml/_yaml.pyx":752
 *             plain_implicit = True
 *         quoted_implicit = False
 *         if self.parsed_event.data.scalar.quoted_implicit == 1:             # <<<<<<<<<<<<<<
 *             quoted_implicit = True
 *         if self.parsed_event.data.scalar.tag == NULL    \
 */
  __pyx_t_5 = (__pyx_v_self->parsed_event.data.scalar.quoted_implicit == 1);
  if (__pyx_t_5) {

    /* "yaml/_yaml.pyx":753
 *         quoted_implicit = False
 *         if self.parsed_event.data.scalar.quoted_implicit == 1:
 *             quoted_implicit = True             # <<<<<<<<<<<<<<
 *         if self.parsed_event.data.scalar.tag == NULL    \
 *                 or (self.parsed_event.data.scalar.tag[0] == c'!'
 */
    __pyx_v_quoted_implicit = 1;

    /* "yaml/_yaml.pyx":752
 *             plain_implicit = True
 *         quoted_implicit = False
 *         if self.parsed_event.data.scalar.quoted_implicit == 1:             # <<<<<<<<<<<<<<
 *             quoted_implicit = True
 *         if self.parsed_event.data.scalar.tag == NULL    \
 */
  }

  /* "yaml/_yaml.pyx":754
 *         if self.parsed_event.data.scalar.quoted_implicit == 1:
 *             quoted_implicit = True
 *         if self.parsed_event.data.scalar.tag == NULL    \             # <<<<<<<<<<<<<<
 *                 or (self.parsed_event.data.scalar.tag[0] == c'!'
 *                         and self.parsed_event.data.scalar.tag[1] == c'\0'):
 */
  __pyx_t_6 = (__pyx_v_self->parsed_event.data.scalar.tag == NULL);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }

  /* "yaml/_yaml.pyx":755
 *             quoted_implicit = True
 *         if self.parsed_event.data.scalar.tag == NULL    \
 *                 or (self.parsed_event.data.scalar.tag[0] == c'!'             # <<<<<<<<<<<<<<
 *                         and self.parsed_event.data.scalar.tag[1] == c'\0'):
 *             tag = self.resolve(ScalarNode, value, (plain_implicit, quoted_implicit))
 */
  __pyx_t_6 = ((__pyx_v_self->parsed_event.data.scalar.tag[0]) == '!');
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }

  /* "yaml/_yaml.pyx":756
 *         if self.parsed_event.data.scalar.tag == NULL    \
 *                 or (self.parsed_event.data.scalar.tag[0] == c'!'
 *                         and self.parsed_event.data.scalar.tag[1] == c'\0'):             # <<<<<<<<<<<<<<
 *             tag = self.resolve(ScalarNode, value, (plain_implicit, quoted_implicit))
 *         else:
 */
  __pyx_t_6 = ((__pyx_v_self->parsed_event.data.scalar.tag[1]) == '\x00');
  __pyx_t_5 = __pyx_t_6;
  __pyx_L6_bool_binop_done:;

  /* "yaml/_yaml.pyx":754
 *         if self.parsed_event.data.scalar.quoted_implicit == 1:
 *             quoted_implicit = True
 *         if self.parsed_event.data.scalar.tag == NULL    \             # <<<<<<<<<<<<<<
 *                 or (self.parsed_event.data.scalar.tag[0] == c'!'
 *                         and self.parsed_event.data.scalar.tag[1] == c'\0'):
 */
  if (__pyx_t_5) {

    /* "yaml/_yaml.pyx":757
 *                 or (self.parsed_event.data.scalar.tag[0] == c'!'
 *                         and self.parsed_event.data.scalar.tag[1] == c'\0'):
 *             tag = self.resolve(ScalarNode, value, (plain_implicit, quoted_implicit))             # <<<<<<<<<<<<<<
 *         else:
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.scalar.tag)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_resolve); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ScalarNode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_plain_implicit); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_quoted_implicit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 757, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_3)) __PYX_ERR(0, 757, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_7);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_7)) __PYX_ERR(0, 757, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_t_4, __pyx_v_value, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_9, 3+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 757, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_v_tag = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "yaml/_yaml.pyx":754
 *         if self.parsed_event.data.scalar.quoted_implicit == 1:
 *             quoted_implicit = True
 *         if self.parsed_event.data.scalar.tag == NULL    \             # <<<<<<<<<<<<<<
 *                 or (self.parsed_event.data.scalar.tag[0] == c'!'
 *                         and self.parsed_event.data.scalar.tag[1] == c'\0'):
 */
    goto __pyx_L5;
  }

  /* "yaml/_yaml.pyx":759
 *             tag = self.resolve(ScalarNode, value, (plain_implicit, quoted_implicit))
 *         else:
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.scalar.tag)             # <<<<<<<<<<<<<<
 *         style = None
 *         if self.parsed_event.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:
 */
  /*else*/ {
    __pyx_t_2 = PyUnicode_FromYamlString(__pyx_v_self->parsed_event.data.scalar.tag); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 759, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_tag = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L5:;

  /* "yaml/_yaml.pyx":760
 *         else:
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.scalar.tag)
 *         style = None             # <<<<<<<<<<<<<<
 *         if self.parsed_event.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:
 *             style = u''
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_style = ((PyObject*)Py_None);

  /* "yaml/_yaml.pyx":761
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.scalar.tag)
 *         style = None
 *         if self.parsed_event.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *             style = u''
 *         elif self.parsed_event.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 */
  switch (__pyx_v_self->parsed_event.data.scalar.style) {
    case YAML_PLAIN_SCALAR_STYLE:

    /* "yaml/_yaml.pyx":762
 *         style = None
 *         if self.parsed_event.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:
 *             style = u''             # <<<<<<<<<<<<<<
 *         elif self.parsed_event.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 *             style = u'\''
 */
    __Pyx_INCREF(__pyx_kp_u__4);
    __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__4);

    /* "yaml/_yaml.pyx":761
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.scalar.tag)
 *         style = None
 *         if self.parsed_event.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *             style = u''
 *         elif self.parsed_event.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 */
    break;
    case YAML_SINGLE_QUOTED_SCALAR_STYLE:

    /* "yaml/_yaml.pyx":764
 *             style = u''
 *         elif self.parsed_event.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 *             style = u'\''             # <<<<<<<<<<<<<<
 *         elif self.parsed_event.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:
 *             style = u'"'
 */
    __Pyx_INCREF(__pyx_kp_u__5);
    __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__5);

    /* "yaml/_yaml.pyx":763
 *         if self.parsed_event.data.scalar.style == YAML_PLAIN_SCALAR_STYLE:
 *             style = u''
 *         elif self.parsed_event.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *             style = u'\''
 *         elif self.parsed_event.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:
 */
    break;
    case YAML_DOUBLE_QUOTED_SCALAR_STYLE:

    /* "yaml/_yaml.pyx":766
 *             style = u'\''
 *         elif self.parsed_event.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:
 *             style = u'"'             # <<<<<<<<<<<<<<
 *         elif self.parsed_event.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:
 *             style = u'|'
 */
    __Pyx_INCREF(__pyx_kp_u__6);
    __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__6);

    /* "yaml/_yaml.pyx":765
 *         elif self.parsed_event.data.scalar.style == YAML_SINGLE_QUOTED_SCALAR_STYLE:
 *             style = u'\''
 *         elif self.parsed_event.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *             style = u'"'
 *         elif self.parsed_event.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:
 */
    break;
    case YAML_LITERAL_SCALAR_STYLE:

    /* "yaml/_yaml.pyx":768
 *             style = u'"'
 *         elif self.parsed_event.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:
 *             style = u'|'             # <<<<<<<<<<<<<<
 *         elif self.parsed_event.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:
 *             style = u'>'
 */
    __Pyx_INCREF(__pyx_kp_u__7);
    __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__7);

    /* "yaml/_yaml.pyx":767
 *         elif self.parsed_event.data.scalar.style == YAML_DOUBLE_QUOTED_SCALAR_STYLE:
 *             style = u'"'
 *         elif self.parsed_event.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *             style = u'|'
 *         elif self.parsed_event.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:
 */
    break;
    case YAML_FOLDED_SCALAR_STYLE:

    /* "yaml/_yaml.pyx":770
 *             style = u'|'
 *         elif self.parsed_event.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:
 *             style = u'>'             # <<<<<<<<<<<<<<
 *         node = ScalarNode(tag, value, start_mark, end_mark, style)
 *         if anchor is not None:
 */
    __Pyx_INCREF(__pyx_kp_u__8);
    __Pyx_DECREF_SET(__pyx_v_style, __pyx_kp_u__8);

    /* "yaml/_yaml.pyx":769
 *         elif self.parsed_event.data.scalar.style == YAML_LITERAL_SCALAR_STYLE:
 *             style = u'|'
 *         elif self.parsed_event.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:             # <<<<<<<<<<<<<<
 *             style = u'>'
 *         node = ScalarNode(tag, value, start_mark, end_mark, style)
 */
    break;
    default: break;
  }

  /* "yaml/_yaml.pyx":771
 *         elif self.parsed_event.data.scalar.style == YAML_FOLDED_SCALAR_STYLE:
 *             style = u'>'
 *         node = ScalarNode(tag, value, start_mark, end_mark, style)             # <<<<<<<<<<<<<<
 *         if anchor is not None:
 *             self.anchors[anchor] = node
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ScalarNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[6] = {__pyx_t_8, __pyx_v_tag, __pyx_v_value, ((PyObject *)__pyx_v_start_mark), ((PyObject *)__pyx_v_end_mark), __pyx_v_style};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_9, 5+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_node = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":772
 *             style = u'>'
 *         node = ScalarNode(tag, value, start_mark, end_mark, style)
 *         if anchor is not None:             # <<<<<<<<<<<<<<
 *             self.anchors[anchor] = node
 *         yaml_event_delete(&self.parsed_event)
 */
  __pyx_t_5 = (__pyx_v_anchor != Py_None);
  if (__pyx_t_5) {

    /* "yaml/_yaml.pyx":773
 *         node = ScalarNode(tag, value, start_mark, end_mark, style)
 *         if anchor is not None:
 *             self.anchors[anchor] = node             # <<<<<<<<<<<<<<
 *         yaml_event_delete(&self.parsed_event)
 *         return node
 */
    if (unlikely((PyObject_SetItem(__pyx_v_self->anchors, __pyx_v_anchor, __pyx_v_node) < 0))) __PYX_ERR(0, 773, __pyx_L1_error)

    /* "yaml/_yaml.pyx":772
 *             style = u'>'
 *         node = ScalarNode(tag, value, start_mark, end_mark, style)
 *         if anchor is not None:             # <<<<<<<<<<<<<<
 *             self.anchors[anchor] = node
 *         yaml_event_delete(&self.parsed_event)
 */
  }

  /* "yaml/_yaml.pyx":774
 *         if anchor is not None:
 *             self.anchors[anchor] = node
 *         yaml_event_delete(&self.parsed_event)             # <<<<<<<<<<<<<<
 *         return node
 * 
 */
  yaml_event_delete((&__pyx_v_self->parsed_event));

  /* "yaml/_yaml.pyx":775
 *             self.anchors[anchor] = node
 *         yaml_event_delete(&self.parsed_event)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     cdef _compose_sequence_node(self, object anchor):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":735
 *         return node
 * 
 *     cdef _compose_scalar_node(self, object anchor):             # <<<<<<<<<<<<<<
 *         start_mark = Mark(self.stream_name,
 *                 self.parsed_event.start_mark.index,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("yaml._yaml.CParser._compose_scalar_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_start_mark);
  __Pyx_XDECREF((PyObject *)__pyx_v_end_mark);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_tag);
  __Pyx_XDECREF(__pyx_v_style);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":777
 *         return node
 * 
 *     cdef _compose_sequence_node(self, object anchor):             # <<<<<<<<<<<<<<
 *         cdef int index
 *         start_mark = Mark(self.stream_name,
 */

static PyObject *__pyx_f_4yaml_5_yaml_7CParser__compose_sequence_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_anchor) {
  int __pyx_v_index;
  struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_start_mark = NULL;
  int __pyx_v_implicit;
  PyObject *__pyx_v_tag = NULL;
  PyObject *__pyx_v_flow_style = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_compose_sequence_node", 1);

  /* "yaml/_yaml.pyx":780
 *         cdef int index
 *         start_mark = Mark(self.stream_name,
 *                 self.parsed_event.start_mark.index,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.start_mark.line,
 *                 self.parsed_event.start_mark.column,
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "yaml/_yaml.pyx":781
 *         start_mark = Mark(self.stream_name,
 *                 self.parsed_event.start_mark.index,
 *                 self.parsed_event.start_mark.line,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.start_mark.column,
 *                 None, None)
 */
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.line); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 781, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "yaml/_yaml.pyx":782
 *                 self.parsed_event.start_mark.index,
 *                 self.parsed_event.start_mark.line,
 *                 self.parsed_event.start_mark.column,             # <<<<<<<<<<<<<<
 *                 None, None)
 *         implicit = False
 */
  __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.column); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "yaml/_yaml.pyx":779
 *     cdef _compose_sequence_node(self, object anchor):
 *         cdef int index
 *         start_mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.start_mark.index,
 *                 self.parsed_event.start_mark.line,
 */
  __pyx_t_4 = PyTuple_New(6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self->stream_name);
  __Pyx_GIVEREF(__pyx_v_self->stream_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 779, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(0, 779, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_2)) __PYX_ERR(0, 779, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_3)) __PYX_ERR(0, 779, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 4, Py_None)) __PYX_ERR(0, 779, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 5, Py_None)) __PYX_ERR(0, 779, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_start_mark = ((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "yaml/_yaml.pyx":784
 *                 self.parsed_event.start_mark.column,
 *                 None, None)
 *         implicit = False             # <<<<<<<<<<<<<<
 *         if self.parsed_event.data.sequence_start.implicit == 1:
 *             implicit = True
 */
  __pyx_v_implicit = 0;

  /* "yaml/_yaml.pyx":785
 *                 None, None)
 *         implicit = False
 *         if self.parsed_event.data.sequence_start.implicit == 1:             # <<<<<<<<<<<<<<
 *             implicit = True
 *         if self.parsed_event.data.sequence_start.tag == NULL    \
 */
  __pyx_t_5 = (__pyx_v_self->parsed_event.data.sequence_start.implicit == 1);
  if (__pyx_t_5) {

    /* "yaml/_yaml.pyx":786
 *         implicit = False
 *         if self.parsed_event.data.sequence_start.implicit == 1:
 *             implicit = True             # <<<<<<<<<<<<<<
 *         if self.parsed_event.data.sequence_start.tag == NULL    \
 *                 or (self.parsed_event.data.sequence_start.tag[0] == c'!'
 */
    __pyx_v_implicit = 1;

    /* "yaml/_yaml.pyx":785
 *                 None, None)
 *         implicit = False
 *         if self.parsed_event.data.sequence_start.implicit == 1:             # <<<<<<<<<<<<<<
 *             implicit = True
 *         if self.parsed_event.data.sequence_start.tag == NULL    \
 */
  }

  /* "yaml/_yaml.pyx":787
 *         if self.parsed_event.data.sequence_start.implicit == 1:
 *             implicit = True
 *         if self.parsed_event.data.sequence_start.tag == NULL    \             # <<<<<<<<<<<<<<
 *                 or (self.parsed_event.data.sequence_start.tag[0] == c'!'
 *                         and self.parsed_event.data.sequence_start.tag[1] == c'\0'):
 */
  __pyx_t_6 = (__pyx_v_self->parsed_event.data.sequence_start.tag == NULL);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L5_bool_binop_done;
  }

  /* "yaml/_yaml.pyx":788
 *             implicit = True
 *         if self.parsed_event.data.sequence_start.tag == NULL    \
 *                 or (self.parsed_event.data.sequence_start.tag[0] == c'!'             # <<<<<<<<<<<<<<
 *                         and self.parsed_event.data.sequence_start.tag[1] == c'\0'):
 *             tag = self.resolve(SequenceNode, None, implicit)
 */
  __pyx_t_6 = ((__pyx_v_self->parsed_event.data.sequence_start.tag[0]) == '!');
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L5_bool_binop_done;
  }

  /* "yaml/_yaml.pyx":789
 *         if self.parsed_event.data.sequence_start.tag == NULL    \
 *                 or (self.parsed_event.data.sequence_start.tag[0] == c'!'
 *                         and self.parsed_event.data.sequence_start.tag[1] == c'\0'):             # <<<<<<<<<<<<<<
 *             tag = self.resolve(SequenceNode, None, implicit)
 *         else:
 */
  __pyx_t_6 = ((__pyx_v_self->parsed_event.data.sequence_start.tag[1]) == '\x00');
  __pyx_t_5 = __pyx_t_6;
  __pyx_L5_bool_binop_done:;

  /* "yaml/_yaml.pyx":787
 *         if self.parsed_event.data.sequence_start.implicit == 1:
 *             implicit = True
 *         if self.parsed_event.data.sequence_start.tag == NULL    \             # <<<<<<<<<<<<<<
 *                 or (self.parsed_event.data.sequence_start.tag[0] == c'!'
 *                         and self.parsed_event.data.sequence_start.tag[1] == c'\0'):
 */
  if (__pyx_t_5) {

    /* "yaml/_yaml.pyx":790
 *                 or (self.parsed_event.data.sequence_start.tag[0] == c'!'
 *                         and self.parsed_event.data.sequence_start.tag[1] == c'\0'):
 *             tag = self.resolve(SequenceNode, None, implicit)             # <<<<<<<<<<<<<<
 *         else:
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.tag)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_resolve); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_SequenceNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_implicit); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 790, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_t_2, Py_None, __pyx_t_1};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_8, 3+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 790, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_tag = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "yaml/_yaml.pyx":787
 *         if self.parsed_event.data.sequence_start.implicit == 1:
 *             implicit = True
 *         if self.parsed_event.data.sequence_start.tag == NULL    \             # <<<<<<<<<<<<<<
 *                 or (self.parsed_event.data.sequence_start.tag[0] == c'!'
 *                         and self.parsed_event.data.sequence_start.tag[1] == c'\0'):
 */
    goto __pyx_L4;
  }

  /* "yaml/_yaml.pyx":792
 *             tag = self.resolve(SequenceNode, None, implicit)
 *         else:
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.tag)             # <<<<<<<<<<<<<<
 *         flow_style = None
 *         if self.parsed_event.data.sequence_start.style == YAML_FLOW_SEQUENCE_STYLE:
 */
  /*else*/ {
    __pyx_t_3 = PyUnicode_FromYamlString(__pyx_v_self->parsed_event.data.sequence_start.tag); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 792, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_tag = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_L4:;

  /* "yaml/_yaml.pyx":793
 *         else:
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.tag)
 *         flow_style = None             # <<<<<<<<<<<<<<
 *         if self.parsed_event.data.sequence_start.style == YAML_FLOW_SEQUENCE_STYLE:
 *             flow_style = True
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_flow_style = Py_None;

  /* "yaml/_yaml.pyx":794
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.tag)
 *         flow_style = None
 *         if self.parsed_event.data.sequence_start.style == YAML_FLOW_SEQUENCE_STYLE:             # <<<<<<<<<<<<<<
 *             flow_style = True
 *         elif self.parsed_event.data.sequence_start.style == YAML_BLOCK_SEQUENCE_STYLE:
 */
  switch (__pyx_v_self->parsed_event.data.sequence_start.style) {
    case YAML_FLOW_SEQUENCE_STYLE:

    /* "yaml/_yaml.pyx":795
 *         flow_style = None
 *         if self.parsed_event.data.sequence_start.style == YAML_FLOW_SEQUENCE_STYLE:
 *             flow_style = True             # <<<<<<<<<<<<<<
 *         elif self.parsed_event.data.sequence_start.style == YAML_BLOCK_SEQUENCE_STYLE:
 *             flow_style = False
 */
    __Pyx_INCREF(Py_True);
    __Pyx_DECREF_SET(__pyx_v_flow_style, Py_True);

    /* "yaml/_yaml.pyx":794
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.sequence_start.tag)
 *         flow_style = None
 *         if self.parsed_event.data.sequence_start.style == YAML_FLOW_SEQUENCE_STYLE:             # <<<<<<<<<<<<<<
 *             flow_style = True
 *         elif self.parsed_event.data.sequence_start.style == YAML_BLOCK_SEQUENCE_STYLE:
 */
    break;
    case YAML_BLOCK_SEQUENCE_STYLE:

    /* "yaml/_yaml.pyx":797
 *             flow_style = True
 *         elif self.parsed_event.data.sequence_start.style == YAML_BLOCK_SEQUENCE_STYLE:
 *             flow_style = False             # <<<<<<<<<<<<<<
 *         value = []
 *         node = SequenceNode(tag, value, start_mark, None, flow_style)
 */
    __Pyx_INCREF(Py_False);
    __Pyx_DECREF_SET(__pyx_v_flow_style, Py_False);

    /* "yaml/_yaml.pyx":796
 *         if self.parsed_event.data.sequence_start.style == YAML_FLOW_SEQUENCE_STYLE:
 *             flow_style = True
 *         elif self.parsed_event.data.sequence_start.style == YAML_BLOCK_SEQUENCE_STYLE:             # <<<<<<<<<<<<<<
 *             flow_style = False
 *         value = []
 */
    break;
    default: break;
  }

  /* "yaml/_yaml.pyx":798
 *         elif self.parsed_event.data.sequence_start.style == YAML_BLOCK_SEQUENCE_STYLE:
 *             flow_style = False
 *         value = []             # <<<<<<<<<<<<<<
 *         node = SequenceNode(tag, value, start_mark, None, flow_style)
 *         if anchor is not None:
 */
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 798, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_value = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "yaml/_yaml.pyx":799
 *             flow_style = False
 *         value = []
 *         node = SequenceNode(tag, value, start_mark, None, flow_style)             # <<<<<<<<<<<<<<
 *         if anchor is not None:
 *             self.anchors[anchor] = node
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_SequenceNode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[6] = {__pyx_t_1, __pyx_v_tag, __pyx_v_value, ((PyObject *)__pyx_v_start_mark), Py_None, __pyx_v_flow_style};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_8, 5+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_node = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "yaml/_yaml.pyx":800
 *         value = []
 *         node = SequenceNode(tag, value, start_mark, None, flow_style)
 *         if anchor is not None:             # <<<<<<<<<<<<<<
 *             self.anchors[anchor] = node
 *         yaml_event_delete(&self.parsed_event)
 */
  __pyx_t_5 = (__pyx_v_anchor != Py_None);
  if (__pyx_t_5) {

    /* "yaml/_yaml.pyx":801
 *         node = SequenceNode(tag, value, start_mark, None, flow_style)
 *         if anchor is not None:
 *             self.anchors[anchor] = node             # <<<<<<<<<<<<<<
 *         yaml_event_delete(&self.parsed_event)
 *         index = 0
 */
    if (unlikely((PyObject_SetItem(__pyx_v_self->anchors, __pyx_v_anchor, __pyx_v_node) < 0))) __PYX_ERR(0, 801, __pyx_L1_error)

    /* "yaml/_yaml.pyx":800
 *         value = []
 *         node = SequenceNode(tag, value, start_mark, None, flow_style)
 *         if anchor is not None:             # <<<<<<<<<<<<<<
 *             self.anchors[anchor] = node
 *         yaml_event_delete(&self.parsed_event)
 */
  }

  /* "yaml/_yaml.pyx":802
 *         if anchor is not None:
 *             self.anchors[anchor] = node
 *         yaml_event_delete(&self.parsed_event)             # <<<<<<<<<<<<<<
 *         index = 0
 *         self._parse_next_event()
 */
  yaml_event_delete((&__pyx_v_self->parsed_event));

  /* "yaml/_yaml.pyx":803
 *             self.anchors[anchor] = node
 *         yaml_event_delete(&self.parsed_event)
 *         index = 0             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         while self.parsed_event.type != YAML_SEQUENCE_END_EVENT:
 */
  __pyx_v_index = 0;

  /* "yaml/_yaml.pyx":804
 *         yaml_event_delete(&self.parsed_event)
 *         index = 0
 *         self._parse_next_event()             # <<<<<<<<<<<<<<
 *         while self.parsed_event.type != YAML_SEQUENCE_END_EVENT:
 *             value.append(self._compose_node(node, index))
 */
  __pyx_t_8 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse_next_event(__pyx_v_self); if (unlikely(__pyx_t_8 == ((int)0))) __PYX_ERR(0, 804, __pyx_L1_error)

  /* "yaml/_yaml.pyx":805
 *         index = 0
 *         self._parse_next_event()
 *         while self.parsed_event.type != YAML_SEQUENCE_END_EVENT:             # <<<<<<<<<<<<<<
 *             value.append(self._compose_node(node, index))
 *             index = index+1
 */
  while (1) {
    __pyx_t_5 = (__pyx_v_self->parsed_event.type != YAML_SEQUENCE_END_EVENT);
    if (!__pyx_t_5) break;

    /* "yaml/_yaml.pyx":806
 *         self._parse_next_event()
 *         while self.parsed_event.type != YAML_SEQUENCE_END_EVENT:
 *             value.append(self._compose_node(node, index))             # <<<<<<<<<<<<<<
 *             index = index+1
 *             self._parse_next_event()
 */
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 806, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_compose_node(__pyx_v_self, __pyx_v_node, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 806, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_value, __pyx_t_4); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 806, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":807
 *         while self.parsed_event.type != YAML_SEQUENCE_END_EVENT:
 *             value.append(self._compose_node(node, index))
 *             index = index+1             # <<<<<<<<<<<<<<
 *             self._parse_next_event()
 *         node.end_mark = Mark(self.stream_name,
 */
    __pyx_v_index = (__pyx_v_index + 1);

    /* "yaml/_yaml.pyx":808
 *             value.append(self._compose_node(node, index))
 *             index = index+1
 *             self._parse_next_event()             # <<<<<<<<<<<<<<
 *         node.end_mark = Mark(self.stream_name,
 *                 self.parsed_event.end_mark.index,
 */
    __pyx_t_8 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse_next_event(__pyx_v_self); if (unlikely(__pyx_t_8 == ((int)0))) __PYX_ERR(0, 808, __pyx_L1_error)
  }

  /* "yaml/_yaml.pyx":810
 *             self._parse_next_event()
 *         node.end_mark = Mark(self.stream_name,
 *                 self.parsed_event.end_mark.index,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.end_mark.line,
 *                 self.parsed_event.end_mark.column,
 */
  __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.end_mark.index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 810, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "yaml/_yaml.pyx":811
 *         node.end_mark = Mark(self.stream_name,
 *                 self.parsed_event.end_mark.index,
 *                 self.parsed_event.end_mark.line,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.end_mark.column,
 *                 None, None)
 */
  __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.end_mark.line); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 811, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "yaml/_yaml.pyx":812
 *                 self.parsed_event.end_mark.index,
 *                 self.parsed_event.end_mark.line,
 *                 self.parsed_event.end_mark.column,             # <<<<<<<<<<<<<<
 *                 None, None)
 *         yaml_event_delete(&self.parsed_event)
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.end_mark.column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "yaml/_yaml.pyx":809
 *             index = index+1
 *             self._parse_next_event()
 *         node.end_mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.end_mark.index,
 *                 self.parsed_event.end_mark.line,
 */
  __pyx_t_2 = PyTuple_New(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->stream_name);
  __Pyx_GIVEREF(__pyx_v_self->stream_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 809, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(0, 809, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_3)) __PYX_ERR(0, 809, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_t_1)) __PYX_ERR(0, 809, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 4, Py_None)) __PYX_ERR(0, 809, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 5, Py_None)) __PYX_ERR(0, 809, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_3 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_n_s_end_mark, __pyx_t_1) < 0) __PYX_ERR(0, 809, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "yaml/_yaml.pyx":814
 *                 self.parsed_event.end_mark.column,
 *                 None, None)
 *         yaml_event_delete(&self.parsed_event)             # <<<<<<<<<<<<<<
 *         return node
 * 
 */
  yaml_event_delete((&__pyx_v_self->parsed_event));

  /* "yaml/_yaml.pyx":815
 *                 None, None)
 *         yaml_event_delete(&self.parsed_event)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     cdef _compose_mapping_node(self, object anchor):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":777
 *         return node
 * 
 *     cdef _compose_sequence_node(self, object anchor):             # <<<<<<<<<<<<<<
 *         cdef int index
 *         start_mark = Mark(self.stream_name,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("yaml._yaml.CParser._compose_sequence_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_start_mark);
  __Pyx_XDECREF(__pyx_v_tag);
  __Pyx_XDECREF(__pyx_v_flow_style);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":817
 *         return node
 * 
 *     cdef _compose_mapping_node(self, object anchor):             # <<<<<<<<<<<<<<
 *         start_mark = Mark(self.stream_name,
 *                 self.parsed_event.start_mark.index,
 */

static PyObject *__pyx_f_4yaml_5_yaml_7CParser__compose_mapping_node(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, PyObject *__pyx_v_anchor) {
  struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v_start_mark = NULL;
  int __pyx_v_implicit;
  PyObject *__pyx_v_tag = NULL;
  PyObject *__pyx_v_flow_style = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_node = NULL;
  PyObject *__pyx_v_item_key = NULL;
  PyObject *__pyx_v_item_value = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_compose_mapping_node", 1);

  /* "yaml/_yaml.pyx":819
 *     cdef _compose_mapping_node(self, object anchor):
 *         start_mark = Mark(self.stream_name,
 *                 self.parsed_event.start_mark.index,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.start_mark.line,
 *                 self.parsed_event.start_mark.column,
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 819, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "yaml/_yaml.pyx":820
 *         start_mark = Mark(self.stream_name,
 *                 self.parsed_event.start_mark.index,
 *                 self.parsed_event.start_mark.line,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.start_mark.column,
 *                 None, None)
 */
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.line); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "yaml/_yaml.pyx":821
 *                 self.parsed_event.start_mark.index,
 *                 self.parsed_event.start_mark.line,
 *                 self.parsed_event.start_mark.column,             # <<<<<<<<<<<<<<
 *                 None, None)
 *         implicit = False
 */
  __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.start_mark.column); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "yaml/_yaml.pyx":818
 * 
 *     cdef _compose_mapping_node(self, object anchor):
 *         start_mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.start_mark.index,
 *                 self.parsed_event.start_mark.line,
 */
  __pyx_t_4 = PyTuple_New(6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self->stream_name);
  __Pyx_GIVEREF(__pyx_v_self->stream_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 818, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(0, 818, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_2)) __PYX_ERR(0, 818, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_3)) __PYX_ERR(0, 818, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 4, Py_None)) __PYX_ERR(0, 818, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 5, Py_None)) __PYX_ERR(0, 818, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_start_mark = ((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "yaml/_yaml.pyx":823
 *                 self.parsed_event.start_mark.column,
 *                 None, None)
 *         implicit = False             # <<<<<<<<<<<<<<
 *         if self.parsed_event.data.mapping_start.implicit == 1:
 *             implicit = True
 */
  __pyx_v_implicit = 0;

  /* "yaml/_yaml.pyx":824
 *                 None, None)
 *         implicit = False
 *         if self.parsed_event.data.mapping_start.implicit == 1:             # <<<<<<<<<<<<<<
 *             implicit = True
 *         if self.parsed_event.data.mapping_start.tag == NULL    \
 */
  __pyx_t_5 = (__pyx_v_self->parsed_event.data.mapping_start.implicit == 1);
  if (__pyx_t_5) {

    /* "yaml/_yaml.pyx":825
 *         implicit = False
 *         if self.parsed_event.data.mapping_start.implicit == 1:
 *             implicit = True             # <<<<<<<<<<<<<<
 *         if self.parsed_event.data.mapping_start.tag == NULL    \
 *                 or (self.parsed_event.data.mapping_start.tag[0] == c'!'
 */
    __pyx_v_implicit = 1;

    /* "yaml/_yaml.pyx":824
 *                 None, None)
 *         implicit = False
 *         if self.parsed_event.data.mapping_start.implicit == 1:             # <<<<<<<<<<<<<<
 *             implicit = True
 *         if self.parsed_event.data.mapping_start.tag == NULL    \
 */
  }

  /* "yaml/_yaml.pyx":826
 *         if self.parsed_event.data.mapping_start.implicit == 1:
 *             implicit = True
 *         if self.parsed_event.data.mapping_start.tag == NULL    \             # <<<<<<<<<<<<<<
 *                 or (self.parsed_event.data.mapping_start.tag[0] == c'!'
 *                         and self.parsed_event.data.mapping_start.tag[1] == c'\0'):
 */
  __pyx_t_6 = (__pyx_v_self->parsed_event.data.mapping_start.tag == NULL);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L5_bool_binop_done;
  }

  /* "yaml/_yaml.pyx":827
 *             implicit = True
 *         if self.parsed_event.data.mapping_start.tag == NULL    \
 *                 or (self.parsed_event.data.mapping_start.tag[0] == c'!'             # <<<<<<<<<<<<<<
 *                         and self.parsed_event.data.mapping_start.tag[1] == c'\0'):
 *             tag = self.resolve(MappingNode, None, implicit)
 */
  __pyx_t_6 = ((__pyx_v_self->parsed_event.data.mapping_start.tag[0]) == '!');
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L5_bool_binop_done;
  }

  /* "yaml/_yaml.pyx":828
 *         if self.parsed_event.data.mapping_start.tag == NULL    \
 *                 or (self.parsed_event.data.mapping_start.tag[0] == c'!'
 *                         and self.parsed_event.data.mapping_start.tag[1] == c'\0'):             # <<<<<<<<<<<<<<
 *             tag = self.resolve(MappingNode, None, implicit)
 *         else:
 */
  __pyx_t_6 = ((__pyx_v_self->parsed_event.data.mapping_start.tag[1]) == '\x00');
  __pyx_t_5 = __pyx_t_6;
  __pyx_L5_bool_binop_done:;

  /* "yaml/_yaml.pyx":826
 *         if self.parsed_event.data.mapping_start.implicit == 1:
 *             implicit = True
 *         if self.parsed_event.data.mapping_start.tag == NULL    \             # <<<<<<<<<<<<<<
 *                 or (self.parsed_event.data.mapping_start.tag[0] == c'!'
 *                         and self.parsed_event.data.mapping_start.tag[1] == c'\0'):
 */
  if (__pyx_t_5) {

    /* "yaml/_yaml.pyx":829
 *                 or (self.parsed_event.data.mapping_start.tag[0] == c'!'
 *                         and self.parsed_event.data.mapping_start.tag[1] == c'\0'):
 *             tag = self.resolve(MappingNode, None, implicit)             # <<<<<<<<<<<<<<
 *         else:
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.tag)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_resolve); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MappingNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_implicit); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 829, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_t_2, Py_None, __pyx_t_1};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_8, 3+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 829, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_tag = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "yaml/_yaml.pyx":826
 *         if self.parsed_event.data.mapping_start.implicit == 1:
 *             implicit = True
 *         if self.parsed_event.data.mapping_start.tag == NULL    \             # <<<<<<<<<<<<<<
 *                 or (self.parsed_event.data.mapping_start.tag[0] == c'!'
 *                         and self.parsed_event.data.mapping_start.tag[1] == c'\0'):
 */
    goto __pyx_L4;
  }

  /* "yaml/_yaml.pyx":831
 *             tag = self.resolve(MappingNode, None, implicit)
 *         else:
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.tag)             # <<<<<<<<<<<<<<
 *         flow_style = None
 *         if self.parsed_event.data.mapping_start.style == YAML_FLOW_MAPPING_STYLE:
 */
  /*else*/ {
    __pyx_t_3 = PyUnicode_FromYamlString(__pyx_v_self->parsed_event.data.mapping_start.tag); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 831, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_tag = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_L4:;

  /* "yaml/_yaml.pyx":832
 *         else:
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.tag)
 *         flow_style = None             # <<<<<<<<<<<<<<
 *         if self.parsed_event.data.mapping_start.style == YAML_FLOW_MAPPING_STYLE:
 *             flow_style = True
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_flow_style = Py_None;

  /* "yaml/_yaml.pyx":833
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.tag)
 *         flow_style = None
 *         if self.parsed_event.data.mapping_start.style == YAML_FLOW_MAPPING_STYLE:             # <<<<<<<<<<<<<<
 *             flow_style = True
 *         elif self.parsed_event.data.mapping_start.style == YAML_BLOCK_MAPPING_STYLE:
 */
  switch (__pyx_v_self->parsed_event.data.mapping_start.style) {
    case YAML_FLOW_MAPPING_STYLE:

    /* "yaml/_yaml.pyx":834
 *         flow_style = None
 *         if self.parsed_event.data.mapping_start.style == YAML_FLOW_MAPPING_STYLE:
 *             flow_style = True             # <<<<<<<<<<<<<<
 *         elif self.parsed_event.data.mapping_start.style == YAML_BLOCK_MAPPING_STYLE:
 *             flow_style = False
 */
    __Pyx_INCREF(Py_True);
    __Pyx_DECREF_SET(__pyx_v_flow_style, Py_True);

    /* "yaml/_yaml.pyx":833
 *             tag = PyUnicode_FromYamlString(self.parsed_event.data.mapping_start.tag)
 *         flow_style = None
 *         if self.parsed_event.data.mapping_start.style == YAML_FLOW_MAPPING_STYLE:             # <<<<<<<<<<<<<<
 *             flow_style = True
 *         elif self.parsed_event.data.mapping_start.style == YAML_BLOCK_MAPPING_STYLE:
 */
    break;
    case YAML_BLOCK_MAPPING_STYLE:

    /* "yaml/_yaml.pyx":836
 *             flow_style = True
 *         elif self.parsed_event.data.mapping_start.style == YAML_BLOCK_MAPPING_STYLE:
 *             flow_style = False             # <<<<<<<<<<<<<<
 *         value = []
 *         node = MappingNode(tag, value, start_mark, None, flow_style)
 */
    __Pyx_INCREF(Py_False);
    __Pyx_DECREF_SET(__pyx_v_flow_style, Py_False);

    /* "yaml/_yaml.pyx":835
 *         if self.parsed_event.data.mapping_start.style == YAML_FLOW_MAPPING_STYLE:
 *             flow_style = True
 *         elif self.parsed_event.data.mapping_start.style == YAML_BLOCK_MAPPING_STYLE:             # <<<<<<<<<<<<<<
 *             flow_style = False
 *         value = []
 */
    break;
    default: break;
  }

  /* "yaml/_yaml.pyx":837
 *         elif self.parsed_event.data.mapping_start.style == YAML_BLOCK_MAPPING_STYLE:
 *             flow_style = False
 *         value = []             # <<<<<<<<<<<<<<
 *         node = MappingNode(tag, value, start_mark, None, flow_style)
 *         if anchor is not None:
 */
  __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_value = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "yaml/_yaml.pyx":838
 *             flow_style = False
 *         value = []
 *         node = MappingNode(tag, value, start_mark, None, flow_style)             # <<<<<<<<<<<<<<
 *         if anchor is not None:
 *             self.anchors[anchor] = node
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_MappingNode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = NULL;
  __pyx_t_8 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_8 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[6] = {__pyx_t_1, __pyx_v_tag, __pyx_v_value, ((PyObject *)__pyx_v_start_mark), Py_None, __pyx_v_flow_style};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_8, 5+__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 838, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_v_node = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "yaml/_yaml.pyx":839
 *         value = []
 *         node = MappingNode(tag, value, start_mark, None, flow_style)
 *         if anchor is not None:             # <<<<<<<<<<<<<<
 *             self.anchors[anchor] = node
 *         yaml_event_delete(&self.parsed_event)
 */
  __pyx_t_5 = (__pyx_v_anchor != Py_None);
  if (__pyx_t_5) {

    /* "yaml/_yaml.pyx":840
 *         node = MappingNode(tag, value, start_mark, None, flow_style)
 *         if anchor is not None:
 *             self.anchors[anchor] = node             # <<<<<<<<<<<<<<
 *         yaml_event_delete(&self.parsed_event)
 *         self._parse_next_event()
 */
    if (unlikely((PyObject_SetItem(__pyx_v_self->anchors, __pyx_v_anchor, __pyx_v_node) < 0))) __PYX_ERR(0, 840, __pyx_L1_error)

    /* "yaml/_yaml.pyx":839
 *         value = []
 *         node = MappingNode(tag, value, start_mark, None, flow_style)
 *         if anchor is not None:             # <<<<<<<<<<<<<<
 *             self.anchors[anchor] = node
 *         yaml_event_delete(&self.parsed_event)
 */
  }

  /* "yaml/_yaml.pyx":841
 *         if anchor is not None:
 *             self.anchors[anchor] = node
 *         yaml_event_delete(&self.parsed_event)             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         while self.parsed_event.type != YAML_MAPPING_END_EVENT:
 */
  yaml_event_delete((&__pyx_v_self->parsed_event));

  /* "yaml/_yaml.pyx":842
 *             self.anchors[anchor] = node
 *         yaml_event_delete(&self.parsed_event)
 *         self._parse_next_event()             # <<<<<<<<<<<<<<
 *         while self.parsed_event.type != YAML_MAPPING_END_EVENT:
 *             item_key = self._compose_node(node, None)
 */
  __pyx_t_8 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse_next_event(__pyx_v_self); if (unlikely(__pyx_t_8 == ((int)0))) __PYX_ERR(0, 842, __pyx_L1_error)

  /* "yaml/_yaml.pyx":843
 *         yaml_event_delete(&self.parsed_event)
 *         self._parse_next_event()
 *         while self.parsed_event.type != YAML_MAPPING_END_EVENT:             # <<<<<<<<<<<<<<
 *             item_key = self._compose_node(node, None)
 *             item_value = self._compose_node(node, item_key)
 */
  while (1) {
    __pyx_t_5 = (__pyx_v_self->parsed_event.type != YAML_MAPPING_END_EVENT);
    if (!__pyx_t_5) break;

    /* "yaml/_yaml.pyx":844
 *         self._parse_next_event()
 *         while self.parsed_event.type != YAML_MAPPING_END_EVENT:
 *             item_key = self._compose_node(node, None)             # <<<<<<<<<<<<<<
 *             item_value = self._compose_node(node, item_key)
 *             value.append((item_key, item_value))
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_compose_node(__pyx_v_self, __pyx_v_node, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 844, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_item_key, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "yaml/_yaml.pyx":845
 *         while self.parsed_event.type != YAML_MAPPING_END_EVENT:
 *             item_key = self._compose_node(node, None)
 *             item_value = self._compose_node(node, item_key)             # <<<<<<<<<<<<<<
 *             value.append((item_key, item_value))
 *             self._parse_next_event()
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_compose_node(__pyx_v_self, __pyx_v_node, __pyx_v_item_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_item_value, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "yaml/_yaml.pyx":846
 *             item_key = self._compose_node(node, None)
 *             item_value = self._compose_node(node, item_key)
 *             value.append((item_key, item_value))             # <<<<<<<<<<<<<<
 *             self._parse_next_event()
 *         node.end_mark = Mark(self.stream_name,
 */
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 846, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_item_key);
    __Pyx_GIVEREF(__pyx_v_item_key);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_item_key)) __PYX_ERR(0, 846, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_item_value);
    __Pyx_GIVEREF(__pyx_v_item_value);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_item_value)) __PYX_ERR(0, 846, __pyx_L1_error);
    __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_value, __pyx_t_3); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 846, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "yaml/_yaml.pyx":847
 *             item_value = self._compose_node(node, item_key)
 *             value.append((item_key, item_value))
 *             self._parse_next_event()             # <<<<<<<<<<<<<<
 *         node.end_mark = Mark(self.stream_name,
 *                 self.parsed_event.end_mark.index,
 */
    __pyx_t_8 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parse_next_event(__pyx_v_self); if (unlikely(__pyx_t_8 == ((int)0))) __PYX_ERR(0, 847, __pyx_L1_error)
  }

  /* "yaml/_yaml.pyx":849
 *             self._parse_next_event()
 *         node.end_mark = Mark(self.stream_name,
 *                 self.parsed_event.end_mark.index,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.end_mark.line,
 *                 self.parsed_event.end_mark.column,
 */
  __pyx_t_3 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.end_mark.index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 849, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "yaml/_yaml.pyx":850
 *         node.end_mark = Mark(self.stream_name,
 *                 self.parsed_event.end_mark.index,
 *                 self.parsed_event.end_mark.line,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.end_mark.column,
 *                 None, None)
 */
  __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.end_mark.line); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 850, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "yaml/_yaml.pyx":851
 *                 self.parsed_event.end_mark.index,
 *                 self.parsed_event.end_mark.line,
 *                 self.parsed_event.end_mark.column,             # <<<<<<<<<<<<<<
 *                 None, None)
 *         yaml_event_delete(&self.parsed_event)
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->parsed_event.end_mark.column); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 851, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "yaml/_yaml.pyx":848
 *             value.append((item_key, item_value))
 *             self._parse_next_event()
 *         node.end_mark = Mark(self.stream_name,             # <<<<<<<<<<<<<<
 *                 self.parsed_event.end_mark.index,
 *                 self.parsed_event.end_mark.line,
 */
  __pyx_t_2 = PyTuple_New(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->stream_name);
  __Pyx_GIVEREF(__pyx_v_self->stream_name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->stream_name)) __PYX_ERR(0, 848, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3)) __PYX_ERR(0, 848, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_4)) __PYX_ERR(0, 848, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_t_1)) __PYX_ERR(0, 848, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 4, Py_None)) __PYX_ERR(0, 848, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 5, Py_None)) __PYX_ERR(0, 848, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 848, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_node, __pyx_n_s_end_mark, __pyx_t_1) < 0) __PYX_ERR(0, 848, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "yaml/_yaml.pyx":853
 *                 self.parsed_event.end_mark.column,
 *                 None, None)
 *         yaml_event_delete(&self.parsed_event)             # <<<<<<<<<<<<<<
 *         return node
 * 
 */
  yaml_event_delete((&__pyx_v_self->parsed_event));

  /* "yaml/_yaml.pyx":854
 *                 None, None)
 *         yaml_event_delete(&self.parsed_event)
 *         return node             # <<<<<<<<<<<<<<
 * 
 *     cdef int _parse_next_event(self) except 0:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_node);
  __pyx_r = __pyx_v_node;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":817
 *         return node
 * 
 *     cdef _compose_mapping_node(self, object anchor):             # <<<<<<<<<<<<<<
 *         start_mark = Mark(self.stream_name,
 *                 self.parsed_event.start_mark.index,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("yaml._yaml.CParser._compose_mapping_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_start_mark);
  __Pyx_XDECREF(__pyx_v_tag);
  __Pyx_XDECREF(__pyx_v_flow_style);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XDECREF(__pyx_v_item_key);
  __Pyx_XDECREF(__pyx_v_item_value);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":856
 *         return node
 * 
 *     cdef int _parse_next_event(self) except 0:             # <<<<<<<<<<<<<<
 *         if self.parsed_event.type == YAML_NO_EVENT:
 *             if yaml_parser_parse(&self.parser, &self.parsed_event) == 0:
 */

static int __pyx_f_4yaml_5_yaml_7CParser__parse_next_event(struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  PyObject *__pyx_v_error = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_parse_next_event", 1);

  /* "yaml/_yaml.pyx":857
 * 
 *     cdef int _parse_next_event(self) except 0:
 *         if self.parsed_event.type == YAML_NO_EVENT:             # <<<<<<<<<<<<<<
 *             if yaml_parser_parse(&self.parser, &self.parsed_event) == 0:
 *                 error = self._parser_error()
 */
  __pyx_t_1 = (__pyx_v_self->parsed_event.type == YAML_NO_EVENT);
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":858
 *     cdef int _parse_next_event(self) except 0:
 *         if self.parsed_event.type == YAML_NO_EVENT:
 *             if yaml_parser_parse(&self.parser, &self.parsed_event) == 0:             # <<<<<<<<<<<<<<
 *                 error = self._parser_error()
 *                 raise error
 */
    __pyx_t_2 = yaml_parser_parse((&__pyx_v_self->parser), (&__pyx_v_self->parsed_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 858, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_2 == 0);
    if (unlikely(__pyx_t_1)) {

      /* "yaml/_yaml.pyx":859
 *         if self.parsed_event.type == YAML_NO_EVENT:
 *             if yaml_parser_parse(&self.parser, &self.parsed_event) == 0:
 *                 error = self._parser_error()             # <<<<<<<<<<<<<<
 *                 raise error
 *         return 1
 */
      __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CParser *)__pyx_v_self->__pyx_vtab)->_parser_error(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 859, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_error = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "yaml/_yaml.pyx":860
 *             if yaml_parser_parse(&self.parser, &self.parsed_event) == 0:
 *                 error = self._parser_error()
 *                 raise error             # <<<<<<<<<<<<<<
 *         return 1
 * 
 */
      __Pyx_Raise(__pyx_v_error, 0, 0, 0);
      __PYX_ERR(0, 860, __pyx_L1_error)

      /* "yaml/_yaml.pyx":858
 *     cdef int _parse_next_event(self) except 0:
 *         if self.parsed_event.type == YAML_NO_EVENT:
 *             if yaml_parser_parse(&self.parser, &self.parsed_event) == 0:             # <<<<<<<<<<<<<<
 *                 error = self._parser_error()
 *                 raise error
 */
    }

    /* "yaml/_yaml.pyx":857
 * 
 *     cdef int _parse_next_event(self) except 0:
 *         if self.parsed_event.type == YAML_NO_EVENT:             # <<<<<<<<<<<<<<
 *             if yaml_parser_parse(&self.parser, &self.parsed_event) == 0:
 *                 error = self._parser_error()
 */
  }

  /* "yaml/_yaml.pyx":861
 *                 error = self._parser_error()
 *                 raise error
 *         return 1             # <<<<<<<<<<<<<<
 * 
 * cdef int input_handler(void *data, unsigned char *buffer, size_t size, size_t *read) except 0:
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":856
 *         return node
 * 
 *     cdef int _parse_next_event(self) except 0:             # <<<<<<<<<<<<<<
 *         if self.parsed_event.type == YAML_NO_EVENT:
 *             if yaml_parser_parse(&self.parser, &self.parsed_event) == 0:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("yaml._yaml.CParser._parse_next_event", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_29__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_29__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_29__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_29__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_28__reduce_cython__(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_28__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_parsed_event_cannot_be_conv, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("yaml._yaml.CParser.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_31__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_7CParser_31__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_31__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_7CParser_31__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("yaml._yaml.CParser.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4yaml_5_yaml_7CParser_30__setstate_cython__(((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_7CParser_30__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_parsed_event_cannot_be_conv, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("yaml._yaml.CParser.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":863
 *         return 1
 * 
 * cdef int input_handler(void *data, unsigned char *buffer, size_t size, size_t *read) except 0:             # <<<<<<<<<<<<<<
 *     cdef CParser parser
 *     parser = <CParser>data
 */

static int __pyx_f_4yaml_5_yaml_input_handler(void *__pyx_v_data, unsigned char *__pyx_v_buffer, size_t __pyx_v_size, size_t *__pyx_v_read) {
  struct __pyx_obj_4yaml_5_yaml_CParser *__pyx_v_parser = 0;
  PyObject *__pyx_v_value = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("input_handler", 1);

  /* "yaml/_yaml.pyx":865
 * cdef int input_handler(void *data, unsigned char *buffer, size_t size, size_t *read) except 0:
 *     cdef CParser parser
 *     parser = <CParser>data             # <<<<<<<<<<<<<<
 *     if parser.stream_cache is None:
 *         value = parser.stream.read(size)
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_data);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_parser = ((struct __pyx_obj_4yaml_5_yaml_CParser *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "yaml/_yaml.pyx":866
 *     cdef CParser parser
 *     parser = <CParser>data
 *     if parser.stream_cache is None:             # <<<<<<<<<<<<<<
 *         value = parser.stream.read(size)
 *         if PyUnicode_CheckExact(value) != 0:
 */
  __pyx_t_2 = (__pyx_v_parser->stream_cache == Py_None);
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":867
 *     parser = <CParser>data
 *     if parser.stream_cache is None:
 *         value = parser.stream.read(size)             # <<<<<<<<<<<<<<
 *         if PyUnicode_CheckExact(value) != 0:
 *             value = PyUnicode_AsUTF8String(value)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_parser->stream, __pyx_n_s_read); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyInt_FromSize_t(__pyx_v_size); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 867, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 867, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_v_value = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "yaml/_yaml.pyx":868
 *     if parser.stream_cache is None:
 *         value = parser.stream.read(size)
 *         if PyUnicode_CheckExact(value) != 0:             # <<<<<<<<<<<<<<
 *             value = PyUnicode_AsUTF8String(value)
 *             parser.unicode_source = 1
 */
    __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_value) != 0);
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":869
 *         value = parser.stream.read(size)
 *         if PyUnicode_CheckExact(value) != 0:
 *             value = PyUnicode_AsUTF8String(value)             # <<<<<<<<<<<<<<
 *             parser.unicode_source = 1
 *         if PyBytes_CheckExact(value) == 0:
 */
      __pyx_t_1 = PyUnicode_AsUTF8String(__pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 869, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "yaml/_yaml.pyx":870
 *         if PyUnicode_CheckExact(value) != 0:
 *             value = PyUnicode_AsUTF8String(value)
 *             parser.unicode_source = 1             # <<<<<<<<<<<<<<
 *         if PyBytes_CheckExact(value) == 0:
 *             raise TypeError(u"a string value is expected")
 */
      __pyx_v_parser->unicode_source = 1;

      /* "yaml/_yaml.pyx":868
 *     if parser.stream_cache is None:
 *         value = parser.stream.read(size)
 *         if PyUnicode_CheckExact(value) != 0:             # <<<<<<<<<<<<<<
 *             value = PyUnicode_AsUTF8String(value)
 *             parser.unicode_source = 1
 */
    }

    /* "yaml/_yaml.pyx":871
 *             value = PyUnicode_AsUTF8String(value)
 *             parser.unicode_source = 1
 *         if PyBytes_CheckExact(value) == 0:             # <<<<<<<<<<<<<<
 *             raise TypeError(u"a string value is expected")
 *         parser.stream_cache = value
 */
    __pyx_t_2 = (PyBytes_CheckExact(__pyx_v_value) == 0);
    if (unlikely(__pyx_t_2)) {

      /* "yaml/_yaml.pyx":872
 *             parser.unicode_source = 1
 *         if PyBytes_CheckExact(value) == 0:
 *             raise TypeError(u"a string value is expected")             # <<<<<<<<<<<<<<
 *         parser.stream_cache = value
 *         parser.stream_cache_pos = 0
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 872, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 872, __pyx_L1_error)

      /* "yaml/_yaml.pyx":871
 *             value = PyUnicode_AsUTF8String(value)
 *             parser.unicode_source = 1
 *         if PyBytes_CheckExact(value) == 0:             # <<<<<<<<<<<<<<
 *             raise TypeError(u"a string value is expected")
 *         parser.stream_cache = value
 */
    }

    /* "yaml/_yaml.pyx":873
 *         if PyBytes_CheckExact(value) == 0:
 *             raise TypeError(u"a string value is expected")
 *         parser.stream_cache = value             # <<<<<<<<<<<<<<
 *         parser.stream_cache_pos = 0
 *         parser.stream_cache_len = PyBytes_GET_SIZE(value)
 */
    __Pyx_INCREF(__pyx_v_value);
    __Pyx_GIVEREF(__pyx_v_value);
    __Pyx_GOTREF(__pyx_v_parser->stream_cache);
    __Pyx_DECREF(__pyx_v_parser->stream_cache);
    __pyx_v_parser->stream_cache = __pyx_v_value;

    /* "yaml/_yaml.pyx":874
 *             raise TypeError(u"a string value is expected")
 *         parser.stream_cache = value
 *         parser.stream_cache_pos = 0             # <<<<<<<<<<<<<<
 *         parser.stream_cache_len = PyBytes_GET_SIZE(value)
 *     if (parser.stream_cache_len - parser.stream_cache_pos) < <int>size:
 */
    __pyx_v_parser->stream_cache_pos = 0;

    /* "yaml/_yaml.pyx":875
 *         parser.stream_cache = value
 *         parser.stream_cache_pos = 0
 *         parser.stream_cache_len = PyBytes_GET_SIZE(value)             # <<<<<<<<<<<<<<
 *     if (parser.stream_cache_len - parser.stream_cache_pos) < <int>size:
 *         size = parser.stream_cache_len - parser.stream_cache_pos
 */
    __pyx_v_parser->stream_cache_len = PyBytes_GET_SIZE(__pyx_v_value);

    /* "yaml/_yaml.pyx":866
 *     cdef CParser parser
 *     parser = <CParser>data
 *     if parser.stream_cache is None:             # <<<<<<<<<<<<<<
 *         value = parser.stream.read(size)
 *         if PyUnicode_CheckExact(value) != 0:
 */
  }

  /* "yaml/_yaml.pyx":876
 *         parser.stream_cache_pos = 0
 *         parser.stream_cache_len = PyBytes_GET_SIZE(value)
 *     if (parser.stream_cache_len - parser.stream_cache_pos) < <int>size:             # <<<<<<<<<<<<<<
 *         size = parser.stream_cache_len - parser.stream_cache_pos
 *     if size > 0:
 */
  __pyx_t_2 = ((__pyx_v_parser->stream_cache_len - __pyx_v_parser->stream_cache_pos) < ((int)__pyx_v_size));
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":877
 *         parser.stream_cache_len = PyBytes_GET_SIZE(value)
 *     if (parser.stream_cache_len - parser.stream_cache_pos) < <int>size:
 *         size = parser.stream_cache_len - parser.stream_cache_pos             # <<<<<<<<<<<<<<
 *     if size > 0:
 *         memcpy(buffer, PyBytes_AS_STRING(parser.stream_cache)
 */
    __pyx_v_size = (__pyx_v_parser->stream_cache_len - __pyx_v_parser->stream_cache_pos);

    /* "yaml/_yaml.pyx":876
 *         parser.stream_cache_pos = 0
 *         parser.stream_cache_len = PyBytes_GET_SIZE(value)
 *     if (parser.stream_cache_len - parser.stream_cache_pos) < <int>size:             # <<<<<<<<<<<<<<
 *         size = parser.stream_cache_len - parser.stream_cache_pos
 *     if size > 0:
 */
  }

  /* "yaml/_yaml.pyx":878
 *     if (parser.stream_cache_len - parser.stream_cache_pos) < <int>size:
 *         size = parser.stream_cache_len - parser.stream_cache_pos
 *     if size > 0:             # <<<<<<<<<<<<<<
 *         memcpy(buffer, PyBytes_AS_STRING(parser.stream_cache)
 *                             + parser.stream_cache_pos, size)
 */
  __pyx_t_2 = (__pyx_v_size > 0);
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":879
 *         size = parser.stream_cache_len - parser.stream_cache_pos
 *     if size > 0:
 *         memcpy(buffer, PyBytes_AS_STRING(parser.stream_cache)             # <<<<<<<<<<<<<<
 *                             + parser.stream_cache_pos, size)
 *     read[0] = size
 */
    __pyx_t_1 = __pyx_v_parser->stream_cache;
    __Pyx_INCREF(__pyx_t_1);

    /* "yaml/_yaml.pyx":880
 *     if size > 0:
 *         memcpy(buffer, PyBytes_AS_STRING(parser.stream_cache)
 *                             + parser.stream_cache_pos, size)             # <<<<<<<<<<<<<<
 *     read[0] = size
 *     parser.stream_cache_pos += size
 */
    memcpy(__pyx_v_buffer, (PyBytes_AS_STRING(__pyx_t_1) + __pyx_v_parser->stream_cache_pos), __pyx_v_size);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "yaml/_yaml.pyx":878
 *     if (parser.stream_cache_len - parser.stream_cache_pos) < <int>size:
 *         size = parser.stream_cache_len - parser.stream_cache_pos
 *     if size > 0:             # <<<<<<<<<<<<<<
 *         memcpy(buffer, PyBytes_AS_STRING(parser.stream_cache)
 *                             + parser.stream_cache_pos, size)
 */
  }

  /* "yaml/_yaml.pyx":881
 *         memcpy(buffer, PyBytes_AS_STRING(parser.stream_cache)
 *                             + parser.stream_cache_pos, size)
 *     read[0] = size             # <<<<<<<<<<<<<<
 *     parser.stream_cache_pos += size
 *     if parser.stream_cache_pos == parser.stream_cache_len:
 */
  (__pyx_v_read[0]) = __pyx_v_size;

  /* "yaml/_yaml.pyx":882
 *                             + parser.stream_cache_pos, size)
 *     read[0] = size
 *     parser.stream_cache_pos += size             # <<<<<<<<<<<<<<
 *     if parser.stream_cache_pos == parser.stream_cache_len:
 *         parser.stream_cache = None
 */
  __pyx_v_parser->stream_cache_pos = (__pyx_v_parser->stream_cache_pos + __pyx_v_size);

  /* "yaml/_yaml.pyx":883
 *     read[0] = size
 *     parser.stream_cache_pos += size
 *     if parser.stream_cache_pos == parser.stream_cache_len:             # <<<<<<<<<<<<<<
 *         parser.stream_cache = None
 *     return 1
 */
  __pyx_t_2 = (__pyx_v_parser->stream_cache_pos == __pyx_v_parser->stream_cache_len);
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":884
 *     parser.stream_cache_pos += size
 *     if parser.stream_cache_pos == parser.stream_cache_len:
 *         parser.stream_cache = None             # <<<<<<<<<<<<<<
 *     return 1
 * 
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_parser->stream_cache);
    __Pyx_DECREF(__pyx_v_parser->stream_cache);
    __pyx_v_parser->stream_cache = Py_None;

    /* "yaml/_yaml.pyx":883
 *     read[0] = size
 *     parser.stream_cache_pos += size
 *     if parser.stream_cache_pos == parser.stream_cache_len:             # <<<<<<<<<<<<<<
 *         parser.stream_cache = None
 *     return 1
 */
  }

  /* "yaml/_yaml.pyx":885
 *     if parser.stream_cache_pos == parser.stream_cache_len:
 *         parser.stream_cache = None
 *     return 1             # <<<<<<<<<<<<<<
 * 
 * cdef class CEmitter:
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":863
 *         return 1
 * 
 * cdef int input_handler(void *data, unsigned char *buffer, size_t size, size_t *read) except 0:             # <<<<<<<<<<<<<<
 *     cdef CParser parser
 *     parser = <CParser>data
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("yaml._yaml.input_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_parser);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":905
 *     cdef object use_encoding
 * 
 *     def __init__(self, stream, canonical=None, indent=None, width=None,             # <<<<<<<<<<<<<<
 *             allow_unicode=None, line_break=None, encoding=None,
 *             explicit_start=None, explicit_end=None, version=None, tags=None):
 */

/* Python wrapper */
static int __pyx_pw_4yaml_5_yaml_8CEmitter_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_4yaml_5_yaml_8CEmitter_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_stream = 0;
  PyObject *__pyx_v_canonical = 0;
  PyObject *__pyx_v_indent = 0;
  PyObject *__pyx_v_width = 0;
  PyObject *__pyx_v_allow_unicode = 0;
  PyObject *__pyx_v_line_break = 0;
  PyObject *__pyx_v_encoding = 0;
  PyObject *__pyx_v_explicit_start = 0;
  PyObject *__pyx_v_explicit_end = 0;
  PyObject *__pyx_v_version = 0;
  PyObject *__pyx_v_tags = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[11] = {0,0,0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_stream,&__pyx_n_s_canonical,&__pyx_n_s_indent,&__pyx_n_s_width,&__pyx_n_s_allow_unicode,&__pyx_n_s_line_break,&__pyx_n_s_encoding,&__pyx_n_s_explicit_start,&__pyx_n_s_explicit_end,&__pyx_n_s_version,&__pyx_n_s_tags,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    values[2] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));

    /* "yaml/_yaml.pyx":906
 * 
 *     def __init__(self, stream, canonical=None, indent=None, width=None,
 *             allow_unicode=None, line_break=None, encoding=None,             # <<<<<<<<<<<<<<
 *             explicit_start=None, explicit_end=None, version=None, tags=None):
 *         if yaml_emitter_initialize(&self.emitter) == 0:
 */
    values[4] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    values[6] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));

    /* "yaml/_yaml.pyx":907
 *     def __init__(self, stream, canonical=None, indent=None, width=None,
 *             allow_unicode=None, line_break=None, encoding=None,
 *             explicit_start=None, explicit_end=None, version=None, tags=None):             # <<<<<<<<<<<<<<
 *         if yaml_emitter_initialize(&self.emitter) == 0:
 *             raise MemoryError
 */
    values[7] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    values[8] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    values[9] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    values[10] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case 11: values[10] = __Pyx_Arg_VARARGS(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = __Pyx_Arg_VARARGS(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = __Pyx_Arg_VARARGS(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_VARARGS(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_VARARGS(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_stream)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 905, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_canonical);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_indent);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_width);
          if (value) { values[3] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_allow_unicode);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_line_break);
          if (value) { values[5] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_encoding);
          if (value) { values[6] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_explicit_start);
          if (value) { values[7] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_explicit_end);
          if (value) { values[8] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_version);
          if (value) { values[9] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 905, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_tags);
          if (value) { values[10] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 905, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(0, 905, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case 11: values[10] = __Pyx_Arg_VARARGS(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = __Pyx_Arg_VARARGS(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = __Pyx_Arg_VARARGS(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_VARARGS(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_VARARGS(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_VARARGS(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_stream = values[0];
    __pyx_v_canonical = values[1];
    __pyx_v_indent = values[2];
    __pyx_v_width = values[3];
    __pyx_v_allow_unicode = values[4];
    __pyx_v_line_break = values[5];
    __pyx_v_encoding = values[6];
    __pyx_v_explicit_start = values[7];
    __pyx_v_explicit_end = values[8];
    __pyx_v_version = values[9];
    __pyx_v_tags = values[10];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 11, __pyx_nargs); __PYX_ERR(0, 905, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("yaml._yaml.CEmitter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4yaml_5_yaml_8CEmitter___init__(((struct __pyx_obj_4yaml_5_yaml_CEmitter *)__pyx_v_self), __pyx_v_stream, __pyx_v_canonical, __pyx_v_indent, __pyx_v_width, __pyx_v_allow_unicode, __pyx_v_line_break, __pyx_v_encoding, __pyx_v_explicit_start, __pyx_v_explicit_end, __pyx_v_version, __pyx_v_tags);

  /* "yaml/_yaml.pyx":905
 *     cdef object use_encoding
 * 
 *     def __init__(self, stream, canonical=None, indent=None, width=None,             # <<<<<<<<<<<<<<
 *             allow_unicode=None, line_break=None, encoding=None,
 *             explicit_start=None, explicit_end=None, version=None, tags=None):
 */

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_4yaml_5_yaml_8CEmitter___init__(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, PyObject *__pyx_v_stream, PyObject *__pyx_v_canonical, PyObject *__pyx_v_indent, PyObject *__pyx_v_width, PyObject *__pyx_v_allow_unicode, PyObject *__pyx_v_line_break, PyObject *__pyx_v_encoding, PyObject *__pyx_v_explicit_start, PyObject *__pyx_v_explicit_end, PyObject *__pyx_v_version, PyObject *__pyx_v_tags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "yaml/_yaml.pyx":908
 *             allow_unicode=None, line_break=None, encoding=None,
 *             explicit_start=None, explicit_end=None, version=None, tags=None):
 *         if yaml_emitter_initialize(&self.emitter) == 0:             # <<<<<<<<<<<<<<
 *             raise MemoryError
 *         self.stream = stream
 */
  __pyx_t_1 = (yaml_emitter_initialize((&__pyx_v_self->emitter)) == 0);
  if (unlikely(__pyx_t_1)) {

    /* "yaml/_yaml.pyx":909
 *             explicit_start=None, explicit_end=None, version=None, tags=None):
 *         if yaml_emitter_initialize(&self.emitter) == 0:
 *             raise MemoryError             # <<<<<<<<<<<<<<
 *         self.stream = stream
 *         self.dump_unicode = 0
 */
    PyErr_NoMemory(); __PYX_ERR(0, 909, __pyx_L1_error)

    /* "yaml/_yaml.pyx":908
 *             allow_unicode=None, line_break=None, encoding=None,
 *             explicit_start=None, explicit_end=None, version=None, tags=None):
 *         if yaml_emitter_initialize(&self.emitter) == 0:             # <<<<<<<<<<<<<<
 *             raise MemoryError
 *         self.stream = stream
 */
  }

  /* "yaml/_yaml.pyx":910
 *         if yaml_emitter_initialize(&self.emitter) == 0:
 *             raise MemoryError
 *         self.stream = stream             # <<<<<<<<<<<<<<
 *         self.dump_unicode = 0
 *         if hasattr(stream, u'encoding'):
 */
  __Pyx_INCREF(__pyx_v_stream);
  __Pyx_GIVEREF(__pyx_v_stream);
  __Pyx_GOTREF(__pyx_v_self->stream);
  __Pyx_DECREF(__pyx_v_self->stream);
  __pyx_v_self->stream = __pyx_v_stream;

  /* "yaml/_yaml.pyx":911
 *             raise MemoryError
 *         self.stream = stream
 *         self.dump_unicode = 0             # <<<<<<<<<<<<<<
 *         if hasattr(stream, u'encoding'):
 *             self.dump_unicode = 1
 */
  __pyx_v_self->dump_unicode = 0;

  /* "yaml/_yaml.pyx":912
 *         self.stream = stream
 *         self.dump_unicode = 0
 *         if hasattr(stream, u'encoding'):             # <<<<<<<<<<<<<<
 *             self.dump_unicode = 1
 *         self.use_encoding = encoding
 */
  __pyx_t_1 = __Pyx_HasAttr(__pyx_v_stream, __pyx_n_u_encoding); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 912, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":913
 *         self.dump_unicode = 0
 *         if hasattr(stream, u'encoding'):
 *             self.dump_unicode = 1             # <<<<<<<<<<<<<<
 *         self.use_encoding = encoding
 *         yaml_emitter_set_output(&self.emitter, output_handler, <void *>self)
 */
    __pyx_v_self->dump_unicode = 1;

    /* "yaml/_yaml.pyx":912
 *         self.stream = stream
 *         self.dump_unicode = 0
 *         if hasattr(stream, u'encoding'):             # <<<<<<<<<<<<<<
 *             self.dump_unicode = 1
 *         self.use_encoding = encoding
 */
  }

  /* "yaml/_yaml.pyx":914
 *         if hasattr(stream, u'encoding'):
 *             self.dump_unicode = 1
 *         self.use_encoding = encoding             # <<<<<<<<<<<<<<
 *         yaml_emitter_set_output(&self.emitter, output_handler, <void *>self)
 *         if canonical:
 */
  __Pyx_INCREF(__pyx_v_encoding);
  __Pyx_GIVEREF(__pyx_v_encoding);
  __Pyx_GOTREF(__pyx_v_self->use_encoding);
  __Pyx_DECREF(__pyx_v_self->use_encoding);
  __pyx_v_self->use_encoding = __pyx_v_encoding;

  /* "yaml/_yaml.pyx":915
 *             self.dump_unicode = 1
 *         self.use_encoding = encoding
 *         yaml_emitter_set_output(&self.emitter, output_handler, <void *>self)             # <<<<<<<<<<<<<<
 *         if canonical:
 *             yaml_emitter_set_canonical(&self.emitter, 1)
 */
  yaml_emitter_set_output((&__pyx_v_self->emitter), __pyx_f_4yaml_5_yaml_output_handler, ((void *)__pyx_v_self));

  /* "yaml/_yaml.pyx":916
 *         self.use_encoding = encoding
 *         yaml_emitter_set_output(&self.emitter, output_handler, <void *>self)
 *         if canonical:             # <<<<<<<<<<<<<<
 *             yaml_emitter_set_canonical(&self.emitter, 1)
 *         if indent is not None:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_canonical); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 916, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":917
 *         yaml_emitter_set_output(&self.emitter, output_handler, <void *>self)
 *         if canonical:
 *             yaml_emitter_set_canonical(&self.emitter, 1)             # <<<<<<<<<<<<<<
 *         if indent is not None:
 *             yaml_emitter_set_indent(&self.emitter, indent)
 */
    yaml_emitter_set_canonical((&__pyx_v_self->emitter), 1);

    /* "yaml/_yaml.pyx":916
 *         self.use_encoding = encoding
 *         yaml_emitter_set_output(&self.emitter, output_handler, <void *>self)
 *         if canonical:             # <<<<<<<<<<<<<<
 *             yaml_emitter_set_canonical(&self.emitter, 1)
 *         if indent is not None:
 */
  }

  /* "yaml/_yaml.pyx":918
 *         if canonical:
 *             yaml_emitter_set_canonical(&self.emitter, 1)
 *         if indent is not None:             # <<<<<<<<<<<<<<
 *             yaml_emitter_set_indent(&self.emitter, indent)
 *         if width is not None:
 */
  __pyx_t_1 = (__pyx_v_indent != Py_None);
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":919
 *             yaml_emitter_set_canonical(&self.emitter, 1)
 *         if indent is not None:
 *             yaml_emitter_set_indent(&self.emitter, indent)             # <<<<<<<<<<<<<<
 *         if width is not None:
 *             yaml_emitter_set_width(&self.emitter, width)
 */
    __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_v_indent); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 919, __pyx_L1_error)
    yaml_emitter_set_indent((&__pyx_v_self->emitter), __pyx_t_2);

    /* "yaml/_yaml.pyx":918
 *         if canonical:
 *             yaml_emitter_set_canonical(&self.emitter, 1)
 *         if indent is not None:             # <<<<<<<<<<<<<<
 *             yaml_emitter_set_indent(&self.emitter, indent)
 *         if width is not None:
 */
  }

  /* "yaml/_yaml.pyx":920
 *         if indent is not None:
 *             yaml_emitter_set_indent(&self.emitter, indent)
 *         if width is not None:             # <<<<<<<<<<<<<<
 *             yaml_emitter_set_width(&self.emitter, width)
 *         if allow_unicode:
 */
  __pyx_t_1 = (__pyx_v_width != Py_None);
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":921
 *             yaml_emitter_set_indent(&self.emitter, indent)
 *         if width is not None:
 *             yaml_emitter_set_width(&self.emitter, width)             # <<<<<<<<<<<<<<
 *         if allow_unicode:
 *             yaml_emitter_set_unicode(&self.emitter, 1)
 */
    __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_v_width); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 921, __pyx_L1_error)
    yaml_emitter_set_width((&__pyx_v_self->emitter), __pyx_t_2);

    /* "yaml/_yaml.pyx":920
 *         if indent is not None:
 *             yaml_emitter_set_indent(&self.emitter, indent)
 *         if width is not None:             # <<<<<<<<<<<<<<
 *             yaml_emitter_set_width(&self.emitter, width)
 *         if allow_unicode:
 */
  }

  /* "yaml/_yaml.pyx":922
 *         if width is not None:
 *             yaml_emitter_set_width(&self.emitter, width)
 *         if allow_unicode:             # <<<<<<<<<<<<<<
 *             yaml_emitter_set_unicode(&self.emitter, 1)
 *         if line_break is not None:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_allow_unicode); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 922, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":923
 *             yaml_emitter_set_width(&self.emitter, width)
 *         if allow_unicode:
 *             yaml_emitter_set_unicode(&self.emitter, 1)             # <<<<<<<<<<<<<<
 *         if line_break is not None:
 *             if line_break == '\r':
 */
    yaml_emitter_set_unicode((&__pyx_v_self->emitter), 1);

    /* "yaml/_yaml.pyx":922
 *         if width is not None:
 *             yaml_emitter_set_width(&self.emitter, width)
 *         if allow_unicode:             # <<<<<<<<<<<<<<
 *             yaml_emitter_set_unicode(&self.emitter, 1)
 *         if line_break is not None:
 */
  }

  /* "yaml/_yaml.pyx":924
 *         if allow_unicode:
 *             yaml_emitter_set_unicode(&self.emitter, 1)
 *         if line_break is not None:             # <<<<<<<<<<<<<<
 *             if line_break == '\r':
 *                 yaml_emitter_set_break(&self.emitter, YAML_CR_BREAK)
 */
  __pyx_t_1 = (__pyx_v_line_break != Py_None);
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":925
 *             yaml_emitter_set_unicode(&self.emitter, 1)
 *         if line_break is not None:
 *             if line_break == '\r':             # <<<<<<<<<<<<<<
 *                 yaml_emitter_set_break(&self.emitter, YAML_CR_BREAK)
 *             elif line_break == '\n':
 */
    __pyx_t_1 = (__Pyx_PyString_Equals(__pyx_v_line_break, __pyx_kp_s__12, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 925, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "yaml/_yaml.pyx":926
 *         if line_break is not None:
 *             if line_break == '\r':
 *                 yaml_emitter_set_break(&self.emitter, YAML_CR_BREAK)             # <<<<<<<<<<<<<<
 *             elif line_break == '\n':
 *                 yaml_emitter_set_break(&self.emitter, YAML_LN_BREAK)
 */
      yaml_emitter_set_break((&__pyx_v_self->emitter), YAML_CR_BREAK);

      /* "yaml/_yaml.pyx":925
 *             yaml_emitter_set_unicode(&self.emitter, 1)
 *         if line_break is not None:
 *             if line_break == '\r':             # <<<<<<<<<<<<<<
 *                 yaml_emitter_set_break(&self.emitter, YAML_CR_BREAK)
 *             elif line_break == '\n':
 */
      goto __pyx_L10;
    }

    /* "yaml/_yaml.pyx":927
 *             if line_break == '\r':
 *                 yaml_emitter_set_break(&self.emitter, YAML_CR_BREAK)
 *             elif line_break == '\n':             # <<<<<<<<<<<<<<
 *                 yaml_emitter_set_break(&self.emitter, YAML_LN_BREAK)
 *             elif line_break == '\r\n':
 */
    __pyx_t_1 = (__Pyx_PyString_Equals(__pyx_v_line_break, __pyx_kp_s__13, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 927, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "yaml/_yaml.pyx":928
 *                 yaml_emitter_set_break(&self.emitter, YAML_CR_BREAK)
 *             elif line_break == '\n':
 *                 yaml_emitter_set_break(&self.emitter, YAML_LN_BREAK)             # <<<<<<<<<<<<<<
 *             elif line_break == '\r\n':
 *                 yaml_emitter_set_break(&self.emitter, YAML_CRLN_BREAK)
 */
      yaml_emitter_set_break((&__pyx_v_self->emitter), YAML_LN_BREAK);

      /* "yaml/_yaml.pyx":927
 *             if line_break == '\r':
 *                 yaml_emitter_set_break(&self.emitter, YAML_CR_BREAK)
 *             elif line_break == '\n':             # <<<<<<<<<<<<<<
 *                 yaml_emitter_set_break(&self.emitter, YAML_LN_BREAK)
 *             elif line_break == '\r\n':
 */
      goto __pyx_L10;
    }

    /* "yaml/_yaml.pyx":929
 *             elif line_break == '\n':
 *                 yaml_emitter_set_break(&self.emitter, YAML_LN_BREAK)
 *             elif line_break == '\r\n':             # <<<<<<<<<<<<<<
 *                 yaml_emitter_set_break(&self.emitter, YAML_CRLN_BREAK)
 *         self.document_start_implicit = 1
 */
    __pyx_t_1 = (__Pyx_PyString_Equals(__pyx_v_line_break, __pyx_kp_s__14, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 929, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "yaml/_yaml.pyx":930
 *                 yaml_emitter_set_break(&self.emitter, YAML_LN_BREAK)
 *             elif line_break == '\r\n':
 *                 yaml_emitter_set_break(&self.emitter, YAML_CRLN_BREAK)             # <<<<<<<<<<<<<<
 *         self.document_start_implicit = 1
 *         if explicit_start:
 */
      yaml_emitter_set_break((&__pyx_v_self->emitter), YAML_CRLN_BREAK);

      /* "yaml/_yaml.pyx":929
 *             elif line_break == '\n':
 *                 yaml_emitter_set_break(&self.emitter, YAML_LN_BREAK)
 *             elif line_break == '\r\n':             # <<<<<<<<<<<<<<
 *                 yaml_emitter_set_break(&self.emitter, YAML_CRLN_BREAK)
 *         self.document_start_implicit = 1
 */
    }
    __pyx_L10:;

    /* "yaml/_yaml.pyx":924
 *         if allow_unicode:
 *             yaml_emitter_set_unicode(&self.emitter, 1)
 *         if line_break is not None:             # <<<<<<<<<<<<<<
 *             if line_break == '\r':
 *                 yaml_emitter_set_break(&self.emitter, YAML_CR_BREAK)
 */
  }

  /* "yaml/_yaml.pyx":931
 *             elif line_break == '\r\n':
 *                 yaml_emitter_set_break(&self.emitter, YAML_CRLN_BREAK)
 *         self.document_start_implicit = 1             # <<<<<<<<<<<<<<
 *         if explicit_start:
 *             self.document_start_implicit = 0
 */
  __pyx_v_self->document_start_implicit = 1;

  /* "yaml/_yaml.pyx":932
 *                 yaml_emitter_set_break(&self.emitter, YAML_CRLN_BREAK)
 *         self.document_start_implicit = 1
 *         if explicit_start:             # <<<<<<<<<<<<<<
 *             self.document_start_implicit = 0
 *         self.document_end_implicit = 1
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_explicit_start); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 932, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":933
 *         self.document_start_implicit = 1
 *         if explicit_start:
 *             self.document_start_implicit = 0             # <<<<<<<<<<<<<<
 *         self.document_end_implicit = 1
 *         if explicit_end:
 */
    __pyx_v_self->document_start_implicit = 0;

    /* "yaml/_yaml.pyx":932
 *                 yaml_emitter_set_break(&self.emitter, YAML_CRLN_BREAK)
 *         self.document_start_implicit = 1
 *         if explicit_start:             # <<<<<<<<<<<<<<
 *             self.document_start_implicit = 0
 *         self.document_end_implicit = 1
 */
  }

  /* "yaml/_yaml.pyx":934
 *         if explicit_start:
 *             self.document_start_implicit = 0
 *         self.document_end_implicit = 1             # <<<<<<<<<<<<<<
 *         if explicit_end:
 *             self.document_end_implicit = 0
 */
  __pyx_v_self->document_end_implicit = 1;

  /* "yaml/_yaml.pyx":935
 *             self.document_start_implicit = 0
 *         self.document_end_implicit = 1
 *         if explicit_end:             # <<<<<<<<<<<<<<
 *             self.document_end_implicit = 0
 *         self.use_version = version
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_explicit_end); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 935, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":936
 *         self.document_end_implicit = 1
 *         if explicit_end:
 *             self.document_end_implicit = 0             # <<<<<<<<<<<<<<
 *         self.use_version = version
 *         self.use_tags = tags
 */
    __pyx_v_self->document_end_implicit = 0;

    /* "yaml/_yaml.pyx":935
 *             self.document_start_implicit = 0
 *         self.document_end_implicit = 1
 *         if explicit_end:             # <<<<<<<<<<<<<<
 *             self.document_end_implicit = 0
 *         self.use_version = version
 */
  }

  /* "yaml/_yaml.pyx":937
 *         if explicit_end:
 *             self.document_end_implicit = 0
 *         self.use_version = version             # <<<<<<<<<<<<<<
 *         self.use_tags = tags
 *         self.serialized_nodes = {}
 */
  __Pyx_INCREF(__pyx_v_version);
  __Pyx_GIVEREF(__pyx_v_version);
  __Pyx_GOTREF(__pyx_v_self->use_version);
  __Pyx_DECREF(__pyx_v_self->use_version);
  __pyx_v_self->use_version = __pyx_v_version;

  /* "yaml/_yaml.pyx":938
 *             self.document_end_implicit = 0
 *         self.use_version = version
 *         self.use_tags = tags             # <<<<<<<<<<<<<<
 *         self.serialized_nodes = {}
 *         self.anchors = {}
 */
  __Pyx_INCREF(__pyx_v_tags);
  __Pyx_GIVEREF(__pyx_v_tags);
  __Pyx_GOTREF(__pyx_v_self->use_tags);
  __Pyx_DECREF(__pyx_v_self->use_tags);
  __pyx_v_self->use_tags = __pyx_v_tags;

  /* "yaml/_yaml.pyx":939
 *         self.use_version = version
 *         self.use_tags = tags
 *         self.serialized_nodes = {}             # <<<<<<<<<<<<<<
 *         self.anchors = {}
 *         self.last_alias_id = 0
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->serialized_nodes);
  __Pyx_DECREF(__pyx_v_self->serialized_nodes);
  __pyx_v_self->serialized_nodes = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "yaml/_yaml.pyx":940
 *         self.use_tags = tags
 *         self.serialized_nodes = {}
 *         self.anchors = {}             # <<<<<<<<<<<<<<
 *         self.last_alias_id = 0
 *         self.closed = -1
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 940, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->anchors);
  __Pyx_DECREF(__pyx_v_self->anchors);
  __pyx_v_self->anchors = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "yaml/_yaml.pyx":941
 *         self.serialized_nodes = {}
 *         self.anchors = {}
 *         self.last_alias_id = 0             # <<<<<<<<<<<<<<
 *         self.closed = -1
 * 
 */
  __pyx_v_self->last_alias_id = 0;

  /* "yaml/_yaml.pyx":942
 *         self.anchors = {}
 *         self.last_alias_id = 0
 *         self.closed = -1             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_v_self->closed = -1;

  /* "yaml/_yaml.pyx":905
 *     cdef object use_encoding
 * 
 *     def __init__(self, stream, canonical=None, indent=None, width=None,             # <<<<<<<<<<<<<<
 *             allow_unicode=None, line_break=None, encoding=None,
 *             explicit_start=None, explicit_end=None, version=None, tags=None):
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("yaml._yaml.CEmitter.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":944
 *         self.closed = -1
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         yaml_emitter_delete(&self.emitter)
 * 
 */

/* Python wrapper */
static void __pyx_pw_4yaml_5_yaml_8CEmitter_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_4yaml_5_yaml_8CEmitter_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_4yaml_5_yaml_8CEmitter_2__dealloc__(((struct __pyx_obj_4yaml_5_yaml_CEmitter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_4yaml_5_yaml_8CEmitter_2__dealloc__(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self) {

  /* "yaml/_yaml.pyx":945
 * 
 *     def __dealloc__(self):
 *         yaml_emitter_delete(&self.emitter)             # <<<<<<<<<<<<<<
 * 
 *     def dispose(self):
 */
  yaml_emitter_delete((&__pyx_v_self->emitter));

  /* "yaml/_yaml.pyx":944
 *         self.closed = -1
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         yaml_emitter_delete(&self.emitter)
 * 
 */

  /* function exit code */
}

/* "yaml/_yaml.pyx":947
 *         yaml_emitter_delete(&self.emitter)
 * 
 *     def dispose(self):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_5dispose(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_8CEmitter_5dispose = {"dispose", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_5dispose, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_5dispose(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dispose (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("dispose", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "dispose", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_8CEmitter_4dispose(((struct __pyx_obj_4yaml_5_yaml_CEmitter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_4dispose(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dispose", 1);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":950
 *         pass
 * 
 *     cdef object _emitter_error(self):             # <<<<<<<<<<<<<<
 *         if self.emitter.error == YAML_MEMORY_ERROR:
 *             return MemoryError
 */

static PyObject *__pyx_f_4yaml_5_yaml_8CEmitter__emitter_error(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self) {
  PyObject *__pyx_v_problem = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_emitter_error", 1);

  /* "yaml/_yaml.pyx":951
 * 
 *     cdef object _emitter_error(self):
 *         if self.emitter.error == YAML_MEMORY_ERROR:             # <<<<<<<<<<<<<<
 *             return MemoryError
 *         elif self.emitter.error == YAML_EMITTER_ERROR:
 */
  switch (__pyx_v_self->emitter.error) {
    case YAML_MEMORY_ERROR:

    /* "yaml/_yaml.pyx":952
 *     cdef object _emitter_error(self):
 *         if self.emitter.error == YAML_MEMORY_ERROR:
 *             return MemoryError             # <<<<<<<<<<<<<<
 *         elif self.emitter.error == YAML_EMITTER_ERROR:
 *             problem = PyUnicode_FromString(self.emitter.problem)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_builtin_MemoryError);
    __pyx_r = __pyx_builtin_MemoryError;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":951
 * 
 *     cdef object _emitter_error(self):
 *         if self.emitter.error == YAML_MEMORY_ERROR:             # <<<<<<<<<<<<<<
 *             return MemoryError
 *         elif self.emitter.error == YAML_EMITTER_ERROR:
 */
    break;
    case YAML_EMITTER_ERROR:

    /* "yaml/_yaml.pyx":954
 *             return MemoryError
 *         elif self.emitter.error == YAML_EMITTER_ERROR:
 *             problem = PyUnicode_FromString(self.emitter.problem)             # <<<<<<<<<<<<<<
 *             return EmitterError(problem)
 *         raise ValueError(u"no emitter error")
 */
    __pyx_t_1 = PyUnicode_FromString(__pyx_v_self->emitter.problem); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 954, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_problem = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "yaml/_yaml.pyx":955
 *         elif self.emitter.error == YAML_EMITTER_ERROR:
 *             problem = PyUnicode_FromString(self.emitter.problem)
 *             return EmitterError(problem)             # <<<<<<<<<<<<<<
 *         raise ValueError(u"no emitter error")
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_EmitterError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 955, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_problem};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 955, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "yaml/_yaml.pyx":953
 *         if self.emitter.error == YAML_MEMORY_ERROR:
 *             return MemoryError
 *         elif self.emitter.error == YAML_EMITTER_ERROR:             # <<<<<<<<<<<<<<
 *             problem = PyUnicode_FromString(self.emitter.problem)
 *             return EmitterError(problem)
 */
    break;
    default: break;
  }

  /* "yaml/_yaml.pyx":956
 *             problem = PyUnicode_FromString(self.emitter.problem)
 *             return EmitterError(problem)
 *         raise ValueError(u"no emitter error")             # <<<<<<<<<<<<<<
 * 
 *     cdef int _object_to_event(self, object event_object, yaml_event_t *event) except 0:
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 956, __pyx_L1_error)

  /* "yaml/_yaml.pyx":950
 *         pass
 * 
 *     cdef object _emitter_error(self):             # <<<<<<<<<<<<<<
 *         if self.emitter.error == YAML_MEMORY_ERROR:
 *             return MemoryError
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("yaml._yaml.CEmitter._emitter_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_problem);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":958
 *         raise ValueError(u"no emitter error")
 * 
 *     cdef int _object_to_event(self, object event_object, yaml_event_t *event) except 0:             # <<<<<<<<<<<<<<
 *         cdef yaml_encoding_t encoding
 *         cdef yaml_version_directive_t version_directive_value
 */

static int __pyx_f_4yaml_5_yaml_8CEmitter__object_to_event(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, PyObject *__pyx_v_event_object, yaml_event_t *__pyx_v_event) {
  yaml_encoding_t __pyx_v_encoding;
  yaml_version_directive_t __pyx_v_version_directive_value;
  yaml_version_directive_t *__pyx_v_version_directive;
  yaml_tag_directive_t __pyx_v_tag_directives_value[0x80];
  yaml_tag_directive_t *__pyx_v_tag_directives_start;
  yaml_tag_directive_t *__pyx_v_tag_directives_end;
  int __pyx_v_implicit;
  int __pyx_v_plain_implicit;
  int __pyx_v_quoted_implicit;
  yaml_char_t *__pyx_v_anchor;
  yaml_char_t *__pyx_v_tag;
  yaml_char_t *__pyx_v_value;
  int __pyx_v_length;
  yaml_scalar_style_t __pyx_v_scalar_style;
  yaml_sequence_style_t __pyx_v_sequence_style;
  yaml_mapping_style_t __pyx_v_mapping_style;
  PyObject *__pyx_v_event_class = NULL;
  PyObject *__pyx_v_cache = NULL;
  PyObject *__pyx_v_handle = NULL;
  PyObject *__pyx_v_prefix = NULL;
  PyObject *__pyx_v_anchor_object = NULL;
  PyObject *__pyx_v_tag_object = NULL;
  PyObject *__pyx_v_value_object = NULL;
  PyObject *__pyx_v_style_object = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_object_to_event", 1);

  /* "yaml/_yaml.pyx":975
 *         cdef yaml_sequence_style_t sequence_style
 *         cdef yaml_mapping_style_t mapping_style
 *         event_class = event_object.__class__             # <<<<<<<<<<<<<<
 *         if event_class is StreamStartEvent:
 *             encoding = YAML_UTF8_ENCODING
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_event_class = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "yaml/_yaml.pyx":976
 *         cdef yaml_mapping_style_t mapping_style
 *         event_class = event_object.__class__
 *         if event_class is StreamStartEvent:             # <<<<<<<<<<<<<<
 *             encoding = YAML_UTF8_ENCODING
 *             if event_object.encoding == u'utf-16-le' or event_object.encoding == 'utf-16-le':
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_StreamStartEvent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_v_event_class == __pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":977
 *         event_class = event_object.__class__
 *         if event_class is StreamStartEvent:
 *             encoding = YAML_UTF8_ENCODING             # <<<<<<<<<<<<<<
 *             if event_object.encoding == u'utf-16-le' or event_object.encoding == 'utf-16-le':
 *                 encoding = YAML_UTF16LE_ENCODING
 */
    __pyx_v_encoding = YAML_UTF8_ENCODING;

    /* "yaml/_yaml.pyx":978
 *         if event_class is StreamStartEvent:
 *             encoding = YAML_UTF8_ENCODING
 *             if event_object.encoding == u'utf-16-le' or event_object.encoding == 'utf-16-le':             # <<<<<<<<<<<<<<
 *                 encoding = YAML_UTF16LE_ENCODING
 *             elif event_object.encoding == u'utf-16-be' or event_object.encoding == 'utf-16-be':
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_encoding); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_utf_16_le, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 978, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_encoding); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 978, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_kp_s_utf_16_le, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 978, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __pyx_t_3;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":979
 *             encoding = YAML_UTF8_ENCODING
 *             if event_object.encoding == u'utf-16-le' or event_object.encoding == 'utf-16-le':
 *                 encoding = YAML_UTF16LE_ENCODING             # <<<<<<<<<<<<<<
 *             elif event_object.encoding == u'utf-16-be' or event_object.encoding == 'utf-16-be':
 *                 encoding = YAML_UTF16BE_ENCODING
 */
      __pyx_v_encoding = YAML_UTF16LE_ENCODING;

      /* "yaml/_yaml.pyx":978
 *         if event_class is StreamStartEvent:
 *             encoding = YAML_UTF8_ENCODING
 *             if event_object.encoding == u'utf-16-le' or event_object.encoding == 'utf-16-le':             # <<<<<<<<<<<<<<
 *                 encoding = YAML_UTF16LE_ENCODING
 *             elif event_object.encoding == u'utf-16-be' or event_object.encoding == 'utf-16-be':
 */
      goto __pyx_L4;
    }

    /* "yaml/_yaml.pyx":980
 *             if event_object.encoding == u'utf-16-le' or event_object.encoding == 'utf-16-le':
 *                 encoding = YAML_UTF16LE_ENCODING
 *             elif event_object.encoding == u'utf-16-be' or event_object.encoding == 'utf-16-be':             # <<<<<<<<<<<<<<
 *                 encoding = YAML_UTF16BE_ENCODING
 *             if event_object.encoding is None:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_encoding); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_utf_16_be, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 980, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_encoding); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_kp_s_utf_16_be, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 980, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __pyx_t_3;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":981
 *                 encoding = YAML_UTF16LE_ENCODING
 *             elif event_object.encoding == u'utf-16-be' or event_object.encoding == 'utf-16-be':
 *                 encoding = YAML_UTF16BE_ENCODING             # <<<<<<<<<<<<<<
 *             if event_object.encoding is None:
 *                 self.dump_unicode = 1
 */
      __pyx_v_encoding = YAML_UTF16BE_ENCODING;

      /* "yaml/_yaml.pyx":980
 *             if event_object.encoding == u'utf-16-le' or event_object.encoding == 'utf-16-le':
 *                 encoding = YAML_UTF16LE_ENCODING
 *             elif event_object.encoding == u'utf-16-be' or event_object.encoding == 'utf-16-be':             # <<<<<<<<<<<<<<
 *                 encoding = YAML_UTF16BE_ENCODING
 *             if event_object.encoding is None:
 */
    }
    __pyx_L4:;

    /* "yaml/_yaml.pyx":982
 *             elif event_object.encoding == u'utf-16-be' or event_object.encoding == 'utf-16-be':
 *                 encoding = YAML_UTF16BE_ENCODING
 *             if event_object.encoding is None:             # <<<<<<<<<<<<<<
 *                 self.dump_unicode = 1
 *             if self.dump_unicode == 1:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_encoding); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 982, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_t_1 == Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":983
 *                 encoding = YAML_UTF16BE_ENCODING
 *             if event_object.encoding is None:
 *                 self.dump_unicode = 1             # <<<<<<<<<<<<<<
 *             if self.dump_unicode == 1:
 *                 encoding = YAML_UTF8_ENCODING
 */
      __pyx_v_self->dump_unicode = 1;

      /* "yaml/_yaml.pyx":982
 *             elif event_object.encoding == u'utf-16-be' or event_object.encoding == 'utf-16-be':
 *                 encoding = YAML_UTF16BE_ENCODING
 *             if event_object.encoding is None:             # <<<<<<<<<<<<<<
 *                 self.dump_unicode = 1
 *             if self.dump_unicode == 1:
 */
    }

    /* "yaml/_yaml.pyx":984
 *             if event_object.encoding is None:
 *                 self.dump_unicode = 1
 *             if self.dump_unicode == 1:             # <<<<<<<<<<<<<<
 *                 encoding = YAML_UTF8_ENCODING
 *             yaml_stream_start_event_initialize(event, encoding)
 */
    __pyx_t_2 = (__pyx_v_self->dump_unicode == 1);
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":985
 *                 self.dump_unicode = 1
 *             if self.dump_unicode == 1:
 *                 encoding = YAML_UTF8_ENCODING             # <<<<<<<<<<<<<<
 *             yaml_stream_start_event_initialize(event, encoding)
 *         elif event_class is StreamEndEvent:
 */
      __pyx_v_encoding = YAML_UTF8_ENCODING;

      /* "yaml/_yaml.pyx":984
 *             if event_object.encoding is None:
 *                 self.dump_unicode = 1
 *             if self.dump_unicode == 1:             # <<<<<<<<<<<<<<
 *                 encoding = YAML_UTF8_ENCODING
 *             yaml_stream_start_event_initialize(event, encoding)
 */
    }

    /* "yaml/_yaml.pyx":986
 *             if self.dump_unicode == 1:
 *                 encoding = YAML_UTF8_ENCODING
 *             yaml_stream_start_event_initialize(event, encoding)             # <<<<<<<<<<<<<<
 *         elif event_class is StreamEndEvent:
 *             yaml_stream_end_event_initialize(event)
 */
    (void)(yaml_stream_start_event_initialize(__pyx_v_event, __pyx_v_encoding));

    /* "yaml/_yaml.pyx":976
 *         cdef yaml_mapping_style_t mapping_style
 *         event_class = event_object.__class__
 *         if event_class is StreamStartEvent:             # <<<<<<<<<<<<<<
 *             encoding = YAML_UTF8_ENCODING
 *             if event_object.encoding == u'utf-16-le' or event_object.encoding == 'utf-16-le':
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":987
 *                 encoding = YAML_UTF8_ENCODING
 *             yaml_stream_start_event_initialize(event, encoding)
 *         elif event_class is StreamEndEvent:             # <<<<<<<<<<<<<<
 *             yaml_stream_end_event_initialize(event)
 *         elif event_class is DocumentStartEvent:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_StreamEndEvent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 987, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_v_event_class == __pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":988
 *             yaml_stream_start_event_initialize(event, encoding)
 *         elif event_class is StreamEndEvent:
 *             yaml_stream_end_event_initialize(event)             # <<<<<<<<<<<<<<
 *         elif event_class is DocumentStartEvent:
 *             version_directive = NULL
 */
    (void)(yaml_stream_end_event_initialize(__pyx_v_event));

    /* "yaml/_yaml.pyx":987
 *                 encoding = YAML_UTF8_ENCODING
 *             yaml_stream_start_event_initialize(event, encoding)
 *         elif event_class is StreamEndEvent:             # <<<<<<<<<<<<<<
 *             yaml_stream_end_event_initialize(event)
 *         elif event_class is DocumentStartEvent:
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":989
 *         elif event_class is StreamEndEvent:
 *             yaml_stream_end_event_initialize(event)
 *         elif event_class is DocumentStartEvent:             # <<<<<<<<<<<<<<
 *             version_directive = NULL
 *             if event_object.version:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_DocumentStartEvent); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_v_event_class == __pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":990
 *             yaml_stream_end_event_initialize(event)
 *         elif event_class is DocumentStartEvent:
 *             version_directive = NULL             # <<<<<<<<<<<<<<
 *             if event_object.version:
 *                 version_directive_value.major = event_object.version[0]
 */
    __pyx_v_version_directive = NULL;

    /* "yaml/_yaml.pyx":991
 *         elif event_class is DocumentStartEvent:
 *             version_directive = NULL
 *             if event_object.version:             # <<<<<<<<<<<<<<
 *                 version_directive_value.major = event_object.version[0]
 *                 version_directive_value.minor = event_object.version[1]
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_version); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 991, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 991, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":992
 *             version_directive = NULL
 *             if event_object.version:
 *                 version_directive_value.major = event_object.version[0]             # <<<<<<<<<<<<<<
 *                 version_directive_value.minor = event_object.version[1]
 *                 version_directive = &version_directive_value
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_version); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 992, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 992, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 992, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_version_directive_value.major = __pyx_t_5;

      /* "yaml/_yaml.pyx":993
 *             if event_object.version:
 *                 version_directive_value.major = event_object.version[0]
 *                 version_directive_value.minor = event_object.version[1]             # <<<<<<<<<<<<<<
 *                 version_directive = &version_directive_value
 *             tag_directives_start = NULL
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_version); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 993, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_4, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 993, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 993, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_version_directive_value.minor = __pyx_t_5;

      /* "yaml/_yaml.pyx":994
 *                 version_directive_value.major = event_object.version[0]
 *                 version_directive_value.minor = event_object.version[1]
 *                 version_directive = &version_directive_value             # <<<<<<<<<<<<<<
 *             tag_directives_start = NULL
 *             tag_directives_end = NULL
 */
      __pyx_v_version_directive = (&__pyx_v_version_directive_value);

      /* "yaml/_yaml.pyx":991
 *         elif event_class is DocumentStartEvent:
 *             version_directive = NULL
 *             if event_object.version:             # <<<<<<<<<<<<<<
 *                 version_directive_value.major = event_object.version[0]
 *                 version_directive_value.minor = event_object.version[1]
 */
    }

    /* "yaml/_yaml.pyx":995
 *                 version_directive_value.minor = event_object.version[1]
 *                 version_directive = &version_directive_value
 *             tag_directives_start = NULL             # <<<<<<<<<<<<<<
 *             tag_directives_end = NULL
 *             if event_object.tags:
 */
    __pyx_v_tag_directives_start = NULL;

    /* "yaml/_yaml.pyx":996
 *                 version_directive = &version_directive_value
 *             tag_directives_start = NULL
 *             tag_directives_end = NULL             # <<<<<<<<<<<<<<
 *             if event_object.tags:
 *                 if len(event_object.tags) > 128:
 */
    __pyx_v_tag_directives_end = NULL;

    /* "yaml/_yaml.pyx":997
 *             tag_directives_start = NULL
 *             tag_directives_end = NULL
 *             if event_object.tags:             # <<<<<<<<<<<<<<
 *                 if len(event_object.tags) > 128:
 *                     raise ValueError(u"too many tags")
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_tags); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 997, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 997, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":998
 *             tag_directives_end = NULL
 *             if event_object.tags:
 *                 if len(event_object.tags) > 128:             # <<<<<<<<<<<<<<
 *                     raise ValueError(u"too many tags")
 *                 tag_directives_start = tag_directives_value
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_tags); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 998, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 998, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_2 = (__pyx_t_6 > 0x80);
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":999
 *             if event_object.tags:
 *                 if len(event_object.tags) > 128:
 *                     raise ValueError(u"too many tags")             # <<<<<<<<<<<<<<
 *                 tag_directives_start = tag_directives_value
 *                 tag_directives_end = tag_directives_value
 */
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 999, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __PYX_ERR(0, 999, __pyx_L1_error)

        /* "yaml/_yaml.pyx":998
 *             tag_directives_end = NULL
 *             if event_object.tags:
 *                 if len(event_object.tags) > 128:             # <<<<<<<<<<<<<<
 *                     raise ValueError(u"too many tags")
 *                 tag_directives_start = tag_directives_value
 */
      }

      /* "yaml/_yaml.pyx":1000
 *                 if len(event_object.tags) > 128:
 *                     raise ValueError(u"too many tags")
 *                 tag_directives_start = tag_directives_value             # <<<<<<<<<<<<<<
 *                 tag_directives_end = tag_directives_value
 *                 cache = []
 */
      __pyx_v_tag_directives_start = __pyx_v_tag_directives_value;

      /* "yaml/_yaml.pyx":1001
 *                     raise ValueError(u"too many tags")
 *                 tag_directives_start = tag_directives_value
 *                 tag_directives_end = tag_directives_value             # <<<<<<<<<<<<<<
 *                 cache = []
 *                 for handle in event_object.tags:
 */
      __pyx_v_tag_directives_end = __pyx_v_tag_directives_value;

      /* "yaml/_yaml.pyx":1002
 *                 tag_directives_start = tag_directives_value
 *                 tag_directives_end = tag_directives_value
 *                 cache = []             # <<<<<<<<<<<<<<
 *                 for handle in event_object.tags:
 *                     prefix = event_object.tags[handle]
 */
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1002, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_cache = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "yaml/_yaml.pyx":1003
 *                 tag_directives_end = tag_directives_value
 *                 cache = []
 *                 for handle in event_object.tags:             # <<<<<<<<<<<<<<
 *                     prefix = event_object.tags[handle]
 *                     if PyUnicode_CheckExact(handle):
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_tags); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1003, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4);
        __pyx_t_6 = 0;
        __pyx_t_7 = NULL;
      } else {
        __pyx_t_6 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1003, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1003, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_7)) {
          if (likely(PyList_CheckExact(__pyx_t_4))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1003, __pyx_L1_error)
              #endif
              if (__pyx_t_6 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1003, __pyx_L1_error)
            #else
            __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1003, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1003, __pyx_L1_error)
              #endif
              if (__pyx_t_6 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1003, __pyx_L1_error)
            #else
            __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1003, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_7(__pyx_t_4);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1003, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_v_handle, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "yaml/_yaml.pyx":1004
 *                 cache = []
 *                 for handle in event_object.tags:
 *                     prefix = event_object.tags[handle]             # <<<<<<<<<<<<<<
 *                     if PyUnicode_CheckExact(handle):
 *                         handle = PyUnicode_AsUTF8String(handle)
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_tags); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1004, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_handle); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1004, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_prefix, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "yaml/_yaml.pyx":1005
 *                 for handle in event_object.tags:
 *                     prefix = event_object.tags[handle]
 *                     if PyUnicode_CheckExact(handle):             # <<<<<<<<<<<<<<
 *                         handle = PyUnicode_AsUTF8String(handle)
 *                         cache.append(handle)
 */
        __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_handle) != 0);
        if (__pyx_t_2) {

          /* "yaml/_yaml.pyx":1006
 *                     prefix = event_object.tags[handle]
 *                     if PyUnicode_CheckExact(handle):
 *                         handle = PyUnicode_AsUTF8String(handle)             # <<<<<<<<<<<<<<
 *                         cache.append(handle)
 *                     if not PyBytes_CheckExact(handle):
 */
          __pyx_t_8 = PyUnicode_AsUTF8String(__pyx_v_handle); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1006, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF_SET(__pyx_v_handle, __pyx_t_8);
          __pyx_t_8 = 0;

          /* "yaml/_yaml.pyx":1007
 *                     if PyUnicode_CheckExact(handle):
 *                         handle = PyUnicode_AsUTF8String(handle)
 *                         cache.append(handle)             # <<<<<<<<<<<<<<
 *                     if not PyBytes_CheckExact(handle):
 *                         raise TypeError(u"tag handle must be a string")
 */
          __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_cache, __pyx_v_handle); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 1007, __pyx_L1_error)

          /* "yaml/_yaml.pyx":1005
 *                 for handle in event_object.tags:
 *                     prefix = event_object.tags[handle]
 *                     if PyUnicode_CheckExact(handle):             # <<<<<<<<<<<<<<
 *                         handle = PyUnicode_AsUTF8String(handle)
 *                         cache.append(handle)
 */
        }

        /* "yaml/_yaml.pyx":1008
 *                         handle = PyUnicode_AsUTF8String(handle)
 *                         cache.append(handle)
 *                     if not PyBytes_CheckExact(handle):             # <<<<<<<<<<<<<<
 *                         raise TypeError(u"tag handle must be a string")
 *                     tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)
 */
        __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_handle) != 0));
        if (unlikely(__pyx_t_2)) {

          /* "yaml/_yaml.pyx":1009
 *                         cache.append(handle)
 *                     if not PyBytes_CheckExact(handle):
 *                         raise TypeError(u"tag handle must be a string")             # <<<<<<<<<<<<<<
 *                     tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)
 *                     if PyUnicode_CheckExact(prefix):
 */
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1009, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_Raise(__pyx_t_8, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __PYX_ERR(0, 1009, __pyx_L1_error)

          /* "yaml/_yaml.pyx":1008
 *                         handle = PyUnicode_AsUTF8String(handle)
 *                         cache.append(handle)
 *                     if not PyBytes_CheckExact(handle):             # <<<<<<<<<<<<<<
 *                         raise TypeError(u"tag handle must be a string")
 *                     tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)
 */
        }

        /* "yaml/_yaml.pyx":1010
 *                     if not PyBytes_CheckExact(handle):
 *                         raise TypeError(u"tag handle must be a string")
 *                     tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)             # <<<<<<<<<<<<<<
 *                     if PyUnicode_CheckExact(prefix):
 *                         prefix = PyUnicode_AsUTF8String(prefix)
 */
        __pyx_v_tag_directives_end->handle = PyBytes_AS_Yaml_STRING(__pyx_v_handle);

        /* "yaml/_yaml.pyx":1011
 *                         raise TypeError(u"tag handle must be a string")
 *                     tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)
 *                     if PyUnicode_CheckExact(prefix):             # <<<<<<<<<<<<<<
 *                         prefix = PyUnicode_AsUTF8String(prefix)
 *                         cache.append(prefix)
 */
        __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_prefix) != 0);
        if (__pyx_t_2) {

          /* "yaml/_yaml.pyx":1012
 *                     tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)
 *                     if PyUnicode_CheckExact(prefix):
 *                         prefix = PyUnicode_AsUTF8String(prefix)             # <<<<<<<<<<<<<<
 *                         cache.append(prefix)
 *                     if not PyBytes_CheckExact(prefix):
 */
          __pyx_t_8 = PyUnicode_AsUTF8String(__pyx_v_prefix); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1012, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF_SET(__pyx_v_prefix, __pyx_t_8);
          __pyx_t_8 = 0;

          /* "yaml/_yaml.pyx":1013
 *                     if PyUnicode_CheckExact(prefix):
 *                         prefix = PyUnicode_AsUTF8String(prefix)
 *                         cache.append(prefix)             # <<<<<<<<<<<<<<
 *                     if not PyBytes_CheckExact(prefix):
 *                         raise TypeError(u"tag prefix must be a string")
 */
          __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_cache, __pyx_v_prefix); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 1013, __pyx_L1_error)

          /* "yaml/_yaml.pyx":1011
 *                         raise TypeError(u"tag handle must be a string")
 *                     tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)
 *                     if PyUnicode_CheckExact(prefix):             # <<<<<<<<<<<<<<
 *                         prefix = PyUnicode_AsUTF8String(prefix)
 *                         cache.append(prefix)
 */
        }

        /* "yaml/_yaml.pyx":1014
 *                         prefix = PyUnicode_AsUTF8String(prefix)
 *                         cache.append(prefix)
 *                     if not PyBytes_CheckExact(prefix):             # <<<<<<<<<<<<<<
 *                         raise TypeError(u"tag prefix must be a string")
 *                     tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)
 */
        __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_prefix) != 0));
        if (unlikely(__pyx_t_2)) {

          /* "yaml/_yaml.pyx":1015
 *                         cache.append(prefix)
 *                     if not PyBytes_CheckExact(prefix):
 *                         raise TypeError(u"tag prefix must be a string")             # <<<<<<<<<<<<<<
 *                     tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)
 *                     tag_directives_end = tag_directives_end+1
 */
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1015, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_Raise(__pyx_t_8, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __PYX_ERR(0, 1015, __pyx_L1_error)

          /* "yaml/_yaml.pyx":1014
 *                         prefix = PyUnicode_AsUTF8String(prefix)
 *                         cache.append(prefix)
 *                     if not PyBytes_CheckExact(prefix):             # <<<<<<<<<<<<<<
 *                         raise TypeError(u"tag prefix must be a string")
 *                     tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)
 */
        }

        /* "yaml/_yaml.pyx":1016
 *                     if not PyBytes_CheckExact(prefix):
 *                         raise TypeError(u"tag prefix must be a string")
 *                     tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)             # <<<<<<<<<<<<<<
 *                     tag_directives_end = tag_directives_end+1
 *             implicit = 1
 */
        __pyx_v_tag_directives_end->prefix = PyBytes_AS_Yaml_STRING(__pyx_v_prefix);

        /* "yaml/_yaml.pyx":1017
 *                         raise TypeError(u"tag prefix must be a string")
 *                     tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)
 *                     tag_directives_end = tag_directives_end+1             # <<<<<<<<<<<<<<
 *             implicit = 1
 *             if event_object.explicit:
 */
        __pyx_v_tag_directives_end = (__pyx_v_tag_directives_end + 1);

        /* "yaml/_yaml.pyx":1003
 *                 tag_directives_end = tag_directives_value
 *                 cache = []
 *                 for handle in event_object.tags:             # <<<<<<<<<<<<<<
 *                     prefix = event_object.tags[handle]
 *                     if PyUnicode_CheckExact(handle):
 */
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "yaml/_yaml.pyx":997
 *             tag_directives_start = NULL
 *             tag_directives_end = NULL
 *             if event_object.tags:             # <<<<<<<<<<<<<<
 *                 if len(event_object.tags) > 128:
 *                     raise ValueError(u"too many tags")
 */
    }

    /* "yaml/_yaml.pyx":1018
 *                     tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)
 *                     tag_directives_end = tag_directives_end+1
 *             implicit = 1             # <<<<<<<<<<<<<<
 *             if event_object.explicit:
 *                 implicit = 0
 */
    __pyx_v_implicit = 1;

    /* "yaml/_yaml.pyx":1019
 *                     tag_directives_end = tag_directives_end+1
 *             implicit = 1
 *             if event_object.explicit:             # <<<<<<<<<<<<<<
 *                 implicit = 0
 *             if yaml_document_start_event_initialize(event, version_directive,
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_explicit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1019, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1019, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1020
 *             implicit = 1
 *             if event_object.explicit:
 *                 implicit = 0             # <<<<<<<<<<<<<<
 *             if yaml_document_start_event_initialize(event, version_directive,
 *                     tag_directives_start, tag_directives_end, implicit) == 0:
 */
      __pyx_v_implicit = 0;

      /* "yaml/_yaml.pyx":1019
 *                     tag_directives_end = tag_directives_end+1
 *             implicit = 1
 *             if event_object.explicit:             # <<<<<<<<<<<<<<
 *                 implicit = 0
 *             if yaml_document_start_event_initialize(event, version_directive,
 */
    }

    /* "yaml/_yaml.pyx":1022
 *                 implicit = 0
 *             if yaml_document_start_event_initialize(event, version_directive,
 *                     tag_directives_start, tag_directives_end, implicit) == 0:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *         elif event_class is DocumentEndEvent:
 */
    __pyx_t_2 = (yaml_document_start_event_initialize(__pyx_v_event, __pyx_v_version_directive, __pyx_v_tag_directives_start, __pyx_v_tag_directives_end, __pyx_v_implicit) == 0);

    /* "yaml/_yaml.pyx":1021
 *             if event_object.explicit:
 *                 implicit = 0
 *             if yaml_document_start_event_initialize(event, version_directive,             # <<<<<<<<<<<<<<
 *                     tag_directives_start, tag_directives_end, implicit) == 0:
 *                 raise MemoryError
 */
    if (unlikely(__pyx_t_2)) {

      /* "yaml/_yaml.pyx":1023
 *             if yaml_document_start_event_initialize(event, version_directive,
 *                     tag_directives_start, tag_directives_end, implicit) == 0:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 *         elif event_class is DocumentEndEvent:
 *             implicit = 1
 */
      PyErr_NoMemory(); __PYX_ERR(0, 1023, __pyx_L1_error)

      /* "yaml/_yaml.pyx":1021
 *             if event_object.explicit:
 *                 implicit = 0
 *             if yaml_document_start_event_initialize(event, version_directive,             # <<<<<<<<<<<<<<
 *                     tag_directives_start, tag_directives_end, implicit) == 0:
 *                 raise MemoryError
 */
    }

    /* "yaml/_yaml.pyx":989
 *         elif event_class is StreamEndEvent:
 *             yaml_stream_end_event_initialize(event)
 *         elif event_class is DocumentStartEvent:             # <<<<<<<<<<<<<<
 *             version_directive = NULL
 *             if event_object.version:
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":1024
 *                     tag_directives_start, tag_directives_end, implicit) == 0:
 *                 raise MemoryError
 *         elif event_class is DocumentEndEvent:             # <<<<<<<<<<<<<<
 *             implicit = 1
 *             if event_object.explicit:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_DocumentEndEvent); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = (__pyx_v_event_class == __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":1025
 *                 raise MemoryError
 *         elif event_class is DocumentEndEvent:
 *             implicit = 1             # <<<<<<<<<<<<<<
 *             if event_object.explicit:
 *                 implicit = 0
 */
    __pyx_v_implicit = 1;

    /* "yaml/_yaml.pyx":1026
 *         elif event_class is DocumentEndEvent:
 *             implicit = 1
 *             if event_object.explicit:             # <<<<<<<<<<<<<<
 *                 implicit = 0
 *             yaml_document_end_event_initialize(event, implicit)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_explicit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1026, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1026, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1027
 *             implicit = 1
 *             if event_object.explicit:
 *                 implicit = 0             # <<<<<<<<<<<<<<
 *             yaml_document_end_event_initialize(event, implicit)
 *         elif event_class is AliasEvent:
 */
      __pyx_v_implicit = 0;

      /* "yaml/_yaml.pyx":1026
 *         elif event_class is DocumentEndEvent:
 *             implicit = 1
 *             if event_object.explicit:             # <<<<<<<<<<<<<<
 *                 implicit = 0
 *             yaml_document_end_event_initialize(event, implicit)
 */
    }

    /* "yaml/_yaml.pyx":1028
 *             if event_object.explicit:
 *                 implicit = 0
 *             yaml_document_end_event_initialize(event, implicit)             # <<<<<<<<<<<<<<
 *         elif event_class is AliasEvent:
 *             anchor = NULL
 */
    (void)(yaml_document_end_event_initialize(__pyx_v_event, __pyx_v_implicit));

    /* "yaml/_yaml.pyx":1024
 *                     tag_directives_start, tag_directives_end, implicit) == 0:
 *                 raise MemoryError
 *         elif event_class is DocumentEndEvent:             # <<<<<<<<<<<<<<
 *             implicit = 1
 *             if event_object.explicit:
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":1029
 *                 implicit = 0
 *             yaml_document_end_event_initialize(event, implicit)
 *         elif event_class is AliasEvent:             # <<<<<<<<<<<<<<
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_AliasEvent); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = (__pyx_v_event_class == __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":1030
 *             yaml_document_end_event_initialize(event, implicit)
 *         elif event_class is AliasEvent:
 *             anchor = NULL             # <<<<<<<<<<<<<<
 *             anchor_object = event_object.anchor
 *             if PyUnicode_CheckExact(anchor_object):
 */
    __pyx_v_anchor = NULL;

    /* "yaml/_yaml.pyx":1031
 *         elif event_class is AliasEvent:
 *             anchor = NULL
 *             anchor_object = event_object.anchor             # <<<<<<<<<<<<<<
 *             if PyUnicode_CheckExact(anchor_object):
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_anchor); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_anchor_object = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":1032
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 *             if PyUnicode_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *             if not PyBytes_CheckExact(anchor_object):
 */
    __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_anchor_object) != 0);
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1033
 *             anchor_object = event_object.anchor
 *             if PyUnicode_CheckExact(anchor_object):
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)             # <<<<<<<<<<<<<<
 *             if not PyBytes_CheckExact(anchor_object):
 *                 raise TypeError(u"anchor must be a string")
 */
      __pyx_t_4 = PyUnicode_AsUTF8String(__pyx_v_anchor_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1033, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_anchor_object, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "yaml/_yaml.pyx":1032
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 *             if PyUnicode_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *             if not PyBytes_CheckExact(anchor_object):
 */
    }

    /* "yaml/_yaml.pyx":1034
 *             if PyUnicode_CheckExact(anchor_object):
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *             if not PyBytes_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                 raise TypeError(u"anchor must be a string")
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 */
    __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_anchor_object) != 0));
    if (unlikely(__pyx_t_2)) {

      /* "yaml/_yaml.pyx":1035
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *             if not PyBytes_CheckExact(anchor_object):
 *                 raise TypeError(u"anchor must be a string")             # <<<<<<<<<<<<<<
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             if yaml_alias_event_initialize(event, anchor) == 0:
 */
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1035, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 1035, __pyx_L1_error)

      /* "yaml/_yaml.pyx":1034
 *             if PyUnicode_CheckExact(anchor_object):
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *             if not PyBytes_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                 raise TypeError(u"anchor must be a string")
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 */
    }

    /* "yaml/_yaml.pyx":1036
 *             if not PyBytes_CheckExact(anchor_object):
 *                 raise TypeError(u"anchor must be a string")
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)             # <<<<<<<<<<<<<<
 *             if yaml_alias_event_initialize(event, anchor) == 0:
 *                 raise MemoryError
 */
    __pyx_v_anchor = PyBytes_AS_Yaml_STRING(__pyx_v_anchor_object);

    /* "yaml/_yaml.pyx":1037
 *                 raise TypeError(u"anchor must be a string")
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             if yaml_alias_event_initialize(event, anchor) == 0:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *         elif event_class is ScalarEvent:
 */
    __pyx_t_2 = (yaml_alias_event_initialize(__pyx_v_event, __pyx_v_anchor) == 0);
    if (unlikely(__pyx_t_2)) {

      /* "yaml/_yaml.pyx":1038
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             if yaml_alias_event_initialize(event, anchor) == 0:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 *         elif event_class is ScalarEvent:
 *             anchor = NULL
 */
      PyErr_NoMemory(); __PYX_ERR(0, 1038, __pyx_L1_error)

      /* "yaml/_yaml.pyx":1037
 *                 raise TypeError(u"anchor must be a string")
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             if yaml_alias_event_initialize(event, anchor) == 0:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *         elif event_class is ScalarEvent:
 */
    }

    /* "yaml/_yaml.pyx":1029
 *                 implicit = 0
 *             yaml_document_end_event_initialize(event, implicit)
 *         elif event_class is AliasEvent:             # <<<<<<<<<<<<<<
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":1039
 *             if yaml_alias_event_initialize(event, anchor) == 0:
 *                 raise MemoryError
 *         elif event_class is ScalarEvent:             # <<<<<<<<<<<<<<
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_ScalarEvent); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = (__pyx_v_event_class == __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":1040
 *                 raise MemoryError
 *         elif event_class is ScalarEvent:
 *             anchor = NULL             # <<<<<<<<<<<<<<
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:
 */
    __pyx_v_anchor = NULL;

    /* "yaml/_yaml.pyx":1041
 *         elif event_class is ScalarEvent:
 *             anchor = NULL
 *             anchor_object = event_object.anchor             # <<<<<<<<<<<<<<
 *             if anchor_object is not None:
 *                 if PyUnicode_CheckExact(anchor_object):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_anchor); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1041, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_anchor_object = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":1042
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 */
    __pyx_t_2 = (__pyx_v_anchor_object != Py_None);
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1043
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:
 *                 if PyUnicode_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):
 */
      __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_anchor_object) != 0);
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1044
 *             if anchor_object is not None:
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)             # <<<<<<<<<<<<<<
 *                 if not PyBytes_CheckExact(anchor_object):
 *                     raise TypeError(u"anchor must be a string")
 */
        __pyx_t_4 = PyUnicode_AsUTF8String(__pyx_v_anchor_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1044, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF_SET(__pyx_v_anchor_object, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "yaml/_yaml.pyx":1043
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:
 *                 if PyUnicode_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):
 */
      }

      /* "yaml/_yaml.pyx":1045
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"anchor must be a string")
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 */
      __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_anchor_object) != 0));
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1046
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):
 *                     raise TypeError(u"anchor must be a string")             # <<<<<<<<<<<<<<
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             tag = NULL
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1046, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 1046, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1045
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"anchor must be a string")
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 */
      }

      /* "yaml/_yaml.pyx":1047
 *                 if not PyBytes_CheckExact(anchor_object):
 *                     raise TypeError(u"anchor must be a string")
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)             # <<<<<<<<<<<<<<
 *             tag = NULL
 *             tag_object = event_object.tag
 */
      __pyx_v_anchor = PyBytes_AS_Yaml_STRING(__pyx_v_anchor_object);

      /* "yaml/_yaml.pyx":1042
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 */
    }

    /* "yaml/_yaml.pyx":1048
 *                     raise TypeError(u"anchor must be a string")
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             tag = NULL             # <<<<<<<<<<<<<<
 *             tag_object = event_object.tag
 *             if tag_object is not None:
 */
    __pyx_v_tag = NULL;

    /* "yaml/_yaml.pyx":1049
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             tag = NULL
 *             tag_object = event_object.tag             # <<<<<<<<<<<<<<
 *             if tag_object is not None:
 *                 if PyUnicode_CheckExact(tag_object):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_tag); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1049, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_tag_object = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":1050
 *             tag = NULL
 *             tag_object = event_object.tag
 *             if tag_object is not None:             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 */
    __pyx_t_2 = (__pyx_v_tag_object != Py_None);
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1051
 *             tag_object = event_object.tag
 *             if tag_object is not None:
 *                 if PyUnicode_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):
 */
      __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_tag_object) != 0);
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1052
 *             if tag_object is not None:
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)             # <<<<<<<<<<<<<<
 *                 if not PyBytes_CheckExact(tag_object):
 *                     raise TypeError(u"tag must be a string")
 */
        __pyx_t_4 = PyUnicode_AsUTF8String(__pyx_v_tag_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1052, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF_SET(__pyx_v_tag_object, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "yaml/_yaml.pyx":1051
 *             tag_object = event_object.tag
 *             if tag_object is not None:
 *                 if PyUnicode_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):
 */
      }

      /* "yaml/_yaml.pyx":1053
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"tag must be a string")
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 */
      __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_tag_object) != 0));
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1054
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):
 *                     raise TypeError(u"tag must be a string")             # <<<<<<<<<<<<<<
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 *             value_object = event_object.value
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1054, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 1054, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1053
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"tag must be a string")
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 */
      }

      /* "yaml/_yaml.pyx":1055
 *                 if not PyBytes_CheckExact(tag_object):
 *                     raise TypeError(u"tag must be a string")
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)             # <<<<<<<<<<<<<<
 *             value_object = event_object.value
 *             if PyUnicode_CheckExact(value_object):
 */
      __pyx_v_tag = PyBytes_AS_Yaml_STRING(__pyx_v_tag_object);

      /* "yaml/_yaml.pyx":1050
 *             tag = NULL
 *             tag_object = event_object.tag
 *             if tag_object is not None:             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 */
    }

    /* "yaml/_yaml.pyx":1056
 *                     raise TypeError(u"tag must be a string")
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 *             value_object = event_object.value             # <<<<<<<<<<<<<<
 *             if PyUnicode_CheckExact(value_object):
 *                 value_object = PyUnicode_AsUTF8String(value_object)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_value); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1056, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_value_object = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":1057
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 *             value_object = event_object.value
 *             if PyUnicode_CheckExact(value_object):             # <<<<<<<<<<<<<<
 *                 value_object = PyUnicode_AsUTF8String(value_object)
 *             if not PyBytes_CheckExact(value_object):
 */
    __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_value_object) != 0);
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1058
 *             value_object = event_object.value
 *             if PyUnicode_CheckExact(value_object):
 *                 value_object = PyUnicode_AsUTF8String(value_object)             # <<<<<<<<<<<<<<
 *             if not PyBytes_CheckExact(value_object):
 *                 raise TypeError(u"value must be a string")
 */
      __pyx_t_4 = PyUnicode_AsUTF8String(__pyx_v_value_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1058, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_value_object, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "yaml/_yaml.pyx":1057
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 *             value_object = event_object.value
 *             if PyUnicode_CheckExact(value_object):             # <<<<<<<<<<<<<<
 *                 value_object = PyUnicode_AsUTF8String(value_object)
 *             if not PyBytes_CheckExact(value_object):
 */
    }

    /* "yaml/_yaml.pyx":1059
 *             if PyUnicode_CheckExact(value_object):
 *                 value_object = PyUnicode_AsUTF8String(value_object)
 *             if not PyBytes_CheckExact(value_object):             # <<<<<<<<<<<<<<
 *                 raise TypeError(u"value must be a string")
 *             value = PyBytes_AS_Yaml_STRING(value_object)
 */
    __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_value_object) != 0));
    if (unlikely(__pyx_t_2)) {

      /* "yaml/_yaml.pyx":1060
 *                 value_object = PyUnicode_AsUTF8String(value_object)
 *             if not PyBytes_CheckExact(value_object):
 *                 raise TypeError(u"value must be a string")             # <<<<<<<<<<<<<<
 *             value = PyBytes_AS_Yaml_STRING(value_object)
 *             length = PyBytes_GET_SIZE(value_object)
 */
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1060, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 1060, __pyx_L1_error)

      /* "yaml/_yaml.pyx":1059
 *             if PyUnicode_CheckExact(value_object):
 *                 value_object = PyUnicode_AsUTF8String(value_object)
 *             if not PyBytes_CheckExact(value_object):             # <<<<<<<<<<<<<<
 *                 raise TypeError(u"value must be a string")
 *             value = PyBytes_AS_Yaml_STRING(value_object)
 */
    }

    /* "yaml/_yaml.pyx":1061
 *             if not PyBytes_CheckExact(value_object):
 *                 raise TypeError(u"value must be a string")
 *             value = PyBytes_AS_Yaml_STRING(value_object)             # <<<<<<<<<<<<<<
 *             length = PyBytes_GET_SIZE(value_object)
 *             plain_implicit = 0
 */
    __pyx_v_value = PyBytes_AS_Yaml_STRING(__pyx_v_value_object);

    /* "yaml/_yaml.pyx":1062
 *                 raise TypeError(u"value must be a string")
 *             value = PyBytes_AS_Yaml_STRING(value_object)
 *             length = PyBytes_GET_SIZE(value_object)             # <<<<<<<<<<<<<<
 *             plain_implicit = 0
 *             quoted_implicit = 0
 */
    __pyx_v_length = PyBytes_GET_SIZE(__pyx_v_value_object);

    /* "yaml/_yaml.pyx":1063
 *             value = PyBytes_AS_Yaml_STRING(value_object)
 *             length = PyBytes_GET_SIZE(value_object)
 *             plain_implicit = 0             # <<<<<<<<<<<<<<
 *             quoted_implicit = 0
 *             if event_object.implicit is not None:
 */
    __pyx_v_plain_implicit = 0;

    /* "yaml/_yaml.pyx":1064
 *             length = PyBytes_GET_SIZE(value_object)
 *             plain_implicit = 0
 *             quoted_implicit = 0             # <<<<<<<<<<<<<<
 *             if event_object.implicit is not None:
 *                 plain_implicit = event_object.implicit[0]
 */
    __pyx_v_quoted_implicit = 0;

    /* "yaml/_yaml.pyx":1065
 *             plain_implicit = 0
 *             quoted_implicit = 0
 *             if event_object.implicit is not None:             # <<<<<<<<<<<<<<
 *                 plain_implicit = event_object.implicit[0]
 *                 quoted_implicit = event_object.implicit[1]
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_implicit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = (__pyx_t_4 != Py_None);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1066
 *             quoted_implicit = 0
 *             if event_object.implicit is not None:
 *                 plain_implicit = event_object.implicit[0]             # <<<<<<<<<<<<<<
 *                 quoted_implicit = event_object.implicit[1]
 *             style_object = event_object.style
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_implicit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1066, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1066, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_8); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1066, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_plain_implicit = __pyx_t_5;

      /* "yaml/_yaml.pyx":1067
 *             if event_object.implicit is not None:
 *                 plain_implicit = event_object.implicit[0]
 *                 quoted_implicit = event_object.implicit[1]             # <<<<<<<<<<<<<<
 *             style_object = event_object.style
 *             scalar_style = YAML_PLAIN_SCALAR_STYLE
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_implicit); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1067, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_8, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1067, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1067, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_quoted_implicit = __pyx_t_5;

      /* "yaml/_yaml.pyx":1065
 *             plain_implicit = 0
 *             quoted_implicit = 0
 *             if event_object.implicit is not None:             # <<<<<<<<<<<<<<
 *                 plain_implicit = event_object.implicit[0]
 *                 quoted_implicit = event_object.implicit[1]
 */
    }

    /* "yaml/_yaml.pyx":1068
 *                 plain_implicit = event_object.implicit[0]
 *                 quoted_implicit = event_object.implicit[1]
 *             style_object = event_object.style             # <<<<<<<<<<<<<<
 *             scalar_style = YAML_PLAIN_SCALAR_STYLE
 *             if style_object == "'" or style_object == u"'":
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_style); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_style_object = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":1069
 *                 quoted_implicit = event_object.implicit[1]
 *             style_object = event_object.style
 *             scalar_style = YAML_PLAIN_SCALAR_STYLE             # <<<<<<<<<<<<<<
 *             if style_object == "'" or style_object == u"'":
 *                 scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE
 */
    __pyx_v_scalar_style = YAML_PLAIN_SCALAR_STYLE;

    /* "yaml/_yaml.pyx":1070
 *             style_object = event_object.style
 *             scalar_style = YAML_PLAIN_SCALAR_STYLE
 *             if style_object == "'" or style_object == u"'":             # <<<<<<<<<<<<<<
 *                 scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE
 *             elif style_object == "\"" or style_object == u"\"":
 */
    __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_style_object, __pyx_kp_s__5, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1070, __pyx_L1_error)
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L37_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_style_object, __pyx_kp_u__5, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1070, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_3;
    __pyx_L37_bool_binop_done:;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1071
 *             scalar_style = YAML_PLAIN_SCALAR_STYLE
 *             if style_object == "'" or style_object == u"'":
 *                 scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE             # <<<<<<<<<<<<<<
 *             elif style_object == "\"" or style_object == u"\"":
 *                 scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE
 */
      __pyx_v_scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE;

      /* "yaml/_yaml.pyx":1070
 *             style_object = event_object.style
 *             scalar_style = YAML_PLAIN_SCALAR_STYLE
 *             if style_object == "'" or style_object == u"'":             # <<<<<<<<<<<<<<
 *                 scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE
 *             elif style_object == "\"" or style_object == u"\"":
 */
      goto __pyx_L36;
    }

    /* "yaml/_yaml.pyx":1072
 *             if style_object == "'" or style_object == u"'":
 *                 scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE
 *             elif style_object == "\"" or style_object == u"\"":             # <<<<<<<<<<<<<<
 *                 scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE
 *             elif style_object == "|" or style_object == u"|":
 */
    __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_style_object, __pyx_kp_s__6, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1072, __pyx_L1_error)
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L39_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_style_object, __pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1072, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_3;
    __pyx_L39_bool_binop_done:;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1073
 *                 scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE
 *             elif style_object == "\"" or style_object == u"\"":
 *                 scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE             # <<<<<<<<<<<<<<
 *             elif style_object == "|" or style_object == u"|":
 *                 scalar_style = YAML_LITERAL_SCALAR_STYLE
 */
      __pyx_v_scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE;

      /* "yaml/_yaml.pyx":1072
 *             if style_object == "'" or style_object == u"'":
 *                 scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE
 *             elif style_object == "\"" or style_object == u"\"":             # <<<<<<<<<<<<<<
 *                 scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE
 *             elif style_object == "|" or style_object == u"|":
 */
      goto __pyx_L36;
    }

    /* "yaml/_yaml.pyx":1074
 *             elif style_object == "\"" or style_object == u"\"":
 *                 scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE
 *             elif style_object == "|" or style_object == u"|":             # <<<<<<<<<<<<<<
 *                 scalar_style = YAML_LITERAL_SCALAR_STYLE
 *             elif style_object == ">" or style_object == u">":
 */
    __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_style_object, __pyx_kp_s__7, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1074, __pyx_L1_error)
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L41_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_style_object, __pyx_kp_u__7, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1074, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_3;
    __pyx_L41_bool_binop_done:;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1075
 *                 scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE
 *             elif style_object == "|" or style_object == u"|":
 *                 scalar_style = YAML_LITERAL_SCALAR_STYLE             # <<<<<<<<<<<<<<
 *             elif style_object == ">" or style_object == u">":
 *                 scalar_style = YAML_FOLDED_SCALAR_STYLE
 */
      __pyx_v_scalar_style = YAML_LITERAL_SCALAR_STYLE;

      /* "yaml/_yaml.pyx":1074
 *             elif style_object == "\"" or style_object == u"\"":
 *                 scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE
 *             elif style_object == "|" or style_object == u"|":             # <<<<<<<<<<<<<<
 *                 scalar_style = YAML_LITERAL_SCALAR_STYLE
 *             elif style_object == ">" or style_object == u">":
 */
      goto __pyx_L36;
    }

    /* "yaml/_yaml.pyx":1076
 *             elif style_object == "|" or style_object == u"|":
 *                 scalar_style = YAML_LITERAL_SCALAR_STYLE
 *             elif style_object == ">" or style_object == u">":             # <<<<<<<<<<<<<<
 *                 scalar_style = YAML_FOLDED_SCALAR_STYLE
 *             if yaml_scalar_event_initialize(event, anchor, tag, value, length,
 */
    __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_style_object, __pyx_kp_s__8, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1076, __pyx_L1_error)
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L43_bool_binop_done;
    }
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_style_object, __pyx_kp_u__8, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(0, 1076, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_3;
    __pyx_L43_bool_binop_done:;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1077
 *                 scalar_style = YAML_LITERAL_SCALAR_STYLE
 *             elif style_object == ">" or style_object == u">":
 *                 scalar_style = YAML_FOLDED_SCALAR_STYLE             # <<<<<<<<<<<<<<
 *             if yaml_scalar_event_initialize(event, anchor, tag, value, length,
 *                     plain_implicit, quoted_implicit, scalar_style) == 0:
 */
      __pyx_v_scalar_style = YAML_FOLDED_SCALAR_STYLE;

      /* "yaml/_yaml.pyx":1076
 *             elif style_object == "|" or style_object == u"|":
 *                 scalar_style = YAML_LITERAL_SCALAR_STYLE
 *             elif style_object == ">" or style_object == u">":             # <<<<<<<<<<<<<<
 *                 scalar_style = YAML_FOLDED_SCALAR_STYLE
 *             if yaml_scalar_event_initialize(event, anchor, tag, value, length,
 */
    }
    __pyx_L36:;

    /* "yaml/_yaml.pyx":1079
 *                 scalar_style = YAML_FOLDED_SCALAR_STYLE
 *             if yaml_scalar_event_initialize(event, anchor, tag, value, length,
 *                     plain_implicit, quoted_implicit, scalar_style) == 0:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *         elif event_class is SequenceStartEvent:
 */
    __pyx_t_2 = (yaml_scalar_event_initialize(__pyx_v_event, __pyx_v_anchor, __pyx_v_tag, __pyx_v_value, __pyx_v_length, __pyx_v_plain_implicit, __pyx_v_quoted_implicit, __pyx_v_scalar_style) == 0);

    /* "yaml/_yaml.pyx":1078
 *             elif style_object == ">" or style_object == u">":
 *                 scalar_style = YAML_FOLDED_SCALAR_STYLE
 *             if yaml_scalar_event_initialize(event, anchor, tag, value, length,             # <<<<<<<<<<<<<<
 *                     plain_implicit, quoted_implicit, scalar_style) == 0:
 *                 raise MemoryError
 */
    if (unlikely(__pyx_t_2)) {

      /* "yaml/_yaml.pyx":1080
 *             if yaml_scalar_event_initialize(event, anchor, tag, value, length,
 *                     plain_implicit, quoted_implicit, scalar_style) == 0:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 *         elif event_class is SequenceStartEvent:
 *             anchor = NULL
 */
      PyErr_NoMemory(); __PYX_ERR(0, 1080, __pyx_L1_error)

      /* "yaml/_yaml.pyx":1078
 *             elif style_object == ">" or style_object == u">":
 *                 scalar_style = YAML_FOLDED_SCALAR_STYLE
 *             if yaml_scalar_event_initialize(event, anchor, tag, value, length,             # <<<<<<<<<<<<<<
 *                     plain_implicit, quoted_implicit, scalar_style) == 0:
 *                 raise MemoryError
 */
    }

    /* "yaml/_yaml.pyx":1039
 *             if yaml_alias_event_initialize(event, anchor) == 0:
 *                 raise MemoryError
 *         elif event_class is ScalarEvent:             # <<<<<<<<<<<<<<
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":1081
 *                     plain_implicit, quoted_implicit, scalar_style) == 0:
 *                 raise MemoryError
 *         elif event_class is SequenceStartEvent:             # <<<<<<<<<<<<<<
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_SequenceStartEvent); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1081, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = (__pyx_v_event_class == __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":1082
 *                 raise MemoryError
 *         elif event_class is SequenceStartEvent:
 *             anchor = NULL             # <<<<<<<<<<<<<<
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:
 */
    __pyx_v_anchor = NULL;

    /* "yaml/_yaml.pyx":1083
 *         elif event_class is SequenceStartEvent:
 *             anchor = NULL
 *             anchor_object = event_object.anchor             # <<<<<<<<<<<<<<
 *             if anchor_object is not None:
 *                 if PyUnicode_CheckExact(anchor_object):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_anchor); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1083, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_anchor_object = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":1084
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 */
    __pyx_t_2 = (__pyx_v_anchor_object != Py_None);
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1085
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:
 *                 if PyUnicode_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):
 */
      __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_anchor_object) != 0);
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1086
 *             if anchor_object is not None:
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)             # <<<<<<<<<<<<<<
 *                 if not PyBytes_CheckExact(anchor_object):
 *                     raise TypeError(u"anchor must be a string")
 */
        __pyx_t_4 = PyUnicode_AsUTF8String(__pyx_v_anchor_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1086, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF_SET(__pyx_v_anchor_object, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "yaml/_yaml.pyx":1085
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:
 *                 if PyUnicode_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):
 */
      }

      /* "yaml/_yaml.pyx":1087
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"anchor must be a string")
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 */
      __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_anchor_object) != 0));
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1088
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):
 *                     raise TypeError(u"anchor must be a string")             # <<<<<<<<<<<<<<
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             tag = NULL
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1088, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 1088, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1087
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"anchor must be a string")
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 */
      }

      /* "yaml/_yaml.pyx":1089
 *                 if not PyBytes_CheckExact(anchor_object):
 *                     raise TypeError(u"anchor must be a string")
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)             # <<<<<<<<<<<<<<
 *             tag = NULL
 *             tag_object = event_object.tag
 */
      __pyx_v_anchor = PyBytes_AS_Yaml_STRING(__pyx_v_anchor_object);

      /* "yaml/_yaml.pyx":1084
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 */
    }

    /* "yaml/_yaml.pyx":1090
 *                     raise TypeError(u"anchor must be a string")
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             tag = NULL             # <<<<<<<<<<<<<<
 *             tag_object = event_object.tag
 *             if tag_object is not None:
 */
    __pyx_v_tag = NULL;

    /* "yaml/_yaml.pyx":1091
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             tag = NULL
 *             tag_object = event_object.tag             # <<<<<<<<<<<<<<
 *             if tag_object is not None:
 *                 if PyUnicode_CheckExact(tag_object):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_tag); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1091, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_tag_object = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":1092
 *             tag = NULL
 *             tag_object = event_object.tag
 *             if tag_object is not None:             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 */
    __pyx_t_2 = (__pyx_v_tag_object != Py_None);
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1093
 *             tag_object = event_object.tag
 *             if tag_object is not None:
 *                 if PyUnicode_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):
 */
      __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_tag_object) != 0);
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1094
 *             if tag_object is not None:
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)             # <<<<<<<<<<<<<<
 *                 if not PyBytes_CheckExact(tag_object):
 *                     raise TypeError(u"tag must be a string")
 */
        __pyx_t_4 = PyUnicode_AsUTF8String(__pyx_v_tag_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1094, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF_SET(__pyx_v_tag_object, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "yaml/_yaml.pyx":1093
 *             tag_object = event_object.tag
 *             if tag_object is not None:
 *                 if PyUnicode_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):
 */
      }

      /* "yaml/_yaml.pyx":1095
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"tag must be a string")
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 */
      __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_tag_object) != 0));
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1096
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):
 *                     raise TypeError(u"tag must be a string")             # <<<<<<<<<<<<<<
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 *             implicit = 0
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1096, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 1096, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1095
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"tag must be a string")
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 */
      }

      /* "yaml/_yaml.pyx":1097
 *                 if not PyBytes_CheckExact(tag_object):
 *                     raise TypeError(u"tag must be a string")
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)             # <<<<<<<<<<<<<<
 *             implicit = 0
 *             if event_object.implicit:
 */
      __pyx_v_tag = PyBytes_AS_Yaml_STRING(__pyx_v_tag_object);

      /* "yaml/_yaml.pyx":1092
 *             tag = NULL
 *             tag_object = event_object.tag
 *             if tag_object is not None:             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 */
    }

    /* "yaml/_yaml.pyx":1098
 *                     raise TypeError(u"tag must be a string")
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 *             implicit = 0             # <<<<<<<<<<<<<<
 *             if event_object.implicit:
 *                 implicit = 1
 */
    __pyx_v_implicit = 0;

    /* "yaml/_yaml.pyx":1099
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 *             implicit = 0
 *             if event_object.implicit:             # <<<<<<<<<<<<<<
 *                 implicit = 1
 *             sequence_style = YAML_BLOCK_SEQUENCE_STYLE
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_implicit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1099, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1100
 *             implicit = 0
 *             if event_object.implicit:
 *                 implicit = 1             # <<<<<<<<<<<<<<
 *             sequence_style = YAML_BLOCK_SEQUENCE_STYLE
 *             if event_object.flow_style:
 */
      __pyx_v_implicit = 1;

      /* "yaml/_yaml.pyx":1099
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 *             implicit = 0
 *             if event_object.implicit:             # <<<<<<<<<<<<<<
 *                 implicit = 1
 *             sequence_style = YAML_BLOCK_SEQUENCE_STYLE
 */
    }

    /* "yaml/_yaml.pyx":1101
 *             if event_object.implicit:
 *                 implicit = 1
 *             sequence_style = YAML_BLOCK_SEQUENCE_STYLE             # <<<<<<<<<<<<<<
 *             if event_object.flow_style:
 *                 sequence_style = YAML_FLOW_SEQUENCE_STYLE
 */
    __pyx_v_sequence_style = YAML_BLOCK_SEQUENCE_STYLE;

    /* "yaml/_yaml.pyx":1102
 *                 implicit = 1
 *             sequence_style = YAML_BLOCK_SEQUENCE_STYLE
 *             if event_object.flow_style:             # <<<<<<<<<<<<<<
 *                 sequence_style = YAML_FLOW_SEQUENCE_STYLE
 *             if yaml_sequence_start_event_initialize(event, anchor, tag,
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_flow_style); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1102, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1102, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1103
 *             sequence_style = YAML_BLOCK_SEQUENCE_STYLE
 *             if event_object.flow_style:
 *                 sequence_style = YAML_FLOW_SEQUENCE_STYLE             # <<<<<<<<<<<<<<
 *             if yaml_sequence_start_event_initialize(event, anchor, tag,
 *                     implicit, sequence_style) == 0:
 */
      __pyx_v_sequence_style = YAML_FLOW_SEQUENCE_STYLE;

      /* "yaml/_yaml.pyx":1102
 *                 implicit = 1
 *             sequence_style = YAML_BLOCK_SEQUENCE_STYLE
 *             if event_object.flow_style:             # <<<<<<<<<<<<<<
 *                 sequence_style = YAML_FLOW_SEQUENCE_STYLE
 *             if yaml_sequence_start_event_initialize(event, anchor, tag,
 */
    }

    /* "yaml/_yaml.pyx":1105
 *                 sequence_style = YAML_FLOW_SEQUENCE_STYLE
 *             if yaml_sequence_start_event_initialize(event, anchor, tag,
 *                     implicit, sequence_style) == 0:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *         elif event_class is MappingStartEvent:
 */
    __pyx_t_2 = (yaml_sequence_start_event_initialize(__pyx_v_event, __pyx_v_anchor, __pyx_v_tag, __pyx_v_implicit, __pyx_v_sequence_style) == 0);

    /* "yaml/_yaml.pyx":1104
 *             if event_object.flow_style:
 *                 sequence_style = YAML_FLOW_SEQUENCE_STYLE
 *             if yaml_sequence_start_event_initialize(event, anchor, tag,             # <<<<<<<<<<<<<<
 *                     implicit, sequence_style) == 0:
 *                 raise MemoryError
 */
    if (unlikely(__pyx_t_2)) {

      /* "yaml/_yaml.pyx":1106
 *             if yaml_sequence_start_event_initialize(event, anchor, tag,
 *                     implicit, sequence_style) == 0:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 *         elif event_class is MappingStartEvent:
 *             anchor = NULL
 */
      PyErr_NoMemory(); __PYX_ERR(0, 1106, __pyx_L1_error)

      /* "yaml/_yaml.pyx":1104
 *             if event_object.flow_style:
 *                 sequence_style = YAML_FLOW_SEQUENCE_STYLE
 *             if yaml_sequence_start_event_initialize(event, anchor, tag,             # <<<<<<<<<<<<<<
 *                     implicit, sequence_style) == 0:
 *                 raise MemoryError
 */
    }

    /* "yaml/_yaml.pyx":1081
 *                     plain_implicit, quoted_implicit, scalar_style) == 0:
 *                 raise MemoryError
 *         elif event_class is SequenceStartEvent:             # <<<<<<<<<<<<<<
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":1107
 *                     implicit, sequence_style) == 0:
 *                 raise MemoryError
 *         elif event_class is MappingStartEvent:             # <<<<<<<<<<<<<<
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_MappingStartEvent); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = (__pyx_v_event_class == __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":1108
 *                 raise MemoryError
 *         elif event_class is MappingStartEvent:
 *             anchor = NULL             # <<<<<<<<<<<<<<
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:
 */
    __pyx_v_anchor = NULL;

    /* "yaml/_yaml.pyx":1109
 *         elif event_class is MappingStartEvent:
 *             anchor = NULL
 *             anchor_object = event_object.anchor             # <<<<<<<<<<<<<<
 *             if anchor_object is not None:
 *                 if PyUnicode_CheckExact(anchor_object):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_anchor); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1109, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_anchor_object = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":1110
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 */
    __pyx_t_2 = (__pyx_v_anchor_object != Py_None);
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1111
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:
 *                 if PyUnicode_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):
 */
      __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_anchor_object) != 0);
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1112
 *             if anchor_object is not None:
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)             # <<<<<<<<<<<<<<
 *                 if not PyBytes_CheckExact(anchor_object):
 *                     raise TypeError(u"anchor must be a string")
 */
        __pyx_t_4 = PyUnicode_AsUTF8String(__pyx_v_anchor_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1112, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF_SET(__pyx_v_anchor_object, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "yaml/_yaml.pyx":1111
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:
 *                 if PyUnicode_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):
 */
      }

      /* "yaml/_yaml.pyx":1113
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"anchor must be a string")
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 */
      __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_anchor_object) != 0));
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1114
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):
 *                     raise TypeError(u"anchor must be a string")             # <<<<<<<<<<<<<<
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             tag = NULL
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1114, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 1114, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1113
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *                 if not PyBytes_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"anchor must be a string")
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 */
      }

      /* "yaml/_yaml.pyx":1115
 *                 if not PyBytes_CheckExact(anchor_object):
 *                     raise TypeError(u"anchor must be a string")
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)             # <<<<<<<<<<<<<<
 *             tag = NULL
 *             tag_object = event_object.tag
 */
      __pyx_v_anchor = PyBytes_AS_Yaml_STRING(__pyx_v_anchor_object);

      /* "yaml/_yaml.pyx":1110
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 *             if anchor_object is not None:             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(anchor_object):
 *                     anchor_object = PyUnicode_AsUTF8String(anchor_object)
 */
    }

    /* "yaml/_yaml.pyx":1116
 *                     raise TypeError(u"anchor must be a string")
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             tag = NULL             # <<<<<<<<<<<<<<
 *             tag_object = event_object.tag
 *             if tag_object is not None:
 */
    __pyx_v_tag = NULL;

    /* "yaml/_yaml.pyx":1117
 *                 anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             tag = NULL
 *             tag_object = event_object.tag             # <<<<<<<<<<<<<<
 *             if tag_object is not None:
 *                 if PyUnicode_CheckExact(tag_object):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_tag); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_tag_object = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "yaml/_yaml.pyx":1118
 *             tag = NULL
 *             tag_object = event_object.tag
 *             if tag_object is not None:             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 */
    __pyx_t_2 = (__pyx_v_tag_object != Py_None);
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1119
 *             tag_object = event_object.tag
 *             if tag_object is not None:
 *                 if PyUnicode_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):
 */
      __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_tag_object) != 0);
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1120
 *             if tag_object is not None:
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)             # <<<<<<<<<<<<<<
 *                 if not PyBytes_CheckExact(tag_object):
 *                     raise TypeError(u"tag must be a string")
 */
        __pyx_t_4 = PyUnicode_AsUTF8String(__pyx_v_tag_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1120, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF_SET(__pyx_v_tag_object, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "yaml/_yaml.pyx":1119
 *             tag_object = event_object.tag
 *             if tag_object is not None:
 *                 if PyUnicode_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):
 */
      }

      /* "yaml/_yaml.pyx":1121
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"tag must be a string")
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 */
      __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_tag_object) != 0));
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1122
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):
 *                     raise TypeError(u"tag must be a string")             # <<<<<<<<<<<<<<
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 *             implicit = 0
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1122, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 1122, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1121
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"tag must be a string")
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 */
      }

      /* "yaml/_yaml.pyx":1123
 *                 if not PyBytes_CheckExact(tag_object):
 *                     raise TypeError(u"tag must be a string")
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)             # <<<<<<<<<<<<<<
 *             implicit = 0
 *             if event_object.implicit:
 */
      __pyx_v_tag = PyBytes_AS_Yaml_STRING(__pyx_v_tag_object);

      /* "yaml/_yaml.pyx":1118
 *             tag = NULL
 *             tag_object = event_object.tag
 *             if tag_object is not None:             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(tag_object):
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 */
    }

    /* "yaml/_yaml.pyx":1124
 *                     raise TypeError(u"tag must be a string")
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 *             implicit = 0             # <<<<<<<<<<<<<<
 *             if event_object.implicit:
 *                 implicit = 1
 */
    __pyx_v_implicit = 0;

    /* "yaml/_yaml.pyx":1125
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 *             implicit = 0
 *             if event_object.implicit:             # <<<<<<<<<<<<<<
 *                 implicit = 1
 *             mapping_style = YAML_BLOCK_MAPPING_STYLE
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_implicit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1125, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1126
 *             implicit = 0
 *             if event_object.implicit:
 *                 implicit = 1             # <<<<<<<<<<<<<<
 *             mapping_style = YAML_BLOCK_MAPPING_STYLE
 *             if event_object.flow_style:
 */
      __pyx_v_implicit = 1;

      /* "yaml/_yaml.pyx":1125
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 *             implicit = 0
 *             if event_object.implicit:             # <<<<<<<<<<<<<<
 *                 implicit = 1
 *             mapping_style = YAML_BLOCK_MAPPING_STYLE
 */
    }

    /* "yaml/_yaml.pyx":1127
 *             if event_object.implicit:
 *                 implicit = 1
 *             mapping_style = YAML_BLOCK_MAPPING_STYLE             # <<<<<<<<<<<<<<
 *             if event_object.flow_style:
 *                 mapping_style = YAML_FLOW_MAPPING_STYLE
 */
    __pyx_v_mapping_style = YAML_BLOCK_MAPPING_STYLE;

    /* "yaml/_yaml.pyx":1128
 *                 implicit = 1
 *             mapping_style = YAML_BLOCK_MAPPING_STYLE
 *             if event_object.flow_style:             # <<<<<<<<<<<<<<
 *                 mapping_style = YAML_FLOW_MAPPING_STYLE
 *             if yaml_mapping_start_event_initialize(event, anchor, tag,
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_event_object, __pyx_n_s_flow_style); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1128, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1128, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1129
 *             mapping_style = YAML_BLOCK_MAPPING_STYLE
 *             if event_object.flow_style:
 *                 mapping_style = YAML_FLOW_MAPPING_STYLE             # <<<<<<<<<<<<<<
 *             if yaml_mapping_start_event_initialize(event, anchor, tag,
 *                     implicit, mapping_style) == 0:
 */
      __pyx_v_mapping_style = YAML_FLOW_MAPPING_STYLE;

      /* "yaml/_yaml.pyx":1128
 *                 implicit = 1
 *             mapping_style = YAML_BLOCK_MAPPING_STYLE
 *             if event_object.flow_style:             # <<<<<<<<<<<<<<
 *                 mapping_style = YAML_FLOW_MAPPING_STYLE
 *             if yaml_mapping_start_event_initialize(event, anchor, tag,
 */
    }

    /* "yaml/_yaml.pyx":1131
 *                 mapping_style = YAML_FLOW_MAPPING_STYLE
 *             if yaml_mapping_start_event_initialize(event, anchor, tag,
 *                     implicit, mapping_style) == 0:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *         elif event_class is SequenceEndEvent:
 */
    __pyx_t_2 = (yaml_mapping_start_event_initialize(__pyx_v_event, __pyx_v_anchor, __pyx_v_tag, __pyx_v_implicit, __pyx_v_mapping_style) == 0);

    /* "yaml/_yaml.pyx":1130
 *             if event_object.flow_style:
 *                 mapping_style = YAML_FLOW_MAPPING_STYLE
 *             if yaml_mapping_start_event_initialize(event, anchor, tag,             # <<<<<<<<<<<<<<
 *                     implicit, mapping_style) == 0:
 *                 raise MemoryError
 */
    if (unlikely(__pyx_t_2)) {

      /* "yaml/_yaml.pyx":1132
 *             if yaml_mapping_start_event_initialize(event, anchor, tag,
 *                     implicit, mapping_style) == 0:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 *         elif event_class is SequenceEndEvent:
 *             yaml_sequence_end_event_initialize(event)
 */
      PyErr_NoMemory(); __PYX_ERR(0, 1132, __pyx_L1_error)

      /* "yaml/_yaml.pyx":1130
 *             if event_object.flow_style:
 *                 mapping_style = YAML_FLOW_MAPPING_STYLE
 *             if yaml_mapping_start_event_initialize(event, anchor, tag,             # <<<<<<<<<<<<<<
 *                     implicit, mapping_style) == 0:
 *                 raise MemoryError
 */
    }

    /* "yaml/_yaml.pyx":1107
 *                     implicit, sequence_style) == 0:
 *                 raise MemoryError
 *         elif event_class is MappingStartEvent:             # <<<<<<<<<<<<<<
 *             anchor = NULL
 *             anchor_object = event_object.anchor
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":1133
 *                     implicit, mapping_style) == 0:
 *                 raise MemoryError
 *         elif event_class is SequenceEndEvent:             # <<<<<<<<<<<<<<
 *             yaml_sequence_end_event_initialize(event)
 *         elif event_class is MappingEndEvent:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_SequenceEndEvent); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = (__pyx_v_event_class == __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":1134
 *                 raise MemoryError
 *         elif event_class is SequenceEndEvent:
 *             yaml_sequence_end_event_initialize(event)             # <<<<<<<<<<<<<<
 *         elif event_class is MappingEndEvent:
 *             yaml_mapping_end_event_initialize(event)
 */
    (void)(yaml_sequence_end_event_initialize(__pyx_v_event));

    /* "yaml/_yaml.pyx":1133
 *                     implicit, mapping_style) == 0:
 *                 raise MemoryError
 *         elif event_class is SequenceEndEvent:             # <<<<<<<<<<<<<<
 *             yaml_sequence_end_event_initialize(event)
 *         elif event_class is MappingEndEvent:
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":1135
 *         elif event_class is SequenceEndEvent:
 *             yaml_sequence_end_event_initialize(event)
 *         elif event_class is MappingEndEvent:             # <<<<<<<<<<<<<<
 *             yaml_mapping_end_event_initialize(event)
 *         else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_MappingEndEvent); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = (__pyx_v_event_class == __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (likely(__pyx_t_2)) {

    /* "yaml/_yaml.pyx":1136
 *             yaml_sequence_end_event_initialize(event)
 *         elif event_class is MappingEndEvent:
 *             yaml_mapping_end_event_initialize(event)             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError(u"invalid event %s" % event_object)
 */
    (void)(yaml_mapping_end_event_initialize(__pyx_v_event));

    /* "yaml/_yaml.pyx":1135
 *         elif event_class is SequenceEndEvent:
 *             yaml_sequence_end_event_initialize(event)
 *         elif event_class is MappingEndEvent:             # <<<<<<<<<<<<<<
 *             yaml_mapping_end_event_initialize(event)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":1138
 *             yaml_mapping_end_event_initialize(event)
 *         else:
 *             raise TypeError(u"invalid event %s" % event_object)             # <<<<<<<<<<<<<<
 *         return 1
 * 
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_invalid_event_s, __pyx_v_event_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_8, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __PYX_ERR(0, 1138, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "yaml/_yaml.pyx":1139
 *         else:
 *             raise TypeError(u"invalid event %s" % event_object)
 *         return 1             # <<<<<<<<<<<<<<
 * 
 *     def emit(self, event_object):
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":958
 *         raise ValueError(u"no emitter error")
 * 
 *     cdef int _object_to_event(self, object event_object, yaml_event_t *event) except 0:             # <<<<<<<<<<<<<<
 *         cdef yaml_encoding_t encoding
 *         cdef yaml_version_directive_t version_directive_value
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("yaml._yaml.CEmitter._object_to_event", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_event_class);
  __Pyx_XDECREF(__pyx_v_cache);
  __Pyx_XDECREF(__pyx_v_handle);
  __Pyx_XDECREF(__pyx_v_prefix);
  __Pyx_XDECREF(__pyx_v_anchor_object);
  __Pyx_XDECREF(__pyx_v_tag_object);
  __Pyx_XDECREF(__pyx_v_value_object);
  __Pyx_XDECREF(__pyx_v_style_object);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":1141
 *         return 1
 * 
 *     def emit(self, event_object):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         self._object_to_event(event_object, &event)
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_7emit(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_8CEmitter_7emit = {"emit", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_7emit, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_7emit(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_event_object = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("emit (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_event_object,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_event_object)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1141, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "emit") < 0)) __PYX_ERR(0, 1141, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_event_object = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("emit", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1141, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("yaml._yaml.CEmitter.emit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4yaml_5_yaml_8CEmitter_6emit(((struct __pyx_obj_4yaml_5_yaml_CEmitter *)__pyx_v_self), __pyx_v_event_object);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_6emit(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, PyObject *__pyx_v_event_object) {
  yaml_event_t __pyx_v_event;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("emit", 1);

  /* "yaml/_yaml.pyx":1143
 *     def emit(self, event_object):
 *         cdef yaml_event_t event
 *         self._object_to_event(event_object, &event)             # <<<<<<<<<<<<<<
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:
 *             error = self._emitter_error()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_object_to_event(__pyx_v_self, __pyx_v_event_object, (&__pyx_v_event)); if (unlikely(__pyx_t_1 == ((int)0))) __PYX_ERR(0, 1143, __pyx_L1_error)

  /* "yaml/_yaml.pyx":1144
 *         cdef yaml_event_t event
 *         self._object_to_event(event_object, &event)
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *             error = self._emitter_error()
 *             raise error
 */
  __pyx_t_1 = yaml_emitter_emit((&__pyx_v_self->emitter), (&__pyx_v_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1144, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 == 0);
  if (unlikely(__pyx_t_2)) {

    /* "yaml/_yaml.pyx":1145
 *         self._object_to_event(event_object, &event)
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:
 *             error = self._emitter_error()             # <<<<<<<<<<<<<<
 *             raise error
 * 
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_emitter_error(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1145, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_error = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "yaml/_yaml.pyx":1146
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:
 *             error = self._emitter_error()
 *             raise error             # <<<<<<<<<<<<<<
 * 
 *     def open(self):
 */
    __Pyx_Raise(__pyx_v_error, 0, 0, 0);
    __PYX_ERR(0, 1146, __pyx_L1_error)

    /* "yaml/_yaml.pyx":1144
 *         cdef yaml_event_t event
 *         self._object_to_event(event_object, &event)
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *             error = self._emitter_error()
 *             raise error
 */
  }

  /* "yaml/_yaml.pyx":1141
 *         return 1
 * 
 *     def emit(self, event_object):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         self._object_to_event(event_object, &event)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("yaml._yaml.CEmitter.emit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":1148
 *             raise error
 * 
 *     def open(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef yaml_encoding_t encoding
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_9open(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_8CEmitter_9open = {"open", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_9open, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_9open(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("open (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("open", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "open", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_8CEmitter_8open(((struct __pyx_obj_4yaml_5_yaml_CEmitter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_8open(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self) {
  yaml_event_t __pyx_v_event;
  yaml_encoding_t __pyx_v_encoding;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("open", 1);

  /* "yaml/_yaml.pyx":1151
 *         cdef yaml_event_t event
 *         cdef yaml_encoding_t encoding
 *         if self.closed == -1:             # <<<<<<<<<<<<<<
 *             if self.use_encoding == u'utf-16-le' or self.use_encoding == 'utf-16-le':
 *                 encoding = YAML_UTF16LE_ENCODING
 */
  switch (__pyx_v_self->closed) {
    case -1L:

    /* "yaml/_yaml.pyx":1152
 *         cdef yaml_encoding_t encoding
 *         if self.closed == -1:
 *             if self.use_encoding == u'utf-16-le' or self.use_encoding == 'utf-16-le':             # <<<<<<<<<<<<<<
 *                 encoding = YAML_UTF16LE_ENCODING
 *             elif self.use_encoding == u'utf-16-be' or self.use_encoding == 'utf-16-be':
 */
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_self->use_encoding, __pyx_kp_u_utf_16_le, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1152, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_v_self->use_encoding, __pyx_kp_s_utf_16_le, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1152, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_2;
    __pyx_L4_bool_binop_done:;
    if (__pyx_t_1) {

      /* "yaml/_yaml.pyx":1153
 *         if self.closed == -1:
 *             if self.use_encoding == u'utf-16-le' or self.use_encoding == 'utf-16-le':
 *                 encoding = YAML_UTF16LE_ENCODING             # <<<<<<<<<<<<<<
 *             elif self.use_encoding == u'utf-16-be' or self.use_encoding == 'utf-16-be':
 *                 encoding = YAML_UTF16BE_ENCODING
 */
      __pyx_v_encoding = YAML_UTF16LE_ENCODING;

      /* "yaml/_yaml.pyx":1152
 *         cdef yaml_encoding_t encoding
 *         if self.closed == -1:
 *             if self.use_encoding == u'utf-16-le' or self.use_encoding == 'utf-16-le':             # <<<<<<<<<<<<<<
 *                 encoding = YAML_UTF16LE_ENCODING
 *             elif self.use_encoding == u'utf-16-be' or self.use_encoding == 'utf-16-be':
 */
      goto __pyx_L3;
    }

    /* "yaml/_yaml.pyx":1154
 *             if self.use_encoding == u'utf-16-le' or self.use_encoding == 'utf-16-le':
 *                 encoding = YAML_UTF16LE_ENCODING
 *             elif self.use_encoding == u'utf-16-be' or self.use_encoding == 'utf-16-be':             # <<<<<<<<<<<<<<
 *                 encoding = YAML_UTF16BE_ENCODING
 *             else:
 */
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_self->use_encoding, __pyx_kp_u_utf_16_be, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1154, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_v_self->use_encoding, __pyx_kp_s_utf_16_be, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1154, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_2;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_1) {

      /* "yaml/_yaml.pyx":1155
 *                 encoding = YAML_UTF16LE_ENCODING
 *             elif self.use_encoding == u'utf-16-be' or self.use_encoding == 'utf-16-be':
 *                 encoding = YAML_UTF16BE_ENCODING             # <<<<<<<<<<<<<<
 *             else:
 *                 encoding = YAML_UTF8_ENCODING
 */
      __pyx_v_encoding = YAML_UTF16BE_ENCODING;

      /* "yaml/_yaml.pyx":1154
 *             if self.use_encoding == u'utf-16-le' or self.use_encoding == 'utf-16-le':
 *                 encoding = YAML_UTF16LE_ENCODING
 *             elif self.use_encoding == u'utf-16-be' or self.use_encoding == 'utf-16-be':             # <<<<<<<<<<<<<<
 *                 encoding = YAML_UTF16BE_ENCODING
 *             else:
 */
      goto __pyx_L3;
    }

    /* "yaml/_yaml.pyx":1157
 *                 encoding = YAML_UTF16BE_ENCODING
 *             else:
 *                 encoding = YAML_UTF8_ENCODING             # <<<<<<<<<<<<<<
 *             if self.use_encoding is None:
 *                 self.dump_unicode = 1
 */
    /*else*/ {
      __pyx_v_encoding = YAML_UTF8_ENCODING;
    }
    __pyx_L3:;

    /* "yaml/_yaml.pyx":1158
 *             else:
 *                 encoding = YAML_UTF8_ENCODING
 *             if self.use_encoding is None:             # <<<<<<<<<<<<<<
 *                 self.dump_unicode = 1
 *             if self.dump_unicode == 1:
 */
    __pyx_t_1 = (__pyx_v_self->use_encoding == Py_None);
    if (__pyx_t_1) {

      /* "yaml/_yaml.pyx":1159
 *                 encoding = YAML_UTF8_ENCODING
 *             if self.use_encoding is None:
 *                 self.dump_unicode = 1             # <<<<<<<<<<<<<<
 *             if self.dump_unicode == 1:
 *                 encoding = YAML_UTF8_ENCODING
 */
      __pyx_v_self->dump_unicode = 1;

      /* "yaml/_yaml.pyx":1158
 *             else:
 *                 encoding = YAML_UTF8_ENCODING
 *             if self.use_encoding is None:             # <<<<<<<<<<<<<<
 *                 self.dump_unicode = 1
 *             if self.dump_unicode == 1:
 */
    }

    /* "yaml/_yaml.pyx":1160
 *             if self.use_encoding is None:
 *                 self.dump_unicode = 1
 *             if self.dump_unicode == 1:             # <<<<<<<<<<<<<<
 *                 encoding = YAML_UTF8_ENCODING
 *             yaml_stream_start_event_initialize(&event, encoding)
 */
    __pyx_t_1 = (__pyx_v_self->dump_unicode == 1);
    if (__pyx_t_1) {

      /* "yaml/_yaml.pyx":1161
 *                 self.dump_unicode = 1
 *             if self.dump_unicode == 1:
 *                 encoding = YAML_UTF8_ENCODING             # <<<<<<<<<<<<<<
 *             yaml_stream_start_event_initialize(&event, encoding)
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:
 */
      __pyx_v_encoding = YAML_UTF8_ENCODING;

      /* "yaml/_yaml.pyx":1160
 *             if self.use_encoding is None:
 *                 self.dump_unicode = 1
 *             if self.dump_unicode == 1:             # <<<<<<<<<<<<<<
 *                 encoding = YAML_UTF8_ENCODING
 *             yaml_stream_start_event_initialize(&event, encoding)
 */
    }

    /* "yaml/_yaml.pyx":1162
 *             if self.dump_unicode == 1:
 *                 encoding = YAML_UTF8_ENCODING
 *             yaml_stream_start_event_initialize(&event, encoding)             # <<<<<<<<<<<<<<
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                 error = self._emitter_error()
 */
    (void)(yaml_stream_start_event_initialize((&__pyx_v_event), __pyx_v_encoding));

    /* "yaml/_yaml.pyx":1163
 *                 encoding = YAML_UTF8_ENCODING
 *             yaml_stream_start_event_initialize(&event, encoding)
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                 error = self._emitter_error()
 *                 raise error
 */
    __pyx_t_3 = yaml_emitter_emit((&__pyx_v_self->emitter), (&__pyx_v_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1163, __pyx_L1_error)
    __pyx_t_1 = (__pyx_t_3 == 0);
    if (unlikely(__pyx_t_1)) {

      /* "yaml/_yaml.pyx":1164
 *             yaml_stream_start_event_initialize(&event, encoding)
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                 error = self._emitter_error()             # <<<<<<<<<<<<<<
 *                 raise error
 *             self.closed = 0
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_emitter_error(__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_error = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "yaml/_yaml.pyx":1165
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                 error = self._emitter_error()
 *                 raise error             # <<<<<<<<<<<<<<
 *             self.closed = 0
 *         elif self.closed == 1:
 */
      __Pyx_Raise(__pyx_v_error, 0, 0, 0);
      __PYX_ERR(0, 1165, __pyx_L1_error)

      /* "yaml/_yaml.pyx":1163
 *                 encoding = YAML_UTF8_ENCODING
 *             yaml_stream_start_event_initialize(&event, encoding)
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                 error = self._emitter_error()
 *                 raise error
 */
    }

    /* "yaml/_yaml.pyx":1166
 *                 error = self._emitter_error()
 *                 raise error
 *             self.closed = 0             # <<<<<<<<<<<<<<
 *         elif self.closed == 1:
 *             raise SerializerError(u"serializer is closed")
 */
    __pyx_v_self->closed = 0;

    /* "yaml/_yaml.pyx":1151
 *         cdef yaml_event_t event
 *         cdef yaml_encoding_t encoding
 *         if self.closed == -1:             # <<<<<<<<<<<<<<
 *             if self.use_encoding == u'utf-16-le' or self.use_encoding == 'utf-16-le':
 *                 encoding = YAML_UTF16LE_ENCODING
 */
    break;
    case 1:

    /* "yaml/_yaml.pyx":1168
 *             self.closed = 0
 *         elif self.closed == 1:
 *             raise SerializerError(u"serializer is closed")             # <<<<<<<<<<<<<<
 *         else:
 *             raise SerializerError(u"serializer is already opened")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SerializerError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_3 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_3 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_kp_u_serializer_is_closed};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_3, 1+__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1168, __pyx_L1_error)

    /* "yaml/_yaml.pyx":1167
 *                 raise error
 *             self.closed = 0
 *         elif self.closed == 1:             # <<<<<<<<<<<<<<
 *             raise SerializerError(u"serializer is closed")
 *         else:
 */
    break;
    default:

    /* "yaml/_yaml.pyx":1170
 *             raise SerializerError(u"serializer is closed")
 *         else:
 *             raise SerializerError(u"serializer is already opened")             # <<<<<<<<<<<<<<
 * 
 *     def close(self):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SerializerError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1170, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_3 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_3 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_kp_u_serializer_is_already_opened};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_3, 1+__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 1170, __pyx_L1_error)
    break;
  }

  /* "yaml/_yaml.pyx":1148
 *             raise error
 * 
 *     def open(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef yaml_encoding_t encoding
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("yaml._yaml.CEmitter.open", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":1172
 *             raise SerializerError(u"serializer is already opened")
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         if self.closed == -1:
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_11close(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_8CEmitter_11close = {"close", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_11close, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_11close(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("close", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "close", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_8CEmitter_10close(((struct __pyx_obj_4yaml_5_yaml_CEmitter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_10close(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self) {
  yaml_event_t __pyx_v_event;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("close", 1);

  /* "yaml/_yaml.pyx":1174
 *     def close(self):
 *         cdef yaml_event_t event
 *         if self.closed == -1:             # <<<<<<<<<<<<<<
 *             raise SerializerError(u"serializer is not opened")
 *         elif self.closed == 0:
 */
  switch (__pyx_v_self->closed) {
    case -1L:

    /* "yaml/_yaml.pyx":1175
 *         cdef yaml_event_t event
 *         if self.closed == -1:
 *             raise SerializerError(u"serializer is not opened")             # <<<<<<<<<<<<<<
 *         elif self.closed == 0:
 *             yaml_stream_end_event_initialize(&event)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_SerializerError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1175, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_u_serializer_is_not_opened};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1175, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1175, __pyx_L1_error)

    /* "yaml/_yaml.pyx":1174
 *     def close(self):
 *         cdef yaml_event_t event
 *         if self.closed == -1:             # <<<<<<<<<<<<<<
 *             raise SerializerError(u"serializer is not opened")
 *         elif self.closed == 0:
 */
    break;
    case 0:

    /* "yaml/_yaml.pyx":1177
 *             raise SerializerError(u"serializer is not opened")
 *         elif self.closed == 0:
 *             yaml_stream_end_event_initialize(&event)             # <<<<<<<<<<<<<<
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                 error = self._emitter_error()
 */
    (void)(yaml_stream_end_event_initialize((&__pyx_v_event)));

    /* "yaml/_yaml.pyx":1178
 *         elif self.closed == 0:
 *             yaml_stream_end_event_initialize(&event)
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                 error = self._emitter_error()
 *                 raise error
 */
    __pyx_t_4 = yaml_emitter_emit((&__pyx_v_self->emitter), (&__pyx_v_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1178, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_4 == 0);
    if (unlikely(__pyx_t_5)) {

      /* "yaml/_yaml.pyx":1179
 *             yaml_stream_end_event_initialize(&event)
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                 error = self._emitter_error()             # <<<<<<<<<<<<<<
 *                 raise error
 *             self.closed = 1
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_emitter_error(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1179, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_error = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "yaml/_yaml.pyx":1180
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                 error = self._emitter_error()
 *                 raise error             # <<<<<<<<<<<<<<
 *             self.closed = 1
 * 
 */
      __Pyx_Raise(__pyx_v_error, 0, 0, 0);
      __PYX_ERR(0, 1180, __pyx_L1_error)

      /* "yaml/_yaml.pyx":1178
 *         elif self.closed == 0:
 *             yaml_stream_end_event_initialize(&event)
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                 error = self._emitter_error()
 *                 raise error
 */
    }

    /* "yaml/_yaml.pyx":1181
 *                 error = self._emitter_error()
 *                 raise error
 *             self.closed = 1             # <<<<<<<<<<<<<<
 * 
 *     def serialize(self, node):
 */
    __pyx_v_self->closed = 1;

    /* "yaml/_yaml.pyx":1176
 *         if self.closed == -1:
 *             raise SerializerError(u"serializer is not opened")
 *         elif self.closed == 0:             # <<<<<<<<<<<<<<
 *             yaml_stream_end_event_initialize(&event)
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:
 */
    break;
    default: break;
  }

  /* "yaml/_yaml.pyx":1172
 *             raise SerializerError(u"serializer is already opened")
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         if self.closed == -1:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("yaml._yaml.CEmitter.close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":1183
 *             self.closed = 1
 * 
 *     def serialize(self, node):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef yaml_version_directive_t version_directive_value
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_13serialize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_8CEmitter_13serialize = {"serialize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_13serialize, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_13serialize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_node = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("serialize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_node,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_node)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1183, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "serialize") < 0)) __PYX_ERR(0, 1183, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_node = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("serialize", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 1183, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("yaml._yaml.CEmitter.serialize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4yaml_5_yaml_8CEmitter_12serialize(((struct __pyx_obj_4yaml_5_yaml_CEmitter *)__pyx_v_self), __pyx_v_node);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_12serialize(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, PyObject *__pyx_v_node) {
  yaml_event_t __pyx_v_event;
  yaml_version_directive_t __pyx_v_version_directive_value;
  yaml_version_directive_t *__pyx_v_version_directive;
  yaml_tag_directive_t __pyx_v_tag_directives_value[0x80];
  yaml_tag_directive_t *__pyx_v_tag_directives_start;
  yaml_tag_directive_t *__pyx_v_tag_directives_end;
  PyObject *__pyx_v_cache = NULL;
  PyObject *__pyx_v_handle = NULL;
  PyObject *__pyx_v_prefix = NULL;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("serialize", 1);

  /* "yaml/_yaml.pyx":1190
 *         cdef yaml_tag_directive_t *tag_directives_start
 *         cdef yaml_tag_directive_t *tag_directives_end
 *         if self.closed == -1:             # <<<<<<<<<<<<<<
 *             raise SerializerError(u"serializer is not opened")
 *         elif self.closed == 1:
 */
  switch (__pyx_v_self->closed) {
    case -1L:

    /* "yaml/_yaml.pyx":1191
 *         cdef yaml_tag_directive_t *tag_directives_end
 *         if self.closed == -1:
 *             raise SerializerError(u"serializer is not opened")             # <<<<<<<<<<<<<<
 *         elif self.closed == 1:
 *             raise SerializerError(u"serializer is closed")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_SerializerError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_u_serializer_is_not_opened};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1191, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1191, __pyx_L1_error)

    /* "yaml/_yaml.pyx":1190
 *         cdef yaml_tag_directive_t *tag_directives_start
 *         cdef yaml_tag_directive_t *tag_directives_end
 *         if self.closed == -1:             # <<<<<<<<<<<<<<
 *             raise SerializerError(u"serializer is not opened")
 *         elif self.closed == 1:
 */
    break;
    case 1:

    /* "yaml/_yaml.pyx":1193
 *             raise SerializerError(u"serializer is not opened")
 *         elif self.closed == 1:
 *             raise SerializerError(u"serializer is closed")             # <<<<<<<<<<<<<<
 *         cache = []
 *         version_directive = NULL
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_SerializerError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_u_serializer_is_closed};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1193, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 1193, __pyx_L1_error)

    /* "yaml/_yaml.pyx":1192
 *         if self.closed == -1:
 *             raise SerializerError(u"serializer is not opened")
 *         elif self.closed == 1:             # <<<<<<<<<<<<<<
 *             raise SerializerError(u"serializer is closed")
 *         cache = []
 */
    break;
    default: break;
  }

  /* "yaml/_yaml.pyx":1194
 *         elif self.closed == 1:
 *             raise SerializerError(u"serializer is closed")
 *         cache = []             # <<<<<<<<<<<<<<
 *         version_directive = NULL
 *         if self.use_version:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_cache = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "yaml/_yaml.pyx":1195
 *             raise SerializerError(u"serializer is closed")
 *         cache = []
 *         version_directive = NULL             # <<<<<<<<<<<<<<
 *         if self.use_version:
 *             version_directive_value.major = self.use_version[0]
 */
  __pyx_v_version_directive = NULL;

  /* "yaml/_yaml.pyx":1196
 *         cache = []
 *         version_directive = NULL
 *         if self.use_version:             # <<<<<<<<<<<<<<
 *             version_directive_value.major = self.use_version[0]
 *             version_directive_value.minor = self.use_version[1]
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->use_version); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1196, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "yaml/_yaml.pyx":1197
 *         version_directive = NULL
 *         if self.use_version:
 *             version_directive_value.major = self.use_version[0]             # <<<<<<<<<<<<<<
 *             version_directive_value.minor = self.use_version[1]
 *             version_directive = &version_directive_value
 */
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_self->use_version, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1197, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_version_directive_value.major = __pyx_t_4;

    /* "yaml/_yaml.pyx":1198
 *         if self.use_version:
 *             version_directive_value.major = self.use_version[0]
 *             version_directive_value.minor = self.use_version[1]             # <<<<<<<<<<<<<<
 *             version_directive = &version_directive_value
 *         tag_directives_start = NULL
 */
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_self->use_version, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 1198, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_version_directive_value.minor = __pyx_t_4;

    /* "yaml/_yaml.pyx":1199
 *             version_directive_value.major = self.use_version[0]
 *             version_directive_value.minor = self.use_version[1]
 *             version_directive = &version_directive_value             # <<<<<<<<<<<<<<
 *         tag_directives_start = NULL
 *         tag_directives_end = NULL
 */
    __pyx_v_version_directive = (&__pyx_v_version_directive_value);

    /* "yaml/_yaml.pyx":1196
 *         cache = []
 *         version_directive = NULL
 *         if self.use_version:             # <<<<<<<<<<<<<<
 *             version_directive_value.major = self.use_version[0]
 *             version_directive_value.minor = self.use_version[1]
 */
  }

  /* "yaml/_yaml.pyx":1200
 *             version_directive_value.minor = self.use_version[1]
 *             version_directive = &version_directive_value
 *         tag_directives_start = NULL             # <<<<<<<<<<<<<<
 *         tag_directives_end = NULL
 *         if self.use_tags:
 */
  __pyx_v_tag_directives_start = NULL;

  /* "yaml/_yaml.pyx":1201
 *             version_directive = &version_directive_value
 *         tag_directives_start = NULL
 *         tag_directives_end = NULL             # <<<<<<<<<<<<<<
 *         if self.use_tags:
 *             if len(self.use_tags) > 128:
 */
  __pyx_v_tag_directives_end = NULL;

  /* "yaml/_yaml.pyx":1202
 *         tag_directives_start = NULL
 *         tag_directives_end = NULL
 *         if self.use_tags:             # <<<<<<<<<<<<<<
 *             if len(self.use_tags) > 128:
 *                 raise ValueError(u"too many tags")
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_self->use_tags); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 1202, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "yaml/_yaml.pyx":1203
 *         tag_directives_end = NULL
 *         if self.use_tags:
 *             if len(self.use_tags) > 128:             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"too many tags")
 *             tag_directives_start = tag_directives_value
 */
    __pyx_t_1 = __pyx_v_self->use_tags;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_6 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1203, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = (__pyx_t_6 > 0x80);
    if (unlikely(__pyx_t_5)) {

      /* "yaml/_yaml.pyx":1204
 *         if self.use_tags:
 *             if len(self.use_tags) > 128:
 *                 raise ValueError(u"too many tags")             # <<<<<<<<<<<<<<
 *             tag_directives_start = tag_directives_value
 *             tag_directives_end = tag_directives_value
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 1204, __pyx_L1_error)

      /* "yaml/_yaml.pyx":1203
 *         tag_directives_end = NULL
 *         if self.use_tags:
 *             if len(self.use_tags) > 128:             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"too many tags")
 *             tag_directives_start = tag_directives_value
 */
    }

    /* "yaml/_yaml.pyx":1205
 *             if len(self.use_tags) > 128:
 *                 raise ValueError(u"too many tags")
 *             tag_directives_start = tag_directives_value             # <<<<<<<<<<<<<<
 *             tag_directives_end = tag_directives_value
 *             for handle in self.use_tags:
 */
    __pyx_v_tag_directives_start = __pyx_v_tag_directives_value;

    /* "yaml/_yaml.pyx":1206
 *                 raise ValueError(u"too many tags")
 *             tag_directives_start = tag_directives_value
 *             tag_directives_end = tag_directives_value             # <<<<<<<<<<<<<<
 *             for handle in self.use_tags:
 *                 prefix = self.use_tags[handle]
 */
    __pyx_v_tag_directives_end = __pyx_v_tag_directives_value;

    /* "yaml/_yaml.pyx":1207
 *             tag_directives_start = tag_directives_value
 *             tag_directives_end = tag_directives_value
 *             for handle in self.use_tags:             # <<<<<<<<<<<<<<
 *                 prefix = self.use_tags[handle]
 *                 if PyUnicode_CheckExact(handle):
 */
    if (likely(PyList_CheckExact(__pyx_v_self->use_tags)) || PyTuple_CheckExact(__pyx_v_self->use_tags)) {
      __pyx_t_1 = __pyx_v_self->use_tags; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_self->use_tags); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1207, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1207, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1207, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1207, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1207, __pyx_L1_error)
            #endif
            if (__pyx_t_6 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(0, 1207, __pyx_L1_error)
          #else
          __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1207, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_7(__pyx_t_1);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 1207, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_handle, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "yaml/_yaml.pyx":1208
 *             tag_directives_end = tag_directives_value
 *             for handle in self.use_tags:
 *                 prefix = self.use_tags[handle]             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(handle):
 *                     handle = PyUnicode_AsUTF8String(handle)
 */
      __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_self->use_tags, __pyx_v_handle); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_prefix, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "yaml/_yaml.pyx":1209
 *             for handle in self.use_tags:
 *                 prefix = self.use_tags[handle]
 *                 if PyUnicode_CheckExact(handle):             # <<<<<<<<<<<<<<
 *                     handle = PyUnicode_AsUTF8String(handle)
 *                     cache.append(handle)
 */
      __pyx_t_5 = (PyUnicode_CheckExact(__pyx_v_handle) != 0);
      if (__pyx_t_5) {

        /* "yaml/_yaml.pyx":1210
 *                 prefix = self.use_tags[handle]
 *                 if PyUnicode_CheckExact(handle):
 *                     handle = PyUnicode_AsUTF8String(handle)             # <<<<<<<<<<<<<<
 *                     cache.append(handle)
 *                 if not PyBytes_CheckExact(handle):
 */
        __pyx_t_2 = PyUnicode_AsUTF8String(__pyx_v_handle); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1210, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF_SET(__pyx_v_handle, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "yaml/_yaml.pyx":1211
 *                 if PyUnicode_CheckExact(handle):
 *                     handle = PyUnicode_AsUTF8String(handle)
 *                     cache.append(handle)             # <<<<<<<<<<<<<<
 *                 if not PyBytes_CheckExact(handle):
 *                     raise TypeError(u"tag handle must be a string")
 */
        __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_cache, __pyx_v_handle); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1211, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1209
 *             for handle in self.use_tags:
 *                 prefix = self.use_tags[handle]
 *                 if PyUnicode_CheckExact(handle):             # <<<<<<<<<<<<<<
 *                     handle = PyUnicode_AsUTF8String(handle)
 *                     cache.append(handle)
 */
      }

      /* "yaml/_yaml.pyx":1212
 *                     handle = PyUnicode_AsUTF8String(handle)
 *                     cache.append(handle)
 *                 if not PyBytes_CheckExact(handle):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"tag handle must be a string")
 *                 tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)
 */
      __pyx_t_5 = (!(PyBytes_CheckExact(__pyx_v_handle) != 0));
      if (unlikely(__pyx_t_5)) {

        /* "yaml/_yaml.pyx":1213
 *                     cache.append(handle)
 *                 if not PyBytes_CheckExact(handle):
 *                     raise TypeError(u"tag handle must be a string")             # <<<<<<<<<<<<<<
 *                 tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)
 *                 if PyUnicode_CheckExact(prefix):
 */
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1213, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(0, 1213, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1212
 *                     handle = PyUnicode_AsUTF8String(handle)
 *                     cache.append(handle)
 *                 if not PyBytes_CheckExact(handle):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"tag handle must be a string")
 *                 tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)
 */
      }

      /* "yaml/_yaml.pyx":1214
 *                 if not PyBytes_CheckExact(handle):
 *                     raise TypeError(u"tag handle must be a string")
 *                 tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(prefix):
 *                     prefix = PyUnicode_AsUTF8String(prefix)
 */
      __pyx_v_tag_directives_end->handle = PyBytes_AS_Yaml_STRING(__pyx_v_handle);

      /* "yaml/_yaml.pyx":1215
 *                     raise TypeError(u"tag handle must be a string")
 *                 tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)
 *                 if PyUnicode_CheckExact(prefix):             # <<<<<<<<<<<<<<
 *                     prefix = PyUnicode_AsUTF8String(prefix)
 *                     cache.append(prefix)
 */
      __pyx_t_5 = (PyUnicode_CheckExact(__pyx_v_prefix) != 0);
      if (__pyx_t_5) {

        /* "yaml/_yaml.pyx":1216
 *                 tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)
 *                 if PyUnicode_CheckExact(prefix):
 *                     prefix = PyUnicode_AsUTF8String(prefix)             # <<<<<<<<<<<<<<
 *                     cache.append(prefix)
 *                 if not PyBytes_CheckExact(prefix):
 */
        __pyx_t_2 = PyUnicode_AsUTF8String(__pyx_v_prefix); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1216, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF_SET(__pyx_v_prefix, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "yaml/_yaml.pyx":1217
 *                 if PyUnicode_CheckExact(prefix):
 *                     prefix = PyUnicode_AsUTF8String(prefix)
 *                     cache.append(prefix)             # <<<<<<<<<<<<<<
 *                 if not PyBytes_CheckExact(prefix):
 *                     raise TypeError(u"tag prefix must be a string")
 */
        __pyx_t_8 = __Pyx_PyList_Append(__pyx_v_cache, __pyx_v_prefix); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 1217, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1215
 *                     raise TypeError(u"tag handle must be a string")
 *                 tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)
 *                 if PyUnicode_CheckExact(prefix):             # <<<<<<<<<<<<<<
 *                     prefix = PyUnicode_AsUTF8String(prefix)
 *                     cache.append(prefix)
 */
      }

      /* "yaml/_yaml.pyx":1218
 *                     prefix = PyUnicode_AsUTF8String(prefix)
 *                     cache.append(prefix)
 *                 if not PyBytes_CheckExact(prefix):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"tag prefix must be a string")
 *                 tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)
 */
      __pyx_t_5 = (!(PyBytes_CheckExact(__pyx_v_prefix) != 0));
      if (unlikely(__pyx_t_5)) {

        /* "yaml/_yaml.pyx":1219
 *                     cache.append(prefix)
 *                 if not PyBytes_CheckExact(prefix):
 *                     raise TypeError(u"tag prefix must be a string")             # <<<<<<<<<<<<<<
 *                 tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)
 *                 tag_directives_end = tag_directives_end+1
 */
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1219, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(0, 1219, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1218
 *                     prefix = PyUnicode_AsUTF8String(prefix)
 *                     cache.append(prefix)
 *                 if not PyBytes_CheckExact(prefix):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"tag prefix must be a string")
 *                 tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)
 */
      }

      /* "yaml/_yaml.pyx":1220
 *                 if not PyBytes_CheckExact(prefix):
 *                     raise TypeError(u"tag prefix must be a string")
 *                 tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)             # <<<<<<<<<<<<<<
 *                 tag_directives_end = tag_directives_end+1
 *         if yaml_document_start_event_initialize(&event, version_directive,
 */
      __pyx_v_tag_directives_end->prefix = PyBytes_AS_Yaml_STRING(__pyx_v_prefix);

      /* "yaml/_yaml.pyx":1221
 *                     raise TypeError(u"tag prefix must be a string")
 *                 tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)
 *                 tag_directives_end = tag_directives_end+1             # <<<<<<<<<<<<<<
 *         if yaml_document_start_event_initialize(&event, version_directive,
 *                 tag_directives_start, tag_directives_end,
 */
      __pyx_v_tag_directives_end = (__pyx_v_tag_directives_end + 1);

      /* "yaml/_yaml.pyx":1207
 *             tag_directives_start = tag_directives_value
 *             tag_directives_end = tag_directives_value
 *             for handle in self.use_tags:             # <<<<<<<<<<<<<<
 *                 prefix = self.use_tags[handle]
 *                 if PyUnicode_CheckExact(handle):
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "yaml/_yaml.pyx":1202
 *         tag_directives_start = NULL
 *         tag_directives_end = NULL
 *         if self.use_tags:             # <<<<<<<<<<<<<<
 *             if len(self.use_tags) > 128:
 *                 raise ValueError(u"too many tags")
 */
  }

  /* "yaml/_yaml.pyx":1224
 *         if yaml_document_start_event_initialize(&event, version_directive,
 *                 tag_directives_start, tag_directives_end,
 *                 self.document_start_implicit) == 0:             # <<<<<<<<<<<<<<
 *             raise MemoryError
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:
 */
  __pyx_t_5 = (yaml_document_start_event_initialize((&__pyx_v_event), __pyx_v_version_directive, __pyx_v_tag_directives_start, __pyx_v_tag_directives_end, __pyx_v_self->document_start_implicit) == 0);

  /* "yaml/_yaml.pyx":1222
 *                 tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)
 *                 tag_directives_end = tag_directives_end+1
 *         if yaml_document_start_event_initialize(&event, version_directive,             # <<<<<<<<<<<<<<
 *                 tag_directives_start, tag_directives_end,
 *                 self.document_start_implicit) == 0:
 */
  if (unlikely(__pyx_t_5)) {

    /* "yaml/_yaml.pyx":1225
 *                 tag_directives_start, tag_directives_end,
 *                 self.document_start_implicit) == 0:
 *             raise MemoryError             # <<<<<<<<<<<<<<
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:
 *             error = self._emitter_error()
 */
    PyErr_NoMemory(); __PYX_ERR(0, 1225, __pyx_L1_error)

    /* "yaml/_yaml.pyx":1222
 *                 tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)
 *                 tag_directives_end = tag_directives_end+1
 *         if yaml_document_start_event_initialize(&event, version_directive,             # <<<<<<<<<<<<<<
 *                 tag_directives_start, tag_directives_end,
 *                 self.document_start_implicit) == 0:
 */
  }

  /* "yaml/_yaml.pyx":1226
 *                 self.document_start_implicit) == 0:
 *             raise MemoryError
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *             error = self._emitter_error()
 *             raise error
 */
  __pyx_t_4 = yaml_emitter_emit((&__pyx_v_self->emitter), (&__pyx_v_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1226, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 == 0);
  if (unlikely(__pyx_t_5)) {

    /* "yaml/_yaml.pyx":1227
 *             raise MemoryError
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:
 *             error = self._emitter_error()             # <<<<<<<<<<<<<<
 *             raise error
 *         self._anchor_node(node)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_emitter_error(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_error = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "yaml/_yaml.pyx":1228
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:
 *             error = self._emitter_error()
 *             raise error             # <<<<<<<<<<<<<<
 *         self._anchor_node(node)
 *         self._serialize_node(node, None, None)
 */
    __Pyx_Raise(__pyx_v_error, 0, 0, 0);
    __PYX_ERR(0, 1228, __pyx_L1_error)

    /* "yaml/_yaml.pyx":1226
 *                 self.document_start_implicit) == 0:
 *             raise MemoryError
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *             error = self._emitter_error()
 *             raise error
 */
  }

  /* "yaml/_yaml.pyx":1229
 *             error = self._emitter_error()
 *             raise error
 *         self._anchor_node(node)             # <<<<<<<<<<<<<<
 *         self._serialize_node(node, None, None)
 *         yaml_document_end_event_initialize(&event, self.document_end_implicit)
 */
  __pyx_t_4 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_anchor_node(__pyx_v_self, __pyx_v_node); if (unlikely(__pyx_t_4 == ((int)0))) __PYX_ERR(0, 1229, __pyx_L1_error)

  /* "yaml/_yaml.pyx":1230
 *             raise error
 *         self._anchor_node(node)
 *         self._serialize_node(node, None, None)             # <<<<<<<<<<<<<<
 *         yaml_document_end_event_initialize(&event, self.document_end_implicit)
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:
 */
  __pyx_t_4 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_serialize_node(__pyx_v_self, __pyx_v_node, Py_None, Py_None); if (unlikely(__pyx_t_4 == ((int)0))) __PYX_ERR(0, 1230, __pyx_L1_error)

  /* "yaml/_yaml.pyx":1231
 *         self._anchor_node(node)
 *         self._serialize_node(node, None, None)
 *         yaml_document_end_event_initialize(&event, self.document_end_implicit)             # <<<<<<<<<<<<<<
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:
 *             error = self._emitter_error()
 */
  (void)(yaml_document_end_event_initialize((&__pyx_v_event), __pyx_v_self->document_end_implicit));

  /* "yaml/_yaml.pyx":1232
 *         self._serialize_node(node, None, None)
 *         yaml_document_end_event_initialize(&event, self.document_end_implicit)
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *             error = self._emitter_error()
 *             raise error
 */
  __pyx_t_4 = yaml_emitter_emit((&__pyx_v_self->emitter), (&__pyx_v_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1232, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 == 0);
  if (unlikely(__pyx_t_5)) {

    /* "yaml/_yaml.pyx":1233
 *         yaml_document_end_event_initialize(&event, self.document_end_implicit)
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:
 *             error = self._emitter_error()             # <<<<<<<<<<<<<<
 *             raise error
 *         self.serialized_nodes = {}
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_emitter_error(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_error = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "yaml/_yaml.pyx":1234
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:
 *             error = self._emitter_error()
 *             raise error             # <<<<<<<<<<<<<<
 *         self.serialized_nodes = {}
 *         self.anchors = {}
 */
    __Pyx_Raise(__pyx_v_error, 0, 0, 0);
    __PYX_ERR(0, 1234, __pyx_L1_error)

    /* "yaml/_yaml.pyx":1232
 *         self._serialize_node(node, None, None)
 *         yaml_document_end_event_initialize(&event, self.document_end_implicit)
 *         if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *             error = self._emitter_error()
 *             raise error
 */
  }

  /* "yaml/_yaml.pyx":1235
 *             error = self._emitter_error()
 *             raise error
 *         self.serialized_nodes = {}             # <<<<<<<<<<<<<<
 *         self.anchors = {}
 *         self.last_alias_id = 0
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->serialized_nodes);
  __Pyx_DECREF(__pyx_v_self->serialized_nodes);
  __pyx_v_self->serialized_nodes = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "yaml/_yaml.pyx":1236
 *             raise error
 *         self.serialized_nodes = {}
 *         self.anchors = {}             # <<<<<<<<<<<<<<
 *         self.last_alias_id = 0
 * 
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->anchors);
  __Pyx_DECREF(__pyx_v_self->anchors);
  __pyx_v_self->anchors = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "yaml/_yaml.pyx":1237
 *         self.serialized_nodes = {}
 *         self.anchors = {}
 *         self.last_alias_id = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef int _anchor_node(self, object node) except 0:
 */
  __pyx_v_self->last_alias_id = 0;

  /* "yaml/_yaml.pyx":1183
 *             self.closed = 1
 * 
 *     def serialize(self, node):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef yaml_version_directive_t version_directive_value
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("yaml._yaml.CEmitter.serialize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cache);
  __Pyx_XDECREF(__pyx_v_handle);
  __Pyx_XDECREF(__pyx_v_prefix);
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":1239
 *         self.last_alias_id = 0
 * 
 *     cdef int _anchor_node(self, object node) except 0:             # <<<<<<<<<<<<<<
 *         if node in self.anchors:
 *             if self.anchors[node] is None:
 */

static int __pyx_f_4yaml_5_yaml_8CEmitter__anchor_node(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, PyObject *__pyx_v_node) {
  PyObject *__pyx_v_node_class = NULL;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_value = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_anchor_node", 1);

  /* "yaml/_yaml.pyx":1240
 * 
 *     cdef int _anchor_node(self, object node) except 0:
 *         if node in self.anchors:             # <<<<<<<<<<<<<<
 *             if self.anchors[node] is None:
 *                 self.last_alias_id = self.last_alias_id+1
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_node, __pyx_v_self->anchors, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(0, 1240, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "yaml/_yaml.pyx":1241
 *     cdef int _anchor_node(self, object node) except 0:
 *         if node in self.anchors:
 *             if self.anchors[node] is None:             # <<<<<<<<<<<<<<
 *                 self.last_alias_id = self.last_alias_id+1
 *                 self.anchors[node] = u"id%03d" % self.last_alias_id
 */
    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_self->anchors, __pyx_v_node); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = (__pyx_t_2 == Py_None);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "yaml/_yaml.pyx":1242
 *         if node in self.anchors:
 *             if self.anchors[node] is None:
 *                 self.last_alias_id = self.last_alias_id+1             # <<<<<<<<<<<<<<
 *                 self.anchors[node] = u"id%03d" % self.last_alias_id
 *         else:
 */
      __pyx_v_self->last_alias_id = (__pyx_v_self->last_alias_id + 1);

      /* "yaml/_yaml.pyx":1243
 *             if self.anchors[node] is None:
 *                 self.last_alias_id = self.last_alias_id+1
 *                 self.anchors[node] = u"id%03d" % self.last_alias_id             # <<<<<<<<<<<<<<
 *         else:
 *             self.anchors[node] = None
 */
      __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->last_alias_id); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1243, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_id_03d, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1243, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely((PyObject_SetItem(__pyx_v_self->anchors, __pyx_v_node, __pyx_t_3) < 0))) __PYX_ERR(0, 1243, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "yaml/_yaml.pyx":1241
 *     cdef int _anchor_node(self, object node) except 0:
 *         if node in self.anchors:
 *             if self.anchors[node] is None:             # <<<<<<<<<<<<<<
 *                 self.last_alias_id = self.last_alias_id+1
 *                 self.anchors[node] = u"id%03d" % self.last_alias_id
 */
    }

    /* "yaml/_yaml.pyx":1240
 * 
 *     cdef int _anchor_node(self, object node) except 0:
 *         if node in self.anchors:             # <<<<<<<<<<<<<<
 *             if self.anchors[node] is None:
 *                 self.last_alias_id = self.last_alias_id+1
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":1245
 *                 self.anchors[node] = u"id%03d" % self.last_alias_id
 *         else:
 *             self.anchors[node] = None             # <<<<<<<<<<<<<<
 *             node_class = node.__class__
 *             if node_class is SequenceNode:
 */
  /*else*/ {
    if (unlikely((PyObject_SetItem(__pyx_v_self->anchors, __pyx_v_node, Py_None) < 0))) __PYX_ERR(0, 1245, __pyx_L1_error)

    /* "yaml/_yaml.pyx":1246
 *         else:
 *             self.anchors[node] = None
 *             node_class = node.__class__             # <<<<<<<<<<<<<<
 *             if node_class is SequenceNode:
 *                 for item in node.value:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_node_class = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "yaml/_yaml.pyx":1247
 *             self.anchors[node] = None
 *             node_class = node.__class__
 *             if node_class is SequenceNode:             # <<<<<<<<<<<<<<
 *                 for item in node.value:
 *                     self._anchor_node(item)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_SequenceNode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = (__pyx_v_node_class == __pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_1) {

      /* "yaml/_yaml.pyx":1248
 *             node_class = node.__class__
 *             if node_class is SequenceNode:
 *                 for item in node.value:             # <<<<<<<<<<<<<<
 *                     self._anchor_node(item)
 *             elif node_class is MappingNode:
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
        __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2);
        __pyx_t_4 = 0;
        __pyx_t_5 = NULL;
      } else {
        __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1248, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1248, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      for (;;) {
        if (likely(!__pyx_t_5)) {
          if (likely(PyList_CheckExact(__pyx_t_2))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1248, __pyx_L1_error)
              #endif
              if (__pyx_t_4 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 1248, __pyx_L1_error)
            #else
            __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1248, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1248, __pyx_L1_error)
              #endif
              if (__pyx_t_4 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 1248, __pyx_L1_error)
            #else
            __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1248, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            #endif
          }
        } else {
          __pyx_t_3 = __pyx_t_5(__pyx_t_2);
          if (unlikely(!__pyx_t_3)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1248, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "yaml/_yaml.pyx":1249
 *             if node_class is SequenceNode:
 *                 for item in node.value:
 *                     self._anchor_node(item)             # <<<<<<<<<<<<<<
 *             elif node_class is MappingNode:
 *                 for key, value in node.value:
 */
        __pyx_t_6 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_anchor_node(__pyx_v_self, __pyx_v_item); if (unlikely(__pyx_t_6 == ((int)0))) __PYX_ERR(0, 1249, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1248
 *             node_class = node.__class__
 *             if node_class is SequenceNode:
 *                 for item in node.value:             # <<<<<<<<<<<<<<
 *                     self._anchor_node(item)
 *             elif node_class is MappingNode:
 */
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "yaml/_yaml.pyx":1247
 *             self.anchors[node] = None
 *             node_class = node.__class__
 *             if node_class is SequenceNode:             # <<<<<<<<<<<<<<
 *                 for item in node.value:
 *                     self._anchor_node(item)
 */
      goto __pyx_L5;
    }

    /* "yaml/_yaml.pyx":1250
 *                 for item in node.value:
 *                     self._anchor_node(item)
 *             elif node_class is MappingNode:             # <<<<<<<<<<<<<<
 *                 for key, value in node.value:
 *                     self._anchor_node(key)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_MappingNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1250, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = (__pyx_v_node_class == __pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_1) {

      /* "yaml/_yaml.pyx":1251
 *                     self._anchor_node(item)
 *             elif node_class is MappingNode:
 *                 for key, value in node.value:             # <<<<<<<<<<<<<<
 *                     self._anchor_node(key)
 *                     self._anchor_node(value)
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1251, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
        __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3);
        __pyx_t_4 = 0;
        __pyx_t_5 = NULL;
      } else {
        __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1251, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1251, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      for (;;) {
        if (likely(!__pyx_t_5)) {
          if (likely(PyList_CheckExact(__pyx_t_3))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_3);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1251, __pyx_L1_error)
              #endif
              if (__pyx_t_4 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 1251, __pyx_L1_error)
            #else
            __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1251, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_3);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1251, __pyx_L1_error)
              #endif
              if (__pyx_t_4 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(0, 1251, __pyx_L1_error)
            #else
            __pyx_t_2 = __Pyx_PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1251, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            #endif
          }
        } else {
          __pyx_t_2 = __pyx_t_5(__pyx_t_3);
          if (unlikely(!__pyx_t_2)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1251, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_2);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
          PyObject* sequence = __pyx_t_2;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 1251, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          #else
          __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1251, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1251, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          #endif
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_9 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1251, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_9);
          index = 0; __pyx_t_7 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_7)) goto __pyx_L11_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_7);
          index = 1; __pyx_t_8 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L11_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_8);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_9), 2) < 0) __PYX_ERR(0, 1251, __pyx_L1_error)
          __pyx_t_10 = NULL;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          goto __pyx_L12_unpacking_done;
          __pyx_L11_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_10 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 1251, __pyx_L1_error)
          __pyx_L12_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_7);
        __pyx_t_7 = 0;
        __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "yaml/_yaml.pyx":1252
 *             elif node_class is MappingNode:
 *                 for key, value in node.value:
 *                     self._anchor_node(key)             # <<<<<<<<<<<<<<
 *                     self._anchor_node(value)
 *         return 1
 */
        __pyx_t_6 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_anchor_node(__pyx_v_self, __pyx_v_key); if (unlikely(__pyx_t_6 == ((int)0))) __PYX_ERR(0, 1252, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1253
 *                 for key, value in node.value:
 *                     self._anchor_node(key)
 *                     self._anchor_node(value)             # <<<<<<<<<<<<<<
 *         return 1
 * 
 */
        __pyx_t_6 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_anchor_node(__pyx_v_self, __pyx_v_value); if (unlikely(__pyx_t_6 == ((int)0))) __PYX_ERR(0, 1253, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1251
 *                     self._anchor_node(item)
 *             elif node_class is MappingNode:
 *                 for key, value in node.value:             # <<<<<<<<<<<<<<
 *                     self._anchor_node(key)
 *                     self._anchor_node(value)
 */
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "yaml/_yaml.pyx":1250
 *                 for item in node.value:
 *                     self._anchor_node(item)
 *             elif node_class is MappingNode:             # <<<<<<<<<<<<<<
 *                 for key, value in node.value:
 *                     self._anchor_node(key)
 */
    }
    __pyx_L5:;
  }
  __pyx_L3:;

  /* "yaml/_yaml.pyx":1254
 *                     self._anchor_node(key)
 *                     self._anchor_node(value)
 *         return 1             # <<<<<<<<<<<<<<
 * 
 *     cdef int _serialize_node(self, object node, object parent, object index) except 0:
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":1239
 *         self.last_alias_id = 0
 * 
 *     cdef int _anchor_node(self, object node) except 0:             # <<<<<<<<<<<<<<
 *         if node in self.anchors:
 *             if self.anchors[node] is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("yaml._yaml.CEmitter._anchor_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_node_class);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":1256
 *         return 1
 * 
 *     cdef int _serialize_node(self, object node, object parent, object index) except 0:             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef int implicit
 */

static int __pyx_f_4yaml_5_yaml_8CEmitter__serialize_node(struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, PyObject *__pyx_v_node, PyObject *__pyx_v_parent, PyObject *__pyx_v_index) {
  yaml_event_t __pyx_v_event;
  int __pyx_v_implicit;
  int __pyx_v_plain_implicit;
  int __pyx_v_quoted_implicit;
  yaml_char_t *__pyx_v_anchor;
  yaml_char_t *__pyx_v_tag;
  yaml_char_t *__pyx_v_value;
  int __pyx_v_length;
  int __pyx_v_item_index;
  yaml_scalar_style_t __pyx_v_scalar_style;
  yaml_sequence_style_t __pyx_v_sequence_style;
  yaml_mapping_style_t __pyx_v_mapping_style;
  PyObject *__pyx_v_anchor_object = NULL;
  PyObject *__pyx_v_error = NULL;
  PyObject *__pyx_v_node_class = NULL;
  PyObject *__pyx_v_tag_object = NULL;
  PyObject *__pyx_v_value_object = NULL;
  PyObject *__pyx_v_style_object = NULL;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_v_item_key = NULL;
  PyObject *__pyx_v_item_value = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_serialize_node", 1);

  /* "yaml/_yaml.pyx":1269
 *         cdef yaml_sequence_style_t sequence_style
 *         cdef yaml_mapping_style_t mapping_style
 *         anchor_object = self.anchors[node]             # <<<<<<<<<<<<<<
 *         anchor = NULL
 *         if anchor_object is not None:
 */
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_self->anchors, __pyx_v_node); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_anchor_object = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "yaml/_yaml.pyx":1270
 *         cdef yaml_mapping_style_t mapping_style
 *         anchor_object = self.anchors[node]
 *         anchor = NULL             # <<<<<<<<<<<<<<
 *         if anchor_object is not None:
 *             if PyUnicode_CheckExact(anchor_object):
 */
  __pyx_v_anchor = NULL;

  /* "yaml/_yaml.pyx":1271
 *         anchor_object = self.anchors[node]
 *         anchor = NULL
 *         if anchor_object is not None:             # <<<<<<<<<<<<<<
 *             if PyUnicode_CheckExact(anchor_object):
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 */
  __pyx_t_2 = (__pyx_v_anchor_object != Py_None);
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":1272
 *         anchor = NULL
 *         if anchor_object is not None:
 *             if PyUnicode_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *             if not PyBytes_CheckExact(anchor_object):
 */
    __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_anchor_object) != 0);
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1273
 *         if anchor_object is not None:
 *             if PyUnicode_CheckExact(anchor_object):
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)             # <<<<<<<<<<<<<<
 *             if not PyBytes_CheckExact(anchor_object):
 *                 raise TypeError(u"anchor must be a string")
 */
      __pyx_t_1 = PyUnicode_AsUTF8String(__pyx_v_anchor_object); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_anchor_object, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "yaml/_yaml.pyx":1272
 *         anchor = NULL
 *         if anchor_object is not None:
 *             if PyUnicode_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *             if not PyBytes_CheckExact(anchor_object):
 */
    }

    /* "yaml/_yaml.pyx":1274
 *             if PyUnicode_CheckExact(anchor_object):
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *             if not PyBytes_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                 raise TypeError(u"anchor must be a string")
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 */
    __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_anchor_object) != 0));
    if (unlikely(__pyx_t_2)) {

      /* "yaml/_yaml.pyx":1275
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *             if not PyBytes_CheckExact(anchor_object):
 *                 raise TypeError(u"anchor must be a string")             # <<<<<<<<<<<<<<
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *         if node in self.serialized_nodes:
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1275, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(0, 1275, __pyx_L1_error)

      /* "yaml/_yaml.pyx":1274
 *             if PyUnicode_CheckExact(anchor_object):
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *             if not PyBytes_CheckExact(anchor_object):             # <<<<<<<<<<<<<<
 *                 raise TypeError(u"anchor must be a string")
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 */
    }

    /* "yaml/_yaml.pyx":1276
 *             if not PyBytes_CheckExact(anchor_object):
 *                 raise TypeError(u"anchor must be a string")
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)             # <<<<<<<<<<<<<<
 *         if node in self.serialized_nodes:
 *             if yaml_alias_event_initialize(&event, anchor) == 0:
 */
    __pyx_v_anchor = PyBytes_AS_Yaml_STRING(__pyx_v_anchor_object);

    /* "yaml/_yaml.pyx":1271
 *         anchor_object = self.anchors[node]
 *         anchor = NULL
 *         if anchor_object is not None:             # <<<<<<<<<<<<<<
 *             if PyUnicode_CheckExact(anchor_object):
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 */
  }

  /* "yaml/_yaml.pyx":1277
 *                 raise TypeError(u"anchor must be a string")
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *         if node in self.serialized_nodes:             # <<<<<<<<<<<<<<
 *             if yaml_alias_event_initialize(&event, anchor) == 0:
 *                 raise MemoryError
 */
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_node, __pyx_v_self->serialized_nodes, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1277, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":1278
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *         if node in self.serialized_nodes:
 *             if yaml_alias_event_initialize(&event, anchor) == 0:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:
 */
    __pyx_t_2 = (yaml_alias_event_initialize((&__pyx_v_event), __pyx_v_anchor) == 0);
    if (unlikely(__pyx_t_2)) {

      /* "yaml/_yaml.pyx":1279
 *         if node in self.serialized_nodes:
 *             if yaml_alias_event_initialize(&event, anchor) == 0:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                 error = self._emitter_error()
 */
      PyErr_NoMemory(); __PYX_ERR(0, 1279, __pyx_L1_error)

      /* "yaml/_yaml.pyx":1278
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *         if node in self.serialized_nodes:
 *             if yaml_alias_event_initialize(&event, anchor) == 0:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:
 */
    }

    /* "yaml/_yaml.pyx":1280
 *             if yaml_alias_event_initialize(&event, anchor) == 0:
 *                 raise MemoryError
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                 error = self._emitter_error()
 *                 raise error
 */
    __pyx_t_3 = yaml_emitter_emit((&__pyx_v_self->emitter), (&__pyx_v_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1280, __pyx_L1_error)
    __pyx_t_2 = (__pyx_t_3 == 0);
    if (unlikely(__pyx_t_2)) {

      /* "yaml/_yaml.pyx":1281
 *                 raise MemoryError
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                 error = self._emitter_error()             # <<<<<<<<<<<<<<
 *                 raise error
 *         else:
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_emitter_error(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_error = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "yaml/_yaml.pyx":1282
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                 error = self._emitter_error()
 *                 raise error             # <<<<<<<<<<<<<<
 *         else:
 *             node_class = node.__class__
 */
      __Pyx_Raise(__pyx_v_error, 0, 0, 0);
      __PYX_ERR(0, 1282, __pyx_L1_error)

      /* "yaml/_yaml.pyx":1280
 *             if yaml_alias_event_initialize(&event, anchor) == 0:
 *                 raise MemoryError
 *             if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                 error = self._emitter_error()
 *                 raise error
 */
    }

    /* "yaml/_yaml.pyx":1277
 *                 raise TypeError(u"anchor must be a string")
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *         if node in self.serialized_nodes:             # <<<<<<<<<<<<<<
 *             if yaml_alias_event_initialize(&event, anchor) == 0:
 *                 raise MemoryError
 */
    goto __pyx_L6;
  }

  /* "yaml/_yaml.pyx":1284
 *                 raise error
 *         else:
 *             node_class = node.__class__             # <<<<<<<<<<<<<<
 *             self.serialized_nodes[node] = True
 *             self.descend_resolver(parent, index)
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1284, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_node_class = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "yaml/_yaml.pyx":1285
 *         else:
 *             node_class = node.__class__
 *             self.serialized_nodes[node] = True             # <<<<<<<<<<<<<<
 *             self.descend_resolver(parent, index)
 *             if node_class is ScalarNode:
 */
    if (unlikely((PyObject_SetItem(__pyx_v_self->serialized_nodes, __pyx_v_node, Py_True) < 0))) __PYX_ERR(0, 1285, __pyx_L1_error)

    /* "yaml/_yaml.pyx":1286
 *             node_class = node.__class__
 *             self.serialized_nodes[node] = True
 *             self.descend_resolver(parent, index)             # <<<<<<<<<<<<<<
 *             if node_class is ScalarNode:
 *                 plain_implicit = 0
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_descend_resolver); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_3 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_3 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_parent, __pyx_v_index};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_3, 2+__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1286, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "yaml/_yaml.pyx":1287
 *             self.serialized_nodes[node] = True
 *             self.descend_resolver(parent, index)
 *             if node_class is ScalarNode:             # <<<<<<<<<<<<<<
 *                 plain_implicit = 0
 *                 quoted_implicit = 0
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_ScalarNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_v_node_class == __pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1288
 *             self.descend_resolver(parent, index)
 *             if node_class is ScalarNode:
 *                 plain_implicit = 0             # <<<<<<<<<<<<<<
 *                 quoted_implicit = 0
 *                 tag_object = node.tag
 */
      __pyx_v_plain_implicit = 0;

      /* "yaml/_yaml.pyx":1289
 *             if node_class is ScalarNode:
 *                 plain_implicit = 0
 *                 quoted_implicit = 0             # <<<<<<<<<<<<<<
 *                 tag_object = node.tag
 *                 if self.resolve(ScalarNode, node.value, (True, False)) == tag_object:
 */
      __pyx_v_quoted_implicit = 0;

      /* "yaml/_yaml.pyx":1290
 *                 plain_implicit = 0
 *                 quoted_implicit = 0
 *                 tag_object = node.tag             # <<<<<<<<<<<<<<
 *                 if self.resolve(ScalarNode, node.value, (True, False)) == tag_object:
 *                     plain_implicit = 1
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_tag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_tag_object = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "yaml/_yaml.pyx":1291
 *                 quoted_implicit = 0
 *                 tag_object = node.tag
 *                 if self.resolve(ScalarNode, node.value, (True, False)) == tag_object:             # <<<<<<<<<<<<<<
 *                     plain_implicit = 1
 *                 if self.resolve(ScalarNode, node.value, (False, True)) == tag_object:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_resolve); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1291, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_ScalarNode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1291, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_value); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1291, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_3 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_3 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_t_5, __pyx_t_6, __pyx_tuple__22};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_3, 3+__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1291, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_1, __pyx_v_tag_object, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1291, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1291, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1292
 *                 tag_object = node.tag
 *                 if self.resolve(ScalarNode, node.value, (True, False)) == tag_object:
 *                     plain_implicit = 1             # <<<<<<<<<<<<<<
 *                 if self.resolve(ScalarNode, node.value, (False, True)) == tag_object:
 *                     quoted_implicit = 1
 */
        __pyx_v_plain_implicit = 1;

        /* "yaml/_yaml.pyx":1291
 *                 quoted_implicit = 0
 *                 tag_object = node.tag
 *                 if self.resolve(ScalarNode, node.value, (True, False)) == tag_object:             # <<<<<<<<<<<<<<
 *                     plain_implicit = 1
 *                 if self.resolve(ScalarNode, node.value, (False, True)) == tag_object:
 */
      }

      /* "yaml/_yaml.pyx":1293
 *                 if self.resolve(ScalarNode, node.value, (True, False)) == tag_object:
 *                     plain_implicit = 1
 *                 if self.resolve(ScalarNode, node.value, (False, True)) == tag_object:             # <<<<<<<<<<<<<<
 *                     quoted_implicit = 1
 *                 tag = NULL
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_resolve); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1293, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_ScalarNode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1293, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_value); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1293, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = NULL;
      __pyx_t_3 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_3 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_t_6, __pyx_t_5, __pyx_tuple__23};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_3, 3+__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1293, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_t_1 = PyObject_RichCompare(__pyx_t_4, __pyx_v_tag_object, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1293, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1293, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1294
 *                     plain_implicit = 1
 *                 if self.resolve(ScalarNode, node.value, (False, True)) == tag_object:
 *                     quoted_implicit = 1             # <<<<<<<<<<<<<<
 *                 tag = NULL
 *                 if tag_object is not None:
 */
        __pyx_v_quoted_implicit = 1;

        /* "yaml/_yaml.pyx":1293
 *                 if self.resolve(ScalarNode, node.value, (True, False)) == tag_object:
 *                     plain_implicit = 1
 *                 if self.resolve(ScalarNode, node.value, (False, True)) == tag_object:             # <<<<<<<<<<<<<<
 *                     quoted_implicit = 1
 *                 tag = NULL
 */
      }

      /* "yaml/_yaml.pyx":1295
 *                 if self.resolve(ScalarNode, node.value, (False, True)) == tag_object:
 *                     quoted_implicit = 1
 *                 tag = NULL             # <<<<<<<<<<<<<<
 *                 if tag_object is not None:
 *                     if PyUnicode_CheckExact(tag_object):
 */
      __pyx_v_tag = NULL;

      /* "yaml/_yaml.pyx":1296
 *                     quoted_implicit = 1
 *                 tag = NULL
 *                 if tag_object is not None:             # <<<<<<<<<<<<<<
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 */
      __pyx_t_2 = (__pyx_v_tag_object != Py_None);
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1297
 *                 tag = NULL
 *                 if tag_object is not None:
 *                     if PyUnicode_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):
 */
        __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_tag_object) != 0);
        if (__pyx_t_2) {

          /* "yaml/_yaml.pyx":1298
 *                 if tag_object is not None:
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)             # <<<<<<<<<<<<<<
 *                     if not PyBytes_CheckExact(tag_object):
 *                         raise TypeError(u"tag must be a string")
 */
          __pyx_t_1 = PyUnicode_AsUTF8String(__pyx_v_tag_object); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1298, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF_SET(__pyx_v_tag_object, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "yaml/_yaml.pyx":1297
 *                 tag = NULL
 *                 if tag_object is not None:
 *                     if PyUnicode_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):
 */
        }

        /* "yaml/_yaml.pyx":1299
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                         raise TypeError(u"tag must be a string")
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 */
        __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_tag_object) != 0));
        if (unlikely(__pyx_t_2)) {

          /* "yaml/_yaml.pyx":1300
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):
 *                         raise TypeError(u"tag must be a string")             # <<<<<<<<<<<<<<
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 *                 value_object = node.value
 */
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1300, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_Raise(__pyx_t_1, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __PYX_ERR(0, 1300, __pyx_L1_error)

          /* "yaml/_yaml.pyx":1299
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                         raise TypeError(u"tag must be a string")
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 */
        }

        /* "yaml/_yaml.pyx":1301
 *                     if not PyBytes_CheckExact(tag_object):
 *                         raise TypeError(u"tag must be a string")
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)             # <<<<<<<<<<<<<<
 *                 value_object = node.value
 *                 if PyUnicode_CheckExact(value_object):
 */
        __pyx_v_tag = PyBytes_AS_Yaml_STRING(__pyx_v_tag_object);

        /* "yaml/_yaml.pyx":1296
 *                     quoted_implicit = 1
 *                 tag = NULL
 *                 if tag_object is not None:             # <<<<<<<<<<<<<<
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 */
      }

      /* "yaml/_yaml.pyx":1302
 *                         raise TypeError(u"tag must be a string")
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 *                 value_object = node.value             # <<<<<<<<<<<<<<
 *                 if PyUnicode_CheckExact(value_object):
 *                     value_object = PyUnicode_AsUTF8String(value_object)
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1302, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_value_object = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "yaml/_yaml.pyx":1303
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 *                 value_object = node.value
 *                 if PyUnicode_CheckExact(value_object):             # <<<<<<<<<<<<<<
 *                     value_object = PyUnicode_AsUTF8String(value_object)
 *                 if not PyBytes_CheckExact(value_object):
 */
      __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_value_object) != 0);
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1304
 *                 value_object = node.value
 *                 if PyUnicode_CheckExact(value_object):
 *                     value_object = PyUnicode_AsUTF8String(value_object)             # <<<<<<<<<<<<<<
 *                 if not PyBytes_CheckExact(value_object):
 *                     raise TypeError(u"value must be a string")
 */
        __pyx_t_1 = PyUnicode_AsUTF8String(__pyx_v_value_object); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1304, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_value_object, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "yaml/_yaml.pyx":1303
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 *                 value_object = node.value
 *                 if PyUnicode_CheckExact(value_object):             # <<<<<<<<<<<<<<
 *                     value_object = PyUnicode_AsUTF8String(value_object)
 *                 if not PyBytes_CheckExact(value_object):
 */
      }

      /* "yaml/_yaml.pyx":1305
 *                 if PyUnicode_CheckExact(value_object):
 *                     value_object = PyUnicode_AsUTF8String(value_object)
 *                 if not PyBytes_CheckExact(value_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"value must be a string")
 *                 value = PyBytes_AS_Yaml_STRING(value_object)
 */
      __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_value_object) != 0));
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1306
 *                     value_object = PyUnicode_AsUTF8String(value_object)
 *                 if not PyBytes_CheckExact(value_object):
 *                     raise TypeError(u"value must be a string")             # <<<<<<<<<<<<<<
 *                 value = PyBytes_AS_Yaml_STRING(value_object)
 *                 length = PyBytes_GET_SIZE(value_object)
 */
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1306, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __PYX_ERR(0, 1306, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1305
 *                 if PyUnicode_CheckExact(value_object):
 *                     value_object = PyUnicode_AsUTF8String(value_object)
 *                 if not PyBytes_CheckExact(value_object):             # <<<<<<<<<<<<<<
 *                     raise TypeError(u"value must be a string")
 *                 value = PyBytes_AS_Yaml_STRING(value_object)
 */
      }

      /* "yaml/_yaml.pyx":1307
 *                 if not PyBytes_CheckExact(value_object):
 *                     raise TypeError(u"value must be a string")
 *                 value = PyBytes_AS_Yaml_STRING(value_object)             # <<<<<<<<<<<<<<
 *                 length = PyBytes_GET_SIZE(value_object)
 *                 style_object = node.style
 */
      __pyx_v_value = PyBytes_AS_Yaml_STRING(__pyx_v_value_object);

      /* "yaml/_yaml.pyx":1308
 *                     raise TypeError(u"value must be a string")
 *                 value = PyBytes_AS_Yaml_STRING(value_object)
 *                 length = PyBytes_GET_SIZE(value_object)             # <<<<<<<<<<<<<<
 *                 style_object = node.style
 *                 scalar_style = YAML_PLAIN_SCALAR_STYLE
 */
      __pyx_v_length = PyBytes_GET_SIZE(__pyx_v_value_object);

      /* "yaml/_yaml.pyx":1309
 *                 value = PyBytes_AS_Yaml_STRING(value_object)
 *                 length = PyBytes_GET_SIZE(value_object)
 *                 style_object = node.style             # <<<<<<<<<<<<<<
 *                 scalar_style = YAML_PLAIN_SCALAR_STYLE
 *                 if style_object == "'" or style_object == u"'":
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_style); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1309, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_style_object = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "yaml/_yaml.pyx":1310
 *                 length = PyBytes_GET_SIZE(value_object)
 *                 style_object = node.style
 *                 scalar_style = YAML_PLAIN_SCALAR_STYLE             # <<<<<<<<<<<<<<
 *                 if style_object == "'" or style_object == u"'":
 *                     scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE
 */
      __pyx_v_scalar_style = YAML_PLAIN_SCALAR_STYLE;

      /* "yaml/_yaml.pyx":1311
 *                 style_object = node.style
 *                 scalar_style = YAML_PLAIN_SCALAR_STYLE
 *                 if style_object == "'" or style_object == u"'":             # <<<<<<<<<<<<<<
 *                     scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE
 *                 elif style_object == "\"" or style_object == u"\"":
 */
      __pyx_t_8 = (__Pyx_PyString_Equals(__pyx_v_style_object, __pyx_kp_s__5, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1311, __pyx_L1_error)
      if (!__pyx_t_8) {
      } else {
        __pyx_t_2 = __pyx_t_8;
        goto __pyx_L18_bool_binop_done;
      }
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_style_object, __pyx_kp_u__5, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1311, __pyx_L1_error)
      __pyx_t_2 = __pyx_t_8;
      __pyx_L18_bool_binop_done:;
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1312
 *                 scalar_style = YAML_PLAIN_SCALAR_STYLE
 *                 if style_object == "'" or style_object == u"'":
 *                     scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE             # <<<<<<<<<<<<<<
 *                 elif style_object == "\"" or style_object == u"\"":
 *                     scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE
 */
        __pyx_v_scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE;

        /* "yaml/_yaml.pyx":1311
 *                 style_object = node.style
 *                 scalar_style = YAML_PLAIN_SCALAR_STYLE
 *                 if style_object == "'" or style_object == u"'":             # <<<<<<<<<<<<<<
 *                     scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE
 *                 elif style_object == "\"" or style_object == u"\"":
 */
        goto __pyx_L17;
      }

      /* "yaml/_yaml.pyx":1313
 *                 if style_object == "'" or style_object == u"'":
 *                     scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE
 *                 elif style_object == "\"" or style_object == u"\"":             # <<<<<<<<<<<<<<
 *                     scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE
 *                 elif style_object == "|" or style_object == u"|":
 */
      __pyx_t_8 = (__Pyx_PyString_Equals(__pyx_v_style_object, __pyx_kp_s__6, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1313, __pyx_L1_error)
      if (!__pyx_t_8) {
      } else {
        __pyx_t_2 = __pyx_t_8;
        goto __pyx_L20_bool_binop_done;
      }
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_style_object, __pyx_kp_u__6, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1313, __pyx_L1_error)
      __pyx_t_2 = __pyx_t_8;
      __pyx_L20_bool_binop_done:;
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1314
 *                     scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE
 *                 elif style_object == "\"" or style_object == u"\"":
 *                     scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE             # <<<<<<<<<<<<<<
 *                 elif style_object == "|" or style_object == u"|":
 *                     scalar_style = YAML_LITERAL_SCALAR_STYLE
 */
        __pyx_v_scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE;

        /* "yaml/_yaml.pyx":1313
 *                 if style_object == "'" or style_object == u"'":
 *                     scalar_style = YAML_SINGLE_QUOTED_SCALAR_STYLE
 *                 elif style_object == "\"" or style_object == u"\"":             # <<<<<<<<<<<<<<
 *                     scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE
 *                 elif style_object == "|" or style_object == u"|":
 */
        goto __pyx_L17;
      }

      /* "yaml/_yaml.pyx":1315
 *                 elif style_object == "\"" or style_object == u"\"":
 *                     scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE
 *                 elif style_object == "|" or style_object == u"|":             # <<<<<<<<<<<<<<
 *                     scalar_style = YAML_LITERAL_SCALAR_STYLE
 *                 elif style_object == ">" or style_object == u">":
 */
      __pyx_t_8 = (__Pyx_PyString_Equals(__pyx_v_style_object, __pyx_kp_s__7, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1315, __pyx_L1_error)
      if (!__pyx_t_8) {
      } else {
        __pyx_t_2 = __pyx_t_8;
        goto __pyx_L22_bool_binop_done;
      }
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_style_object, __pyx_kp_u__7, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1315, __pyx_L1_error)
      __pyx_t_2 = __pyx_t_8;
      __pyx_L22_bool_binop_done:;
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1316
 *                     scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE
 *                 elif style_object == "|" or style_object == u"|":
 *                     scalar_style = YAML_LITERAL_SCALAR_STYLE             # <<<<<<<<<<<<<<
 *                 elif style_object == ">" or style_object == u">":
 *                     scalar_style = YAML_FOLDED_SCALAR_STYLE
 */
        __pyx_v_scalar_style = YAML_LITERAL_SCALAR_STYLE;

        /* "yaml/_yaml.pyx":1315
 *                 elif style_object == "\"" or style_object == u"\"":
 *                     scalar_style = YAML_DOUBLE_QUOTED_SCALAR_STYLE
 *                 elif style_object == "|" or style_object == u"|":             # <<<<<<<<<<<<<<
 *                     scalar_style = YAML_LITERAL_SCALAR_STYLE
 *                 elif style_object == ">" or style_object == u">":
 */
        goto __pyx_L17;
      }

      /* "yaml/_yaml.pyx":1317
 *                 elif style_object == "|" or style_object == u"|":
 *                     scalar_style = YAML_LITERAL_SCALAR_STYLE
 *                 elif style_object == ">" or style_object == u">":             # <<<<<<<<<<<<<<
 *                     scalar_style = YAML_FOLDED_SCALAR_STYLE
 *                 if yaml_scalar_event_initialize(&event, anchor, tag, value, length,
 */
      __pyx_t_8 = (__Pyx_PyString_Equals(__pyx_v_style_object, __pyx_kp_s__8, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1317, __pyx_L1_error)
      if (!__pyx_t_8) {
      } else {
        __pyx_t_2 = __pyx_t_8;
        goto __pyx_L24_bool_binop_done;
      }
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_v_style_object, __pyx_kp_u__8, Py_EQ)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 1317, __pyx_L1_error)
      __pyx_t_2 = __pyx_t_8;
      __pyx_L24_bool_binop_done:;
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1318
 *                     scalar_style = YAML_LITERAL_SCALAR_STYLE
 *                 elif style_object == ">" or style_object == u">":
 *                     scalar_style = YAML_FOLDED_SCALAR_STYLE             # <<<<<<<<<<<<<<
 *                 if yaml_scalar_event_initialize(&event, anchor, tag, value, length,
 *                         plain_implicit, quoted_implicit, scalar_style) == 0:
 */
        __pyx_v_scalar_style = YAML_FOLDED_SCALAR_STYLE;

        /* "yaml/_yaml.pyx":1317
 *                 elif style_object == "|" or style_object == u"|":
 *                     scalar_style = YAML_LITERAL_SCALAR_STYLE
 *                 elif style_object == ">" or style_object == u">":             # <<<<<<<<<<<<<<
 *                     scalar_style = YAML_FOLDED_SCALAR_STYLE
 *                 if yaml_scalar_event_initialize(&event, anchor, tag, value, length,
 */
      }
      __pyx_L17:;

      /* "yaml/_yaml.pyx":1320
 *                     scalar_style = YAML_FOLDED_SCALAR_STYLE
 *                 if yaml_scalar_event_initialize(&event, anchor, tag, value, length,
 *                         plain_implicit, quoted_implicit, scalar_style) == 0:             # <<<<<<<<<<<<<<
 *                     raise MemoryError
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 */
      __pyx_t_2 = (yaml_scalar_event_initialize((&__pyx_v_event), __pyx_v_anchor, __pyx_v_tag, __pyx_v_value, __pyx_v_length, __pyx_v_plain_implicit, __pyx_v_quoted_implicit, __pyx_v_scalar_style) == 0);

      /* "yaml/_yaml.pyx":1319
 *                 elif style_object == ">" or style_object == u">":
 *                     scalar_style = YAML_FOLDED_SCALAR_STYLE
 *                 if yaml_scalar_event_initialize(&event, anchor, tag, value, length,             # <<<<<<<<<<<<<<
 *                         plain_implicit, quoted_implicit, scalar_style) == 0:
 *                     raise MemoryError
 */
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1321
 *                 if yaml_scalar_event_initialize(&event, anchor, tag, value, length,
 *                         plain_implicit, quoted_implicit, scalar_style) == 0:
 *                     raise MemoryError             # <<<<<<<<<<<<<<
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()
 */
        PyErr_NoMemory(); __PYX_ERR(0, 1321, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1319
 *                 elif style_object == ">" or style_object == u">":
 *                     scalar_style = YAML_FOLDED_SCALAR_STYLE
 *                 if yaml_scalar_event_initialize(&event, anchor, tag, value, length,             # <<<<<<<<<<<<<<
 *                         plain_implicit, quoted_implicit, scalar_style) == 0:
 *                     raise MemoryError
 */
      }

      /* "yaml/_yaml.pyx":1322
 *                         plain_implicit, quoted_implicit, scalar_style) == 0:
 *                     raise MemoryError
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                     error = self._emitter_error()
 *                     raise error
 */
      __pyx_t_3 = yaml_emitter_emit((&__pyx_v_self->emitter), (&__pyx_v_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1322, __pyx_L1_error)
      __pyx_t_2 = (__pyx_t_3 == 0);
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1323
 *                     raise MemoryError
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()             # <<<<<<<<<<<<<<
 *                     raise error
 *             elif node_class is SequenceNode:
 */
        __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_emitter_error(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1323, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_error = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "yaml/_yaml.pyx":1324
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()
 *                     raise error             # <<<<<<<<<<<<<<
 *             elif node_class is SequenceNode:
 *                 implicit = 0
 */
        __Pyx_Raise(__pyx_v_error, 0, 0, 0);
        __PYX_ERR(0, 1324, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1322
 *                         plain_implicit, quoted_implicit, scalar_style) == 0:
 *                     raise MemoryError
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                     error = self._emitter_error()
 *                     raise error
 */
      }

      /* "yaml/_yaml.pyx":1287
 *             self.serialized_nodes[node] = True
 *             self.descend_resolver(parent, index)
 *             if node_class is ScalarNode:             # <<<<<<<<<<<<<<
 *                 plain_implicit = 0
 *                 quoted_implicit = 0
 */
      goto __pyx_L9;
    }

    /* "yaml/_yaml.pyx":1325
 *                     error = self._emitter_error()
 *                     raise error
 *             elif node_class is SequenceNode:             # <<<<<<<<<<<<<<
 *                 implicit = 0
 *                 tag_object = node.tag
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SequenceNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_v_node_class == __pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1326
 *                     raise error
 *             elif node_class is SequenceNode:
 *                 implicit = 0             # <<<<<<<<<<<<<<
 *                 tag_object = node.tag
 *                 if self.resolve(SequenceNode, node.value, True) == tag_object:
 */
      __pyx_v_implicit = 0;

      /* "yaml/_yaml.pyx":1327
 *             elif node_class is SequenceNode:
 *                 implicit = 0
 *                 tag_object = node.tag             # <<<<<<<<<<<<<<
 *                 if self.resolve(SequenceNode, node.value, True) == tag_object:
 *                     implicit = 1
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_tag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1327, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_tag_object = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "yaml/_yaml.pyx":1328
 *                 implicit = 0
 *                 tag_object = node.tag
 *                 if self.resolve(SequenceNode, node.value, True) == tag_object:             # <<<<<<<<<<<<<<
 *                     implicit = 1
 *                 tag = NULL
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_resolve); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1328, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SequenceNode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1328, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_value); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1328, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_3 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_3 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_t_5, __pyx_t_6, Py_True};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_3, 3+__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1328, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_1, __pyx_v_tag_object, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1328, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1328, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1329
 *                 tag_object = node.tag
 *                 if self.resolve(SequenceNode, node.value, True) == tag_object:
 *                     implicit = 1             # <<<<<<<<<<<<<<
 *                 tag = NULL
 *                 if tag_object is not None:
 */
        __pyx_v_implicit = 1;

        /* "yaml/_yaml.pyx":1328
 *                 implicit = 0
 *                 tag_object = node.tag
 *                 if self.resolve(SequenceNode, node.value, True) == tag_object:             # <<<<<<<<<<<<<<
 *                     implicit = 1
 *                 tag = NULL
 */
      }

      /* "yaml/_yaml.pyx":1330
 *                 if self.resolve(SequenceNode, node.value, True) == tag_object:
 *                     implicit = 1
 *                 tag = NULL             # <<<<<<<<<<<<<<
 *                 if tag_object is not None:
 *                     if PyUnicode_CheckExact(tag_object):
 */
      __pyx_v_tag = NULL;

      /* "yaml/_yaml.pyx":1331
 *                     implicit = 1
 *                 tag = NULL
 *                 if tag_object is not None:             # <<<<<<<<<<<<<<
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 */
      __pyx_t_2 = (__pyx_v_tag_object != Py_None);
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1332
 *                 tag = NULL
 *                 if tag_object is not None:
 *                     if PyUnicode_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):
 */
        __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_tag_object) != 0);
        if (__pyx_t_2) {

          /* "yaml/_yaml.pyx":1333
 *                 if tag_object is not None:
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)             # <<<<<<<<<<<<<<
 *                     if not PyBytes_CheckExact(tag_object):
 *                         raise TypeError(u"tag must be a string")
 */
          __pyx_t_4 = PyUnicode_AsUTF8String(__pyx_v_tag_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1333, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF_SET(__pyx_v_tag_object, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "yaml/_yaml.pyx":1332
 *                 tag = NULL
 *                 if tag_object is not None:
 *                     if PyUnicode_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):
 */
        }

        /* "yaml/_yaml.pyx":1334
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                         raise TypeError(u"tag must be a string")
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 */
        __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_tag_object) != 0));
        if (unlikely(__pyx_t_2)) {

          /* "yaml/_yaml.pyx":1335
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):
 *                         raise TypeError(u"tag must be a string")             # <<<<<<<<<<<<<<
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 *                 sequence_style = YAML_BLOCK_SEQUENCE_STYLE
 */
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1335, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_Raise(__pyx_t_4, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __PYX_ERR(0, 1335, __pyx_L1_error)

          /* "yaml/_yaml.pyx":1334
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                         raise TypeError(u"tag must be a string")
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 */
        }

        /* "yaml/_yaml.pyx":1336
 *                     if not PyBytes_CheckExact(tag_object):
 *                         raise TypeError(u"tag must be a string")
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)             # <<<<<<<<<<<<<<
 *                 sequence_style = YAML_BLOCK_SEQUENCE_STYLE
 *                 if node.flow_style:
 */
        __pyx_v_tag = PyBytes_AS_Yaml_STRING(__pyx_v_tag_object);

        /* "yaml/_yaml.pyx":1331
 *                     implicit = 1
 *                 tag = NULL
 *                 if tag_object is not None:             # <<<<<<<<<<<<<<
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 */
      }

      /* "yaml/_yaml.pyx":1337
 *                         raise TypeError(u"tag must be a string")
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 *                 sequence_style = YAML_BLOCK_SEQUENCE_STYLE             # <<<<<<<<<<<<<<
 *                 if node.flow_style:
 *                     sequence_style = YAML_FLOW_SEQUENCE_STYLE
 */
      __pyx_v_sequence_style = YAML_BLOCK_SEQUENCE_STYLE;

      /* "yaml/_yaml.pyx":1338
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 *                 sequence_style = YAML_BLOCK_SEQUENCE_STYLE
 *                 if node.flow_style:             # <<<<<<<<<<<<<<
 *                     sequence_style = YAML_FLOW_SEQUENCE_STYLE
 *                 if yaml_sequence_start_event_initialize(&event, anchor, tag,
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_flow_style); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1338, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1339
 *                 sequence_style = YAML_BLOCK_SEQUENCE_STYLE
 *                 if node.flow_style:
 *                     sequence_style = YAML_FLOW_SEQUENCE_STYLE             # <<<<<<<<<<<<<<
 *                 if yaml_sequence_start_event_initialize(&event, anchor, tag,
 *                         implicit, sequence_style) == 0:
 */
        __pyx_v_sequence_style = YAML_FLOW_SEQUENCE_STYLE;

        /* "yaml/_yaml.pyx":1338
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 *                 sequence_style = YAML_BLOCK_SEQUENCE_STYLE
 *                 if node.flow_style:             # <<<<<<<<<<<<<<
 *                     sequence_style = YAML_FLOW_SEQUENCE_STYLE
 *                 if yaml_sequence_start_event_initialize(&event, anchor, tag,
 */
      }

      /* "yaml/_yaml.pyx":1341
 *                     sequence_style = YAML_FLOW_SEQUENCE_STYLE
 *                 if yaml_sequence_start_event_initialize(&event, anchor, tag,
 *                         implicit, sequence_style) == 0:             # <<<<<<<<<<<<<<
 *                     raise MemoryError
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 */
      __pyx_t_2 = (yaml_sequence_start_event_initialize((&__pyx_v_event), __pyx_v_anchor, __pyx_v_tag, __pyx_v_implicit, __pyx_v_sequence_style) == 0);

      /* "yaml/_yaml.pyx":1340
 *                 if node.flow_style:
 *                     sequence_style = YAML_FLOW_SEQUENCE_STYLE
 *                 if yaml_sequence_start_event_initialize(&event, anchor, tag,             # <<<<<<<<<<<<<<
 *                         implicit, sequence_style) == 0:
 *                     raise MemoryError
 */
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1342
 *                 if yaml_sequence_start_event_initialize(&event, anchor, tag,
 *                         implicit, sequence_style) == 0:
 *                     raise MemoryError             # <<<<<<<<<<<<<<
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()
 */
        PyErr_NoMemory(); __PYX_ERR(0, 1342, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1340
 *                 if node.flow_style:
 *                     sequence_style = YAML_FLOW_SEQUENCE_STYLE
 *                 if yaml_sequence_start_event_initialize(&event, anchor, tag,             # <<<<<<<<<<<<<<
 *                         implicit, sequence_style) == 0:
 *                     raise MemoryError
 */
      }

      /* "yaml/_yaml.pyx":1343
 *                         implicit, sequence_style) == 0:
 *                     raise MemoryError
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                     error = self._emitter_error()
 *                     raise error
 */
      __pyx_t_3 = yaml_emitter_emit((&__pyx_v_self->emitter), (&__pyx_v_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1343, __pyx_L1_error)
      __pyx_t_2 = (__pyx_t_3 == 0);
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1344
 *                     raise MemoryError
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()             # <<<<<<<<<<<<<<
 *                     raise error
 *                 item_index = 0
 */
        __pyx_t_4 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_emitter_error(__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1344, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_v_error = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "yaml/_yaml.pyx":1345
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()
 *                     raise error             # <<<<<<<<<<<<<<
 *                 item_index = 0
 *                 for item in node.value:
 */
        __Pyx_Raise(__pyx_v_error, 0, 0, 0);
        __PYX_ERR(0, 1345, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1343
 *                         implicit, sequence_style) == 0:
 *                     raise MemoryError
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                     error = self._emitter_error()
 *                     raise error
 */
      }

      /* "yaml/_yaml.pyx":1346
 *                     error = self._emitter_error()
 *                     raise error
 *                 item_index = 0             # <<<<<<<<<<<<<<
 *                 for item in node.value:
 *                     self._serialize_node(item, node, item_index)
 */
      __pyx_v_item_index = 0;

      /* "yaml/_yaml.pyx":1347
 *                     raise error
 *                 item_index = 0
 *                 for item in node.value:             # <<<<<<<<<<<<<<
 *                     self._serialize_node(item, node, item_index)
 *                     item_index = item_index+1
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_value); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1347, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1);
        __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
      } else {
        __pyx_t_9 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1347, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1347, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_10)) {
          if (likely(PyList_CheckExact(__pyx_t_1))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1347, __pyx_L1_error)
              #endif
              if (__pyx_t_9 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_9); __Pyx_INCREF(__pyx_t_4); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 1347, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1347, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1347, __pyx_L1_error)
              #endif
              if (__pyx_t_9 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_9); __Pyx_INCREF(__pyx_t_4); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 1347, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1347, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_10(__pyx_t_1);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1347, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "yaml/_yaml.pyx":1348
 *                 item_index = 0
 *                 for item in node.value:
 *                     self._serialize_node(item, node, item_index)             # <<<<<<<<<<<<<<
 *                     item_index = item_index+1
 *                 yaml_sequence_end_event_initialize(&event)
 */
        __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_item_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1348, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_serialize_node(__pyx_v_self, __pyx_v_item, __pyx_v_node, __pyx_t_4); if (unlikely(__pyx_t_3 == ((int)0))) __PYX_ERR(0, 1348, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "yaml/_yaml.pyx":1349
 *                 for item in node.value:
 *                     self._serialize_node(item, node, item_index)
 *                     item_index = item_index+1             # <<<<<<<<<<<<<<
 *                 yaml_sequence_end_event_initialize(&event)
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 */
        __pyx_v_item_index = (__pyx_v_item_index + 1);

        /* "yaml/_yaml.pyx":1347
 *                     raise error
 *                 item_index = 0
 *                 for item in node.value:             # <<<<<<<<<<<<<<
 *                     self._serialize_node(item, node, item_index)
 *                     item_index = item_index+1
 */
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "yaml/_yaml.pyx":1350
 *                     self._serialize_node(item, node, item_index)
 *                     item_index = item_index+1
 *                 yaml_sequence_end_event_initialize(&event)             # <<<<<<<<<<<<<<
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()
 */
      (void)(yaml_sequence_end_event_initialize((&__pyx_v_event)));

      /* "yaml/_yaml.pyx":1351
 *                     item_index = item_index+1
 *                 yaml_sequence_end_event_initialize(&event)
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                     error = self._emitter_error()
 *                     raise error
 */
      __pyx_t_3 = yaml_emitter_emit((&__pyx_v_self->emitter), (&__pyx_v_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1351, __pyx_L1_error)
      __pyx_t_2 = (__pyx_t_3 == 0);
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1352
 *                 yaml_sequence_end_event_initialize(&event)
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()             # <<<<<<<<<<<<<<
 *                     raise error
 *             elif node_class is MappingNode:
 */
        __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_emitter_error(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1352, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_error = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "yaml/_yaml.pyx":1353
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()
 *                     raise error             # <<<<<<<<<<<<<<
 *             elif node_class is MappingNode:
 *                 implicit = 0
 */
        __Pyx_Raise(__pyx_v_error, 0, 0, 0);
        __PYX_ERR(0, 1353, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1351
 *                     item_index = item_index+1
 *                 yaml_sequence_end_event_initialize(&event)
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                     error = self._emitter_error()
 *                     raise error
 */
      }

      /* "yaml/_yaml.pyx":1325
 *                     error = self._emitter_error()
 *                     raise error
 *             elif node_class is SequenceNode:             # <<<<<<<<<<<<<<
 *                 implicit = 0
 *                 tag_object = node.tag
 */
      goto __pyx_L9;
    }

    /* "yaml/_yaml.pyx":1354
 *                     error = self._emitter_error()
 *                     raise error
 *             elif node_class is MappingNode:             # <<<<<<<<<<<<<<
 *                 implicit = 0
 *                 tag_object = node.tag
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_MappingNode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1354, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_v_node_class == __pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_2) {

      /* "yaml/_yaml.pyx":1355
 *                     raise error
 *             elif node_class is MappingNode:
 *                 implicit = 0             # <<<<<<<<<<<<<<
 *                 tag_object = node.tag
 *                 if self.resolve(MappingNode, node.value, True) == tag_object:
 */
      __pyx_v_implicit = 0;

      /* "yaml/_yaml.pyx":1356
 *             elif node_class is MappingNode:
 *                 implicit = 0
 *                 tag_object = node.tag             # <<<<<<<<<<<<<<
 *                 if self.resolve(MappingNode, node.value, True) == tag_object:
 *                     implicit = 1
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_tag); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1356, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_tag_object = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "yaml/_yaml.pyx":1357
 *                 implicit = 0
 *                 tag_object = node.tag
 *                 if self.resolve(MappingNode, node.value, True) == tag_object:             # <<<<<<<<<<<<<<
 *                     implicit = 1
 *                 tag = NULL
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_resolve); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1357, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_MappingNode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1357, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_value); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1357, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = NULL;
      __pyx_t_3 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_3 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_7, __pyx_t_6, __pyx_t_5, Py_True};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_3, 3+__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1357, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_1, __pyx_v_tag_object, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1357, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1357, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1358
 *                 tag_object = node.tag
 *                 if self.resolve(MappingNode, node.value, True) == tag_object:
 *                     implicit = 1             # <<<<<<<<<<<<<<
 *                 tag = NULL
 *                 if tag_object is not None:
 */
        __pyx_v_implicit = 1;

        /* "yaml/_yaml.pyx":1357
 *                 implicit = 0
 *                 tag_object = node.tag
 *                 if self.resolve(MappingNode, node.value, True) == tag_object:             # <<<<<<<<<<<<<<
 *                     implicit = 1
 *                 tag = NULL
 */
      }

      /* "yaml/_yaml.pyx":1359
 *                 if self.resolve(MappingNode, node.value, True) == tag_object:
 *                     implicit = 1
 *                 tag = NULL             # <<<<<<<<<<<<<<
 *                 if tag_object is not None:
 *                     if PyUnicode_CheckExact(tag_object):
 */
      __pyx_v_tag = NULL;

      /* "yaml/_yaml.pyx":1360
 *                     implicit = 1
 *                 tag = NULL
 *                 if tag_object is not None:             # <<<<<<<<<<<<<<
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 */
      __pyx_t_2 = (__pyx_v_tag_object != Py_None);
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1361
 *                 tag = NULL
 *                 if tag_object is not None:
 *                     if PyUnicode_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):
 */
        __pyx_t_2 = (PyUnicode_CheckExact(__pyx_v_tag_object) != 0);
        if (__pyx_t_2) {

          /* "yaml/_yaml.pyx":1362
 *                 if tag_object is not None:
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)             # <<<<<<<<<<<<<<
 *                     if not PyBytes_CheckExact(tag_object):
 *                         raise TypeError(u"tag must be a string")
 */
          __pyx_t_4 = PyUnicode_AsUTF8String(__pyx_v_tag_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1362, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF_SET(__pyx_v_tag_object, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "yaml/_yaml.pyx":1361
 *                 tag = NULL
 *                 if tag_object is not None:
 *                     if PyUnicode_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):
 */
        }

        /* "yaml/_yaml.pyx":1363
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                         raise TypeError(u"tag must be a string")
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 */
        __pyx_t_2 = (!(PyBytes_CheckExact(__pyx_v_tag_object) != 0));
        if (unlikely(__pyx_t_2)) {

          /* "yaml/_yaml.pyx":1364
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):
 *                         raise TypeError(u"tag must be a string")             # <<<<<<<<<<<<<<
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 *                 mapping_style = YAML_BLOCK_MAPPING_STYLE
 */
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1364, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_Raise(__pyx_t_4, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __PYX_ERR(0, 1364, __pyx_L1_error)

          /* "yaml/_yaml.pyx":1363
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 *                     if not PyBytes_CheckExact(tag_object):             # <<<<<<<<<<<<<<
 *                         raise TypeError(u"tag must be a string")
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 */
        }

        /* "yaml/_yaml.pyx":1365
 *                     if not PyBytes_CheckExact(tag_object):
 *                         raise TypeError(u"tag must be a string")
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)             # <<<<<<<<<<<<<<
 *                 mapping_style = YAML_BLOCK_MAPPING_STYLE
 *                 if node.flow_style:
 */
        __pyx_v_tag = PyBytes_AS_Yaml_STRING(__pyx_v_tag_object);

        /* "yaml/_yaml.pyx":1360
 *                     implicit = 1
 *                 tag = NULL
 *                 if tag_object is not None:             # <<<<<<<<<<<<<<
 *                     if PyUnicode_CheckExact(tag_object):
 *                         tag_object = PyUnicode_AsUTF8String(tag_object)
 */
      }

      /* "yaml/_yaml.pyx":1366
 *                         raise TypeError(u"tag must be a string")
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 *                 mapping_style = YAML_BLOCK_MAPPING_STYLE             # <<<<<<<<<<<<<<
 *                 if node.flow_style:
 *                     mapping_style = YAML_FLOW_MAPPING_STYLE
 */
      __pyx_v_mapping_style = YAML_BLOCK_MAPPING_STYLE;

      /* "yaml/_yaml.pyx":1367
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 *                 mapping_style = YAML_BLOCK_MAPPING_STYLE
 *                 if node.flow_style:             # <<<<<<<<<<<<<<
 *                     mapping_style = YAML_FLOW_MAPPING_STYLE
 *                 if yaml_mapping_start_event_initialize(&event, anchor, tag,
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_flow_style); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 1367, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_2) {

        /* "yaml/_yaml.pyx":1368
 *                 mapping_style = YAML_BLOCK_MAPPING_STYLE
 *                 if node.flow_style:
 *                     mapping_style = YAML_FLOW_MAPPING_STYLE             # <<<<<<<<<<<<<<
 *                 if yaml_mapping_start_event_initialize(&event, anchor, tag,
 *                         implicit, mapping_style) == 0:
 */
        __pyx_v_mapping_style = YAML_FLOW_MAPPING_STYLE;

        /* "yaml/_yaml.pyx":1367
 *                     tag = PyBytes_AS_Yaml_STRING(tag_object)
 *                 mapping_style = YAML_BLOCK_MAPPING_STYLE
 *                 if node.flow_style:             # <<<<<<<<<<<<<<
 *                     mapping_style = YAML_FLOW_MAPPING_STYLE
 *                 if yaml_mapping_start_event_initialize(&event, anchor, tag,
 */
      }

      /* "yaml/_yaml.pyx":1370
 *                     mapping_style = YAML_FLOW_MAPPING_STYLE
 *                 if yaml_mapping_start_event_initialize(&event, anchor, tag,
 *                         implicit, mapping_style) == 0:             # <<<<<<<<<<<<<<
 *                     raise MemoryError
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 */
      __pyx_t_2 = (yaml_mapping_start_event_initialize((&__pyx_v_event), __pyx_v_anchor, __pyx_v_tag, __pyx_v_implicit, __pyx_v_mapping_style) == 0);

      /* "yaml/_yaml.pyx":1369
 *                 if node.flow_style:
 *                     mapping_style = YAML_FLOW_MAPPING_STYLE
 *                 if yaml_mapping_start_event_initialize(&event, anchor, tag,             # <<<<<<<<<<<<<<
 *                         implicit, mapping_style) == 0:
 *                     raise MemoryError
 */
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1371
 *                 if yaml_mapping_start_event_initialize(&event, anchor, tag,
 *                         implicit, mapping_style) == 0:
 *                     raise MemoryError             # <<<<<<<<<<<<<<
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()
 */
        PyErr_NoMemory(); __PYX_ERR(0, 1371, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1369
 *                 if node.flow_style:
 *                     mapping_style = YAML_FLOW_MAPPING_STYLE
 *                 if yaml_mapping_start_event_initialize(&event, anchor, tag,             # <<<<<<<<<<<<<<
 *                         implicit, mapping_style) == 0:
 *                     raise MemoryError
 */
      }

      /* "yaml/_yaml.pyx":1372
 *                         implicit, mapping_style) == 0:
 *                     raise MemoryError
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                     error = self._emitter_error()
 *                     raise error
 */
      __pyx_t_3 = yaml_emitter_emit((&__pyx_v_self->emitter), (&__pyx_v_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1372, __pyx_L1_error)
      __pyx_t_2 = (__pyx_t_3 == 0);
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1373
 *                     raise MemoryError
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()             # <<<<<<<<<<<<<<
 *                     raise error
 *                 for item_key, item_value in node.value:
 */
        __pyx_t_4 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_emitter_error(__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1373, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_v_error = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "yaml/_yaml.pyx":1374
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()
 *                     raise error             # <<<<<<<<<<<<<<
 *                 for item_key, item_value in node.value:
 *                     self._serialize_node(item_key, node, None)
 */
        __Pyx_Raise(__pyx_v_error, 0, 0, 0);
        __PYX_ERR(0, 1374, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1372
 *                         implicit, mapping_style) == 0:
 *                     raise MemoryError
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                     error = self._emitter_error()
 *                     raise error
 */
      }

      /* "yaml/_yaml.pyx":1375
 *                     error = self._emitter_error()
 *                     raise error
 *                 for item_key, item_value in node.value:             # <<<<<<<<<<<<<<
 *                     self._serialize_node(item_key, node, None)
 *                     self._serialize_node(item_value, node, item_key)
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_node, __pyx_n_s_value); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1375, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
        __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1);
        __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
      } else {
        __pyx_t_9 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1375, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_10 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1375, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (likely(!__pyx_t_10)) {
          if (likely(PyList_CheckExact(__pyx_t_1))) {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1375, __pyx_L1_error)
              #endif
              if (__pyx_t_9 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_9); __Pyx_INCREF(__pyx_t_4); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 1375, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1375, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            {
              Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
              #if !CYTHON_ASSUME_SAFE_MACROS
              if (unlikely((__pyx_temp < 0))) __PYX_ERR(0, 1375, __pyx_L1_error)
              #endif
              if (__pyx_t_9 >= __pyx_temp) break;
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_9); __Pyx_INCREF(__pyx_t_4); __pyx_t_9++; if (unlikely((0 < 0))) __PYX_ERR(0, 1375, __pyx_L1_error)
            #else
            __pyx_t_4 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1375, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_10(__pyx_t_1);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 1375, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
          PyObject* sequence = __pyx_t_4;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 1375, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          #else
          __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1375, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1375, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1375, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_11 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
          index = 0; __pyx_t_5 = __pyx_t_11(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L48_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_5);
          index = 1; __pyx_t_6 = __pyx_t_11(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L48_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_6);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_7), 2) < 0) __PYX_ERR(0, 1375, __pyx_L1_error)
          __pyx_t_11 = NULL;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          goto __pyx_L49_unpacking_done;
          __pyx_L48_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_11 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 1375, __pyx_L1_error)
          __pyx_L49_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_item_key, __pyx_t_5);
        __pyx_t_5 = 0;
        __Pyx_XDECREF_SET(__pyx_v_item_value, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "yaml/_yaml.pyx":1376
 *                     raise error
 *                 for item_key, item_value in node.value:
 *                     self._serialize_node(item_key, node, None)             # <<<<<<<<<<<<<<
 *                     self._serialize_node(item_value, node, item_key)
 *                 yaml_mapping_end_event_initialize(&event)
 */
        __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_serialize_node(__pyx_v_self, __pyx_v_item_key, __pyx_v_node, Py_None); if (unlikely(__pyx_t_3 == ((int)0))) __PYX_ERR(0, 1376, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1377
 *                 for item_key, item_value in node.value:
 *                     self._serialize_node(item_key, node, None)
 *                     self._serialize_node(item_value, node, item_key)             # <<<<<<<<<<<<<<
 *                 yaml_mapping_end_event_initialize(&event)
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 */
        __pyx_t_3 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_serialize_node(__pyx_v_self, __pyx_v_item_value, __pyx_v_node, __pyx_v_item_key); if (unlikely(__pyx_t_3 == ((int)0))) __PYX_ERR(0, 1377, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1375
 *                     error = self._emitter_error()
 *                     raise error
 *                 for item_key, item_value in node.value:             # <<<<<<<<<<<<<<
 *                     self._serialize_node(item_key, node, None)
 *                     self._serialize_node(item_value, node, item_key)
 */
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "yaml/_yaml.pyx":1378
 *                     self._serialize_node(item_key, node, None)
 *                     self._serialize_node(item_value, node, item_key)
 *                 yaml_mapping_end_event_initialize(&event)             # <<<<<<<<<<<<<<
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()
 */
      (void)(yaml_mapping_end_event_initialize((&__pyx_v_event)));

      /* "yaml/_yaml.pyx":1379
 *                     self._serialize_node(item_value, node, item_key)
 *                 yaml_mapping_end_event_initialize(&event)
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                     error = self._emitter_error()
 *                     raise error
 */
      __pyx_t_3 = yaml_emitter_emit((&__pyx_v_self->emitter), (&__pyx_v_event)); if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1379, __pyx_L1_error)
      __pyx_t_2 = (__pyx_t_3 == 0);
      if (unlikely(__pyx_t_2)) {

        /* "yaml/_yaml.pyx":1380
 *                 yaml_mapping_end_event_initialize(&event)
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()             # <<<<<<<<<<<<<<
 *                     raise error
 *             self.ascend_resolver()
 */
        __pyx_t_1 = ((struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter *)__pyx_v_self->__pyx_vtab)->_emitter_error(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1380, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_error = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "yaml/_yaml.pyx":1381
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:
 *                     error = self._emitter_error()
 *                     raise error             # <<<<<<<<<<<<<<
 *             self.ascend_resolver()
 *         return 1
 */
        __Pyx_Raise(__pyx_v_error, 0, 0, 0);
        __PYX_ERR(0, 1381, __pyx_L1_error)

        /* "yaml/_yaml.pyx":1379
 *                     self._serialize_node(item_value, node, item_key)
 *                 yaml_mapping_end_event_initialize(&event)
 *                 if yaml_emitter_emit(&self.emitter, &event) == 0:             # <<<<<<<<<<<<<<
 *                     error = self._emitter_error()
 *                     raise error
 */
      }

      /* "yaml/_yaml.pyx":1354
 *                     error = self._emitter_error()
 *                     raise error
 *             elif node_class is MappingNode:             # <<<<<<<<<<<<<<
 *                 implicit = 0
 *                 tag_object = node.tag
 */
    }
    __pyx_L9:;

    /* "yaml/_yaml.pyx":1382
 *                     error = self._emitter_error()
 *                     raise error
 *             self.ascend_resolver()             # <<<<<<<<<<<<<<
 *         return 1
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_ascend_resolver); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1382, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    __pyx_t_3 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_3 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_3, 0+__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1382, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L6:;

  /* "yaml/_yaml.pyx":1383
 *                     raise error
 *             self.ascend_resolver()
 *         return 1             # <<<<<<<<<<<<<<
 * 
 * cdef int output_handler(void *data, unsigned char *bufferu, size_t size) except 0:
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":1256
 *         return 1
 * 
 *     cdef int _serialize_node(self, object node, object parent, object index) except 0:             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef int implicit
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("yaml._yaml.CEmitter._serialize_node", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_anchor_object);
  __Pyx_XDECREF(__pyx_v_error);
  __Pyx_XDECREF(__pyx_v_node_class);
  __Pyx_XDECREF(__pyx_v_tag_object);
  __Pyx_XDECREF(__pyx_v_value_object);
  __Pyx_XDECREF(__pyx_v_style_object);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XDECREF(__pyx_v_item_key);
  __Pyx_XDECREF(__pyx_v_item_value);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_15__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_8CEmitter_15__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_15__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_15__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_4yaml_5_yaml_8CEmitter_14__reduce_cython__(((struct __pyx_obj_4yaml_5_yaml_CEmitter *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_14__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_Pickling_of_struct_members_such, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("yaml._yaml.CEmitter.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_17__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_8CEmitter_17__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_17__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_8CEmitter_17__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("yaml._yaml.CEmitter.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4yaml_5_yaml_8CEmitter_16__setstate_cython__(((struct __pyx_obj_4yaml_5_yaml_CEmitter *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_8CEmitter_16__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_Pickling_of_struct_members_such, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("yaml._yaml.CEmitter.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "yaml/_yaml.pyx":1385
 *         return 1
 * 
 * cdef int output_handler(void *data, unsigned char *bufferu, size_t size) except 0:             # <<<<<<<<<<<<<<
 *     cdef CEmitter emitter
 *     cdef char *buffer
 */

static int __pyx_f_4yaml_5_yaml_output_handler(void *__pyx_v_data, unsigned char *__pyx_v_bufferu, size_t __pyx_v_size) {
  struct __pyx_obj_4yaml_5_yaml_CEmitter *__pyx_v_emitter = 0;
  char *__pyx_v_buffer;
  PyObject *__pyx_v_value = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("output_handler", 1);

  /* "yaml/_yaml.pyx":1388
 *     cdef CEmitter emitter
 *     cdef char *buffer
 *     buffer = <char *>bufferu             # <<<<<<<<<<<<<<
 *     emitter = <CEmitter>data
 *     if emitter.dump_unicode == 0:
 */
  __pyx_v_buffer = ((char *)__pyx_v_bufferu);

  /* "yaml/_yaml.pyx":1389
 *     cdef char *buffer
 *     buffer = <char *>bufferu
 *     emitter = <CEmitter>data             # <<<<<<<<<<<<<<
 *     if emitter.dump_unicode == 0:
 *         value = PyBytes_FromStringAndSize(buffer, size)
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_data);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_emitter = ((struct __pyx_obj_4yaml_5_yaml_CEmitter *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "yaml/_yaml.pyx":1390
 *     buffer = <char *>bufferu
 *     emitter = <CEmitter>data
 *     if emitter.dump_unicode == 0:             # <<<<<<<<<<<<<<
 *         value = PyBytes_FromStringAndSize(buffer, size)
 *     else:
 */
  __pyx_t_2 = (__pyx_v_emitter->dump_unicode == 0);
  if (__pyx_t_2) {

    /* "yaml/_yaml.pyx":1391
 *     emitter = <CEmitter>data
 *     if emitter.dump_unicode == 0:
 *         value = PyBytes_FromStringAndSize(buffer, size)             # <<<<<<<<<<<<<<
 *     else:
 *         value = PyUnicode_DecodeUTF8(buffer, size, 'strict')
 */
    __pyx_t_1 = PyBytes_FromStringAndSize(__pyx_v_buffer, __pyx_v_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_value = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "yaml/_yaml.pyx":1390
 *     buffer = <char *>bufferu
 *     emitter = <CEmitter>data
 *     if emitter.dump_unicode == 0:             # <<<<<<<<<<<<<<
 *         value = PyBytes_FromStringAndSize(buffer, size)
 *     else:
 */
    goto __pyx_L3;
  }

  /* "yaml/_yaml.pyx":1393
 *         value = PyBytes_FromStringAndSize(buffer, size)
 *     else:
 *         value = PyUnicode_DecodeUTF8(buffer, size, 'strict')             # <<<<<<<<<<<<<<
 *     emitter.stream.write(value)
 *     return 1
 */
  /*else*/ {
    __pyx_t_1 = PyUnicode_DecodeUTF8(__pyx_v_buffer, __pyx_v_size, ((char *)"strict")); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1393, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_value = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "yaml/_yaml.pyx":1394
 *     else:
 *         value = PyUnicode_DecodeUTF8(buffer, size, 'strict')
 *     emitter.stream.write(value)             # <<<<<<<<<<<<<<
 *     return 1
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_emitter->stream, __pyx_n_s_write); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_value};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1394, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "yaml/_yaml.pyx":1395
 *         value = PyUnicode_DecodeUTF8(buffer, size, 'strict')
 *     emitter.stream.write(value)
 *     return 1             # <<<<<<<<<<<<<<
 * 
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "yaml/_yaml.pyx":1385
 *         return 1
 * 
 * cdef int output_handler(void *data, unsigned char *bufferu, size_t size) except 0:             # <<<<<<<<<<<<<<
 *     cdef CEmitter emitter
 *     cdef char *buffer
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("yaml._yaml.output_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_emitter);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_Mark(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_4yaml_5_yaml_5__pyx_unpickle_Mark(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_4yaml_5_yaml_5__pyx_unpickle_Mark = {"__pyx_unpickle_Mark", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_5__pyx_unpickle_Mark, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_4yaml_5_yaml_5__pyx_unpickle_Mark(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_Mark (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_checksum)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Mark", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Mark", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_unpickle_Mark") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Mark", 1, 3, 3, __pyx_nargs); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("yaml._yaml.__pyx_unpickle_Mark", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_4yaml_5_yaml_4__pyx_unpickle_Mark(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_4yaml_5_yaml_4__pyx_unpickle_Mark(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Mark", 1);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x27a7a5c, 0x5c0fd87, 0x3fa45b6):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x27a7a5c, 0x5c0fd87, 0x3fa45b6) = (buffer, column, index, line, name, pointer))" % __pyx_checksum
 */
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_tuple__24, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x27a7a5c, 0x5c0fd87, 0x3fa45b6):
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x27a7a5c, 0x5c0fd87, 0x3fa45b6) = (buffer, column, index, line, name, pointer))" % __pyx_checksum
 *     __pyx_result = Mark.__new__(__pyx_type)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_PickleError)) __PYX_ERR(1, 5, __pyx_L1_error);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v___pyx_PickleError = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum not in (0x27a7a5c, 0x5c0fd87, 0x3fa45b6):
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x27a7a5c, 0x5c0fd87, 0x3fa45b6) = (buffer, column, index, line, name, pointer))" % __pyx_checksum             # <<<<<<<<<<<<<<
 *     __pyx_result = Mark.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_v___pyx_PickleError, __pyx_t_1, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x27a7a5c, 0x5c0fd87, 0x3fa45b6):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x27a7a5c, 0x5c0fd87, 0x3fa45b6) = (buffer, column, index, line, name, pointer))" % __pyx_checksum
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x27a7a5c, 0x5c0fd87, 0x3fa45b6) = (buffer, column, index, line, name, pointer))" % __pyx_checksum
 *     __pyx_result = Mark.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Mark__set_state(<Mark> __pyx_result, __pyx_state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark), __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v___pyx_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v___pyx_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x27a7a5c, 0x5c0fd87, 0x3fa45b6) = (buffer, column, index, line, name, pointer))" % __pyx_checksum
 *     __pyx_result = Mark.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Mark__set_state(<Mark> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_2 = (__pyx_v___pyx_state != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":9
 *     __pyx_result = Mark.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Mark__set_state(<Mark> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_Mark__set_state(Mark __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_1 = __pyx_f_4yaml_5_yaml___pyx_unpickle_Mark__set_state(((struct __pyx_obj_4yaml_5_yaml_Mark *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x27a7a5c, 0x5c0fd87, 0x3fa45b6) = (buffer, column, index, line, name, pointer))" % __pyx_checksum
 *     __pyx_result = Mark.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Mark__set_state(<Mark> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Mark__set_state(<Mark> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_Mark__set_state(Mark __pyx_result, tuple __pyx_state):
 *     __pyx_result.buffer = __pyx_state[0]; __pyx_result.column = __pyx_state[1]; __pyx_result.index = __pyx_state[2]; __pyx_result.line = __pyx_state[3]; __pyx_result.name = __pyx_state[4]; __pyx_result.pointer = __pyx_state[5]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_Mark(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("yaml._yaml.__pyx_unpickle_Mark", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_Mark__set_state(<Mark> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Mark__set_state(Mark __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.buffer = __pyx_state[0]; __pyx_result.column = __pyx_state[1]; __pyx_result.index = __pyx_state[2]; __pyx_result.line = __pyx_state[3]; __pyx_result.name = __pyx_state[4]; __pyx_result.pointer = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_4yaml_5_yaml___pyx_unpickle_Mark__set_state(struct __pyx_obj_4yaml_5_yaml_Mark *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  size_t __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Mark__set_state", 1);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_Mark__set_state(Mark __pyx_result, tuple __pyx_state):
 *     __pyx_result.buffer = __pyx_state[0]; __pyx_result.column = __pyx_state[1]; __pyx_result.index = __pyx_state[2]; __pyx_result.line = __pyx_state[3]; __pyx_result.name = __pyx_state[4]; __pyx_result.pointer = __pyx_state[5]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[6])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->buffer);
  __Pyx_DECREF(__pyx_v___pyx_result->buffer);
  __pyx_v___pyx_result->buffer = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_size_t(__pyx_t_1); if (unlikely((__pyx_t_2 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->column = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_size_t(__pyx_t_1); if (unlikely((__pyx_t_2 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->index = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_size_t(__pyx_t_1); if (unlikely((__pyx_t_2 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->line = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->name);
  __Pyx_DECREF(__pyx_v___pyx_result->name);
  __pyx_v___pyx_result->name = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->pointer);
  __Pyx_DECREF(__pyx_v___pyx_result->pointer);
  __pyx_v___pyx_result->pointer = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_Mark__set_state(Mark __pyx_result, tuple __pyx_state):
 *     __pyx_result.buffer = __pyx_state[0]; __pyx_result.column = __pyx_state[1]; __pyx_result.index = __pyx_state[2]; __pyx_result.line = __pyx_state[3]; __pyx_result.name = __pyx_state[4]; __pyx_result.pointer = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[6])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 > 6);
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":14
 *     __pyx_result.buffer = __pyx_state[0]; __pyx_result.column = __pyx_state[1]; __pyx_result.index = __pyx_state[2]; __pyx_result.line = __pyx_state[3]; __pyx_result.name = __pyx_state[4]; __pyx_result.pointer = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[6])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    __pyx_t_9 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_9 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_6};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_Mark__set_state(Mark __pyx_result, tuple __pyx_state):
 *     __pyx_result.buffer = __pyx_state[0]; __pyx_result.column = __pyx_state[1]; __pyx_result.index = __pyx_state[2]; __pyx_result.line = __pyx_state[3]; __pyx_result.name = __pyx_state[4]; __pyx_result.pointer = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[6])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_Mark__set_state(<Mark> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Mark__set_state(Mark __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.buffer = __pyx_state[0]; __pyx_result.column = __pyx_state[1]; __pyx_result.index = __pyx_state[2]; __pyx_result.line = __pyx_state[3]; __pyx_result.name = __pyx_state[4]; __pyx_result.pointer = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("yaml._yaml.__pyx_unpickle_Mark__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_4yaml_5_yaml_Mark(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4yaml_5_yaml_Mark *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_obj_4yaml_5_yaml_Mark *)o);
  p->name = Py_None; Py_INCREF(Py_None);
  p->buffer = Py_None; Py_INCREF(Py_None);
  p->pointer = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4yaml_5_yaml_Mark(PyObject *o) {
  struct __pyx_obj_4yaml_5_yaml_Mark *p = (struct __pyx_obj_4yaml_5_yaml_Mark *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_4yaml_5_yaml_Mark) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->name);
  Py_CLEAR(p->buffer);
  Py_CLEAR(p->pointer);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static int __pyx_tp_traverse_4yaml_5_yaml_Mark(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4yaml_5_yaml_Mark *p = (struct __pyx_obj_4yaml_5_yaml_Mark *)o;
  if (p->name) {
    e = (*v)(p->name, a); if (e) return e;
  }
  if (p->buffer) {
    e = (*v)(p->buffer, a); if (e) return e;
  }
  if (p->pointer) {
    e = (*v)(p->pointer, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4yaml_5_yaml_Mark(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_4yaml_5_yaml_Mark *p = (struct __pyx_obj_4yaml_5_yaml_Mark *)o;
  tmp = ((PyObject*)p->name);
  p->name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->buffer);
  p->buffer = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->pointer);
  p->pointer = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_4yaml_5_yaml_4Mark_name(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4yaml_5_yaml_4Mark_4name_1__get__(o);
}

static PyObject *__pyx_getprop_4yaml_5_yaml_4Mark_index(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4yaml_5_yaml_4Mark_5index_1__get__(o);
}

static PyObject *__pyx_getprop_4yaml_5_yaml_4Mark_line(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4yaml_5_yaml_4Mark_4line_1__get__(o);
}

static PyObject *__pyx_getprop_4yaml_5_yaml_4Mark_column(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4yaml_5_yaml_4Mark_6column_1__get__(o);
}

static PyObject *__pyx_getprop_4yaml_5_yaml_4Mark_buffer(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4yaml_5_yaml_4Mark_6buffer_1__get__(o);
}

static PyObject *__pyx_getprop_4yaml_5_yaml_4Mark_pointer(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_4yaml_5_yaml_4Mark_7pointer_1__get__(o);
}

static PyMethodDef __pyx_methods_4yaml_5_yaml_Mark[] = {
  {"get_snippet", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_4Mark_3get_snippet, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_4Mark_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_4Mark_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_4yaml_5_yaml_Mark[] = {
  {(char *)"name", __pyx_getprop_4yaml_5_yaml_4Mark_name, 0, (char *)0, 0},
  {(char *)"index", __pyx_getprop_4yaml_5_yaml_4Mark_index, 0, (char *)0, 0},
  {(char *)"line", __pyx_getprop_4yaml_5_yaml_4Mark_line, 0, (char *)0, 0},
  {(char *)"column", __pyx_getprop_4yaml_5_yaml_4Mark_column, 0, (char *)0, 0},
  {(char *)"buffer", __pyx_getprop_4yaml_5_yaml_4Mark_buffer, 0, (char *)0, 0},
  {(char *)"pointer", __pyx_getprop_4yaml_5_yaml_4Mark_pointer, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_4yaml_5_yaml_Mark_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_4yaml_5_yaml_Mark},
  {Py_tp_str, (void *)__pyx_pw_4yaml_5_yaml_4Mark_5__str__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_4yaml_5_yaml_Mark},
  {Py_tp_clear, (void *)__pyx_tp_clear_4yaml_5_yaml_Mark},
  {Py_tp_methods, (void *)__pyx_methods_4yaml_5_yaml_Mark},
  {Py_tp_getset, (void *)__pyx_getsets_4yaml_5_yaml_Mark},
  {Py_tp_init, (void *)__pyx_pw_4yaml_5_yaml_4Mark_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_4yaml_5_yaml_Mark},
  {0, 0},
};
static PyType_Spec __pyx_type_4yaml_5_yaml_Mark_spec = {
  "yaml._yaml.Mark",
  sizeof(struct __pyx_obj_4yaml_5_yaml_Mark),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_4yaml_5_yaml_Mark_slots,
};
#else

static PyTypeObject __pyx_type_4yaml_5_yaml_Mark = {
  PyVarObject_HEAD_INIT(0, 0)
  "yaml._yaml.""Mark", /*tp_name*/
  sizeof(struct __pyx_obj_4yaml_5_yaml_Mark), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4yaml_5_yaml_Mark, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_pw_4yaml_5_yaml_4Mark_5__str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4yaml_5_yaml_Mark, /*tp_traverse*/
  __pyx_tp_clear_4yaml_5_yaml_Mark, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4yaml_5_yaml_Mark, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_4yaml_5_yaml_Mark, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_4yaml_5_yaml_4Mark_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4yaml_5_yaml_Mark, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_4yaml_5_yaml_CParser __pyx_vtable_4yaml_5_yaml_CParser;

static PyObject *__pyx_tp_new_4yaml_5_yaml_CParser(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4yaml_5_yaml_CParser *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_obj_4yaml_5_yaml_CParser *)o);
  p->__pyx_vtab = __pyx_vtabptr_4yaml_5_yaml_CParser;
  p->stream = Py_None; Py_INCREF(Py_None);
  p->stream_name = Py_None; Py_INCREF(Py_None);
  p->current_token = Py_None; Py_INCREF(Py_None);
  p->current_event = Py_None; Py_INCREF(Py_None);
  p->anchors = Py_None; Py_INCREF(Py_None);
  p->stream_cache = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4yaml_5_yaml_CParser(PyObject *o) {
  struct __pyx_obj_4yaml_5_yaml_CParser *p = (struct __pyx_obj_4yaml_5_yaml_CParser *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_4yaml_5_yaml_CParser) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_4yaml_5_yaml_7CParser_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->stream);
  Py_CLEAR(p->stream_name);
  Py_CLEAR(p->current_token);
  Py_CLEAR(p->current_event);
  Py_CLEAR(p->anchors);
  Py_CLEAR(p->stream_cache);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static int __pyx_tp_traverse_4yaml_5_yaml_CParser(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4yaml_5_yaml_CParser *p = (struct __pyx_obj_4yaml_5_yaml_CParser *)o;
  if (p->stream) {
    e = (*v)(p->stream, a); if (e) return e;
  }
  if (p->stream_name) {
    e = (*v)(p->stream_name, a); if (e) return e;
  }
  if (p->current_token) {
    e = (*v)(p->current_token, a); if (e) return e;
  }
  if (p->current_event) {
    e = (*v)(p->current_event, a); if (e) return e;
  }
  if (p->anchors) {
    e = (*v)(p->anchors, a); if (e) return e;
  }
  if (p->stream_cache) {
    e = (*v)(p->stream_cache, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4yaml_5_yaml_CParser(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_4yaml_5_yaml_CParser *p = (struct __pyx_obj_4yaml_5_yaml_CParser *)o;
  tmp = ((PyObject*)p->stream);
  p->stream = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->stream_name);
  p->stream_name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->current_token);
  p->current_token = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->current_event);
  p->current_event = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->anchors);
  p->anchors = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->stream_cache);
  p->stream_cache = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_4yaml_5_yaml_CParser[] = {
  {"dispose", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_5dispose, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"raw_scan", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_7raw_scan, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_token", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_9get_token, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"peek_token", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_11peek_token, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"check_token", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_13check_token, METH_VARARGS|METH_KEYWORDS, 0},
  {"raw_parse", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_15raw_parse, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_event", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_17get_event, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"peek_event", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_19peek_event, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"check_event", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_21check_event, METH_VARARGS|METH_KEYWORDS, 0},
  {"check_node", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_23check_node, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_node", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_25get_node, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_single_node", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_27get_single_node, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_29__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_7CParser_31__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_4yaml_5_yaml_CParser_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_4yaml_5_yaml_CParser},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_4yaml_5_yaml_CParser},
  {Py_tp_clear, (void *)__pyx_tp_clear_4yaml_5_yaml_CParser},
  {Py_tp_methods, (void *)__pyx_methods_4yaml_5_yaml_CParser},
  {Py_tp_init, (void *)__pyx_pw_4yaml_5_yaml_7CParser_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_4yaml_5_yaml_CParser},
  {0, 0},
};
static PyType_Spec __pyx_type_4yaml_5_yaml_CParser_spec = {
  "yaml._yaml.CParser",
  sizeof(struct __pyx_obj_4yaml_5_yaml_CParser),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_4yaml_5_yaml_CParser_slots,
};
#else

static PyTypeObject __pyx_type_4yaml_5_yaml_CParser = {
  PyVarObject_HEAD_INIT(0, 0)
  "yaml._yaml.""CParser", /*tp_name*/
  sizeof(struct __pyx_obj_4yaml_5_yaml_CParser), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4yaml_5_yaml_CParser, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4yaml_5_yaml_CParser, /*tp_traverse*/
  __pyx_tp_clear_4yaml_5_yaml_CParser, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4yaml_5_yaml_CParser, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_4yaml_5_yaml_7CParser_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4yaml_5_yaml_CParser, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_4yaml_5_yaml_CEmitter __pyx_vtable_4yaml_5_yaml_CEmitter;

static PyObject *__pyx_tp_new_4yaml_5_yaml_CEmitter(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_4yaml_5_yaml_CEmitter *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_obj_4yaml_5_yaml_CEmitter *)o);
  p->__pyx_vtab = __pyx_vtabptr_4yaml_5_yaml_CEmitter;
  p->stream = Py_None; Py_INCREF(Py_None);
  p->use_version = Py_None; Py_INCREF(Py_None);
  p->use_tags = Py_None; Py_INCREF(Py_None);
  p->serialized_nodes = Py_None; Py_INCREF(Py_None);
  p->anchors = Py_None; Py_INCREF(Py_None);
  p->use_encoding = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_4yaml_5_yaml_CEmitter(PyObject *o) {
  struct __pyx_obj_4yaml_5_yaml_CEmitter *p = (struct __pyx_obj_4yaml_5_yaml_CEmitter *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_4yaml_5_yaml_CEmitter) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_4yaml_5_yaml_8CEmitter_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->stream);
  Py_CLEAR(p->use_version);
  Py_CLEAR(p->use_tags);
  Py_CLEAR(p->serialized_nodes);
  Py_CLEAR(p->anchors);
  Py_CLEAR(p->use_encoding);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static int __pyx_tp_traverse_4yaml_5_yaml_CEmitter(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_4yaml_5_yaml_CEmitter *p = (struct __pyx_obj_4yaml_5_yaml_CEmitter *)o;
  if (p->stream) {
    e = (*v)(p->stream, a); if (e) return e;
  }
  if (p->use_version) {
    e = (*v)(p->use_version, a); if (e) return e;
  }
  if (p->use_tags) {
    e = (*v)(p->use_tags, a); if (e) return e;
  }
  if (p->serialized_nodes) {
    e = (*v)(p->serialized_nodes, a); if (e) return e;
  }
  if (p->anchors) {
    e = (*v)(p->anchors, a); if (e) return e;
  }
  if (p->use_encoding) {
    e = (*v)(p->use_encoding, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_4yaml_5_yaml_CEmitter(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_4yaml_5_yaml_CEmitter *p = (struct __pyx_obj_4yaml_5_yaml_CEmitter *)o;
  tmp = ((PyObject*)p->stream);
  p->stream = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->use_version);
  p->use_version = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->use_tags);
  p->use_tags = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->serialized_nodes);
  p->serialized_nodes = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->anchors);
  p->anchors = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->use_encoding);
  p->use_encoding = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_4yaml_5_yaml_CEmitter[] = {
  {"dispose", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_5dispose, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"emit", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_7emit, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"open", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_9open, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"close", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_11close, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"serialize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_13serialize, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_15__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_4yaml_5_yaml_8CEmitter_17__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_4yaml_5_yaml_CEmitter_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_4yaml_5_yaml_CEmitter},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_4yaml_5_yaml_CEmitter},
  {Py_tp_clear, (void *)__pyx_tp_clear_4yaml_5_yaml_CEmitter},
  {Py_tp_methods, (void *)__pyx_methods_4yaml_5_yaml_CEmitter},
  {Py_tp_init, (void *)__pyx_pw_4yaml_5_yaml_8CEmitter_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_4yaml_5_yaml_CEmitter},
  {0, 0},
};
static PyType_Spec __pyx_type_4yaml_5_yaml_CEmitter_spec = {
  "yaml._yaml.CEmitter",
  sizeof(struct __pyx_obj_4yaml_5_yaml_CEmitter),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_4yaml_5_yaml_CEmitter_slots,
};
#else

static PyTypeObject __pyx_type_4yaml_5_yaml_CEmitter = {
  PyVarObject_HEAD_INIT(0, 0)
  "yaml._yaml.""CEmitter", /*tp_name*/
  sizeof(struct __pyx_obj_4yaml_5_yaml_CEmitter), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_4yaml_5_yaml_CEmitter, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_4yaml_5_yaml_CEmitter, /*tp_traverse*/
  __pyx_tp_clear_4yaml_5_yaml_CEmitter, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_4yaml_5_yaml_CEmitter, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_4yaml_5_yaml_8CEmitter_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_4yaml_5_yaml_CEmitter, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static int __Pyx_CreateStringTabAndInitStrings(void) {
  __Pyx_StringTabEntry __pyx_string_tab[] = {
    {&__pyx_n_s_AliasEvent, __pyx_k_AliasEvent, sizeof(__pyx_k_AliasEvent), 0, 0, 1, 1},
    {&__pyx_n_s_AliasToken, __pyx_k_AliasToken, sizeof(__pyx_k_AliasToken), 0, 0, 1, 1},
    {&__pyx_n_s_AnchorToken, __pyx_k_AnchorToken, sizeof(__pyx_k_AnchorToken), 0, 0, 1, 1},
    {&__pyx_n_s_AttributeError, __pyx_k_AttributeError, sizeof(__pyx_k_AttributeError), 0, 0, 1, 1},
    {&__pyx_n_s_BlockEndToken, __pyx_k_BlockEndToken, sizeof(__pyx_k_BlockEndToken), 0, 0, 1, 1},
    {&__pyx_n_s_BlockEntryToken, __pyx_k_BlockEntryToken, sizeof(__pyx_k_BlockEntryToken), 0, 0, 1, 1},
    {&__pyx_n_s_BlockMappingStartToken, __pyx_k_BlockMappingStartToken, sizeof(__pyx_k_BlockMappingStartToken), 0, 0, 1, 1},
    {&__pyx_n_s_BlockSequenceStartToken, __pyx_k_BlockSequenceStartToken, sizeof(__pyx_k_BlockSequenceStartToken), 0, 0, 1, 1},
    {&__pyx_n_s_CEmitter, __pyx_k_CEmitter, sizeof(__pyx_k_CEmitter), 0, 0, 1, 1},
    {&__pyx_n_s_CEmitter___reduce_cython, __pyx_k_CEmitter___reduce_cython, sizeof(__pyx_k_CEmitter___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_CEmitter___setstate_cython, __pyx_k_CEmitter___setstate_cython, sizeof(__pyx_k_CEmitter___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_CEmitter_close, __pyx_k_CEmitter_close, sizeof(__pyx_k_CEmitter_close), 0, 0, 1, 1},
    {&__pyx_n_s_CEmitter_dispose, __pyx_k_CEmitter_dispose, sizeof(__pyx_k_CEmitter_dispose), 0, 0, 1, 1},
    {&__pyx_n_s_CEmitter_emit, __pyx_k_CEmitter_emit, sizeof(__pyx_k_CEmitter_emit), 0, 0, 1, 1},
    {&__pyx_n_s_CEmitter_open, __pyx_k_CEmitter_open, sizeof(__pyx_k_CEmitter_open), 0, 0, 1, 1},
    {&__pyx_n_s_CEmitter_serialize, __pyx_k_CEmitter_serialize, sizeof(__pyx_k_CEmitter_serialize), 0, 0, 1, 1},
    {&__pyx_n_s_CParser, __pyx_k_CParser, sizeof(__pyx_k_CParser), 0, 0, 1, 1},
    {&__pyx_n_s_CParser___reduce_cython, __pyx_k_CParser___reduce_cython, sizeof(__pyx_k_CParser___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_CParser___setstate_cython, __pyx_k_CParser___setstate_cython, sizeof(__pyx_k_CParser___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_CParser_check_event, __pyx_k_CParser_check_event, sizeof(__pyx_k_CParser_check_event), 0, 0, 1, 1},
    {&__pyx_n_s_CParser_check_node, __pyx_k_CParser_check_node, sizeof(__pyx_k_CParser_check_node), 0, 0, 1, 1},
    {&__pyx_n_s_CParser_check_token, __pyx_k_CParser_check_token, sizeof(__pyx_k_CParser_check_token), 0, 0, 1, 1},
    {&__pyx_n_s_CParser_dispose, __pyx_k_CParser_dispose, sizeof(__pyx_k_CParser_dispose), 0, 0, 1, 1},
    {&__pyx_n_s_CParser_get_event, __pyx_k_CParser_get_event, sizeof(__pyx_k_CParser_get_event), 0, 0, 1, 1},
    {&__pyx_n_s_CParser_get_node, __pyx_k_CParser_get_node, sizeof(__pyx_k_CParser_get_node), 0, 0, 1, 1},
    {&__pyx_n_s_CParser_get_single_node, __pyx_k_CParser_get_single_node, sizeof(__pyx_k_CParser_get_single_node), 0, 0, 1, 1},
    {&__pyx_n_s_CParser_get_token, __pyx_k_CParser_get_token, sizeof(__pyx_k_CParser_get_token), 0, 0, 1, 1},
    {&__pyx_n_s_CParser_peek_event, __pyx_k_CParser_peek_event, sizeof(__pyx_k_CParser_peek_event), 0, 0, 1, 1},
    {&__pyx_n_s_CParser_peek_token, __pyx_k_CParser_peek_token, sizeof(__pyx_k_CParser_peek_token), 0, 0, 1, 1},
    {&__pyx_n_s_CParser_raw_parse, __pyx_k_CParser_raw_parse, sizeof(__pyx_k_CParser_raw_parse), 0, 0, 1, 1},
    {&__pyx_n_s_CParser_raw_scan, __pyx_k_CParser_raw_scan, sizeof(__pyx_k_CParser_raw_scan), 0, 0, 1, 1},
    {&__pyx_n_s_ComposerError, __pyx_k_ComposerError, sizeof(__pyx_k_ComposerError), 0, 0, 1, 1},
    {&__pyx_n_s_ConstructorError, __pyx_k_ConstructorError, sizeof(__pyx_k_ConstructorError), 0, 0, 1, 1},
    {&__pyx_n_s_DirectiveToken, __pyx_k_DirectiveToken, sizeof(__pyx_k_DirectiveToken), 0, 0, 1, 1},
    {&__pyx_n_s_DocumentEndEvent, __pyx_k_DocumentEndEvent, sizeof(__pyx_k_DocumentEndEvent), 0, 0, 1, 1},
    {&__pyx_n_s_DocumentEndToken, __pyx_k_DocumentEndToken, sizeof(__pyx_k_DocumentEndToken), 0, 0, 1, 1},
    {&__pyx_n_s_DocumentStartEvent, __pyx_k_DocumentStartEvent, sizeof(__pyx_k_DocumentStartEvent), 0, 0, 1, 1},
    {&__pyx_n_s_DocumentStartToken, __pyx_k_DocumentStartToken, sizeof(__pyx_k_DocumentStartToken), 0, 0, 1, 1},
    {&__pyx_n_s_EmitterError, __pyx_k_EmitterError, sizeof(__pyx_k_EmitterError), 0, 0, 1, 1},
    {&__pyx_n_s_FlowEntryToken, __pyx_k_FlowEntryToken, sizeof(__pyx_k_FlowEntryToken), 0, 0, 1, 1},
    {&__pyx_n_s_FlowMappingEndToken, __pyx_k_FlowMappingEndToken, sizeof(__pyx_k_FlowMappingEndToken), 0, 0, 1, 1},
    {&__pyx_n_s_FlowMappingStartToken, __pyx_k_FlowMappingStartToken, sizeof(__pyx_k_FlowMappingStartToken), 0, 0, 1, 1},
    {&__pyx_n_s_FlowSequenceEndToken, __pyx_k_FlowSequenceEndToken, sizeof(__pyx_k_FlowSequenceEndToken), 0, 0, 1, 1},
    {&__pyx_n_s_FlowSequenceStartToken, __pyx_k_FlowSequenceStartToken, sizeof(__pyx_k_FlowSequenceStartToken), 0, 0, 1, 1},
    {&__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_k_Incompatible_checksums_0x_x_vs_0, sizeof(__pyx_k_Incompatible_checksums_0x_x_vs_0), 0, 0, 1, 0},
    {&__pyx_n_s_KeyToken, __pyx_k_KeyToken, sizeof(__pyx_k_KeyToken), 0, 0, 1, 1},
    {&__pyx_n_s_MappingEndEvent, __pyx_k_MappingEndEvent, sizeof(__pyx_k_MappingEndEvent), 0, 0, 1, 1},
    {&__pyx_n_s_MappingNode, __pyx_k_MappingNode, sizeof(__pyx_k_MappingNode), 0, 0, 1, 1},
    {&__pyx_n_s_MappingStartEvent, __pyx_k_MappingStartEvent, sizeof(__pyx_k_MappingStartEvent), 0, 0, 1, 1},
    {&__pyx_n_s_Mark, __pyx_k_Mark, sizeof(__pyx_k_Mark), 0, 0, 1, 1},
    {&__pyx_n_s_Mark___reduce_cython, __pyx_k_Mark___reduce_cython, sizeof(__pyx_k_Mark___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Mark___setstate_cython, __pyx_k_Mark___setstate_cython, sizeof(__pyx_k_Mark___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Mark_get_snippet, __pyx_k_Mark_get_snippet, sizeof(__pyx_k_Mark_get_snippet), 0, 0, 1, 1},
    {&__pyx_n_s_MemoryError, __pyx_k_MemoryError, sizeof(__pyx_k_MemoryError), 0, 0, 1, 1},
    {&__pyx_n_s_ParserError, __pyx_k_ParserError, sizeof(__pyx_k_ParserError), 0, 0, 1, 1},
    {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
    {&__pyx_kp_s_Pickling_of_struct_members_such, __pyx_k_Pickling_of_struct_members_such, sizeof(__pyx_k_Pickling_of_struct_members_such), 0, 0, 1, 0},
    {&__pyx_n_s_ReaderError, __pyx_k_ReaderError, sizeof(__pyx_k_ReaderError), 0, 0, 1, 1},
    {&__pyx_n_s_RepresenterError, __pyx_k_RepresenterError, sizeof(__pyx_k_RepresenterError), 0, 0, 1, 1},
    {&__pyx_n_s_ScalarEvent, __pyx_k_ScalarEvent, sizeof(__pyx_k_ScalarEvent), 0, 0, 1, 1},
    {&__pyx_n_s_ScalarNode, __pyx_k_ScalarNode, sizeof(__pyx_k_ScalarNode), 0, 0, 1, 1},
    {&__pyx_n_s_ScalarToken, __pyx_k_ScalarToken, sizeof(__pyx_k_ScalarToken), 0, 0, 1, 1},
    {&__pyx_n_s_ScannerError, __pyx_k_ScannerError, sizeof(__pyx_k_ScannerError), 0, 0, 1, 1},
    {&__pyx_n_s_SequenceEndEvent, __pyx_k_SequenceEndEvent, sizeof(__pyx_k_SequenceEndEvent), 0, 0, 1, 1},
    {&__pyx_n_s_SequenceNode, __pyx_k_SequenceNode, sizeof(__pyx_k_SequenceNode), 0, 0, 1, 1},
    {&__pyx_n_s_SequenceStartEvent, __pyx_k_SequenceStartEvent, sizeof(__pyx_k_SequenceStartEvent), 0, 0, 1, 1},
    {&__pyx_n_s_SerializerError, __pyx_k_SerializerError, sizeof(__pyx_k_SerializerError), 0, 0, 1, 1},
    {&__pyx_n_s_StreamEndEvent, __pyx_k_StreamEndEvent, sizeof(__pyx_k_StreamEndEvent), 0, 0, 1, 1},
    {&__pyx_n_s_StreamEndToken, __pyx_k_StreamEndToken, sizeof(__pyx_k_StreamEndToken), 0, 0, 1, 1},
    {&__pyx_n_s_StreamStartEvent, __pyx_k_StreamStartEvent, sizeof(__pyx_k_StreamStartEvent), 0, 0, 1, 1},
    {&__pyx_n_s_StreamStartToken, __pyx_k_StreamStartToken, sizeof(__pyx_k_StreamStartToken), 0, 0, 1, 1},
    {&__pyx_n_u_TAG, __pyx_k_TAG, sizeof(__pyx_k_TAG), 0, 1, 0, 1},
    {&__pyx_n_s_TagToken, __pyx_k_TagToken, sizeof(__pyx_k_TagToken), 0, 0, 1, 1},
    {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
    {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
    {&__pyx_n_s_ValueToken, __pyx_k_ValueToken, sizeof(__pyx_k_ValueToken), 0, 0, 1, 1},
    {&__pyx_n_u_YAML, __pyx_k_YAML, sizeof(__pyx_k_YAML), 0, 1, 0, 1},
    {&__pyx_n_s_YAMLError, __pyx_k_YAMLError, sizeof(__pyx_k_YAMLError), 0, 0, 1, 1},
    {&__pyx_kp_s__12, __pyx_k__12, sizeof(__pyx_k__12), 0, 0, 1, 0},
    {&__pyx_kp_s__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 0, 1, 0},
    {&__pyx_kp_s__14, __pyx_k__14, sizeof(__pyx_k__14), 0, 0, 1, 0},
    {&__pyx_n_s__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 0, 1, 1},
    {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
    {&__pyx_kp_u__25, __pyx_k__25, sizeof(__pyx_k__25), 0, 1, 0, 0},
    {&__pyx_n_s__26, __pyx_k__26, sizeof(__pyx_k__26), 0, 0, 1, 1},
    {&__pyx_kp_u__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 1, 0, 0},
    {&__pyx_kp_s__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 0, 1, 0},
    {&__pyx_kp_u__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 1, 0, 0},
    {&__pyx_kp_s__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 0, 1, 0},
    {&__pyx_kp_u__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 1, 0, 0},
    {&__pyx_kp_s__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 0, 1, 0},
    {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
    {&__pyx_kp_s__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 0, 1, 0},
    {&__pyx_kp_u__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 1, 0, 0},
    {&__pyx_kp_u_a_string_or_stream_input_is_requ, __pyx_k_a_string_or_stream_input_is_requ, sizeof(__pyx_k_a_string_or_stream_input_is_requ), 0, 1, 0, 0},
    {&__pyx_kp_u_a_string_value_is_expected, __pyx_k_a_string_value_is_expected, sizeof(__pyx_k_a_string_value_is_expected), 0, 1, 0, 0},
    {&__pyx_n_s_allow_unicode, __pyx_k_allow_unicode, sizeof(__pyx_k_allow_unicode), 0, 0, 1, 1},
    {&__pyx_n_s_anchor, __pyx_k_anchor, sizeof(__pyx_k_anchor), 0, 0, 1, 1},
    {&__pyx_kp_u_anchor_must_be_a_string, __pyx_k_anchor_must_be_a_string, sizeof(__pyx_k_anchor_must_be_a_string), 0, 1, 0, 0},
    {&__pyx_n_s_ascend_resolver, __pyx_k_ascend_resolver, sizeof(__pyx_k_ascend_resolver), 0, 0, 1, 1},
    {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
    {&__pyx_n_s_buffer, __pyx_k_buffer, sizeof(__pyx_k_buffer), 0, 0, 1, 1},
    {&__pyx_kp_u_but_found_another_document, __pyx_k_but_found_another_document, sizeof(__pyx_k_but_found_another_document), 0, 1, 0, 0},
    {&__pyx_kp_u_byte_string, __pyx_k_byte_string, sizeof(__pyx_k_byte_string), 0, 1, 0, 0},
    {&__pyx_n_s_cache, __pyx_k_cache, sizeof(__pyx_k_cache), 0, 0, 1, 1},
    {&__pyx_n_s_canonical, __pyx_k_canonical, sizeof(__pyx_k_canonical), 0, 0, 1, 1},
    {&__pyx_n_s_check_event, __pyx_k_check_event, sizeof(__pyx_k_check_event), 0, 0, 1, 1},
    {&__pyx_n_s_check_node, __pyx_k_check_node, sizeof(__pyx_k_check_node), 0, 0, 1, 1},
    {&__pyx_n_s_check_token, __pyx_k_check_token, sizeof(__pyx_k_check_token), 0, 0, 1, 1},
    {&__pyx_n_s_choice, __pyx_k_choice, sizeof(__pyx_k_choice), 0, 0, 1, 1},
    {&__pyx_n_s_choices, __pyx_k_choices, sizeof(__pyx_k_choices), 0, 0, 1, 1},
    {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
    {&__pyx_n_s_class_getitem, __pyx_k_class_getitem, sizeof(__pyx_k_class_getitem), 0, 0, 1, 1},
    {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
    {&__pyx_n_s_column, __pyx_k_column, sizeof(__pyx_k_column), 0, 0, 1, 1},
    {&__pyx_n_s_composer, __pyx_k_composer, sizeof(__pyx_k_composer), 0, 0, 1, 1},
    {&__pyx_n_s_constructor, __pyx_k_constructor, sizeof(__pyx_k_constructor), 0, 0, 1, 1},
    {&__pyx_n_s_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 0, 1, 1},
    {&__pyx_n_s_descend_resolver, __pyx_k_descend_resolver, sizeof(__pyx_k_descend_resolver), 0, 0, 1, 1},
    {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
    {&__pyx_n_s_dict_2, __pyx_k_dict_2, sizeof(__pyx_k_dict_2), 0, 0, 1, 1},
    {&__pyx_kp_u_disable, __pyx_k_disable, sizeof(__pyx_k_disable), 0, 1, 0, 0},
    {&__pyx_n_s_dispose, __pyx_k_dispose, sizeof(__pyx_k_dispose), 0, 0, 1, 1},
    {&__pyx_n_s_document, __pyx_k_document, sizeof(__pyx_k_document), 0, 0, 1, 1},
    {&__pyx_n_s_done, __pyx_k_done, sizeof(__pyx_k_done), 0, 0, 1, 1},
    {&__pyx_n_s_emit, __pyx_k_emit, sizeof(__pyx_k_emit), 0, 0, 1, 1},
    {&__pyx_n_s_emitter, __pyx_k_emitter, sizeof(__pyx_k_emitter), 0, 0, 1, 1},
    {&__pyx_kp_u_enable, __pyx_k_enable, sizeof(__pyx_k_enable), 0, 1, 0, 0},
    {&__pyx_n_s_encoding, __pyx_k_encoding, sizeof(__pyx_k_encoding), 0, 0, 1, 1},
    {&__pyx_n_u_encoding, __pyx_k_encoding, sizeof(__pyx_k_encoding), 0, 1, 0, 1},
    {&__pyx_n_s_end_mark, __pyx_k_end_mark, sizeof(__pyx_k_end_mark), 0, 0, 1, 1},
    {&__pyx_n_s_error, __pyx_k_error, sizeof(__pyx_k_error), 0, 0, 1, 1},
    {&__pyx_n_s_event, __pyx_k_event, sizeof(__pyx_k_event), 0, 0, 1, 1},
    {&__pyx_n_s_event_class, __pyx_k_event_class, sizeof(__pyx_k_event_class), 0, 0, 1, 1},
    {&__pyx_n_s_event_object, __pyx_k_event_object, sizeof(__pyx_k_event_object), 0, 0, 1, 1},
    {&__pyx_n_s_events, __pyx_k_events, sizeof(__pyx_k_events), 0, 0, 1, 1},
    {&__pyx_kp_u_expected_a_single_document_in_th, __pyx_k_expected_a_single_document_in_th, sizeof(__pyx_k_expected_a_single_document_in_th), 0, 1, 0, 0},
    {&__pyx_n_s_explicit, __pyx_k_explicit, sizeof(__pyx_k_explicit), 0, 0, 1, 1},
    {&__pyx_n_s_explicit_end, __pyx_k_explicit_end, sizeof(__pyx_k_explicit_end), 0, 0, 1, 1},
    {&__pyx_n_s_explicit_start, __pyx_k_explicit_start, sizeof(__pyx_k_explicit_start), 0, 0, 1, 1},
    {&__pyx_kp_u_file, __pyx_k_file, sizeof(__pyx_k_file), 0, 1, 0, 0},
    {&__pyx_n_s_flow_style, __pyx_k_flow_style, sizeof(__pyx_k_flow_style), 0, 0, 1, 1},
    {&__pyx_kp_u_found_duplicate_anchor_first_occ, __pyx_k_found_duplicate_anchor_first_occ, sizeof(__pyx_k_found_duplicate_anchor_first_occ), 0, 1, 0, 0},
    {&__pyx_kp_u_found_undefined_alias, __pyx_k_found_undefined_alias, sizeof(__pyx_k_found_undefined_alias), 0, 1, 0, 0},
    {&__pyx_kp_u_gc, __pyx_k_gc, sizeof(__pyx_k_gc), 0, 1, 0, 0},
    {&__pyx_n_s_get_event, __pyx_k_get_event, sizeof(__pyx_k_get_event), 0, 0, 1, 1},
    {&__pyx_n_s_get_node, __pyx_k_get_node, sizeof(__pyx_k_get_node), 0, 0, 1, 1},
    {&__pyx_n_s_get_single_node, __pyx_k_get_single_node, sizeof(__pyx_k_get_single_node), 0, 0, 1, 1},
    {&__pyx_n_s_get_snippet, __pyx_k_get_snippet, sizeof(__pyx_k_get_snippet), 0, 0, 1, 1},
    {&__pyx_n_s_get_token, __pyx_k_get_token, sizeof(__pyx_k_get_token), 0, 0, 1, 1},
    {&__pyx_n_s_get_version, __pyx_k_get_version, sizeof(__pyx_k_get_version), 0, 0, 1, 1},
    {&__pyx_n_s_get_version_string, __pyx_k_get_version_string, sizeof(__pyx_k_get_version_string), 0, 0, 1, 1},
    {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
    {&__pyx_n_s_handle, __pyx_k_handle, sizeof(__pyx_k_handle), 0, 0, 1, 1},
    {&__pyx_kp_u_id_03d, __pyx_k_id_03d, sizeof(__pyx_k_id_03d), 0, 1, 0, 0},
    {&__pyx_n_s_implicit, __pyx_k_implicit, sizeof(__pyx_k_implicit), 0, 0, 1, 1},
    {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
    {&__pyx_kp_s_in_s_line_d_column_d, __pyx_k_in_s_line_d_column_d, sizeof(__pyx_k_in_s_line_d_column_d), 0, 0, 1, 0},
    {&__pyx_n_s_indent, __pyx_k_indent, sizeof(__pyx_k_indent), 0, 0, 1, 1},
    {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
    {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
    {&__pyx_kp_u_invalid_event_s, __pyx_k_invalid_event_s, sizeof(__pyx_k_invalid_event_s), 0, 1, 0, 0},
    {&__pyx_n_s_is_coroutine, __pyx_k_is_coroutine, sizeof(__pyx_k_is_coroutine), 0, 0, 1, 1},
    {&__pyx_kp_u_isenabled, __pyx_k_isenabled, sizeof(__pyx_k_isenabled), 0, 1, 0, 0},
    {&__pyx_n_s_line, __pyx_k_line, sizeof(__pyx_k_line), 0, 0, 1, 1},
    {&__pyx_n_s_line_break, __pyx_k_line_break, sizeof(__pyx_k_line_break), 0, 0, 1, 1},
    {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
    {&__pyx_n_s_major, __pyx_k_major, sizeof(__pyx_k_major), 0, 0, 1, 1},
    {&__pyx_n_s_mark, __pyx_k_mark, sizeof(__pyx_k_mark), 0, 0, 1, 1},
    {&__pyx_n_s_minor, __pyx_k_minor, sizeof(__pyx_k_minor), 0, 0, 1, 1},
    {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
    {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
    {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
    {&__pyx_kp_u_no_emitter_error, __pyx_k_no_emitter_error, sizeof(__pyx_k_no_emitter_error), 0, 1, 0, 0},
    {&__pyx_kp_u_no_parser_error, __pyx_k_no_parser_error, sizeof(__pyx_k_no_parser_error), 0, 1, 0, 0},
    {&__pyx_n_s_node, __pyx_k_node, sizeof(__pyx_k_node), 0, 0, 1, 1},
    {&__pyx_n_s_nodes, __pyx_k_nodes, sizeof(__pyx_k_nodes), 0, 0, 1, 1},
    {&__pyx_n_s_open, __pyx_k_open, sizeof(__pyx_k_open), 0, 0, 1, 1},
    {&__pyx_n_s_parser, __pyx_k_parser, sizeof(__pyx_k_parser), 0, 0, 1, 1},
    {&__pyx_n_s_patch, __pyx_k_patch, sizeof(__pyx_k_patch), 0, 0, 1, 1},
    {&__pyx_n_s_peek_event, __pyx_k_peek_event, sizeof(__pyx_k_peek_event), 0, 0, 1, 1},
    {&__pyx_n_s_peek_token, __pyx_k_peek_token, sizeof(__pyx_k_peek_token), 0, 0, 1, 1},
    {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
    {&__pyx_n_s_pointer, __pyx_k_pointer, sizeof(__pyx_k_pointer), 0, 0, 1, 1},
    {&__pyx_n_s_prefix, __pyx_k_prefix, sizeof(__pyx_k_prefix), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_unpickle_Mark, __pyx_k_pyx_unpickle_Mark, sizeof(__pyx_k_pyx_unpickle_Mark), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
    {&__pyx_n_s_raw_parse, __pyx_k_raw_parse, sizeof(__pyx_k_raw_parse), 0, 0, 1, 1},
    {&__pyx_n_s_raw_scan, __pyx_k_raw_scan, sizeof(__pyx_k_raw_scan), 0, 0, 1, 1},
    {&__pyx_n_s_read, __pyx_k_read, sizeof(__pyx_k_read), 0, 0, 1, 1},
    {&__pyx_n_s_reader, __pyx_k_reader, sizeof(__pyx_k_reader), 0, 0, 1, 1},
    {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
    {&__pyx_n_s_representer, __pyx_k_representer, sizeof(__pyx_k_representer), 0, 0, 1, 1},
    {&__pyx_n_s_resolve, __pyx_k_resolve, sizeof(__pyx_k_resolve), 0, 0, 1, 1},
    {&__pyx_n_s_scanner, __pyx_k_scanner, sizeof(__pyx_k_scanner), 0, 0, 1, 1},
    {&__pyx_kp_u_second_occurrence, __pyx_k_second_occurrence, sizeof(__pyx_k_second_occurrence), 0, 1, 0, 0},
    {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
    {&__pyx_kp_s_self_parsed_event_cannot_be_conv, __pyx_k_self_parsed_event_cannot_be_conv, sizeof(__pyx_k_self_parsed_event_cannot_be_conv), 0, 0, 1, 0},
    {&__pyx_n_s_serialize, __pyx_k_serialize, sizeof(__pyx_k_serialize), 0, 0, 1, 1},
    {&__pyx_n_s_serializer, __pyx_k_serializer, sizeof(__pyx_k_serializer), 0, 0, 1, 1},
    {&__pyx_kp_u_serializer_is_already_opened, __pyx_k_serializer_is_already_opened, sizeof(__pyx_k_serializer_is_already_opened), 0, 1, 0, 0},
    {&__pyx_kp_u_serializer_is_closed, __pyx_k_serializer_is_closed, sizeof(__pyx_k_serializer_is_closed), 0, 1, 0, 0},
    {&__pyx_kp_u_serializer_is_not_opened, __pyx_k_serializer_is_not_opened, sizeof(__pyx_k_serializer_is_not_opened), 0, 1, 0, 0},
    {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
    {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
    {&__pyx_n_s_start_mark, __pyx_k_start_mark, sizeof(__pyx_k_start_mark), 0, 0, 1, 1},
    {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
    {&__pyx_n_s_stream, __pyx_k_stream, sizeof(__pyx_k_stream), 0, 0, 1, 1},
    {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
    {&__pyx_n_s_style, __pyx_k_style, sizeof(__pyx_k_style), 0, 0, 1, 1},
    {&__pyx_n_s_tag, __pyx_k_tag, sizeof(__pyx_k_tag), 0, 0, 1, 1},
    {&__pyx_n_s_tag_directives_end, __pyx_k_tag_directives_end, sizeof(__pyx_k_tag_directives_end), 0, 0, 1, 1},
    {&__pyx_n_s_tag_directives_start, __pyx_k_tag_directives_start, sizeof(__pyx_k_tag_directives_start), 0, 0, 1, 1},
    {&__pyx_n_s_tag_directives_value, __pyx_k_tag_directives_value, sizeof(__pyx_k_tag_directives_value), 0, 0, 1, 1},
    {&__pyx_kp_u_tag_handle_must_be_a_string, __pyx_k_tag_handle_must_be_a_string, sizeof(__pyx_k_tag_handle_must_be_a_string), 0, 1, 0, 0},
    {&__pyx_kp_u_tag_must_be_a_string, __pyx_k_tag_must_be_a_string, sizeof(__pyx_k_tag_must_be_a_string), 0, 1, 0, 0},
    {&__pyx_kp_u_tag_prefix_must_be_a_string, __pyx_k_tag_prefix_must_be_a_string, sizeof(__pyx_k_tag_prefix_must_be_a_string), 0, 1, 0, 0},
    {&__pyx_n_s_tags, __pyx_k_tags, sizeof(__pyx_k_tags), 0, 0, 1, 1},
    {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
    {&__pyx_n_s_token, __pyx_k_token, sizeof(__pyx_k_token), 0, 0, 1, 1},
    {&__pyx_n_s_token_class, __pyx_k_token_class, sizeof(__pyx_k_token_class), 0, 0, 1, 1},
    {&__pyx_n_s_tokens, __pyx_k_tokens, sizeof(__pyx_k_tokens), 0, 0, 1, 1},
    {&__pyx_kp_u_too_many_tags, __pyx_k_too_many_tags, sizeof(__pyx_k_too_many_tags), 0, 1, 0, 0},
    {&__pyx_kp_u_unicode_string, __pyx_k_unicode_string, sizeof(__pyx_k_unicode_string), 0, 1, 0, 0},
    {&__pyx_kp_u_unknown_event_type, __pyx_k_unknown_event_type, sizeof(__pyx_k_unknown_event_type), 0, 1, 0, 0},
    {&__pyx_kp_u_unknown_token_type, __pyx_k_unknown_token_type, sizeof(__pyx_k_unknown_token_type), 0, 1, 0, 0},
    {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
    {&__pyx_n_s_use_setstate, __pyx_k_use_setstate, sizeof(__pyx_k_use_setstate), 0, 0, 1, 1},
    {&__pyx_kp_s_utf_16_be, __pyx_k_utf_16_be, sizeof(__pyx_k_utf_16_be), 0, 0, 1, 0},
    {&__pyx_kp_u_utf_16_be, __pyx_k_utf_16_be, sizeof(__pyx_k_utf_16_be), 0, 1, 0, 0},
    {&__pyx_kp_s_utf_16_le, __pyx_k_utf_16_le, sizeof(__pyx_k_utf_16_le), 0, 0, 1, 0},
    {&__pyx_kp_u_utf_16_le, __pyx_k_utf_16_le, sizeof(__pyx_k_utf_16_le), 0, 1, 0, 0},
    {&__pyx_kp_u_utf_8, __pyx_k_utf_8, sizeof(__pyx_k_utf_8), 0, 1, 0, 0},
    {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
    {&__pyx_kp_u_value_must_be_a_string, __pyx_k_value_must_be_a_string, sizeof(__pyx_k_value_must_be_a_string), 0, 1, 0, 0},
    {&__pyx_n_s_version, __pyx_k_version, sizeof(__pyx_k_version), 0, 0, 1, 1},
    {&__pyx_n_s_version_directive, __pyx_k_version_directive, sizeof(__pyx_k_version_directive), 0, 0, 1, 1},
    {&__pyx_n_s_version_directive_value, __pyx_k_version_directive_value, sizeof(__pyx_k_version_directive_value), 0, 0, 1, 1},
    {&__pyx_n_s_width, __pyx_k_width, sizeof(__pyx_k_width), 0, 0, 1, 1},
    {&__pyx_n_s_write, __pyx_k_write, sizeof(__pyx_k_write), 0, 0, 1, 1},
    {&__pyx_n_s_yaml, __pyx_k_yaml, sizeof(__pyx_k_yaml), 0, 0, 1, 1},
    {&__pyx_n_s_yaml__yaml, __pyx_k_yaml__yaml, sizeof(__pyx_k_yaml__yaml), 0, 0, 1, 1},
    {&__pyx_kp_s_yaml__yaml_pyx, __pyx_k_yaml__yaml_pyx, sizeof(__pyx_k_yaml__yaml_pyx), 0, 0, 1, 0},
    {0, 0, 0, 0, 0, 0, 0}
  };
  return __Pyx_InitStrings(__pyx_string_tab);
}
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_MemoryError = __Pyx_GetBuiltinName(__pyx_n_s_MemoryError); if (!__pyx_builtin_MemoryError) __PYX_ERR(0, 262, __pyx_L1_error)
  __pyx_builtin_AttributeError = __Pyx_GetBuiltinName(__pyx_n_s_AttributeError); if (!__pyx_builtin_AttributeError) __PYX_ERR(0, 267, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(0, 288, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 330, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "yaml/_yaml.pyx":288
 *                 self.stream_name = u'<byte string>'
 *             if PyBytes_CheckExact(stream) == 0:
 *                 raise TypeError(u"a string or stream input is required")             # <<<<<<<<<<<<<<
 *             self.stream = stream
 *             yaml_parser_set_input_string(&self.parser, PyBytes_AS_Yaml_STRING(stream), PyBytes_GET_SIZE(stream))
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_u_a_string_or_stream_input_is_requ); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "yaml/_yaml.pyx":330
 *             else:
 *                 return ParserError(context, context_mark, problem, problem_mark)
 *         raise ValueError(u"no parser error")             # <<<<<<<<<<<<<<
 * 
 *     def raw_scan(self):
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_u_no_parser_error); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "yaml/_yaml.pyx":450
 *                     start_mark, end_mark, style)
 *         else:
 *             raise ValueError(u"unknown token type")             # <<<<<<<<<<<<<<
 * 
 *     def get_token(self):
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_u_unknown_token_type); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "yaml/_yaml.pyx":625
 *             return MappingEndEvent(start_mark, end_mark)
 *         else:
 *             raise ValueError(u"unknown event type")             # <<<<<<<<<<<<<<
 * 
 *     def get_event(self):
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_u_unknown_event_type); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "yaml/_yaml.pyx":872
 *             parser.unicode_source = 1
 *         if PyBytes_CheckExact(value) == 0:
 *             raise TypeError(u"a string value is expected")             # <<<<<<<<<<<<<<
 *         parser.stream_cache = value
 *         parser.stream_cache_pos = 0
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_u_a_string_value_is_expected); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "yaml/_yaml.pyx":956
 *             problem = PyUnicode_FromString(self.emitter.problem)
 *             return EmitterError(problem)
 *         raise ValueError(u"no emitter error")             # <<<<<<<<<<<<<<
 * 
 *     cdef int _object_to_event(self, object event_object, yaml_event_t *event) except 0:
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_kp_u_no_emitter_error); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 956, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "yaml/_yaml.pyx":999
 *             if event_object.tags:
 *                 if len(event_object.tags) > 128:
 *                     raise ValueError(u"too many tags")             # <<<<<<<<<<<<<<
 *                 tag_directives_start = tag_directives_value
 *                 tag_directives_end = tag_directives_value
 */
  __pyx_tuple__16 = PyTuple_Pack(1, __pyx_kp_u_too_many_tags); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(0, 999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "yaml/_yaml.pyx":1009
 *                         cache.append(handle)
 *                     if not PyBytes_CheckExact(handle):
 *                         raise TypeError(u"tag handle must be a string")             # <<<<<<<<<<<<<<
 *                     tag_directives_end.handle = PyBytes_AS_Yaml_STRING(handle)
 *                     if PyUnicode_CheckExact(prefix):
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_u_tag_handle_must_be_a_string); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(0, 1009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "yaml/_yaml.pyx":1015
 *                         cache.append(prefix)
 *                     if not PyBytes_CheckExact(prefix):
 *                         raise TypeError(u"tag prefix must be a string")             # <<<<<<<<<<<<<<
 *                     tag_directives_end.prefix = PyBytes_AS_Yaml_STRING(prefix)
 *                     tag_directives_end = tag_directives_end+1
 */
  __pyx_tuple__18 = PyTuple_Pack(1, __pyx_kp_u_tag_prefix_must_be_a_string); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 1015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "yaml/_yaml.pyx":1035
 *                 anchor_object = PyUnicode_AsUTF8String(anchor_object)
 *             if not PyBytes_CheckExact(anchor_object):
 *                 raise TypeError(u"anchor must be a string")             # <<<<<<<<<<<<<<
 *             anchor = PyBytes_AS_Yaml_STRING(anchor_object)
 *             if yaml_alias_event_initialize(event, anchor) == 0:
 */
  __pyx_tuple__19 = PyTuple_Pack(1, __pyx_kp_u_anchor_must_be_a_string); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 1035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "yaml/_yaml.pyx":1054
 *                     tag_object = PyUnicode_AsUTF8String(tag_object)
 *                 if not PyBytes_CheckExact(tag_object):
 *                     raise TypeError(u"tag must be a string")             # <<<<<<<<<<<<<<
 *                 tag = PyBytes_AS_Yaml_STRING(tag_object)
 *             value_object = event_object.value
 */
  __pyx_tuple__20 = PyTuple_Pack(1, __pyx_kp_u_tag_must_be_a_string); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "yaml/_yaml.pyx":1060
 *                 value_object = PyUnicode_AsUTF8String(value_object)
 *             if not PyBytes_CheckExact(value_object):
 *                 raise TypeError(u"value must be a string")             # <<<<<<<<<<<<<<
 *             value = PyBytes_AS_Yaml_STRING(value_object)
 *             length = PyBytes_GET_SIZE(value_object)
 */
  __pyx_tuple__21 = PyTuple_Pack(1, __pyx_kp_u_value_must_be_a_string); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 1060, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "yaml/_yaml.pyx":1291
 *                 quoted_implicit = 0
 *                 tag_object = node.tag
 *                 if self.resolve(ScalarNode, node.value, (True, False)) == tag_object:             # <<<<<<<<<<<<<<
 *                     plain_implicit = 1
 *                 if self.resolve(ScalarNode, node.value, (False, True)) == tag_object:
 */
  __pyx_tuple__22 = PyTuple_Pack(2, Py_True, Py_False); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(0, 1291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "yaml/_yaml.pyx":1293
 *                 if self.resolve(ScalarNode, node.value, (True, False)) == tag_object:
 *                     plain_implicit = 1
 *                 if self.resolve(ScalarNode, node.value, (False, True)) == tag_object:             # <<<<<<<<<<<<<<
 *                     quoted_implicit = 1
 *                 tag = NULL
 */
  __pyx_tuple__23 = PyTuple_Pack(2, Py_False, Py_True); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 1293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x27a7a5c, 0x5c0fd87, 0x3fa45b6):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x27a7a5c, 0x5c0fd87, 0x3fa45b6) = (buffer, column, index, line, name, pointer))" % __pyx_checksum
 */
  __pyx_tuple__24 = PyTuple_Pack(3, __pyx_int_41581148, __pyx_int_96533895, __pyx_int_66733494); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "yaml/_yaml.pyx":4
 * import yaml
 * 
 * def get_version_string():             # <<<<<<<<<<<<<<
 *     cdef const char *value
 *     value = yaml_get_version_string()
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_n_s_value); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);
  __pyx_codeobj__28 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__27, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_get_version_string, 4, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__28)) __PYX_ERR(0, 4, __pyx_L1_error)

  /* "yaml/_yaml.pyx":9
 *     return PyUnicode_FromString(value)
 * 
 * def get_version():             # <<<<<<<<<<<<<<
 *     cdef int major, minor, patch
 *     yaml_get_version(&major, &minor, &patch)
 */
  __pyx_tuple__29 = PyTuple_Pack(3, __pyx_n_s_major, __pyx_n_s_minor, __pyx_n_s_patch); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);
  __pyx_codeobj__30 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__29, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_get_version, 9, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__30)) __PYX_ERR(0, 9, __pyx_L1_error)

  /* "yaml/_yaml.pyx":78
 *         self.pointer = pointer
 * 
 *     def get_snippet(self):             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_tuple__31 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(0, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);
  __pyx_codeobj__32 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__31, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_get_snippet, 78, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__32)) __PYX_ERR(0, 78, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_tuple__33 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_state, __pyx_n_s_dict_2, __pyx_n_s_use_setstate); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);
  __pyx_codeobj__34 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__33, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__34)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Mark, (type(self), 0x27a7a5c, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Mark__set_state(self, __pyx_state)
 */
  __pyx_tuple__35 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pyx_state); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);
  __pyx_codeobj__36 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__35, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 16, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__36)) __PYX_ERR(1, 16, __pyx_L1_error)

  /* "yaml/_yaml.pyx":299
 *         yaml_event_delete(&self.parsed_event)
 * 
 *     def dispose(self):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
  __pyx_codeobj__37 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__31, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_dispose, 299, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__37)) __PYX_ERR(0, 299, __pyx_L1_error)

  /* "yaml/_yaml.pyx":332
 *         raise ValueError(u"no parser error")
 * 
 *     def raw_scan(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_token_t token
 *         cdef int done
 */
  __pyx_tuple__38 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_token, __pyx_n_s_done, __pyx_n_s_count, __pyx_n_s_error); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(0, 332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);
  __pyx_codeobj__39 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__38, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_raw_scan, 332, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__39)) __PYX_ERR(0, 332, __pyx_L1_error)

  /* "yaml/_yaml.pyx":452
 *             raise ValueError(u"unknown token type")
 * 
 *     def get_token(self):             # <<<<<<<<<<<<<<
 *         if self.current_token is not None:
 *             value = self.current_token
 */
  __pyx_tuple__40 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_value); if (unlikely(!__pyx_tuple__40)) __PYX_ERR(0, 452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);
  __pyx_codeobj__41 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__40, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_get_token, 452, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__41)) __PYX_ERR(0, 452, __pyx_L1_error)

  /* "yaml/_yaml.pyx":460
 *         return value
 * 
 *     def peek_token(self):             # <<<<<<<<<<<<<<
 *         if self.current_token is None:
 *             self.current_token = self._scan()
 */
  __pyx_codeobj__42 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__31, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_peek_token, 460, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__42)) __PYX_ERR(0, 460, __pyx_L1_error)

  /* "yaml/_yaml.pyx":465
 *         return self.current_token
 * 
 *     def check_token(self, *choices):             # <<<<<<<<<<<<<<
 *         if self.current_token is None:
 *             self.current_token = self._scan()
 */
  __pyx_tuple__43 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_choices, __pyx_n_s_token_class, __pyx_n_s_choice); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);
  __pyx_codeobj__44 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__43, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_check_token, 465, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__44)) __PYX_ERR(0, 465, __pyx_L1_error)

  /* "yaml/_yaml.pyx":478
 *         return False
 * 
 *     def raw_parse(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef int done
 */
  __pyx_tuple__45 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_event, __pyx_n_s_done, __pyx_n_s_count, __pyx_n_s_error); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);
  __pyx_codeobj__46 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__45, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_raw_parse, 478, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__46)) __PYX_ERR(0, 478, __pyx_L1_error)

  /* "yaml/_yaml.pyx":627
 *             raise ValueError(u"unknown event type")
 * 
 *     def get_event(self):             # <<<<<<<<<<<<<<
 *         if self.current_event is not None:
 *             value = self.current_event
 */
  __pyx_codeobj__47 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__40, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_get_event, 627, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__47)) __PYX_ERR(0, 627, __pyx_L1_error)

  /* "yaml/_yaml.pyx":635
 *         return value
 * 
 *     def peek_event(self):             # <<<<<<<<<<<<<<
 *         if self.current_event is None:
 *             self.current_event = self._parse()
 */
  __pyx_codeobj__48 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__31, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_peek_event, 635, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__48)) __PYX_ERR(0, 635, __pyx_L1_error)

  /* "yaml/_yaml.pyx":640
 *         return self.current_event
 * 
 *     def check_event(self, *choices):             # <<<<<<<<<<<<<<
 *         if self.current_event is None:
 *             self.current_event = self._parse()
 */
  __pyx_tuple__49 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_choices, __pyx_n_s_event_class, __pyx_n_s_choice); if (unlikely(!__pyx_tuple__49)) __PYX_ERR(0, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);
  __pyx_codeobj__50 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS|CO_VARARGS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__49, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_check_event, 640, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__50)) __PYX_ERR(0, 640, __pyx_L1_error)

  /* "yaml/_yaml.pyx":653
 *         return False
 * 
 *     def check_node(self):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         if self.parsed_event.type == YAML_STREAM_START_EVENT:
 */
  __pyx_codeobj__51 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__31, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_check_node, 653, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__51)) __PYX_ERR(0, 653, __pyx_L1_error)

  /* "yaml/_yaml.pyx":662
 *         return False
 * 
 *     def get_node(self):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 */
  __pyx_codeobj__52 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__31, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_get_node, 662, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__52)) __PYX_ERR(0, 662, __pyx_L1_error)

  /* "yaml/_yaml.pyx":667
 *             return self._compose_document()
 * 
 *     def get_single_node(self):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         yaml_event_delete(&self.parsed_event)
 */
  __pyx_tuple__53 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_document, __pyx_n_s_mark); if (unlikely(!__pyx_tuple__53)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);
  __pyx_codeobj__54 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__53, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_get_single_node, 667, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__54)) __PYX_ERR(0, 667, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__55 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__31, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__55)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 */
  __pyx_codeobj__56 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__35, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__56)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "yaml/_yaml.pyx":947
 *         yaml_emitter_delete(&self.emitter)
 * 
 *     def dispose(self):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
  __pyx_codeobj__57 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__31, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_dispose, 947, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__57)) __PYX_ERR(0, 947, __pyx_L1_error)

  /* "yaml/_yaml.pyx":1141
 *         return 1
 * 
 *     def emit(self, event_object):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         self._object_to_event(event_object, &event)
 */
  __pyx_tuple__58 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_event_object, __pyx_n_s_event, __pyx_n_s_error); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(0, 1141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);
  __pyx_codeobj__59 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__58, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_emit, 1141, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__59)) __PYX_ERR(0, 1141, __pyx_L1_error)

  /* "yaml/_yaml.pyx":1148
 *             raise error
 * 
 *     def open(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef yaml_encoding_t encoding
 */
  __pyx_tuple__60 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_event, __pyx_n_s_encoding, __pyx_n_s_error); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(0, 1148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);
  __pyx_codeobj__61 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__60, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_open, 1148, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__61)) __PYX_ERR(0, 1148, __pyx_L1_error)

  /* "yaml/_yaml.pyx":1172
 *             raise SerializerError(u"serializer is already opened")
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         if self.closed == -1:
 */
  __pyx_tuple__62 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_event, __pyx_n_s_error); if (unlikely(!__pyx_tuple__62)) __PYX_ERR(0, 1172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);
  __pyx_codeobj__63 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__62, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_close, 1172, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__63)) __PYX_ERR(0, 1172, __pyx_L1_error)

  /* "yaml/_yaml.pyx":1183
 *             self.closed = 1
 * 
 *     def serialize(self, node):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef yaml_version_directive_t version_directive_value
 */
  __pyx_tuple__64 = PyTuple_Pack(12, __pyx_n_s_self, __pyx_n_s_node, __pyx_n_s_event, __pyx_n_s_version_directive_value, __pyx_n_s_version_directive, __pyx_n_s_tag_directives_value, __pyx_n_s_tag_directives_start, __pyx_n_s_tag_directives_end, __pyx_n_s_cache, __pyx_n_s_handle, __pyx_n_s_prefix, __pyx_n_s_error); if (unlikely(!__pyx_tuple__64)) __PYX_ERR(0, 1183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);
  __pyx_codeobj__65 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 12, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__64, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_yaml__yaml_pyx, __pyx_n_s_serialize, 1183, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__65)) __PYX_ERR(0, 1183, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__66 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__31, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__66)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 */
  __pyx_codeobj__67 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__35, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__67)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __pyx_unpickle_Mark(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__68 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__68)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__68);
  __Pyx_GIVEREF(__pyx_tuple__68);
  __pyx_codeobj__69 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__68, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_Mark, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__69)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitConstants(void) {
  if (__Pyx_CreateStringTabAndInitStrings() < 0) __PYX_ERR(0, 2, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_41581148 = PyInt_FromLong(41581148L); if (unlikely(!__pyx_int_41581148)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_66733494 = PyInt_FromLong(66733494L); if (unlikely(!__pyx_int_66733494)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_96533895 = PyInt_FromLong(96533895L); if (unlikely(!__pyx_int_96533895)) __PYX_ERR(0, 2, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  return 0;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_4yaml_5_yaml_Mark = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_4yaml_5_yaml_Mark_spec, NULL); if (unlikely(!__pyx_ptype_4yaml_5_yaml_Mark)) __PYX_ERR(0, 61, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_4yaml_5_yaml_Mark_spec, __pyx_ptype_4yaml_5_yaml_Mark) < 0) __PYX_ERR(0, 61, __pyx_L1_error)
  #else
  __pyx_ptype_4yaml_5_yaml_Mark = &__pyx_type_4yaml_5_yaml_Mark;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_4yaml_5_yaml_Mark) < 0) __PYX_ERR(0, 61, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_4yaml_5_yaml_Mark->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_4yaml_5_yaml_Mark->tp_dictoffset && __pyx_ptype_4yaml_5_yaml_Mark->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_4yaml_5_yaml_Mark->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Mark, (PyObject *) __pyx_ptype_4yaml_5_yaml_Mark) < 0) __PYX_ERR(0, 61, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_4yaml_5_yaml_Mark) < 0) __PYX_ERR(0, 61, __pyx_L1_error)
  #endif
  __pyx_vtabptr_4yaml_5_yaml_CParser = &__pyx_vtable_4yaml_5_yaml_CParser;
  __pyx_vtable_4yaml_5_yaml_CParser._parser_error = (PyObject *(*)(struct __pyx_obj_4yaml_5_yaml_CParser *))__pyx_f_4yaml_5_yaml_7CParser__parser_error;
  __pyx_vtable_4yaml_5_yaml_CParser._scan = (PyObject *(*)(struct __pyx_obj_4yaml_5_yaml_CParser *))__pyx_f_4yaml_5_yaml_7CParser__scan;
  __pyx_vtable_4yaml_5_yaml_CParser._token_to_object = (PyObject *(*)(struct __pyx_obj_4yaml_5_yaml_CParser *, yaml_token_t *))__pyx_f_4yaml_5_yaml_7CParser__token_to_object;
  __pyx_vtable_4yaml_5_yaml_CParser._parse = (PyObject *(*)(struct __pyx_obj_4yaml_5_yaml_CParser *))__pyx_f_4yaml_5_yaml_7CParser__parse;
  __pyx_vtable_4yaml_5_yaml_CParser._event_to_object = (PyObject *(*)(struct __pyx_obj_4yaml_5_yaml_CParser *, yaml_event_t *))__pyx_f_4yaml_5_yaml_7CParser__event_to_object;
  __pyx_vtable_4yaml_5_yaml_CParser._compose_document = (PyObject *(*)(struct __pyx_obj_4yaml_5_yaml_CParser *))__pyx_f_4yaml_5_yaml_7CParser__compose_document;
  __pyx_vtable_4yaml_5_yaml_CParser._compose_node = (PyObject *(*)(struct __pyx_obj_4yaml_5_yaml_CParser *, PyObject *, PyObject *))__pyx_f_4yaml_5_yaml_7CParser__compose_node;
  __pyx_vtable_4yaml_5_yaml_CParser._compose_scalar_node = (PyObject *(*)(struct __pyx_obj_4yaml_5_yaml_CParser *, PyObject *))__pyx_f_4yaml_5_yaml_7CParser__compose_scalar_node;
  __pyx_vtable_4yaml_5_yaml_CParser._compose_sequence_node = (PyObject *(*)(struct __pyx_obj_4yaml_5_yaml_CParser *, PyObject *))__pyx_f_4yaml_5_yaml_7CParser__compose_sequence_node;
  __pyx_vtable_4yaml_5_yaml_CParser._compose_mapping_node = (PyObject *(*)(struct __pyx_obj_4yaml_5_yaml_CParser *, PyObject *))__pyx_f_4yaml_5_yaml_7CParser__compose_mapping_node;
  __pyx_vtable_4yaml_5_yaml_CParser._parse_next_event = (int (*)(struct __pyx_obj_4yaml_5_yaml_CParser *))__pyx_f_4yaml_5_yaml_7CParser__parse_next_event;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_4yaml_5_yaml_CParser = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_4yaml_5_yaml_CParser_spec, NULL); if (unlikely(!__pyx_ptype_4yaml_5_yaml_CParser)) __PYX_ERR(0, 244, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_4yaml_5_yaml_CParser_spec, __pyx_ptype_4yaml_5_yaml_CParser) < 0) __PYX_ERR(0, 244, __pyx_L1_error)
  #else
  __pyx_ptype_4yaml_5_yaml_CParser = &__pyx_type_4yaml_5_yaml_CParser;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_4yaml_5_yaml_CParser) < 0) __PYX_ERR(0, 244, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_4yaml_5_yaml_CParser->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_4yaml_5_yaml_CParser->tp_dictoffset && __pyx_ptype_4yaml_5_yaml_CParser->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_4yaml_5_yaml_CParser->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_4yaml_5_yaml_CParser, __pyx_vtabptr_4yaml_5_yaml_CParser) < 0) __PYX_ERR(0, 244, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_4yaml_5_yaml_CParser) < 0) __PYX_ERR(0, 244, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_CParser, (PyObject *) __pyx_ptype_4yaml_5_yaml_CParser) < 0) __PYX_ERR(0, 244, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_4yaml_5_yaml_CParser) < 0) __PYX_ERR(0, 244, __pyx_L1_error)
  #endif
  __pyx_vtabptr_4yaml_5_yaml_CEmitter = &__pyx_vtable_4yaml_5_yaml_CEmitter;
  __pyx_vtable_4yaml_5_yaml_CEmitter._emitter_error = (PyObject *(*)(struct __pyx_obj_4yaml_5_yaml_CEmitter *))__pyx_f_4yaml_5_yaml_8CEmitter__emitter_error;
  __pyx_vtable_4yaml_5_yaml_CEmitter._object_to_event = (int (*)(struct __pyx_obj_4yaml_5_yaml_CEmitter *, PyObject *, yaml_event_t *))__pyx_f_4yaml_5_yaml_8CEmitter__object_to_event;
  __pyx_vtable_4yaml_5_yaml_CEmitter._anchor_node = (int (*)(struct __pyx_obj_4yaml_5_yaml_CEmitter *, PyObject *))__pyx_f_4yaml_5_yaml_8CEmitter__anchor_node;
  __pyx_vtable_4yaml_5_yaml_CEmitter._serialize_node = (int (*)(struct __pyx_obj_4yaml_5_yaml_CEmitter *, PyObject *, PyObject *, PyObject *))__pyx_f_4yaml_5_yaml_8CEmitter__serialize_node;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_4yaml_5_yaml_CEmitter = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_4yaml_5_yaml_CEmitter_spec, NULL); if (unlikely(!__pyx_ptype_4yaml_5_yaml_CEmitter)) __PYX_ERR(0, 887, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_4yaml_5_yaml_CEmitter_spec, __pyx_ptype_4yaml_5_yaml_CEmitter) < 0) __PYX_ERR(0, 887, __pyx_L1_error)
  #else
  __pyx_ptype_4yaml_5_yaml_CEmitter = &__pyx_type_4yaml_5_yaml_CEmitter;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_4yaml_5_yaml_CEmitter) < 0) __PYX_ERR(0, 887, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_4yaml_5_yaml_CEmitter->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_4yaml_5_yaml_CEmitter->tp_dictoffset && __pyx_ptype_4yaml_5_yaml_CEmitter->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_4yaml_5_yaml_CEmitter->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_4yaml_5_yaml_CEmitter, __pyx_vtabptr_4yaml_5_yaml_CEmitter) < 0) __PYX_ERR(0, 887, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_4yaml_5_yaml_CEmitter) < 0) __PYX_ERR(0, 887, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_CEmitter, (PyObject *) __pyx_ptype_4yaml_5_yaml_CEmitter) < 0) __PYX_ERR(0, 887, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_4yaml_5_yaml_CEmitter) < 0) __PYX_ERR(0, 887, __pyx_L1_error)
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec__yaml(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec__yaml},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "_yaml",
      0, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC init_yaml(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC init_yaml(void)
#else
__Pyx_PyMODINIT_FUNC PyInit__yaml(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit__yaml(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec__yaml(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module '_yaml' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("_yaml", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 2, __pyx_L1_error)
  #elif CYTHON_USE_MODULE_STATE
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  {
    int add_module_result = PyState_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "_yaml" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 2, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #endif
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 2, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_cython_runtime = __Pyx_PyImport_AddModuleRef((const char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 2, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit__yaml(void)", 0);
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 2, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init(__pyx_m) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init(__pyx_m) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init(__pyx_m) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init(__pyx_m) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init(__pyx_m) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init(__pyx_m) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_yaml___yaml) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 2, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "yaml._yaml")) {
      if (unlikely((PyDict_SetItemString(modules, "yaml._yaml", __pyx_m) < 0))) __PYX_ERR(0, 2, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely((__Pyx_modinit_type_init_code() < 0))) __PYX_ERR(0, 2, __pyx_L1_error)
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif

  /* "yaml/_yaml.pyx":2
 * 
 * import yaml             # <<<<<<<<<<<<<<
 * 
 * def get_version_string():
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_yaml, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_yaml, __pyx_t_2) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":4
 * import yaml
 * 
 * def get_version_string():             # <<<<<<<<<<<<<<
 *     cdef const char *value
 *     value = yaml_get_version_string()
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_1get_version_string, 0, __pyx_n_s_get_version_string, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__28)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_version_string, __pyx_t_2) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":9
 *     return PyUnicode_FromString(value)
 * 
 * def get_version():             # <<<<<<<<<<<<<<
 *     cdef int major, minor, patch
 *     yaml_get_version(&major, &minor, &patch)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_3get_version, 0, __pyx_n_s_get_version, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__30)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_version, __pyx_t_2) < 0) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":15
 * 
 * #Mark = yaml.error.Mark
 * YAMLError = yaml.error.YAMLError             # <<<<<<<<<<<<<<
 * ReaderError = yaml.reader.ReaderError
 * ScannerError = yaml.scanner.ScannerError
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_error); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_YAMLError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_YAMLError, __pyx_t_2) < 0) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":16
 * #Mark = yaml.error.Mark
 * YAMLError = yaml.error.YAMLError
 * ReaderError = yaml.reader.ReaderError             # <<<<<<<<<<<<<<
 * ScannerError = yaml.scanner.ScannerError
 * ParserError = yaml.parser.ParserError
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_reader); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ReaderError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ReaderError, __pyx_t_2) < 0) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":17
 * YAMLError = yaml.error.YAMLError
 * ReaderError = yaml.reader.ReaderError
 * ScannerError = yaml.scanner.ScannerError             # <<<<<<<<<<<<<<
 * ParserError = yaml.parser.ParserError
 * ComposerError = yaml.composer.ComposerError
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_scanner); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ScannerError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ScannerError, __pyx_t_2) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":18
 * ReaderError = yaml.reader.ReaderError
 * ScannerError = yaml.scanner.ScannerError
 * ParserError = yaml.parser.ParserError             # <<<<<<<<<<<<<<
 * ComposerError = yaml.composer.ComposerError
 * ConstructorError = yaml.constructor.ConstructorError
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_parser); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ParserError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ParserError, __pyx_t_2) < 0) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":19
 * ScannerError = yaml.scanner.ScannerError
 * ParserError = yaml.parser.ParserError
 * ComposerError = yaml.composer.ComposerError             # <<<<<<<<<<<<<<
 * ConstructorError = yaml.constructor.ConstructorError
 * EmitterError = yaml.emitter.EmitterError
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_composer); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ComposerError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ComposerError, __pyx_t_2) < 0) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":20
 * ParserError = yaml.parser.ParserError
 * ComposerError = yaml.composer.ComposerError
 * ConstructorError = yaml.constructor.ConstructorError             # <<<<<<<<<<<<<<
 * EmitterError = yaml.emitter.EmitterError
 * SerializerError = yaml.serializer.SerializerError
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_constructor); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ConstructorError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ConstructorError, __pyx_t_2) < 0) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":21
 * ComposerError = yaml.composer.ComposerError
 * ConstructorError = yaml.constructor.ConstructorError
 * EmitterError = yaml.emitter.EmitterError             # <<<<<<<<<<<<<<
 * SerializerError = yaml.serializer.SerializerError
 * RepresenterError = yaml.representer.RepresenterError
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_emitter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_EmitterError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_EmitterError, __pyx_t_2) < 0) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":22
 * ConstructorError = yaml.constructor.ConstructorError
 * EmitterError = yaml.emitter.EmitterError
 * SerializerError = yaml.serializer.SerializerError             # <<<<<<<<<<<<<<
 * RepresenterError = yaml.representer.RepresenterError
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_serializer); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SerializerError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SerializerError, __pyx_t_2) < 0) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":23
 * EmitterError = yaml.emitter.EmitterError
 * SerializerError = yaml.serializer.SerializerError
 * RepresenterError = yaml.representer.RepresenterError             # <<<<<<<<<<<<<<
 * 
 * StreamStartToken = yaml.tokens.StreamStartToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_representer); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_RepresenterError); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_RepresenterError, __pyx_t_2) < 0) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":25
 * RepresenterError = yaml.representer.RepresenterError
 * 
 * StreamStartToken = yaml.tokens.StreamStartToken             # <<<<<<<<<<<<<<
 * StreamEndToken = yaml.tokens.StreamEndToken
 * DirectiveToken = yaml.tokens.DirectiveToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_StreamStartToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_StreamStartToken, __pyx_t_2) < 0) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":26
 * 
 * StreamStartToken = yaml.tokens.StreamStartToken
 * StreamEndToken = yaml.tokens.StreamEndToken             # <<<<<<<<<<<<<<
 * DirectiveToken = yaml.tokens.DirectiveToken
 * DocumentStartToken = yaml.tokens.DocumentStartToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_StreamEndToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_StreamEndToken, __pyx_t_2) < 0) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":27
 * StreamStartToken = yaml.tokens.StreamStartToken
 * StreamEndToken = yaml.tokens.StreamEndToken
 * DirectiveToken = yaml.tokens.DirectiveToken             # <<<<<<<<<<<<<<
 * DocumentStartToken = yaml.tokens.DocumentStartToken
 * DocumentEndToken = yaml.tokens.DocumentEndToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DirectiveToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DirectiveToken, __pyx_t_2) < 0) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":28
 * StreamEndToken = yaml.tokens.StreamEndToken
 * DirectiveToken = yaml.tokens.DirectiveToken
 * DocumentStartToken = yaml.tokens.DocumentStartToken             # <<<<<<<<<<<<<<
 * DocumentEndToken = yaml.tokens.DocumentEndToken
 * BlockSequenceStartToken = yaml.tokens.BlockSequenceStartToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DocumentStartToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DocumentStartToken, __pyx_t_2) < 0) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":29
 * DirectiveToken = yaml.tokens.DirectiveToken
 * DocumentStartToken = yaml.tokens.DocumentStartToken
 * DocumentEndToken = yaml.tokens.DocumentEndToken             # <<<<<<<<<<<<<<
 * BlockSequenceStartToken = yaml.tokens.BlockSequenceStartToken
 * BlockMappingStartToken = yaml.tokens.BlockMappingStartToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DocumentEndToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DocumentEndToken, __pyx_t_2) < 0) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":30
 * DocumentStartToken = yaml.tokens.DocumentStartToken
 * DocumentEndToken = yaml.tokens.DocumentEndToken
 * BlockSequenceStartToken = yaml.tokens.BlockSequenceStartToken             # <<<<<<<<<<<<<<
 * BlockMappingStartToken = yaml.tokens.BlockMappingStartToken
 * BlockEndToken = yaml.tokens.BlockEndToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_BlockSequenceStartToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BlockSequenceStartToken, __pyx_t_2) < 0) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":31
 * DocumentEndToken = yaml.tokens.DocumentEndToken
 * BlockSequenceStartToken = yaml.tokens.BlockSequenceStartToken
 * BlockMappingStartToken = yaml.tokens.BlockMappingStartToken             # <<<<<<<<<<<<<<
 * BlockEndToken = yaml.tokens.BlockEndToken
 * FlowSequenceStartToken = yaml.tokens.FlowSequenceStartToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_BlockMappingStartToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BlockMappingStartToken, __pyx_t_2) < 0) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":32
 * BlockSequenceStartToken = yaml.tokens.BlockSequenceStartToken
 * BlockMappingStartToken = yaml.tokens.BlockMappingStartToken
 * BlockEndToken = yaml.tokens.BlockEndToken             # <<<<<<<<<<<<<<
 * FlowSequenceStartToken = yaml.tokens.FlowSequenceStartToken
 * FlowMappingStartToken = yaml.tokens.FlowMappingStartToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_BlockEndToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BlockEndToken, __pyx_t_2) < 0) __PYX_ERR(0, 32, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":33
 * BlockMappingStartToken = yaml.tokens.BlockMappingStartToken
 * BlockEndToken = yaml.tokens.BlockEndToken
 * FlowSequenceStartToken = yaml.tokens.FlowSequenceStartToken             # <<<<<<<<<<<<<<
 * FlowMappingStartToken = yaml.tokens.FlowMappingStartToken
 * FlowSequenceEndToken = yaml.tokens.FlowSequenceEndToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_FlowSequenceStartToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FlowSequenceStartToken, __pyx_t_2) < 0) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":34
 * BlockEndToken = yaml.tokens.BlockEndToken
 * FlowSequenceStartToken = yaml.tokens.FlowSequenceStartToken
 * FlowMappingStartToken = yaml.tokens.FlowMappingStartToken             # <<<<<<<<<<<<<<
 * FlowSequenceEndToken = yaml.tokens.FlowSequenceEndToken
 * FlowMappingEndToken = yaml.tokens.FlowMappingEndToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_FlowMappingStartToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FlowMappingStartToken, __pyx_t_2) < 0) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":35
 * FlowSequenceStartToken = yaml.tokens.FlowSequenceStartToken
 * FlowMappingStartToken = yaml.tokens.FlowMappingStartToken
 * FlowSequenceEndToken = yaml.tokens.FlowSequenceEndToken             # <<<<<<<<<<<<<<
 * FlowMappingEndToken = yaml.tokens.FlowMappingEndToken
 * KeyToken = yaml.tokens.KeyToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_FlowSequenceEndToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FlowSequenceEndToken, __pyx_t_2) < 0) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":36
 * FlowMappingStartToken = yaml.tokens.FlowMappingStartToken
 * FlowSequenceEndToken = yaml.tokens.FlowSequenceEndToken
 * FlowMappingEndToken = yaml.tokens.FlowMappingEndToken             # <<<<<<<<<<<<<<
 * KeyToken = yaml.tokens.KeyToken
 * ValueToken = yaml.tokens.ValueToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_FlowMappingEndToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FlowMappingEndToken, __pyx_t_2) < 0) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":37
 * FlowSequenceEndToken = yaml.tokens.FlowSequenceEndToken
 * FlowMappingEndToken = yaml.tokens.FlowMappingEndToken
 * KeyToken = yaml.tokens.KeyToken             # <<<<<<<<<<<<<<
 * ValueToken = yaml.tokens.ValueToken
 * BlockEntryToken = yaml.tokens.BlockEntryToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_KeyToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_KeyToken, __pyx_t_2) < 0) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":38
 * FlowMappingEndToken = yaml.tokens.FlowMappingEndToken
 * KeyToken = yaml.tokens.KeyToken
 * ValueToken = yaml.tokens.ValueToken             # <<<<<<<<<<<<<<
 * BlockEntryToken = yaml.tokens.BlockEntryToken
 * FlowEntryToken = yaml.tokens.FlowEntryToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ValueToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ValueToken, __pyx_t_2) < 0) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":39
 * KeyToken = yaml.tokens.KeyToken
 * ValueToken = yaml.tokens.ValueToken
 * BlockEntryToken = yaml.tokens.BlockEntryToken             # <<<<<<<<<<<<<<
 * FlowEntryToken = yaml.tokens.FlowEntryToken
 * AliasToken = yaml.tokens.AliasToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_BlockEntryToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_BlockEntryToken, __pyx_t_2) < 0) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":40
 * ValueToken = yaml.tokens.ValueToken
 * BlockEntryToken = yaml.tokens.BlockEntryToken
 * FlowEntryToken = yaml.tokens.FlowEntryToken             # <<<<<<<<<<<<<<
 * AliasToken = yaml.tokens.AliasToken
 * AnchorToken = yaml.tokens.AnchorToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_FlowEntryToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FlowEntryToken, __pyx_t_2) < 0) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":41
 * BlockEntryToken = yaml.tokens.BlockEntryToken
 * FlowEntryToken = yaml.tokens.FlowEntryToken
 * AliasToken = yaml.tokens.AliasToken             # <<<<<<<<<<<<<<
 * AnchorToken = yaml.tokens.AnchorToken
 * TagToken = yaml.tokens.TagToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_AliasToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_AliasToken, __pyx_t_2) < 0) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":42
 * FlowEntryToken = yaml.tokens.FlowEntryToken
 * AliasToken = yaml.tokens.AliasToken
 * AnchorToken = yaml.tokens.AnchorToken             # <<<<<<<<<<<<<<
 * TagToken = yaml.tokens.TagToken
 * ScalarToken = yaml.tokens.ScalarToken
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_AnchorToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_AnchorToken, __pyx_t_2) < 0) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":43
 * AliasToken = yaml.tokens.AliasToken
 * AnchorToken = yaml.tokens.AnchorToken
 * TagToken = yaml.tokens.TagToken             # <<<<<<<<<<<<<<
 * ScalarToken = yaml.tokens.ScalarToken
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_TagToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_TagToken, __pyx_t_2) < 0) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":44
 * AnchorToken = yaml.tokens.AnchorToken
 * TagToken = yaml.tokens.TagToken
 * ScalarToken = yaml.tokens.ScalarToken             # <<<<<<<<<<<<<<
 * 
 * StreamStartEvent = yaml.events.StreamStartEvent
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tokens); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ScalarToken); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ScalarToken, __pyx_t_2) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":46
 * ScalarToken = yaml.tokens.ScalarToken
 * 
 * StreamStartEvent = yaml.events.StreamStartEvent             # <<<<<<<<<<<<<<
 * StreamEndEvent = yaml.events.StreamEndEvent
 * DocumentStartEvent = yaml.events.DocumentStartEvent
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_StreamStartEvent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_StreamStartEvent, __pyx_t_2) < 0) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":47
 * 
 * StreamStartEvent = yaml.events.StreamStartEvent
 * StreamEndEvent = yaml.events.StreamEndEvent             # <<<<<<<<<<<<<<
 * DocumentStartEvent = yaml.events.DocumentStartEvent
 * DocumentEndEvent = yaml.events.DocumentEndEvent
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_StreamEndEvent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_StreamEndEvent, __pyx_t_2) < 0) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":48
 * StreamStartEvent = yaml.events.StreamStartEvent
 * StreamEndEvent = yaml.events.StreamEndEvent
 * DocumentStartEvent = yaml.events.DocumentStartEvent             # <<<<<<<<<<<<<<
 * DocumentEndEvent = yaml.events.DocumentEndEvent
 * AliasEvent = yaml.events.AliasEvent
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DocumentStartEvent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DocumentStartEvent, __pyx_t_2) < 0) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":49
 * StreamEndEvent = yaml.events.StreamEndEvent
 * DocumentStartEvent = yaml.events.DocumentStartEvent
 * DocumentEndEvent = yaml.events.DocumentEndEvent             # <<<<<<<<<<<<<<
 * AliasEvent = yaml.events.AliasEvent
 * ScalarEvent = yaml.events.ScalarEvent
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DocumentEndEvent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DocumentEndEvent, __pyx_t_2) < 0) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":50
 * DocumentStartEvent = yaml.events.DocumentStartEvent
 * DocumentEndEvent = yaml.events.DocumentEndEvent
 * AliasEvent = yaml.events.AliasEvent             # <<<<<<<<<<<<<<
 * ScalarEvent = yaml.events.ScalarEvent
 * SequenceStartEvent = yaml.events.SequenceStartEvent
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_AliasEvent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_AliasEvent, __pyx_t_2) < 0) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":51
 * DocumentEndEvent = yaml.events.DocumentEndEvent
 * AliasEvent = yaml.events.AliasEvent
 * ScalarEvent = yaml.events.ScalarEvent             # <<<<<<<<<<<<<<
 * SequenceStartEvent = yaml.events.SequenceStartEvent
 * SequenceEndEvent = yaml.events.SequenceEndEvent
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ScalarEvent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ScalarEvent, __pyx_t_2) < 0) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":52
 * AliasEvent = yaml.events.AliasEvent
 * ScalarEvent = yaml.events.ScalarEvent
 * SequenceStartEvent = yaml.events.SequenceStartEvent             # <<<<<<<<<<<<<<
 * SequenceEndEvent = yaml.events.SequenceEndEvent
 * MappingStartEvent = yaml.events.MappingStartEvent
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SequenceStartEvent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SequenceStartEvent, __pyx_t_2) < 0) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":53
 * ScalarEvent = yaml.events.ScalarEvent
 * SequenceStartEvent = yaml.events.SequenceStartEvent
 * SequenceEndEvent = yaml.events.SequenceEndEvent             # <<<<<<<<<<<<<<
 * MappingStartEvent = yaml.events.MappingStartEvent
 * MappingEndEvent = yaml.events.MappingEndEvent
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SequenceEndEvent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SequenceEndEvent, __pyx_t_2) < 0) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":54
 * SequenceStartEvent = yaml.events.SequenceStartEvent
 * SequenceEndEvent = yaml.events.SequenceEndEvent
 * MappingStartEvent = yaml.events.MappingStartEvent             # <<<<<<<<<<<<<<
 * MappingEndEvent = yaml.events.MappingEndEvent
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_MappingStartEvent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MappingStartEvent, __pyx_t_2) < 0) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":55
 * SequenceEndEvent = yaml.events.SequenceEndEvent
 * MappingStartEvent = yaml.events.MappingStartEvent
 * MappingEndEvent = yaml.events.MappingEndEvent             # <<<<<<<<<<<<<<
 * 
 * ScalarNode = yaml.nodes.ScalarNode
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_MappingEndEvent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MappingEndEvent, __pyx_t_2) < 0) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":57
 * MappingEndEvent = yaml.events.MappingEndEvent
 * 
 * ScalarNode = yaml.nodes.ScalarNode             # <<<<<<<<<<<<<<
 * SequenceNode = yaml.nodes.SequenceNode
 * MappingNode = yaml.nodes.MappingNode
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_nodes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ScalarNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ScalarNode, __pyx_t_2) < 0) __PYX_ERR(0, 57, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":58
 * 
 * ScalarNode = yaml.nodes.ScalarNode
 * SequenceNode = yaml.nodes.SequenceNode             # <<<<<<<<<<<<<<
 * MappingNode = yaml.nodes.MappingNode
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_nodes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_SequenceNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SequenceNode, __pyx_t_2) < 0) __PYX_ERR(0, 58, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":59
 * ScalarNode = yaml.nodes.ScalarNode
 * SequenceNode = yaml.nodes.SequenceNode
 * MappingNode = yaml.nodes.MappingNode             # <<<<<<<<<<<<<<
 * 
 * cdef class Mark:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_yaml); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_nodes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_MappingNode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_MappingNode, __pyx_t_2) < 0) __PYX_ERR(0, 59, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":78
 *         self.pointer = pointer
 * 
 *     def get_snippet(self):             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_4Mark_3get_snippet, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Mark_get_snippet, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__32)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark, __pyx_n_s_get_snippet, __pyx_t_2) < 0) __PYX_ERR(0, 78, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_Mark);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_4Mark_7__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Mark___reduce_cython, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__34)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark, __pyx_n_s_reduce_cython, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_Mark);

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Mark, (type(self), 0x27a7a5c, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Mark__set_state(self, __pyx_state)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_4Mark_9__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Mark___setstate_cython, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__36)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_Mark, __pyx_n_s_setstate_cython, __pyx_t_2) < 0) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_Mark);

  /* "yaml/_yaml.pyx":299
 *         yaml_event_delete(&self.parsed_event)
 * 
 *     def dispose(self):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_5dispose, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser_dispose, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__37)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CParser, __pyx_n_s_dispose, __pyx_t_2) < 0) __PYX_ERR(0, 299, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CParser);

  /* "yaml/_yaml.pyx":332
 *         raise ValueError(u"no parser error")
 * 
 *     def raw_scan(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_token_t token
 *         cdef int done
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_7raw_scan, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser_raw_scan, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__39)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CParser, __pyx_n_s_raw_scan, __pyx_t_2) < 0) __PYX_ERR(0, 332, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CParser);

  /* "yaml/_yaml.pyx":452
 *             raise ValueError(u"unknown token type")
 * 
 *     def get_token(self):             # <<<<<<<<<<<<<<
 *         if self.current_token is not None:
 *             value = self.current_token
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_9get_token, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser_get_token, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__41)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CParser, __pyx_n_s_get_token, __pyx_t_2) < 0) __PYX_ERR(0, 452, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CParser);

  /* "yaml/_yaml.pyx":460
 *         return value
 * 
 *     def peek_token(self):             # <<<<<<<<<<<<<<
 *         if self.current_token is None:
 *             self.current_token = self._scan()
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_11peek_token, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser_peek_token, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__42)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CParser, __pyx_n_s_peek_token, __pyx_t_2) < 0) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CParser);

  /* "yaml/_yaml.pyx":465
 *         return self.current_token
 * 
 *     def check_token(self, *choices):             # <<<<<<<<<<<<<<
 *         if self.current_token is None:
 *             self.current_token = self._scan()
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_13check_token, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser_check_token, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__44)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CParser, __pyx_n_s_check_token, __pyx_t_2) < 0) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CParser);

  /* "yaml/_yaml.pyx":478
 *         return False
 * 
 *     def raw_parse(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef int done
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_15raw_parse, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser_raw_parse, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__46)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CParser, __pyx_n_s_raw_parse, __pyx_t_2) < 0) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CParser);

  /* "yaml/_yaml.pyx":627
 *             raise ValueError(u"unknown event type")
 * 
 *     def get_event(self):             # <<<<<<<<<<<<<<
 *         if self.current_event is not None:
 *             value = self.current_event
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_17get_event, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser_get_event, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__47)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CParser, __pyx_n_s_get_event, __pyx_t_2) < 0) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CParser);

  /* "yaml/_yaml.pyx":635
 *         return value
 * 
 *     def peek_event(self):             # <<<<<<<<<<<<<<
 *         if self.current_event is None:
 *             self.current_event = self._parse()
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_19peek_event, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser_peek_event, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__48)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CParser, __pyx_n_s_peek_event, __pyx_t_2) < 0) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CParser);

  /* "yaml/_yaml.pyx":640
 *         return self.current_event
 * 
 *     def check_event(self, *choices):             # <<<<<<<<<<<<<<
 *         if self.current_event is None:
 *             self.current_event = self._parse()
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_21check_event, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser_check_event, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__50)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CParser, __pyx_n_s_check_event, __pyx_t_2) < 0) __PYX_ERR(0, 640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CParser);

  /* "yaml/_yaml.pyx":653
 *         return False
 * 
 *     def check_node(self):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         if self.parsed_event.type == YAML_STREAM_START_EVENT:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_23check_node, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser_check_node, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__51)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CParser, __pyx_n_s_check_node, __pyx_t_2) < 0) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CParser);

  /* "yaml/_yaml.pyx":662
 *         return False
 * 
 *     def get_node(self):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         if self.parsed_event.type != YAML_STREAM_END_EVENT:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_25get_node, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser_get_node, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__52)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CParser, __pyx_n_s_get_node, __pyx_t_2) < 0) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CParser);

  /* "yaml/_yaml.pyx":667
 *             return self._compose_document()
 * 
 *     def get_single_node(self):             # <<<<<<<<<<<<<<
 *         self._parse_next_event()
 *         yaml_event_delete(&self.parsed_event)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_27get_single_node, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser_get_single_node, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__54)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CParser, __pyx_n_s_get_single_node, __pyx_t_2) < 0) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CParser);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_29__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser___reduce_cython, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__55)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.parsed_event cannot be converted to a Python object for pickling"
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_7CParser_31__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CParser___setstate_cython, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__56)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_2) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":947
 *         yaml_emitter_delete(&self.emitter)
 * 
 *     def dispose(self):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_8CEmitter_5dispose, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CEmitter_dispose, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__57)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 947, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CEmitter, __pyx_n_s_dispose, __pyx_t_2) < 0) __PYX_ERR(0, 947, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CEmitter);

  /* "yaml/_yaml.pyx":1141
 *         return 1
 * 
 *     def emit(self, event_object):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         self._object_to_event(event_object, &event)
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_8CEmitter_7emit, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CEmitter_emit, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__59)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CEmitter, __pyx_n_s_emit, __pyx_t_2) < 0) __PYX_ERR(0, 1141, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CEmitter);

  /* "yaml/_yaml.pyx":1148
 *             raise error
 * 
 *     def open(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef yaml_encoding_t encoding
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_8CEmitter_9open, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CEmitter_open, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__61)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CEmitter, __pyx_n_s_open, __pyx_t_2) < 0) __PYX_ERR(0, 1148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CEmitter);

  /* "yaml/_yaml.pyx":1172
 *             raise SerializerError(u"serializer is already opened")
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         if self.closed == -1:
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_8CEmitter_11close, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CEmitter_close, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__63)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CEmitter, __pyx_n_s_close, __pyx_t_2) < 0) __PYX_ERR(0, 1172, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CEmitter);

  /* "yaml/_yaml.pyx":1183
 *             self.closed = 1
 * 
 *     def serialize(self, node):             # <<<<<<<<<<<<<<
 *         cdef yaml_event_t event
 *         cdef yaml_version_directive_t version_directive_value
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_8CEmitter_13serialize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CEmitter_serialize, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__65)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_4yaml_5_yaml_CEmitter, __pyx_n_s_serialize, __pyx_t_2) < 0) __PYX_ERR(0, 1183, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  PyType_Modified(__pyx_ptype_4yaml_5_yaml_CEmitter);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_8CEmitter_15__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CEmitter___reduce_cython, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__66)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "Pickling of struct members such as self.emitter must be explicitly requested with @auto_pickle(True)"
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_8CEmitter_17__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_CEmitter___setstate_cython, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__67)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_2) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_Mark(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_4yaml_5_yaml_5__pyx_unpickle_Mark, 0, __pyx_n_s_pyx_unpickle_Mark, NULL, __pyx_n_s_yaml__yaml, __pyx_d, ((PyObject *)__pyx_codeobj__69)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_Mark, __pyx_t_2) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "yaml/_yaml.pyx":2
 * 
 * import yaml             # <<<<<<<<<<<<<<
 * 
 * def get_version_string():
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_2) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  if (__pyx_m) {
    if (__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init yaml._yaml", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init yaml._yaml");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs = PyTuple_GET_SIZE(kwnames);
    PyObject *dict;
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        Py_XDECREF(key); key = NULL;
        Py_XDECREF(value); value = NULL;
        if (kwds_is_tuple) {
            Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(kwds);
#else
            size = PyTuple_Size(kwds);
            if (size < 0) goto bad;
#endif
            if (pos >= size) break;
#if CYTHON_AVOID_BORROWED_REFS
            key = __Pyx_PySequence_ITEM(kwds, pos);
            if (!key) goto bad;
#elif CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kwds, pos);
#else
            key = PyTuple_GetItem(kwds, pos);
            if (!key) goto bad;
#endif
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(key);
#endif
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(value);
            Py_DECREF(key);
#endif
            key = NULL;
            value = NULL;
            continue;
        }
#if !CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(key);
#endif
        Py_INCREF(value);
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    Py_XDECREF(key);
    Py_XDECREF(value);
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    Py_XDECREF(key);
    Py_XDECREF(value);
    return -1;
}

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kw,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kw, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kw))) {
        Py_ssize_t kwsize;
#if CYTHON_ASSUME_SAFE_MACROS
        kwsize = PyTuple_GET_SIZE(kw);
#else
        kwsize = PyTuple_Size(kw);
        if (kwsize < 0) return 0;
#endif
        if (unlikely(kwsize == 0))
            return 1;
        if (!kw_allowed) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, 0);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            goto invalid_keyword;
        }
#if PY_VERSION_HEX < 0x03090000
        for (pos = 0; pos < kwsize; pos++) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, pos);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
        }
#endif
        return 1;
    }
    while (PyDict_Next(kw, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if (!kw_allowed && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyString_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C00A6
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE && PY_VERSION_HEX >= 0x030C00A6
    if (unlikely(tstate->current_exception))
#elif CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    __Pyx_PyThreadState_declare
    CYTHON_UNUSED_VAR(cause);
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
      #if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
      #elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object"))) {
        return NULL;
    }
    #endif
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) < 0) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
        #if PY_VERSION_HEX < 0x03090000
        vectorcallfunc f = _PyVectorcall_Function(func);
        #else
        vectorcallfunc f = PyVectorcall_Function(func);
        #endif
        if (f) {
            return f(func, args, (size_t)nargs, NULL);
        }
        #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
        if (__Pyx_CyFunction_CheckExact(func)) {
            __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
            if (f) return f(func, args, (size_t)nargs, NULL);
        }
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_n_s_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* RaiseUnboundLocalError */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* HasAttr */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (!r) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.') != NULL) {
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_kp_u__25);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* FixUpExtensionType */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if PY_VERSION_HEX > 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
#else
    const PyType_Slot *slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
        int changed = 0;
#if !(PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON)
        const
#endif
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
#if PY_VERSION_HEX < 0x030900b1
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
#if PY_VERSION_HEX >= 0x030800b4
                    type->tp_vectorcall_offset = memb->offset;
#else
                    type->tp_print = (printfunc) memb->offset;
#endif
                    changed = 1;
                }
#endif
#else
                if ((0));
#endif
#if PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    if (unlikely(PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr) < 0)) {
                        Py_DECREF(descr);
                        return -1;
                    }
                    Py_DECREF(descr);
                    changed = 1;
                }
#endif
            }
            memb++;
        }
        if (changed)
            PyType_Modified(type);
    }
#endif
    return 0;
}
#endif

/* PyObjectCallNoArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#elif PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* ValidateBasesTuple */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_MACROS
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (n < 0) return -1;
#endif
    for (i = 1; i < n; i++)
    {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        PyTypeObject *b;
#if PY_MAJOR_VERSION < 3
        if (PyClass_Check(b0))
        {
            PyErr_Format(PyExc_TypeError, "base class '%.200s' is an old-style class",
                         PyString_AS_STRING(((PyClassObject*)b0)->cl_name));
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !(CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY)
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !(CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API) || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if PY_VERSION_HEX >= 0x030700a1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400)
        gc = PyImport_GetModule(__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    __Pyx_TypeName type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, attr_name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(attr_name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetupReduce */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_n_s_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_n_s_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_n_s_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_n_s_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_n_s_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i;
    void** base_vtables;
    __Pyx_TypeName tp_base_name;
    __Pyx_TypeName base_name;
    void* unknown = (void*)-1;
    PyObject* bases = type->tp_bases;
    int base_depth = 0;
    {
        PyTypeObject* base = type->tp_base;
        while (base) {
            base_depth += 1;
            base = base->tp_base;
        }
    }
    base_vtables = (void**) malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
    for (i = 1; i < PyTuple_GET_SIZE(bases); i++) {
        void* base_vtable = __Pyx_GetVtable(((PyTypeObject*)PyTuple_GET_ITEM(bases, i)));
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = type->tp_base;
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = base->tp_base;
            }
        }
    }
    PyErr_Clear();
    free(base_vtables);
    return 0;
bad:
    tp_base_name = __Pyx_PyType_GetName(type->tp_base);
    base_name = __Pyx_PyType_GetName((PyTypeObject*)PyTuple_GET_ITEM(bases, i));
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
    free(base_vtables);
    return -1;
}
#endif

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple) {
    Py_ssize_t i, nparts;
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (unlikely(!module)) {
        return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
    }
    return module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__26;
    CYTHON_UNUSED_VAR(parts_tuple);
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    return __Pyx_ImportDottedModule_WalkParts(module, name, parts_tuple);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* FetchSharedCythonModule */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef((char*) __PYX_ABI_MODULE_NAME);
}

/* FetchCommonType */
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    const char* object_name;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    object_name = strrchr(type->tp_name, '.');
    object_name = object_name ? object_name+1 : type->tp_name;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              object_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#else
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *cached_type = NULL;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
        PyObject *py_basicsize;
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (unlikely(!py_basicsize)) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
#else
        basicsize = likely(PyType_Check(cached_type)) ? ((PyTypeObject*) cached_type)->tp_basicsize : -1;
#endif
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    CYTHON_UNUSED_VAR(module);
    cached_type = __Pyx_PyType_FromModuleAndSpec(abi_module, spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
#if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure)
{
    CYTHON_UNUSED_VAR(closure);
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#elif PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_tuple;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_kwdict;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->func_annotations;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    int is_coroutine;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
#if PY_VERSION_HEX >= 0x03050000
    if (is_coroutine) {
        PyObject *module, *fromlist, *marker = __pyx_n_s_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_n_s_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        op->func_is_coroutine = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(op->func_is_coroutine)) {
            return __Pyx_NewRef(op->func_is_coroutine);
        }
ignore:
        PyErr_Clear();
    }
#endif
    op->func_is_coroutine = __Pyx_PyBool_FromLong(is_coroutine);
    return __Pyx_NewRef(op->func_is_coroutine);
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {(char *) "_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if CYTHON_METH_FASTCALL
#if CYTHON_BACKPORT_VECTORCALL
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#endif
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    CYTHON_UNUSED_VAR(args);
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(((PyCFunctionObject*)m)->m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyObject *py_name = NULL;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
    if (!py_name) return NULL;
    PyErr_Format(PyExc_TypeError, "%.200S() takes no keyword arguments",
                 py_name);
    Py_DECREF(py_name);
#else
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
#endif
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_MACROS
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(!argc) < 0) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCMethod)(void(*)(void))def->ml_meth)(self, cls, args, (size_t)nargs, kwnames);
}
#endif
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if (defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(PyCFunctionObject, vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_CyFunctionType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result;
        result = PyObject_Call(replace, __pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    #if __PYX_LIMITED_VERSION_HEX < 0x030780000
    {
        PyObject *compiled = NULL, *result = NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "code", code))) return NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "type", (PyObject*)(&PyType_Type)))) return NULL;
        compiled = Py_CompileString(
            "out = type(code)(\n"
            "  code.co_argcount, code.co_kwonlyargcount, code.co_nlocals, code.co_stacksize,\n"
            "  code.co_flags, code.co_code, code.co_consts, code.co_names,\n"
            "  code.co_varnames, code.co_filename, co_name, co_firstlineno,\n"
            "  code.co_lnotab)\n", "<dummy>", Py_file_input);
        if (!compiled) return NULL;
        result = PyEval_EvalCode(compiled, scratch_dict, scratch_dict);
        Py_DECREF(compiled);
        if (!result) PyErr_Print();
        Py_DECREF(result);
        result = PyDict_GetItemString(scratch_dict, "out");
        if (result) Py_INCREF(result);
        return result;
    }
    #else
    return NULL;
    #endif
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        (void) __pyx_cfilenm;
        (void) __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
    if (unlikely(!code_object)) goto bad;
    py_py_line = PyLong_FromLong(py_line);
    if (unlikely(!py_py_line)) goto bad;
    py_funcname = PyUnicode_FromString(funcname);
    if (unlikely(!py_funcname)) goto bad;
    dict = PyDict_New();
    if (unlikely(!dict)) goto bad;
    {
        PyObject *old_code_object = code_object;
        code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
        Py_DECREF(old_code_object);
    }
    if (unlikely(!code_object)) goto bad;
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const size_t neg_one = (size_t) -1, const_zero = (size_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(size_t) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(size_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (size_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(size_t, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(size_t) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) >= 2 * PyLong_SHIFT)) {
                                return (size_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(size_t) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) >= 3 * PyLong_SHIFT)) {
                                return (size_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(size_t) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) >= 4 * PyLong_SHIFT)) {
                                return (size_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (size_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(size_t) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(size_t) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(size_t, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(size_t) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                                return (size_t) (((size_t)-1)*(((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(size_t) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                                return (size_t) ((((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                                return (size_t) (((size_t)-1)*(((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(size_t) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                                return (size_t) ((((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT)) {
                                return (size_t) (((size_t)-1)*(((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(size_t) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT)) {
                                return (size_t) ((((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(size_t) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(size_t) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            size_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (size_t) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (size_t) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (size_t) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (size_t) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (size_t) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(size_t) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((size_t) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(size_t) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((size_t) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((size_t) 1) << (sizeof(size_t) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (size_t) -1;
        }
    } else {
        size_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (size_t) -1;
        val = __Pyx_PyInt_As_size_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to size_t");
    return (size_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to size_t");
    return (size_t) -1;
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(long) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                                return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                                return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                                return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(long) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(long) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (long) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (long) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (long) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (long) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (long) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((long) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((long) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(int));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(int) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                                return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                                return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                                return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(int) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(int) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (int) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (int) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (int) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (int) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (int) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((int) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((int) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name_2);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XDECREF(name);
        name = __Pyx_NewRef(__pyx_n_s__2);
    }
    return name;
}
#endif

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030B00A4
    return Py_Version & ~0xFFUL;
#else
    const char* rt_version = Py_GetVersion();
    unsigned long version = 0;
    unsigned long factor = 0x01000000UL;
    unsigned int digit = 0;
    int i = 0;
    while (factor) {
        while ('0' <= rt_version[i] && rt_version[i] <= '9') {
            digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
            ++i;
        }
        version += factor * digit;
        if (rt_version[i] != '.')
            break;
        digit = 0;
        factor >>= 8;
        ++i;
    }
    return version;
#endif
}
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* InitStrings */
#if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
